import {
  AKChart
} from "./chunk-RQ6FKJAX.js";
import {
  EventGeo,
  EventUser
} from "./chunk-YNQN4LE7.js";
import {
  actionToLabel
} from "./chunk-BEFPUR3G.js";
import "./chunk-FNV26V2B.js";
import "./chunk-DJQHOO67.js";
import {
  TablePage
} from "./chunk-R63EXIDN.js";
import "./chunk-2G3GM457.js";
import "./chunk-OATKFZXF.js";
import "./chunk-KNLDGZQ5.js";
import "./chunk-6KRH5U5H.js";
import "./chunk-WPHOZTKQ.js";
import {
  card_default
} from "./chunk-ITYWTYEW.js";
import {
  TableColumn,
  uiConfig
} from "./chunk-OOB7B3ZK.js";
import "./chunk-K3AR7TXW.js";
import "./chunk-5MMRTU65.js";
import "./chunk-QN67UQKM.js";
import {
  DEFAULT_CONFIG,
  EventsApi,
  getRelativeTime,
  n,
  t
} from "./chunk-EOF5OWT7.js";
import {
  i,
  msg,
  x
} from "./chunk-MDYFRBOX.js";
import {
  __decorateClass
} from "./chunk-6IFWU6BM.js";

// src/admin/events/EventVolumeChart.ts
var EventVolumeChart = class extends AKChart {
  set query(value) {
    this._query = value;
    this.refreshHandler();
  }
  static get styles() {
    return super.styles.concat(
      card_default,
      i`
                .pf-c-card__body {
                    height: 12rem;
                }
            `
    );
  }
  apiRequest() {
    return new EventsApi(DEFAULT_CONFIG).eventsEventsVolumeList(this._query);
  }
  getChartData(data) {
    return {
      datasets: [
        {
          label: msg("Events"),
          backgroundColor: "rgba(189, 229, 184, .5)",
          spanGaps: true,
          data: data.map((cord) => {
            return {
              x: cord.xCord || 0,
              y: cord.yCord || 0
            };
          }) || []
        }
      ]
    };
  }
  render() {
    return x`<div class="pf-c-card">
            <div class="pf-c-card__title">${msg("Event volume")}</div>
            <div class="pf-c-card__body">${super.render()}</div>
        </div>`;
  }
};
__decorateClass([
  n({ attribute: false })
], EventVolumeChart.prototype, "query", 1);
EventVolumeChart = __decorateClass([
  t("ak-events-volume-chart")
], EventVolumeChart);

// src/admin/events/EventListPage.ts
var EventListPage = class extends TablePage {
  constructor() {
    super(...arguments);
    this.expandable = true;
    this.order = "-created";
  }
  pageTitle() {
    return msg("Event Log");
  }
  pageDescription() {
    return;
  }
  pageIcon() {
    return "pf-icon pf-icon-catalog";
  }
  searchEnabled() {
    return true;
  }
  static get styles() {
    return super.styles.concat(i`
            .pf-m-no-padding-bottom {
                padding-bottom: 0;
            }
        `);
  }
  async apiEndpoint(page) {
    return new EventsApi(DEFAULT_CONFIG).eventsEventsList({
      ordering: this.order,
      page,
      pageSize: (await uiConfig()).pagination.perPage,
      search: this.search || ""
    });
  }
  columns() {
    return [
      new TableColumn(msg("Action"), "action"),
      new TableColumn(msg("User"), "user"),
      new TableColumn(msg("Creation Date"), "created"),
      new TableColumn(msg("Client IP"), "client_ip"),
      new TableColumn(msg("Brand"), "brand_name"),
      new TableColumn(msg("Actions"))
    ];
  }
  renderSectionBefore() {
    return x`
            <div class="pf-c-page__main-section pf-m-no-padding-bottom">
                <ak-events-volume-chart
                    .query=${{
      page: this.page,
      search: this.search
    }}
                ></ak-events-volume-chart>
            </div>
        `;
  }
  row(item) {
    return [
      x`<div>${actionToLabel(item.action)}</div>
                <small>${item.app}</small>`,
      EventUser(item),
      x`<div>${getRelativeTime(item.created)}</div>
                <small>${item.created.toLocaleString()}</small>`,
      x`<div>${item.clientIp || msg("-")}</div>
                <small>${EventGeo(item)}</small>`,
      x`<span>${item.brand?.name || msg("-")}</span>`,
      x`<a href="#/events/log/${item.pk}">
                <pf-tooltip position="top" content=${msg("Show details")}>
                    <i class="fas fa-share-square"></i>
                </pf-tooltip>
            </a>`
    ];
  }
  renderExpanded(item) {
    return x` <td role="cell" colspan="5">
                <div class="pf-c-table__expandable-row-content">
                    <ak-event-info .event=${item}></ak-event-info>
                </div>
            </td>
            <td></td>
            <td></td>
            <td></td>`;
  }
};
__decorateClass([
  n()
], EventListPage.prototype, "order", 2);
EventListPage = __decorateClass([
  t("ak-event-list")
], EventListPage);
export {
  EventListPage
};
//# sourceMappingURL=EventListPage-AI3HCR57.js.map
