import "./chunk-EGRHWZRV.js";
import "./chunk-4JTEFESU.js";
import "./chunk-XX4MPIVG.js";
import {
  description_list_default
} from "./chunk-DJQHOO67.js";
import "./chunk-Y5HTBO47.js";
import {
  TablePage
} from "./chunk-R63EXIDN.js";
import "./chunk-XPFXHVQV.js";
import "./chunk-EEANTJCZ.js";
import "./chunk-7XZT6QXJ.js";
import {
  TableColumn,
  uiConfig
} from "./chunk-OOB7B3ZK.js";
import "./chunk-K3AR7TXW.js";
import "./chunk-5MMRTU65.js";
import "./chunk-QN67UQKM.js";
import {
  DEFAULT_CONFIG,
  EVENT_REFRESH,
  EventsApi,
  SystemTaskStatusEnum,
  getRelativeTime,
  n,
  t
} from "./chunk-EOF5OWT7.js";
import {
  msg,
  str,
  x
} from "./chunk-MDYFRBOX.js";
import {
  __decorateClass
} from "./chunk-6IFWU6BM.js";

// src/admin/system-tasks/SystemTaskListPage.ts
var SystemTaskListPage = class extends TablePage {
  constructor() {
    super(...arguments);
    this.expandable = true;
    this.order = "name";
  }
  pageTitle() {
    return msg("System Tasks");
  }
  pageDescription() {
    return msg("Long-running operations which authentik executes in the background.");
  }
  pageIcon() {
    return "pf-icon pf-icon-automation";
  }
  searchEnabled() {
    return true;
  }
  static get styles() {
    return super.styles.concat(description_list_default);
  }
  async apiEndpoint(page) {
    return new EventsApi(DEFAULT_CONFIG).eventsSystemTasksList({
      ordering: this.order,
      page,
      pageSize: (await uiConfig()).pagination.perPage,
      search: this.search || ""
    });
  }
  columns() {
    return [
      new TableColumn(msg("Identifier"), "name"),
      new TableColumn(msg("Description")),
      new TableColumn(msg("Last run")),
      new TableColumn(msg("Status"), "status"),
      new TableColumn(msg("Actions"))
    ];
  }
  taskStatus(task) {
    switch (task.status) {
      case SystemTaskStatusEnum.Successful:
        return x`<ak-label color=${"pf-m-green" /* Green */}>${msg("Successful")}</ak-label>`;
      case SystemTaskStatusEnum.Warning:
        return x`<ak-label color=${"pf-m-orange" /* Orange */}>${msg("Warning")}</ak-label>`;
      case SystemTaskStatusEnum.Error:
        return x`<ak-label color=${"pf-m-red" /* Red */}>${msg("Error")}</ak-label>`;
      default:
        return x`<ak-label color=${"" /* Grey */}>${msg("Unknown")}</ak-label>`;
    }
  }
  renderExpanded(item) {
    return x` <td role="cell" colspan="3">
                <div class="pf-c-table__expandable-row-content">
                    <dl class="pf-c-description-list pf-m-horizontal">
                        <div class="pf-c-description-list__group">
                            <dt class="pf-c-description-list__term">
                                <span class="pf-c-description-list__text">${msg("Duration")}</span>
                            </dt>
                            <dd class="pf-c-description-list__description">
                                <div class="pf-c-description-list__text">
                                    ${msg(str`${item.duration.toFixed(2)} seconds`)}
                                </div>
                            </dd>
                        </div>
                        <div class="pf-c-description-list__group">
                            <dt class="pf-c-description-list__term">
                                <span class="pf-c-description-list__text">${msg("Messages")}</span>
                            </dt>
                            <dd class="pf-c-description-list__description">
                                <div class="pf-c-description-list__text">
                                    <ak-log-viewer .logs=${item?.messages}></ak-log-viewer>
                                </div>
                            </dd>
                        </div>
                    </dl>
                </div>
            </td>
            <td></td>
            <td></td>`;
  }
  row(item) {
    return [
      x`<pre>${item.name}${item.uid ? `:${item.uid}` : ""}</pre>`,
      x`${item.description}`,
      x`<div>${getRelativeTime(item.finishTimestamp)}</div>
                <small>${item.finishTimestamp.toLocaleString()}</small>`,
      this.taskStatus(item),
      x`<ak-action-button
                class="pf-m-plain"
                .apiRequest=${() => {
        return new EventsApi(DEFAULT_CONFIG).eventsSystemTasksRunCreate({
          uuid: item.uuid
        }).then(() => {
          this.dispatchEvent(
            new CustomEvent(EVENT_REFRESH, {
              bubbles: true,
              composed: true
            })
          );
        });
      }}
            >
                <pf-tooltip position="top" content=${msg("Restart task")}>
                    <i class="fas fa-redo" aria-hidden="true"></i>
                </pf-tooltip>
            </ak-action-button>`
    ];
  }
};
__decorateClass([
  n()
], SystemTaskListPage.prototype, "order", 2);
SystemTaskListPage = __decorateClass([
  t("ak-system-task-list")
], SystemTaskListPage);
export {
  SystemTaskListPage
};
//# sourceMappingURL=SystemTaskListPage-X73L5VTH.js.map
