import "./chunk-ZAJ4I4EK.js";
import "./chunk-QPYNOECS.js";
import "./chunk-GOSS526A.js";
import "./chunk-KAVSWSBX.js";
import {
  RbacPermissionsAssignedByUsersListModelEnum
} from "./chunk-EALY7PEX.js";
import "./chunk-ME2U4GBS.js";
import {
  intentToLabel
} from "./chunk-BEFPUR3G.js";
import "./chunk-Z7XVYGD6.js";
import "./chunk-WJSRKCWV.js";
import "./chunk-XCEM2TDB.js";
import "./chunk-XX4MPIVG.js";
import {
  TablePage
} from "./chunk-R63EXIDN.js";
import "./chunk-O7KILHL6.js";
import "./chunk-DP47YJ62.js";
import "./chunk-ZKRIRKRW.js";
import "./chunk-SACHAYPZ.js";
import "./chunk-CZGYCY4V.js";
import {
  ModelForm
} from "./chunk-ZVKXJXN6.js";
import "./chunk-PSPR3SUN.js";
import "./chunk-6KRH5U5H.js";
import "./chunk-GOIBY4UW.js";
import "./chunk-WPHOZTKQ.js";
import "./chunk-ITYWTYEW.js";
import "./chunk-EEANTJCZ.js";
import "./chunk-7XZT6QXJ.js";
import {
  TableColumn,
  uiConfig
} from "./chunk-OOB7B3ZK.js";
import "./chunk-K3AR7TXW.js";
import "./chunk-5MMRTU65.js";
import "./chunk-QN67UQKM.js";
import {
  CoreApi,
  DEFAULT_CONFIG,
  IntentEnum,
  dateTimeLocal,
  first,
  getRelativeTime,
  n,
  r,
  t
} from "./chunk-EOF5OWT7.js";
import {
  msg,
  x
} from "./chunk-MDYFRBOX.js";
import {
  __decorateClass
} from "./chunk-6IFWU6BM.js";

// src/admin/tokens/TokenForm.ts
var TokenForm = class extends ModelForm {
  constructor() {
    super(...arguments);
    this.showExpiry = true;
  }
  async loadInstance(pk) {
    const token = await new CoreApi(DEFAULT_CONFIG).coreTokensRetrieve({
      identifier: pk
    });
    this.showExpiry = token.expiring || true;
    return token;
  }
  getSuccessMessage() {
    return this.instance ? msg("Successfully updated token.") : msg("Successfully created token.");
  }
  async send(data) {
    if (this.instance?.identifier) {
      return new CoreApi(DEFAULT_CONFIG).coreTokensUpdate({
        identifier: this.instance.identifier,
        tokenRequest: data
      });
    } else {
      return new CoreApi(DEFAULT_CONFIG).coreTokensCreate({
        tokenRequest: data
      });
    }
  }
  renderExpiry() {
    return x`<ak-form-element-horizontal label=${msg("Expires on")} name="expires">
            <input
                type="datetime-local"
                data-type="datetime-local"
                value="${dateTimeLocal(first(this.instance?.expires, /* @__PURE__ */ new Date()))}"
                class="pf-c-form-control"
            />
        </ak-form-element-horizontal>`;
  }
  renderForm() {
    return x` <ak-form-element-horizontal
                label=${msg("Identifier")}
                name="identifier"
                ?required=${true}
            >
                <input
                    type="text"
                    value="${first(this.instance?.identifier, "")}"
                    class="pf-c-form-control"
                    required
                />
                <p class="pf-c-form__helper-text">
                    ${msg("Unique identifier the token is referenced by.")}
                </p>
            </ak-form-element-horizontal>
            <ak-form-element-horizontal label=${msg("User")} ?required=${true} name="user">
                <ak-search-select
                    .fetchObjects=${async (query) => {
      const args = {
        ordering: "username"
      };
      if (query !== void 0) {
        args.search = query;
      }
      const users = await new CoreApi(DEFAULT_CONFIG).coreUsersList(args);
      return users.results;
    }}
                    .renderElement=${(user) => {
      return user.username;
    }}
                    .renderDescription=${(user) => {
      return x`${user.name}`;
    }}
                    .value=${(user) => {
      return user?.pk;
    }}
                    .selected=${(user) => {
      return this.instance?.user === user.pk;
    }}
                >
                </ak-search-select>
            </ak-form-element-horizontal>
            <ak-form-element-horizontal label=${msg("Intent")} ?required=${true} name="intent">
                <ak-radio
                    .options=${[
      {
        label: msg("API Token"),
        value: IntentEnum.Api,
        default: true,
        description: x`${msg("Used to access the API programmatically")}`
      },
      {
        label: msg("App password."),
        value: IntentEnum.AppPassword,
        description: x`${msg("Used to login using a flow executor")}`
      }
    ]}
                    .value=${this.instance?.intent}
                >
                </ak-radio>
            </ak-form-element-horizontal>
            <ak-form-element-horizontal label=${msg("Description")} name="description">
                <input
                    type="text"
                    value="${first(this.instance?.description, "")}"
                    class="pf-c-form-control"
                />
            </ak-form-element-horizontal>
            <ak-form-element-horizontal name="expiring">
                <label class="pf-c-switch">
                    <input
                        class="pf-c-switch__input"
                        type="checkbox"
                        ?checked=${first(this.instance?.expiring, true)}
                        @change=${(ev) => {
      const el = ev.target;
      this.showExpiry = el.checked;
    }}
                    />
                    <span class="pf-c-switch__toggle">
                        <span class="pf-c-switch__toggle-icon">
                            <i class="fas fa-check" aria-hidden="true"></i>
                        </span>
                    </span>
                    <span class="pf-c-switch__label">${msg("Expiring")}</span>
                </label>
                <p class="pf-c-form__helper-text">
                    ${msg(
      "If this is selected, the token will expire. Upon expiration, the token will be rotated."
    )}
                </p>
            </ak-form-element-horizontal>
            ${this.showExpiry ? this.renderExpiry() : x``}`;
  }
};
__decorateClass([
  r()
], TokenForm.prototype, "showExpiry", 2);
TokenForm = __decorateClass([
  t("ak-token-form")
], TokenForm);

// src/admin/tokens/TokenListPage.ts
var TokenListPage = class extends TablePage {
  constructor() {
    super(...arguments);
    this.checkbox = true;
    this.clearOnRefresh = true;
    this.order = "expires";
  }
  searchEnabled() {
    return true;
  }
  pageTitle() {
    return msg("Tokens");
  }
  pageDescription() {
    return msg(
      "Tokens are used throughout authentik for Email validation stages, Recovery keys and API access."
    );
  }
  pageIcon() {
    return "pf-icon pf-icon-security";
  }
  async apiEndpoint(page) {
    return new CoreApi(DEFAULT_CONFIG).coreTokensList({
      ordering: this.order,
      page,
      pageSize: (await uiConfig()).pagination.perPage,
      search: this.search || ""
    });
  }
  columns() {
    return [
      new TableColumn(msg("Identifier"), "identifier"),
      new TableColumn(msg("User"), "user"),
      new TableColumn(msg("Expires?"), "expiring"),
      new TableColumn(msg("Expiry date"), "expires"),
      new TableColumn(msg("Intent"), "intent"),
      new TableColumn(msg("Actions"))
    ];
  }
  renderToolbarSelected() {
    const disabled = this.selectedElements.length < 1;
    return x`<ak-forms-delete-bulk
            objectLabel=${msg("Token(s)")}
            .objects=${this.selectedElements}
            .metadata=${(item) => {
      return [{ key: msg("Identifier"), value: item.identifier }];
    }}
            .usedBy=${(item) => {
      return new CoreApi(DEFAULT_CONFIG).coreTokensUsedByList({
        identifier: item.identifier
      });
    }}
            .delete=${(item) => {
      return new CoreApi(DEFAULT_CONFIG).coreTokensDestroy({
        identifier: item.identifier
      });
    }}
        >
            <button ?disabled=${disabled} slot="trigger" class="pf-c-button pf-m-danger">
                ${msg("Delete")}
            </button>
        </ak-forms-delete-bulk>`;
  }
  renderObjectCreate() {
    return x`
            <ak-forms-modal>
                <span slot="submit"> ${msg("Create")} </span>
                <span slot="header"> ${msg("Create Token")} </span>
                <ak-token-form slot="form"> </ak-token-form>
                <button slot="trigger" class="pf-c-button pf-m-primary">${msg("Create")}</button>
            </ak-forms-modal>
        `;
  }
  row(item) {
    return [
      x`<div>${item.identifier}</div>
                ${item.managed ? x`<small>${msg("Token is managed by authentik.")}</small>` : x``}`,
      x`<a href="#/identity/users/${item.userObj?.pk}">${item.userObj?.username}</a>`,
      x`<ak-status-label type="warning" ?good=${item.expiring}></ak-status-label>`,
      x`${item.expires && item.expiring ? x`<div>${getRelativeTime(item.expires)}</div>
                      <small>${item.expires.toLocaleString()}</small>` : msg("-")}`,
      x`${intentToLabel(item.intent ?? IntentEnum.Api)}`,
      x`
                ${!item.managed ? x`<ak-forms-modal>
                          <span slot="submit"> ${msg("Update")} </span>
                          <span slot="header"> ${msg("Update Token")} </span>
                          <ak-token-form slot="form" .instancePk=${item.identifier}></ak-token-form>
                          <button slot="trigger" class="pf-c-button pf-m-plain">
                              <pf-tooltip position="top" content=${msg("Edit")}>
                                  <i class="fas fa-edit"></i>
                              </pf-tooltip>
                          </button>
                      </ak-forms-modal>` : x` <button class="pf-c-button pf-m-plain" disabled>
                          <pf-tooltip
                              position="top"
                              content=${msg("Editing is disabled for managed tokens")}
                          >
                              <i class="fas fa-edit"></i>
                          </pf-tooltip>
                      </button>`}
                <ak-rbac-object-permission-modal
                    model=${RbacPermissionsAssignedByUsersListModelEnum.CoreToken}
                    objectPk=${item.pk}
                >
                </ak-rbac-object-permission-modal>
                <ak-token-copy-button
                    class="pf-c-button pf-m-plain"
                    identifier="${item.identifier}"
                >
                    <pf-tooltip position="top" content=${msg("Copy token")}>
                        <i class="fas fa-copy"></i>
                    </pf-tooltip>
                </ak-token-copy-button>
            `
    ];
  }
};
__decorateClass([
  n()
], TokenListPage.prototype, "order", 2);
TokenListPage = __decorateClass([
  t("ak-token-list")
], TokenListPage);
export {
  TokenListPage
};
//# sourceMappingURL=TokenListPage-YASE3S73.js.map
