import {
  m
} from "./chunk-WPHOZTKQ.js";
import {
  RouteMatch
} from "./chunk-OOB7B3ZK.js";
import {
  empty_state_default,
  title_default
} from "./chunk-5MMRTU65.js";
import {
  AKElement,
  ROUTE_SEPARATOR,
  n,
  patternfly_base_default,
  t
} from "./chunk-EOF5OWT7.js";
import {
  i,
  msg,
  str,
  x
} from "./chunk-MDYFRBOX.js";
import {
  __decorateClass
} from "./chunk-6IFWU6BM.js";

// src/elements/router/Route.ts
var SLUG_REGEX = "[-a-zA-Z0-9_]+";
var ID_REGEX = "\\d+";
var UUID_REGEX = "[0-9a-f]{8}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{12}";
var Route = class {
  constructor(url, callback) {
    this.url = url;
    this.callback = callback;
  }
  redirect(to, raw = false) {
    this.callback = async () => {
      console.debug(`authentik/router: redirecting ${to}`);
      if (!raw) {
        window.location.hash = `#${to}`;
      } else {
        window.location.hash = to;
      }
      return x``;
    };
    return this;
  }
  then(render) {
    this.callback = async (args) => {
      return render(args);
    };
    return this;
  }
  thenAsync(render) {
    this.callback = render;
    return this;
  }
  render(args) {
    if (this.callback) {
      return x`${m(
        this.callback(args),
        x`<ak-empty-state ?loading=${true}></ak-empty-state>`
      )}`;
    }
    if (this.element) {
      return this.element;
    }
    throw new Error("Route does not have callback or element");
  }
  toString() {
    return `<Route url=${this.url} callback=${this.callback ? "true" : "false"}>`;
  }
};

// src/elements/router/Router404.ts
var Router404 = class extends AKElement {
  constructor() {
    super(...arguments);
    this.url = "";
  }
  static get styles() {
    return [patternfly_base_default, empty_state_default, title_default];
  }
  render() {
    return x`<div class="pf-c-empty-state pf-m-full-height">
            <div class="pf-c-empty-state__content">
                <i class="fas fa-question-circle pf-c-empty-state__icon" aria-hidden="true"></i>
                <h1 class="pf-c-title pf-m-lg">${msg("Not found")}</h1>
                <div class="pf-c-empty-state__body">
                    ${msg(str`The URL "${this.url}" was not found.`)}
                </div>
                <a href="#/" class="pf-c-button pf-m-primary" type="button"
                    >${msg("Return home")}</a
                >
            </div>
        </div>`;
  }
};
__decorateClass([
  n()
], Router404.prototype, "url", 2);
Router404 = __decorateClass([
  t("ak-router-404")
], Router404);

// src/elements/router/RouterOutlet.ts
window.addEventListener("load", () => {
  if (!window.HashChangeEvent)
    (function() {
      let lastURL = document.URL;
      window.addEventListener("hashchange", function(event) {
        Object.defineProperty(event, "oldURL", {
          enumerable: true,
          configurable: true,
          value: lastURL
        });
        Object.defineProperty(event, "newURL", {
          enumerable: true,
          configurable: true,
          value: document.URL
        });
        lastURL = document.URL;
      });
    })();
});
function paramURL(url, params) {
  let finalUrl = "#";
  finalUrl += url;
  if (params) {
    finalUrl += ";";
    finalUrl += encodeURIComponent(JSON.stringify(params));
  }
  return finalUrl;
}
var RouterOutlet = class extends AKElement {
  constructor() {
    super();
    this.routes = [];
    window.addEventListener("hashchange", (ev) => this.navigate(ev));
  }
  static get styles() {
    return [
      i`
                :host {
                    background-color: transparent !important;
                }
                *:first-child {
                    flex-direction: column;
                }
            `
    ];
  }
  firstUpdated() {
    this.navigate();
  }
  navigate(ev) {
    let activeUrl = window.location.hash.slice(1, Infinity).split(ROUTE_SEPARATOR)[0];
    if (ev) {
      const oldPath = new URL(ev.oldURL).hash.slice(1, Infinity).split(ROUTE_SEPARATOR)[0];
      if (oldPath === activeUrl)
        return;
    }
    if (activeUrl === "") {
      activeUrl = this.defaultUrl || "/";
      window.location.hash = `#${activeUrl}`;
      console.debug(`authentik/router: defaulted URL to ${window.location.hash}`);
      return;
    }
    let matchedRoute = null;
    this.routes.some((route) => {
      const match = route.url.exec(activeUrl);
      if (match !== null) {
        matchedRoute = new RouteMatch(route);
        matchedRoute.arguments = match.groups || {};
        matchedRoute.fullUrl = activeUrl;
        console.debug("authentik/router: found match ", matchedRoute);
        return true;
      }
      return false;
    });
    if (!matchedRoute) {
      console.debug(`authentik/router: route "${activeUrl}" not defined`);
      const route = new Route(RegExp(""), async () => {
        return x`<div class="pf-c-page__main">
                    <ak-router-404 url=${activeUrl}></ak-router-404>
                </div>`;
      });
      matchedRoute = new RouteMatch(route);
      matchedRoute.arguments = route.url.exec(activeUrl)?.groups || {};
      matchedRoute.fullUrl = activeUrl;
    }
    this.current = matchedRoute;
  }
  render() {
    return this.current?.render();
  }
};
__decorateClass([
  n({ attribute: false })
], RouterOutlet.prototype, "current", 2);
__decorateClass([
  n()
], RouterOutlet.prototype, "defaultUrl", 2);
__decorateClass([
  n({ attribute: false })
], RouterOutlet.prototype, "routes", 2);
RouterOutlet = __decorateClass([
  t("ak-router-outlet")
], RouterOutlet);

export {
  SLUG_REGEX,
  ID_REGEX,
  UUID_REGEX,
  Route,
  paramURL
};
//# sourceMappingURL=chunk-4AZTJNGY.js.map
