import {
  description_list_default
} from "./chunk-DJQHOO67.js";
import {
  Table,
  TableColumn
} from "./chunk-OOB7B3ZK.js";
import {
  LogLevelEnum,
  getRelativeTime,
  n,
  t
} from "./chunk-EOF5OWT7.js";
import {
  msg,
  x
} from "./chunk-MDYFRBOX.js";
import {
  __decorateClass
} from "./chunk-6IFWU6BM.js";

// src/elements/events/LogViewer.ts
var LogViewer = class extends Table {
  constructor() {
    super(...arguments);
    this.logs = [];
    this.expandable = true;
    this.paginated = false;
  }
  static get styles() {
    return super.styles.concat(description_list_default);
  }
  async apiEndpoint(_page) {
    return {
      pagination: {
        next: 0,
        previous: 0,
        count: this.logs?.length || 0,
        current: 1,
        totalPages: 1,
        startIndex: 1,
        endIndex: this.logs?.length || 0
      },
      results: this.logs || []
    };
  }
  renderEmpty() {
    return super.renderEmpty(
      x`<ak-empty-state header=${msg("No log messages.")}> </ak-empty-state>`
    );
  }
  renderExpanded(item) {
    return x`<td role="cell" colspan="4">
            <div class="pf-c-table__expandable-row-content">
                <dl class="pf-c-description-list pf-m-horizontal">
                    <div class="pf-c-description-list__group">
                        <dt class="pf-c-description-list__term">
                            <span class="pf-c-description-list__text">${msg("Timestamp")}</span>
                        </dt>
                        <dd class="pf-c-description-list__description">
                            <div class="pf-c-description-list__text">
                                ${item.timestamp.toLocaleString()}
                            </div>
                        </dd>
                    </div>
                    <div class="pf-c-description-list__group">
                        <dt class="pf-c-description-list__term">
                            <span class="pf-c-description-list__text">${msg("Attributes")}</span>
                        </dt>
                        <dd class="pf-c-description-list__description">
                            <div class="pf-c-description-list__text">
                                <pre>${JSON.stringify(item.attributes, null, 4)}</pre>
                            </div>
                        </dd>
                    </div>
                </dl>
            </div>
        </td>`;
  }
  renderToolbarContainer() {
    return x``;
  }
  columns() {
    return [
      new TableColumn(msg("Time")),
      new TableColumn(msg("Level")),
      new TableColumn(msg("Event")),
      new TableColumn(msg("Logger"))
    ];
  }
  statusForItem(item) {
    switch (item.logLevel) {
      case LogLevelEnum.Critical:
      case LogLevelEnum.Error:
      case LogLevelEnum.Exception:
        return "error";
      case LogLevelEnum.Warn:
      case LogLevelEnum.Warning:
        return "warning";
      default:
        return "info";
    }
  }
  row(item) {
    return [
      x`${getRelativeTime(item.timestamp)}`,
      x`<ak-status-label
                type=${this.statusForItem(item)}
                bad-label=${item.logLevel}
            ></ak-status-label>`,
      x`${item.event}`,
      x`${item.logger}`
    ];
  }
};
__decorateClass([
  n({ attribute: false })
], LogViewer.prototype, "logs", 2);
LogViewer = __decorateClass([
  t("ak-log-viewer")
], LogViewer);
//# sourceMappingURL=chunk-4JTEFESU.js.map
