import {
  BaseAPI,
  JSONApiResponse,
  PaginationFromJSON,
  RequiredError,
  UsedByFromJSON,
  VoidApiResponse
} from "./chunk-EOF5OWT7.js";

// node_modules/@goauthentik/api/dist/esm/models/InstallID.js
function InstallIDFromJSON(json) {
  return InstallIDFromJSONTyped(json, false);
}
function InstallIDFromJSONTyped(json, ignoreDiscriminator) {
  if (json === void 0 || json === null) {
    return json;
  }
  return {
    "installId": json["install_id"]
  };
}

// node_modules/@goauthentik/api/dist/esm/models/License.js
function LicenseFromJSON(json) {
  return LicenseFromJSONTyped(json, false);
}
function LicenseFromJSONTyped(json, ignoreDiscriminator) {
  if (json === void 0 || json === null) {
    return json;
  }
  return {
    "licenseUuid": json["license_uuid"],
    "name": json["name"],
    "key": json["key"],
    "expiry": new Date(json["expiry"]),
    "internalUsers": json["internal_users"],
    "externalUsers": json["external_users"]
  };
}

// node_modules/@goauthentik/api/dist/esm/models/LicenseForecast.js
function LicenseForecastFromJSON(json) {
  return LicenseForecastFromJSONTyped(json, false);
}
function LicenseForecastFromJSONTyped(json, ignoreDiscriminator) {
  if (json === void 0 || json === null) {
    return json;
  }
  return {
    "internalUsers": json["internal_users"],
    "externalUsers": json["external_users"],
    "forecastedInternalUsers": json["forecasted_internal_users"],
    "forecastedExternalUsers": json["forecasted_external_users"]
  };
}

// node_modules/@goauthentik/api/dist/esm/models/LicenseRequest.js
function LicenseRequestToJSON(value) {
  if (value === void 0) {
    return void 0;
  }
  if (value === null) {
    return null;
  }
  return {
    "key": value.key
  };
}

// node_modules/@goauthentik/api/dist/esm/models/LicenseSummary.js
function LicenseSummaryFromJSON(json) {
  return LicenseSummaryFromJSONTyped(json, false);
}
function LicenseSummaryFromJSONTyped(json, ignoreDiscriminator) {
  if (json === void 0 || json === null) {
    return json;
  }
  return {
    "internalUsers": json["internal_users"],
    "externalUsers": json["external_users"],
    "valid": json["valid"],
    "showAdminWarning": json["show_admin_warning"],
    "showUserWarning": json["show_user_warning"],
    "readOnly": json["read_only"],
    "latestValid": new Date(json["latest_valid"]),
    "hasLicense": json["has_license"]
  };
}

// node_modules/@goauthentik/api/dist/esm/models/PaginatedLicenseList.js
function PaginatedLicenseListFromJSON(json) {
  return PaginatedLicenseListFromJSONTyped(json, false);
}
function PaginatedLicenseListFromJSONTyped(json, ignoreDiscriminator) {
  if (json === void 0 || json === null) {
    return json;
  }
  return {
    "pagination": PaginationFromJSON(json["pagination"]),
    "results": json["results"].map(LicenseFromJSON)
  };
}

// node_modules/@goauthentik/api/dist/esm/models/PatchedLicenseRequest.js
function PatchedLicenseRequestToJSON(value) {
  if (value === void 0) {
    return void 0;
  }
  if (value === null) {
    return null;
  }
  return {
    "key": value.key
  };
}

// node_modules/@goauthentik/api/dist/esm/apis/EnterpriseApi.js
var __awaiter = function(thisArg, _arguments, P, generator) {
  function adopt(value) {
    return value instanceof P ? value : new P(function(resolve) {
      resolve(value);
    });
  }
  return new (P || (P = Promise))(function(resolve, reject) {
    function fulfilled(value) {
      try {
        step(generator.next(value));
      } catch (e) {
        reject(e);
      }
    }
    function rejected(value) {
      try {
        step(generator["throw"](value));
      } catch (e) {
        reject(e);
      }
    }
    function step(result) {
      result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected);
    }
    step((generator = generator.apply(thisArg, _arguments || [])).next());
  });
};
var EnterpriseApi = class extends BaseAPI {
  /**
   * License Viewset
   */
  enterpriseLicenseCreateRaw(requestParameters, initOverrides) {
    return __awaiter(this, void 0, void 0, function* () {
      if (requestParameters.licenseRequest === null || requestParameters.licenseRequest === void 0) {
        throw new RequiredError("licenseRequest", "Required parameter requestParameters.licenseRequest was null or undefined when calling enterpriseLicenseCreate.");
      }
      const queryParameters = {};
      const headerParameters = {};
      headerParameters["Content-Type"] = "application/json";
      if (this.configuration && this.configuration.accessToken) {
        const token = this.configuration.accessToken;
        const tokenString = yield token("authentik", []);
        if (tokenString) {
          headerParameters["Authorization"] = `Bearer ${tokenString}`;
        }
      }
      const response = yield this.request({
        path: `/enterprise/license/`,
        method: "POST",
        headers: headerParameters,
        query: queryParameters,
        body: LicenseRequestToJSON(requestParameters.licenseRequest)
      }, initOverrides);
      return new JSONApiResponse(response, (jsonValue) => LicenseFromJSON(jsonValue));
    });
  }
  /**
   * License Viewset
   */
  enterpriseLicenseCreate(requestParameters, initOverrides) {
    return __awaiter(this, void 0, void 0, function* () {
      const response = yield this.enterpriseLicenseCreateRaw(requestParameters, initOverrides);
      return yield response.value();
    });
  }
  /**
   * License Viewset
   */
  enterpriseLicenseDestroyRaw(requestParameters, initOverrides) {
    return __awaiter(this, void 0, void 0, function* () {
      if (requestParameters.licenseUuid === null || requestParameters.licenseUuid === void 0) {
        throw new RequiredError("licenseUuid", "Required parameter requestParameters.licenseUuid was null or undefined when calling enterpriseLicenseDestroy.");
      }
      const queryParameters = {};
      const headerParameters = {};
      if (this.configuration && this.configuration.accessToken) {
        const token = this.configuration.accessToken;
        const tokenString = yield token("authentik", []);
        if (tokenString) {
          headerParameters["Authorization"] = `Bearer ${tokenString}`;
        }
      }
      const response = yield this.request({
        path: `/enterprise/license/{license_uuid}/`.replace(`{${"license_uuid"}}`, encodeURIComponent(String(requestParameters.licenseUuid))),
        method: "DELETE",
        headers: headerParameters,
        query: queryParameters
      }, initOverrides);
      return new VoidApiResponse(response);
    });
  }
  /**
   * License Viewset
   */
  enterpriseLicenseDestroy(requestParameters, initOverrides) {
    return __awaiter(this, void 0, void 0, function* () {
      yield this.enterpriseLicenseDestroyRaw(requestParameters, initOverrides);
    });
  }
  /**
   * Forecast how many users will be required in a year
   */
  enterpriseLicenseForecastRetrieveRaw(initOverrides) {
    return __awaiter(this, void 0, void 0, function* () {
      const queryParameters = {};
      const headerParameters = {};
      if (this.configuration && this.configuration.accessToken) {
        const token = this.configuration.accessToken;
        const tokenString = yield token("authentik", []);
        if (tokenString) {
          headerParameters["Authorization"] = `Bearer ${tokenString}`;
        }
      }
      const response = yield this.request({
        path: `/enterprise/license/forecast/`,
        method: "GET",
        headers: headerParameters,
        query: queryParameters
      }, initOverrides);
      return new JSONApiResponse(response, (jsonValue) => LicenseForecastFromJSON(jsonValue));
    });
  }
  /**
   * Forecast how many users will be required in a year
   */
  enterpriseLicenseForecastRetrieve(initOverrides) {
    return __awaiter(this, void 0, void 0, function* () {
      const response = yield this.enterpriseLicenseForecastRetrieveRaw(initOverrides);
      return yield response.value();
    });
  }
  /**
   * Get install_id
   */
  enterpriseLicenseGetInstallIdRetrieveRaw(initOverrides) {
    return __awaiter(this, void 0, void 0, function* () {
      const queryParameters = {};
      const headerParameters = {};
      if (this.configuration && this.configuration.accessToken) {
        const token = this.configuration.accessToken;
        const tokenString = yield token("authentik", []);
        if (tokenString) {
          headerParameters["Authorization"] = `Bearer ${tokenString}`;
        }
      }
      const response = yield this.request({
        path: `/enterprise/license/get_install_id/`,
        method: "GET",
        headers: headerParameters,
        query: queryParameters
      }, initOverrides);
      return new JSONApiResponse(response, (jsonValue) => InstallIDFromJSON(jsonValue));
    });
  }
  /**
   * Get install_id
   */
  enterpriseLicenseGetInstallIdRetrieve(initOverrides) {
    return __awaiter(this, void 0, void 0, function* () {
      const response = yield this.enterpriseLicenseGetInstallIdRetrieveRaw(initOverrides);
      return yield response.value();
    });
  }
  /**
   * License Viewset
   */
  enterpriseLicenseListRaw(requestParameters, initOverrides) {
    return __awaiter(this, void 0, void 0, function* () {
      const queryParameters = {};
      if (requestParameters.name !== void 0) {
        queryParameters["name"] = requestParameters.name;
      }
      if (requestParameters.ordering !== void 0) {
        queryParameters["ordering"] = requestParameters.ordering;
      }
      if (requestParameters.page !== void 0) {
        queryParameters["page"] = requestParameters.page;
      }
      if (requestParameters.pageSize !== void 0) {
        queryParameters["page_size"] = requestParameters.pageSize;
      }
      if (requestParameters.search !== void 0) {
        queryParameters["search"] = requestParameters.search;
      }
      const headerParameters = {};
      if (this.configuration && this.configuration.accessToken) {
        const token = this.configuration.accessToken;
        const tokenString = yield token("authentik", []);
        if (tokenString) {
          headerParameters["Authorization"] = `Bearer ${tokenString}`;
        }
      }
      const response = yield this.request({
        path: `/enterprise/license/`,
        method: "GET",
        headers: headerParameters,
        query: queryParameters
      }, initOverrides);
      return new JSONApiResponse(response, (jsonValue) => PaginatedLicenseListFromJSON(jsonValue));
    });
  }
  /**
   * License Viewset
   */
  enterpriseLicenseList(requestParameters = {}, initOverrides) {
    return __awaiter(this, void 0, void 0, function* () {
      const response = yield this.enterpriseLicenseListRaw(requestParameters, initOverrides);
      return yield response.value();
    });
  }
  /**
   * License Viewset
   */
  enterpriseLicensePartialUpdateRaw(requestParameters, initOverrides) {
    return __awaiter(this, void 0, void 0, function* () {
      if (requestParameters.licenseUuid === null || requestParameters.licenseUuid === void 0) {
        throw new RequiredError("licenseUuid", "Required parameter requestParameters.licenseUuid was null or undefined when calling enterpriseLicensePartialUpdate.");
      }
      const queryParameters = {};
      const headerParameters = {};
      headerParameters["Content-Type"] = "application/json";
      if (this.configuration && this.configuration.accessToken) {
        const token = this.configuration.accessToken;
        const tokenString = yield token("authentik", []);
        if (tokenString) {
          headerParameters["Authorization"] = `Bearer ${tokenString}`;
        }
      }
      const response = yield this.request({
        path: `/enterprise/license/{license_uuid}/`.replace(`{${"license_uuid"}}`, encodeURIComponent(String(requestParameters.licenseUuid))),
        method: "PATCH",
        headers: headerParameters,
        query: queryParameters,
        body: PatchedLicenseRequestToJSON(requestParameters.patchedLicenseRequest)
      }, initOverrides);
      return new JSONApiResponse(response, (jsonValue) => LicenseFromJSON(jsonValue));
    });
  }
  /**
   * License Viewset
   */
  enterpriseLicensePartialUpdate(requestParameters, initOverrides) {
    return __awaiter(this, void 0, void 0, function* () {
      const response = yield this.enterpriseLicensePartialUpdateRaw(requestParameters, initOverrides);
      return yield response.value();
    });
  }
  /**
   * License Viewset
   */
  enterpriseLicenseRetrieveRaw(requestParameters, initOverrides) {
    return __awaiter(this, void 0, void 0, function* () {
      if (requestParameters.licenseUuid === null || requestParameters.licenseUuid === void 0) {
        throw new RequiredError("licenseUuid", "Required parameter requestParameters.licenseUuid was null or undefined when calling enterpriseLicenseRetrieve.");
      }
      const queryParameters = {};
      const headerParameters = {};
      if (this.configuration && this.configuration.accessToken) {
        const token = this.configuration.accessToken;
        const tokenString = yield token("authentik", []);
        if (tokenString) {
          headerParameters["Authorization"] = `Bearer ${tokenString}`;
        }
      }
      const response = yield this.request({
        path: `/enterprise/license/{license_uuid}/`.replace(`{${"license_uuid"}}`, encodeURIComponent(String(requestParameters.licenseUuid))),
        method: "GET",
        headers: headerParameters,
        query: queryParameters
      }, initOverrides);
      return new JSONApiResponse(response, (jsonValue) => LicenseFromJSON(jsonValue));
    });
  }
  /**
   * License Viewset
   */
  enterpriseLicenseRetrieve(requestParameters, initOverrides) {
    return __awaiter(this, void 0, void 0, function* () {
      const response = yield this.enterpriseLicenseRetrieveRaw(requestParameters, initOverrides);
      return yield response.value();
    });
  }
  /**
   * Get the total license status
   */
  enterpriseLicenseSummaryRetrieveRaw(initOverrides) {
    return __awaiter(this, void 0, void 0, function* () {
      const queryParameters = {};
      const headerParameters = {};
      if (this.configuration && this.configuration.accessToken) {
        const token = this.configuration.accessToken;
        const tokenString = yield token("authentik", []);
        if (tokenString) {
          headerParameters["Authorization"] = `Bearer ${tokenString}`;
        }
      }
      const response = yield this.request({
        path: `/enterprise/license/summary/`,
        method: "GET",
        headers: headerParameters,
        query: queryParameters
      }, initOverrides);
      return new JSONApiResponse(response, (jsonValue) => LicenseSummaryFromJSON(jsonValue));
    });
  }
  /**
   * Get the total license status
   */
  enterpriseLicenseSummaryRetrieve(initOverrides) {
    return __awaiter(this, void 0, void 0, function* () {
      const response = yield this.enterpriseLicenseSummaryRetrieveRaw(initOverrides);
      return yield response.value();
    });
  }
  /**
   * License Viewset
   */
  enterpriseLicenseUpdateRaw(requestParameters, initOverrides) {
    return __awaiter(this, void 0, void 0, function* () {
      if (requestParameters.licenseUuid === null || requestParameters.licenseUuid === void 0) {
        throw new RequiredError("licenseUuid", "Required parameter requestParameters.licenseUuid was null or undefined when calling enterpriseLicenseUpdate.");
      }
      if (requestParameters.licenseRequest === null || requestParameters.licenseRequest === void 0) {
        throw new RequiredError("licenseRequest", "Required parameter requestParameters.licenseRequest was null or undefined when calling enterpriseLicenseUpdate.");
      }
      const queryParameters = {};
      const headerParameters = {};
      headerParameters["Content-Type"] = "application/json";
      if (this.configuration && this.configuration.accessToken) {
        const token = this.configuration.accessToken;
        const tokenString = yield token("authentik", []);
        if (tokenString) {
          headerParameters["Authorization"] = `Bearer ${tokenString}`;
        }
      }
      const response = yield this.request({
        path: `/enterprise/license/{license_uuid}/`.replace(`{${"license_uuid"}}`, encodeURIComponent(String(requestParameters.licenseUuid))),
        method: "PUT",
        headers: headerParameters,
        query: queryParameters,
        body: LicenseRequestToJSON(requestParameters.licenseRequest)
      }, initOverrides);
      return new JSONApiResponse(response, (jsonValue) => LicenseFromJSON(jsonValue));
    });
  }
  /**
   * License Viewset
   */
  enterpriseLicenseUpdate(requestParameters, initOverrides) {
    return __awaiter(this, void 0, void 0, function* () {
      const response = yield this.enterpriseLicenseUpdateRaw(requestParameters, initOverrides);
      return yield response.value();
    });
  }
  /**
   * Get a list of all objects that use this object
   */
  enterpriseLicenseUsedByListRaw(requestParameters, initOverrides) {
    return __awaiter(this, void 0, void 0, function* () {
      if (requestParameters.licenseUuid === null || requestParameters.licenseUuid === void 0) {
        throw new RequiredError("licenseUuid", "Required parameter requestParameters.licenseUuid was null or undefined when calling enterpriseLicenseUsedByList.");
      }
      const queryParameters = {};
      const headerParameters = {};
      if (this.configuration && this.configuration.accessToken) {
        const token = this.configuration.accessToken;
        const tokenString = yield token("authentik", []);
        if (tokenString) {
          headerParameters["Authorization"] = `Bearer ${tokenString}`;
        }
      }
      const response = yield this.request({
        path: `/enterprise/license/{license_uuid}/used_by/`.replace(`{${"license_uuid"}}`, encodeURIComponent(String(requestParameters.licenseUuid))),
        method: "GET",
        headers: headerParameters,
        query: queryParameters
      }, initOverrides);
      return new JSONApiResponse(response, (jsonValue) => jsonValue.map(UsedByFromJSON));
    });
  }
  /**
   * Get a list of all objects that use this object
   */
  enterpriseLicenseUsedByList(requestParameters, initOverrides) {
    return __awaiter(this, void 0, void 0, function* () {
      const response = yield this.enterpriseLicenseUsedByListRaw(requestParameters, initOverrides);
      return yield response.value();
    });
  }
};

export {
  EnterpriseApi
};
//# sourceMappingURL=chunk-DLC2SRWI.js.map
