import {
  PropertymappingsApi
} from "./chunk-G6FYWANS.js";
import {
  FlowSearch_default
} from "./chunk-JMBXTRNL.js";
import {
  ModelForm
} from "./chunk-ZVKXJXN6.js";
import {
  ProvidersApi
} from "./chunk-SFAGFFHP.js";
import {
  SourcesApi
} from "./chunk-XSB422CX.js";
import {
  FlowsInstancesListDesignationEnum
} from "./chunk-2G3GM457.js";
import {
  o
} from "./chunk-5MMRTU65.js";
import {
  ClientTypeEnum,
  DEFAULT_CONFIG,
  IssuerModeEnum,
  SubModeEnum,
  ascii_letters,
  digits,
  first,
  n,
  r,
  randomString,
  t
} from "./chunk-EOF5OWT7.js";
import {
  msg,
  x
} from "./chunk-MDYFRBOX.js";
import {
  __decorateClass
} from "./chunk-6IFWU6BM.js";

// src/admin/providers/BaseProviderForm.ts
var BaseProviderForm = class extends ModelForm {
  getSuccessMessage() {
    return this.instance ? msg("Successfully updated provider.") : msg("Successfully created provider.");
  }
};

// src/admin/providers/oauth2/OAuth2ProviderForm.ts
var clientTypeOptions = [
  {
    label: msg("Confidential"),
    value: ClientTypeEnum.Confidential,
    default: true,
    description: x`${msg(
      "Confidential clients are capable of maintaining the confidentiality of their credentials such as client secrets"
    )}`
  },
  {
    label: msg("Public"),
    value: ClientTypeEnum.Public,
    description: x`${msg(
      "Public clients are incapable of maintaining the confidentiality and should use methods like PKCE. "
    )}`
  }
];
var subjectModeOptions = [
  {
    label: msg("Based on the User's hashed ID"),
    value: SubModeEnum.HashedUserId,
    default: true
  },
  {
    label: msg("Based on the User's ID"),
    value: SubModeEnum.UserId
  },
  {
    label: msg("Based on the User's UUID"),
    value: SubModeEnum.UserUuid
  },
  {
    label: msg("Based on the User's username"),
    value: SubModeEnum.UserUsername
  },
  {
    label: msg("Based on the User's Email"),
    value: SubModeEnum.UserEmail,
    description: x`${msg("This is recommended over the UPN mode.")}`
  },
  {
    label: msg("Based on the User's UPN"),
    value: SubModeEnum.UserUpn,
    description: x`${msg(
      "Requires the user to have a 'upn' attribute set, and falls back to hashed user ID. Use this mode only if you have different UPN and Mail domains."
    )}`
  }
];
var issuerModeOptions = [
  {
    label: msg("Each provider has a different issuer, based on the application slug"),
    value: IssuerModeEnum.PerProvider,
    default: true
  },
  {
    label: msg("Same identifier is used for all providers"),
    value: IssuerModeEnum.Global
  }
];
var redirectUriHelpMessages = [
  msg(
    "Valid redirect URLs after a successful authorization flow. Also specify any origins here for Implicit flows."
  ),
  msg(
    "If no explicit redirect URIs are specified, the first successfully used redirect URI will be saved."
  ),
  msg(
    'To allow any redirect URI, set this value to ".*". Be aware of the possible security implications this can have.'
  )
];
var redirectUriHelp = x`${redirectUriHelpMessages.map(
  (m) => x`<p class="pf-c-form__helper-text">${m}</p>`
)}`;
var OAuth2ProviderFormPage = class extends BaseProviderForm {
  constructor() {
    super(...arguments);
    this.showClientSecret = true;
  }
  async loadInstance(pk) {
    const provider = await new ProvidersApi(DEFAULT_CONFIG).providersOauth2Retrieve({
      id: pk
    });
    this.showClientSecret = provider.clientType === ClientTypeEnum.Confidential;
    return provider;
  }
  async load() {
    this.propertyMappings = await new PropertymappingsApi(
      DEFAULT_CONFIG
    ).propertymappingsScopeList({
      ordering: "scope_name"
    });
    this.oauthSources = await new SourcesApi(DEFAULT_CONFIG).sourcesOauthList({
      ordering: "name",
      hasJwks: true
    });
  }
  async send(data) {
    if (this.instance) {
      return new ProvidersApi(DEFAULT_CONFIG).providersOauth2Update({
        id: this.instance.pk || 0,
        oAuth2ProviderRequest: data
      });
    } else {
      return new ProvidersApi(DEFAULT_CONFIG).providersOauth2Create({
        oAuth2ProviderRequest: data
      });
    }
  }
  renderForm() {
    const provider = this.instance;
    return x` <ak-text-input
                name="name"
                label=${msg("Name")}
                value=${o(provider?.name)}
                required
            ></ak-text-input>

            <ak-form-element-horizontal
                name="authenticationFlow"
                label=${msg("Authentication flow")}
            >
                <ak-flow-search
                    flowType=${FlowsInstancesListDesignationEnum.Authentication}
                    .currentFlow=${provider?.authenticationFlow}
                    required
                ></ak-flow-search>
                <p class="pf-c-form__helper-text">
                    ${msg("Flow used when a user access this provider and is not authenticated.")}
                </p>
            </ak-form-element-horizontal>
            <ak-form-element-horizontal
                name="authorizationFlow"
                label=${msg("Authorization flow")}
                ?required=${true}
            >
                <ak-flow-search
                    flowType=${FlowsInstancesListDesignationEnum.Authorization}
                    .currentFlow=${provider?.authorizationFlow}
                    required
                ></ak-flow-search>
                <p class="pf-c-form__helper-text">
                    ${msg("Flow used when authorizing this provider.")}
                </p>
            </ak-form-element-horizontal>

            <ak-form-group .expanded=${true}>
                <span slot="header"> ${msg("Protocol settings")} </span>
                <div slot="body" class="pf-c-form">
                    <ak-radio-input
                        name="clientType"
                        label=${msg("Client type")}
                        .value=${provider?.clientType}
                        required
                        @change=${(ev) => {
      this.showClientSecret = ev.detail.value !== ClientTypeEnum.Public;
    }}
                        .options=${clientTypeOptions}
                    >
                    </ak-radio-input>
                    <ak-text-input
                        name="clientId"
                        label=${msg("Client ID")}
                        value="${first(
      provider?.clientId,
      randomString(40, ascii_letters + digits)
    )}"
                        required
                    >
                    </ak-text-input>
                    <ak-text-input
                        name="clientSecret"
                        label=${msg("Client Secret")}
                        value="${first(
      provider?.clientSecret,
      randomString(128, ascii_letters + digits)
    )}"
                        ?hidden=${!this.showClientSecret}
                    >
                    </ak-text-input>
                    <ak-textarea-input
                        name="redirectUris"
                        label=${msg("Redirect URIs/Origins (RegEx)")}
                        .value=${provider?.redirectUris}
                        .bighelp=${redirectUriHelp}
                    >
                    </ak-textarea-input>

                    <ak-form-element-horizontal label=${msg("Signing Key")} name="signingKey">
                        <!-- NOTE: 'null' cast to 'undefined' on signingKey to satisfy Lit requirements -->
                        <ak-crypto-certificate-search
                            certificate=${o(this.instance?.signingKey ?? void 0)}
                            singleton
                        ></ak-crypto-certificate-search>
                        <p class="pf-c-form__helper-text">${msg("Key used to sign the tokens.")}</p>
                    </ak-form-element-horizontal>
                </div>
            </ak-form-group>

            <ak-form-group>
                <span slot="header"> ${msg("Advanced protocol settings")} </span>
                <div slot="body" class="pf-c-form">
                    <ak-text-input
                        name="accessCodeValidity"
                        label=${msg("Access code validity")}
                        required
                        value="${first(provider?.accessCodeValidity, "minutes=1")}"
                        .bighelp=${x`<p class="pf-c-form__helper-text">
                                ${msg("Configure how long access codes are valid for.")}
                            </p>
                            <ak-utils-time-delta-help></ak-utils-time-delta-help>`}
                    >
                    </ak-text-input>
                    <ak-text-input
                        name="accessTokenValidity"
                        label=${msg("Access Token validity")}
                        value="${first(provider?.accessTokenValidity, "minutes=5")}"
                        required
                        .bighelp=${x` <p class="pf-c-form__helper-text">
                                ${msg("Configure how long access tokens are valid for.")}
                            </p>
                            <ak-utils-time-delta-help></ak-utils-time-delta-help>`}
                    >
                    </ak-text-input>

                    <ak-text-input
                        name="refreshTokenValidity"
                        label=${msg("Refresh Token validity")}
                        value="${first(provider?.refreshTokenValidity, "days=30")}"
                        ?required=${true}
                        .bighelp=${x` <p class="pf-c-form__helper-text">
                                ${msg("Configure how long refresh tokens are valid for.")}
                            </p>
                            <ak-utils-time-delta-help></ak-utils-time-delta-help>`}
                    >
                    </ak-text-input>
                    <ak-form-element-horizontal label=${msg("Scopes")} name="propertyMappings">
                        <select class="pf-c-form-control" multiple>
                            ${this.propertyMappings?.results.map((scope) => {
      let selected = false;
      if (!provider?.propertyMappings) {
        selected = // By default select all managed scope mappings, except offline_access
        scope.managed?.startsWith(
          "goauthentik.io/providers/oauth2/scope-"
        ) && scope.managed !== "goauthentik.io/providers/oauth2/scope-offline_access" || false;
      } else {
        selected = Array.from(provider?.propertyMappings).some((su) => {
          return su == scope.pk;
        });
      }
      return x`<option
                                    value=${o(scope.pk)}
                                    ?selected=${selected}
                                >
                                    ${scope.name}
                                </option>`;
    })}
                        </select>
                        <p class="pf-c-form__helper-text">
                            ${msg(
      "Select which scopes can be used by the client. The client still has to specify the scope to access the data."
    )}
                        </p>
                        <p class="pf-c-form__helper-text">
                            ${msg("Hold control/command to select multiple items.")}
                        </p>
                    </ak-form-element-horizontal>
                    <ak-radio-input
                        name="subMode"
                        label=${msg("Subject mode")}
                        required
                        .options=${subjectModeOptions}
                        .value=${provider?.subMode}
                        help=${msg(
      "Configure what data should be used as unique User Identifier. For most cases, the default should be fine."
    )}
                    >
                    </ak-radio-input>
                    <ak-switch-input
                        name="includeClaimsInIdToken"
                        label=${msg("Include claims in id_token")}
                        ?checked=${first(provider?.includeClaimsInIdToken, true)}
                        help=${msg(
      "Include User claims from scopes in the id_token, for applications that don't access the userinfo endpoint."
    )}
                    ></ak-switch-input>
                    <ak-radio-input
                        name="issuerMode"
                        label=${msg("Issuer mode")}
                        required
                        .options=${issuerModeOptions}
                        .value=${provider?.issuerMode}
                        help=${msg(
      "Configure how the issuer field of the ID Token should be filled."
    )}
                    >
                    </ak-radio-input>
                </div>
            </ak-form-group>

            <ak-form-group>
                <span slot="header">${msg("Machine-to-Machine authentication settings")}</span>
                <div slot="body" class="pf-c-form">
                    <ak-form-element-horizontal
                        label=${msg("Trusted OIDC Sources")}
                        name="jwksSources"
                    >
                        <select class="pf-c-form-control" multiple>
                            ${this.oauthSources?.results.map((source) => {
      const selected = (provider?.jwksSources || []).some((su) => {
        return su == source.pk;
      });
      return x`<option value=${source.pk} ?selected=${selected}>
                                    ${source.name} (${source.slug})
                                </option>`;
    })}
                        </select>
                        <p class="pf-c-form__helper-text">
                            ${msg(
      "JWTs signed by certificates configured in the selected sources can be used to authenticate to this provider."
    )}
                        </p>
                        <p class="pf-c-form__helper-text">
                            ${msg("Hold control/command to select multiple items.")}
                        </p>
                    </ak-form-element-horizontal>
                </div>
            </ak-form-group>`;
  }
};
__decorateClass([
  r()
], OAuth2ProviderFormPage.prototype, "showClientSecret", 2);
OAuth2ProviderFormPage = __decorateClass([
  t("ak-provider-oauth2-form")
], OAuth2ProviderFormPage);

// src/admin/common/ak-flow-search/ak-branded-flow-search.ts
var AkBrandedFlowSearch = class extends FlowSearch_default {
  constructor() {
    super();
    this.selected = this.selected.bind(this);
  }
  selected(flow) {
    return super.selected(flow) || flow.pk === this.brandFlow;
  }
};
__decorateClass([
  n({ attribute: false, type: String })
], AkBrandedFlowSearch.prototype, "brandFlow", 2);
AkBrandedFlowSearch = __decorateClass([
  t("ak-branded-flow-search")
], AkBrandedFlowSearch);

export {
  BaseProviderForm,
  clientTypeOptions,
  subjectModeOptions,
  issuerModeOptions,
  redirectUriHelp
};
//# sourceMappingURL=chunk-EINGTETQ.js.map
