import {
  ModalButton,
  ModalHideEvent,
  form_default
} from "./chunk-GOIBY4UW.js";
import {
  card_default
} from "./chunk-ITYWTYEW.js";
import {
  alert_default,
  showMessage
} from "./chunk-7XZT6QXJ.js";
import {
  form_control_default,
  input_group_default,
  switch_default
} from "./chunk-OOB7B3ZK.js";
import {
  AKElement,
  EVENT_REFRESH,
  ResponseError,
  ValidationErrorFromJSON,
  button_default,
  camelToSnake,
  convertToSlug,
  dateToUTC,
  n,
  patternfly_base_default,
  r,
  t
} from "./chunk-EOF5OWT7.js";
import {
  i,
  msg,
  x
} from "./chunk-MDYFRBOX.js";
import {
  __decorateClass
} from "./chunk-6IFWU6BM.js";

// src/elements/LoadingOverlay.ts
var LoadingOverlay = class extends AKElement {
  constructor() {
    super(...arguments);
    this.topMost = false;
  }
  static get styles() {
    return [
      patternfly_base_default,
      i`
                :host {
                    display: flex;
                    height: 100%;
                    width: 100%;
                    justify-content: center;
                    align-items: center;
                    position: absolute;
                    background-color: var(--pf-global--BackgroundColor--dark-transparent-200);
                    z-index: 1;
                }
                :host([topMost]) {
                    z-index: 999;
                }
            `
    ];
  }
  render() {
    return x`<ak-empty-state ?loading="${true}">
            <slot name="body" slot="body"></slot>
        </ak-empty-state>`;
  }
};
__decorateClass([
  n({ type: Boolean })
], LoadingOverlay.prototype, "topMost", 2);
LoadingOverlay = __decorateClass([
  t("ak-loading-overlay")
], LoadingOverlay);

// src/elements/forms/ModalForm.ts
var ModalForm = class extends ModalButton {
  constructor() {
    super(...arguments);
    this.closeAfterSuccessfulSubmit = true;
    this.showSubmitButton = true;
    this.loading = false;
    this.cancelText = msg("Cancel");
  }
  async confirm() {
    const form = this.querySelector("[slot=form]");
    if (!form) {
      return Promise.reject(msg("No form found"));
    }
    const formPromise = form.submit(new Event("submit"));
    if (!formPromise) {
      return Promise.reject(msg("Form didn't return a promise for submitting"));
    }
    return formPromise.then(() => {
      if (this.closeAfterSuccessfulSubmit) {
        this.open = false;
        form?.resetForm();
        this.dispatchEvent(
          new CustomEvent(EVENT_REFRESH, {
            bubbles: true,
            composed: true
          })
        );
      }
      this.loading = false;
      this.locked = false;
    }).catch((exc) => {
      this.loading = false;
      this.locked = false;
      throw exc;
    });
  }
  renderModalInner() {
    return x`${this.loading ? x`<ak-loading-overlay ?topMost=${true}></ak-loading-overlay>` : x``}
            <section class="pf-c-modal-box__header pf-c-page__main-section pf-m-light">
                <div class="pf-c-content">
                    <h1 class="pf-c-title pf-m-2xl">
                        <slot name="header"></slot>
                    </h1>
                </div>
            </section>
            <slot name="above-form"></slot>
            <section
                class="pf-c-modal-box__body"
                @scroll=${() => {
      window.dispatchEvent(
        new CustomEvent("scroll", {
          bubbles: true
        })
      );
    }}
            >
                <slot name="form"></slot>
            </section>
            <footer class="pf-c-modal-box__footer">
                ${this.showSubmitButton ? x`<ak-spinner-button
                              .callAction=${() => {
      this.loading = true;
      this.locked = true;
      return this.confirm();
    }}
                              class="pf-m-primary"
                          >
                              <slot name="submit"></slot> </ak-spinner-button
                          >&nbsp;` : x``}
                <ak-spinner-button
                    .callAction=${async () => {
      this.dispatchEvent(new ModalHideEvent(this));
    }}
                    class="pf-m-secondary"
                >
                    ${this.cancelText}
                </ak-spinner-button>
            </footer>`;
  }
};
__decorateClass([
  n({ type: Boolean })
], ModalForm.prototype, "closeAfterSuccessfulSubmit", 2);
__decorateClass([
  n({ type: Boolean })
], ModalForm.prototype, "showSubmitButton", 2);
__decorateClass([
  n({ type: Boolean })
], ModalForm.prototype, "loading", 2);
__decorateClass([
  n({ type: String })
], ModalForm.prototype, "cancelText", 2);
ModalForm = __decorateClass([
  t("ak-forms-modal")
], ModalForm);

// src/elements/forms/HorizontalFormElement.ts
var isAkControl = (el) => el instanceof HTMLElement && "dataset" in el && el.dataset instanceof DOMStringMap && "akControl" in el.dataset;
var nameables = /* @__PURE__ */ new Set([
  "input",
  "textarea",
  "select",
  "ak-codemirror",
  "ak-chip-group",
  "ak-search-select",
  "ak-radio"
]);
var HorizontalFormElement = class extends AKElement {
  constructor() {
    super(...arguments);
    this.label = "";
    this.required = false;
    this.writeOnly = false;
    this.writeOnlyActivated = false;
    this.errorMessages = [];
    this.slugMode = false;
    this._invalid = false;
    this.name = "";
  }
  static get styles() {
    return [
      patternfly_base_default,
      form_default,
      form_control_default,
      i`
                .pf-c-form__group {
                    display: grid;
                    grid-template-columns:
                        var(--pf-c-form--m-horizontal__group-label--md--GridColumnWidth)
                        var(--pf-c-form--m-horizontal__group-control--md--GridColumnWidth);
                }
                .pf-c-form__group-label {
                    padding-top: var(--pf-c-form--m-horizontal__group-label--md--PaddingTop);
                }
            `
    ];
  }
  set invalid(v) {
    this._invalid = v;
    const parent = this.parentElement?.parentElement;
    if (parent && "expanded" in parent) {
      parent.expanded = true;
    }
  }
  get invalid() {
    return this._invalid;
  }
  firstUpdated() {
    this.updated();
  }
  updated() {
    this.querySelectorAll("input[autofocus]").forEach((input) => {
      input.focus();
    });
    if (this.name === "slug" || this.slugMode) {
      this.querySelectorAll("input[type='text']").forEach((input) => {
        input.addEventListener("keyup", () => {
          input.value = convertToSlug(input.value);
        });
      });
    }
    this.querySelectorAll("*").forEach((input) => {
      if (isAkControl(input) && !input.getAttribute("name")) {
        input.setAttribute("name", this.name);
        return;
      }
      if (nameables.has(input.tagName.toLowerCase())) {
        input.setAttribute("name", this.name);
      } else {
        return;
      }
      if (this.writeOnly && !this.writeOnlyActivated) {
        const i2 = input;
        i2.setAttribute("hidden", "true");
        const handler = () => {
          i2.removeAttribute("hidden");
          this.writeOnlyActivated = true;
          i2.parentElement?.removeEventListener("click", handler);
        };
        i2.parentElement?.addEventListener("click", handler);
      }
    });
  }
  render() {
    this.updated();
    return x`<div class="pf-c-form__group">
            <div class="pf-c-form__group-label">
                <label class="pf-c-form__label">
                    <span class="pf-c-form__label-text">${this.label}</span>
                    ${this.required ? x`<span class="pf-c-form__label-required" aria-hidden="true">*</span>` : x``}
                </label>
            </div>
            <div class="pf-c-form__group-control">
                ${this.writeOnly && !this.writeOnlyActivated ? x`<div class="pf-c-form__horizontal-group">
                          <input
                              class="pf-c-form-control"
                              type="password"
                              disabled
                              value="**************"
                          />
                      </div>` : x``}
                <slot class="pf-c-form__horizontal-group"></slot>
                <div class="pf-c-form__horizontal-group">
                    ${this.writeOnly ? x`<p class="pf-c-form__helper-text" aria-live="polite">
                              ${msg("Click to change value")}
                          </p>` : x``}
                    ${this.errorMessages.map((message) => {
      return x`<p class="pf-c-form__helper-text pf-m-error" aria-live="polite">
                            ${message}
                        </p>`;
    })}
                </div>
            </div>
        </div>`;
  }
};
__decorateClass([
  n()
], HorizontalFormElement.prototype, "label", 2);
__decorateClass([
  n({ type: Boolean })
], HorizontalFormElement.prototype, "required", 2);
__decorateClass([
  n({ type: Boolean })
], HorizontalFormElement.prototype, "writeOnly", 2);
__decorateClass([
  n({ type: Boolean })
], HorizontalFormElement.prototype, "writeOnlyActivated", 2);
__decorateClass([
  n({ attribute: false })
], HorizontalFormElement.prototype, "errorMessages", 2);
__decorateClass([
  n({ type: Boolean })
], HorizontalFormElement.prototype, "slugMode", 2);
__decorateClass([
  n({ type: Boolean })
], HorizontalFormElement.prototype, "invalid", 1);
__decorateClass([
  n()
], HorizontalFormElement.prototype, "name", 2);
HorizontalFormElement = __decorateClass([
  t("ak-form-element-horizontal")
], HorizontalFormElement);

// src/elements/forms/helpers.ts
var PreventFormSubmit = class {
  // Stub class which can be returned by form elements to prevent the form from submitting
  constructor(message, element) {
    this.message = message;
    this.element = element;
  }
};

// src/elements/forms/Form.ts
function assignValue(element, value, json) {
  let parent = json;
  if (!element.name?.includes(".")) {
    parent[element.name] = value;
    return;
  }
  const nameElements = element.name.split(".");
  for (let index = 0; index < nameElements.length - 1; index++) {
    const nameEl = nameElements[index];
    if (!(nameEl in parent))
      parent[nameEl] = {};
    parent = parent[nameEl];
  }
  parent[nameElements[nameElements.length - 1]] = value;
}
function serializeForm(elements) {
  const json = {};
  elements.forEach((element) => {
    element.requestUpdate();
    if (element.hidden) {
      return;
    }
    if ("akControl" in element.dataset) {
      assignValue(element, element.json(), json);
      return;
    }
    const inputElement = element.querySelector("[name]");
    if (element.hidden || !inputElement) {
      return;
    }
    if ("akControl" in inputElement.dataset) {
      assignValue(element, inputElement.json(), json);
      return;
    }
    if (element.writeOnly && !element.writeOnlyActivated) {
      return;
    }
    if (inputElement.tagName.toLowerCase() === "select" && "multiple" in inputElement.attributes) {
      const selectElement = inputElement;
      assignValue(
        inputElement,
        Array.from(selectElement.selectedOptions).map((v) => v.value),
        json
      );
    } else if (inputElement.tagName.toLowerCase() === "input" && inputElement.type === "date") {
      assignValue(inputElement, inputElement.valueAsDate, json);
    } else if (inputElement.tagName.toLowerCase() === "input" && inputElement.type === "datetime-local") {
      assignValue(inputElement, dateToUTC(new Date(inputElement.valueAsNumber)), json);
    } else if (inputElement.tagName.toLowerCase() === "input" && "type" in inputElement.dataset && inputElement.dataset["type"] === "datetime-local") {
      assignValue(inputElement, dateToUTC(new Date(inputElement.value)), json);
    } else if (inputElement.tagName.toLowerCase() === "input" && inputElement.type === "checkbox") {
      assignValue(inputElement, inputElement.checked, json);
    } else if ("selectedFlow" in inputElement) {
      assignValue(inputElement, inputElement.value, json);
    } else if (inputElement.tagName.toLowerCase() === "ak-search-select") {
      const select = inputElement;
      try {
        const value = select.toForm();
        assignValue(inputElement, value, json);
      } catch (exc) {
        if (exc instanceof PreventFormSubmit) {
          throw new PreventFormSubmit(exc.message, element);
        }
        throw exc;
      }
    } else {
      assignValue(inputElement, inputElement.value, json);
    }
  });
  return json;
}
var Form = class extends AKElement {
  constructor() {
    super(...arguments);
    this.viewportCheck = true;
    this.successMessage = "";
  }
  static get styles() {
    return [
      patternfly_base_default,
      card_default,
      button_default,
      form_default,
      alert_default,
      input_group_default,
      form_control_default,
      switch_default,
      i`
                select[multiple] {
                    height: 15em;
                }
            `
    ];
  }
  /**
   * Called by the render function. Blocks rendering the form if the form is not within the
   * viewport.
   */
  get isInViewport() {
    const rect = this.getBoundingClientRect();
    return !(rect.x + rect.y + rect.width + rect.height === 0);
  }
  getSuccessMessage() {
    return this.successMessage;
  }
  /**
   * After rendering the form, if there is both a `name` and `slug` element within the form,
   * events the `name` element so that the slug will always have a slugified version of the
   * `name.`. This duplicates functionality within ak-form-element-horizontal.
   */
  updated() {
    this.shadowRoot?.querySelectorAll("ak-form-element-horizontal[name=name]").forEach((nameInput) => {
      const input = nameInput.firstElementChild;
      const form = nameInput.closest("form");
      if (form === null) {
        return;
      }
      const slugFieldWrapper = form.querySelector(
        "ak-form-element-horizontal[name=slug]"
      );
      if (!slugFieldWrapper) {
        return;
      }
      const slugField = slugFieldWrapper.firstElementChild;
      if (convertToSlug(input.value) !== slugField.value) {
        return;
      }
      nameInput.addEventListener("input", () => {
        slugField.value = convertToSlug(input.value);
      });
    });
  }
  resetForm() {
    const form = this.shadowRoot?.querySelector("form");
    form?.reset();
  }
  /**
   * Return the form elements that may contain filenames. Not sure why this is quite so
   * convoluted. There is exactly one case where this is used:
   * `./flow/stages/prompt/PromptStage: 147: case PromptTypeEnum.File.`
   * Consider moving this functionality to there.
   */
  getFormFiles() {
    const files = {};
    const elements = this.shadowRoot?.querySelectorAll(
      "ak-form-element-horizontal"
    ) || [];
    for (let i2 = 0; i2 < elements.length; i2++) {
      const element = elements[i2];
      element.requestUpdate();
      const inputElement = element.querySelector("[name]");
      if (!inputElement) {
        continue;
      }
      if (inputElement.tagName.toLowerCase() === "input" && inputElement.type === "file") {
        if ((inputElement.files || []).length < 1) {
          continue;
        }
        files[element.name] = (inputElement.files || [])[0];
      }
    }
    return files;
  }
  /**
   * Convert the elements of the form to JSON.[4]
   *
   */
  serializeForm() {
    const elements = this.shadowRoot?.querySelectorAll(
      "ak-form-element-horizontal"
    );
    if (!elements) {
      return {};
    }
    return serializeForm(elements);
  }
  /**
   * Serialize and send the form to the destination. The `send()` method must be overridden for
   * this to work. If processing the data results in an error, we catch the error, distribute
   * field-levels errors to the fields, and send the rest of them to the Notifications.
   *
   */
  async submit(ev) {
    ev.preventDefault();
    try {
      const data = this.serializeForm();
      if (!data) {
        return;
      }
      const response = await this.send(data);
      showMessage({
        level: "success" /* success */,
        message: this.getSuccessMessage()
      });
      this.dispatchEvent(
        new CustomEvent(EVENT_REFRESH, {
          bubbles: true,
          composed: true
        })
      );
      return response;
    } catch (ex) {
      if (ex instanceof ResponseError) {
        let msg2 = ex.response.statusText;
        if (ex.response.status > 399 && ex.response.status < 500) {
          const errorMessage = ValidationErrorFromJSON(await ex.response.json());
          if (!errorMessage)
            return errorMessage;
          if (errorMessage instanceof Error) {
            throw errorMessage;
          }
          const elements = this.shadowRoot?.querySelectorAll(
            "ak-form-element-horizontal"
          ) || [];
          elements.forEach((element) => {
            element.requestUpdate();
            const elementName = element.name;
            if (!elementName)
              return;
            if (camelToSnake(elementName) in errorMessage) {
              element.errorMessages = errorMessage[camelToSnake(elementName)];
              element.invalid = true;
            } else {
              element.errorMessages = [];
              element.invalid = false;
            }
          });
          if (errorMessage.nonFieldErrors) {
            this.nonFieldErrors = errorMessage.nonFieldErrors;
          }
          if ("detail" in errorMessage) {
            msg2 = errorMessage.detail;
          }
        }
        showMessage({
          message: msg2,
          level: "error" /* error */
        });
      }
      if (ex instanceof PreventFormSubmit && ex.element) {
        ex.element.errorMessages = [ex.message];
        ex.element.invalid = true;
      }
      throw ex;
    }
  }
  renderFormWrapper() {
    const inline = this.renderForm();
    if (inline) {
      return x`<form
                class="pf-c-form pf-m-horizontal"
                @submit=${(ev) => {
        ev.preventDefault();
      }}
            >
                ${inline}
            </form>`;
    }
    return x`<slot></slot>`;
  }
  renderForm() {
    return void 0;
  }
  renderNonFieldErrors() {
    if (!this.nonFieldErrors) {
      return x``;
    }
    return x`<div class="pf-c-form__alert">
            ${this.nonFieldErrors.map((err) => {
      return x`<div class="pf-c-alert pf-m-inline pf-m-danger">
                    <div class="pf-c-alert__icon">
                        <i class="fas fa-exclamation-circle"></i>
                    </div>
                    <h4 class="pf-c-alert__title">${err}</h4>
                </div>`;
    })}
        </div>`;
  }
  renderVisible() {
    return x` ${this.renderNonFieldErrors()} ${this.renderFormWrapper()}`;
  }
  render() {
    if (this.viewportCheck && !this.isInViewport) {
      return x``;
    }
    return this.renderVisible();
  }
};
__decorateClass([
  n()
], Form.prototype, "successMessage", 2);
__decorateClass([
  r()
], Form.prototype, "nonFieldErrors", 2);
Form = __decorateClass([
  t("ak-form")
], Form);

export {
  PreventFormSubmit,
  serializeForm,
  Form
};
//# sourceMappingURL=chunk-PSPR3SUN.js.map
