import {
  PoliciesApi
} from "./chunk-JSMKLBKU.js";
import {
  ModelForm
} from "./chunk-ZVKXJXN6.js";
import {
  Table,
  TableColumn,
  uiConfig
} from "./chunk-OOB7B3ZK.js";
import {
  o
} from "./chunk-5MMRTU65.js";
import {
  CoreApi,
  DEFAULT_CONFIG,
  content_default,
  first,
  groupBy,
  n,
  r,
  t
} from "./chunk-EOF5OWT7.js";
import {
  msg,
  str,
  x
} from "./chunk-MDYFRBOX.js";
import {
  __decorateClass
} from "./chunk-6IFWU6BM.js";

// src/admin/policies/PolicyBindingForm.ts
var PolicyBindingForm = class extends ModelForm {
  constructor() {
    super(...arguments);
    this.policyGroupUser = "policy" /* policy */;
    this.policyOnly = false;
    this.defaultOrder = 0;
  }
  async loadInstance(pk) {
    const binding = await new PoliciesApi(DEFAULT_CONFIG).policiesBindingsRetrieve({
      policyBindingUuid: pk
    });
    if (binding?.policyObj) {
      this.policyGroupUser = "policy" /* policy */;
    }
    if (binding?.groupObj) {
      this.policyGroupUser = "group" /* group */;
    }
    if (binding?.userObj) {
      this.policyGroupUser = "user" /* user */;
    }
    this.defaultOrder = await this.getOrder();
    return binding;
  }
  getSuccessMessage() {
    if (this.instance?.pk) {
      return msg("Successfully updated binding.");
    } else {
      return msg("Successfully created binding.");
    }
  }
  static get styles() {
    return [...super.styles, content_default];
  }
  send(data) {
    if (this.targetPk) {
      data.target = this.targetPk;
    }
    switch (this.policyGroupUser) {
      case "policy" /* policy */:
        data.user = null;
        data.group = null;
        break;
      case "group" /* group */:
        data.policy = null;
        data.user = null;
        break;
      case "user" /* user */:
        data.policy = null;
        data.group = null;
        break;
    }
    if (this.instance?.pk) {
      return new PoliciesApi(DEFAULT_CONFIG).policiesBindingsUpdate({
        policyBindingUuid: this.instance.pk,
        policyBindingRequest: data
      });
    } else {
      return new PoliciesApi(DEFAULT_CONFIG).policiesBindingsCreate({
        policyBindingRequest: data
      });
    }
  }
  async getOrder() {
    if (this.instance?.pk) {
      return this.instance.order;
    }
    const bindings = await new PoliciesApi(DEFAULT_CONFIG).policiesBindingsList({
      target: this.targetPk || ""
    });
    const orders = bindings.results.map((binding) => binding.order);
    if (orders.length < 1) {
      return 0;
    }
    return Math.max(...orders) + 1;
  }
  renderModeSelector() {
    return x` <ak-toggle-group
            value=${this.policyGroupUser}
            @ak-toggle=${(ev) => {
      this.policyGroupUser = ev.detail.value;
    }}
        >
            <option value=${"policy" /* policy */}>${msg("Policy")}</option>
            <option value=${"group" /* group */}>${msg("Group")}</option>
            <option value=${"user" /* user */}>${msg("User")}</option>
        </ak-toggle-group>`;
  }
  renderForm() {
    return x` <div class="pf-c-card pf-m-selectable pf-m-selected">
                <div class="pf-c-card__body">${this.renderModeSelector()}</div>
                <div class="pf-c-card__footer">
                    <ak-form-element-horizontal
                        label=${msg("Policy")}
                        name="policy"
                        ?hidden=${this.policyGroupUser !== "policy" /* policy */}
                    >
                        <ak-search-select
                            .groupBy=${(items) => {
      return groupBy(items, (policy) => policy.verboseNamePlural);
    }}
                            .fetchObjects=${async (query) => {
      const args = {
        ordering: "name"
      };
      if (query !== void 0) {
        args.search = query;
      }
      const policies = await new PoliciesApi(
        DEFAULT_CONFIG
      ).policiesAllList(args);
      return policies.results;
    }}
                            .renderElement=${(policy) => {
      return policy.name;
    }}
                            .value=${(policy) => {
      return policy?.pk;
    }}
                            .selected=${(policy) => {
      return policy.pk === this.instance?.policy;
    }}
                            ?blankable=${true}
                        >
                        </ak-search-select>
                    </ak-form-element-horizontal>
                    <ak-form-element-horizontal
                        label=${msg("Group")}
                        name="group"
                        ?hidden=${this.policyGroupUser !== "group" /* group */}
                    >
                        <ak-search-select
                            .fetchObjects=${async (query) => {
      const args = {
        ordering: "name"
      };
      if (query !== void 0) {
        args.search = query;
      }
      const groups = await new CoreApi(DEFAULT_CONFIG).coreGroupsList(
        args
      );
      return groups.results;
    }}
                            .renderElement=${(group) => {
      return group.name;
    }}
                            .value=${(group) => {
      return group?.pk;
    }}
                            .selected=${(group) => {
      return group.pk === this.instance?.group;
    }}
                            ?blankable=${true}
                        >
                        </ak-search-select>
                        ${this.policyOnly ? x`<p class="pf-c-form__helper-text">
                                  ${msg(
      "Group mappings can only be checked if a user is already logged in when trying to access this source."
    )}
                              </p>` : x``}
                    </ak-form-element-horizontal>
                    <ak-form-element-horizontal
                        label=${msg("User")}
                        name="user"
                        ?hidden=${this.policyGroupUser !== "user" /* user */}
                    >
                        <ak-search-select
                            .fetchObjects=${async (query) => {
      const args = {
        ordering: "username"
      };
      if (query !== void 0) {
        args.search = query;
      }
      const users = await new CoreApi(DEFAULT_CONFIG).coreUsersList(args);
      return users.results;
    }}
                            .renderElement=${(user) => {
      return user.username;
    }}
                            .renderDescription=${(user) => {
      return x`${user.name}`;
    }}
                            .value=${(user) => {
      return user?.pk;
    }}
                            .selected=${(user) => {
      return user.pk === this.instance?.user;
    }}
                            ?blankable=${true}
                        >
                        </ak-search-select>
                        ${this.policyOnly ? x`<p class="pf-c-form__helper-text">
                                  ${msg(
      "User mappings can only be checked if a user is already logged in when trying to access this source."
    )}
                              </p>` : x``}
                    </ak-form-element-horizontal>
                </div>
            </div>
            <ak-form-element-horizontal name="enabled">
                <label class="pf-c-switch">
                    <input
                        class="pf-c-switch__input"
                        type="checkbox"
                        ?checked=${first(this.instance?.enabled, true)}
                    />
                    <span class="pf-c-switch__toggle">
                        <span class="pf-c-switch__toggle-icon">
                            <i class="fas fa-check" aria-hidden="true"></i>
                        </span>
                    </span>
                    <span class="pf-c-switch__label">${msg("Enabled")}</span>
                </label>
            </ak-form-element-horizontal>
            <ak-form-element-horizontal name="negate">
                <label class="pf-c-switch">
                    <input
                        class="pf-c-switch__input"
                        type="checkbox"
                        ?checked=${first(this.instance?.negate, false)}
                    />
                    <span class="pf-c-switch__toggle">
                        <span class="pf-c-switch__toggle-icon">
                            <i class="fas fa-check" aria-hidden="true"></i>
                        </span>
                    </span>
                    <span class="pf-c-switch__label">${msg("Negate result")}</span>
                </label>
                <p class="pf-c-form__helper-text">
                    ${msg("Negates the outcome of the binding. Messages are unaffected.")}
                </p>
            </ak-form-element-horizontal>
            <ak-form-element-horizontal label=${msg("Order")} ?required=${true} name="order">
                <input
                    type="number"
                    value="${first(this.instance?.order, this.defaultOrder)}"
                    class="pf-c-form-control"
                    required
                />
            </ak-form-element-horizontal>
            <ak-form-element-horizontal label=${msg("Timeout")} ?required=${true} name="timeout">
                <input
                    type="number"
                    value="${first(this.instance?.timeout, 30)}"
                    class="pf-c-form-control"
                    required
                />
            </ak-form-element-horizontal>
            <ak-form-element-horizontal name="failureResult" label=${msg("Failure result")}>
                <ak-radio
                    .options=${[
      {
        label: msg("Pass"),
        value: true
      },
      {
        label: msg("Don't pass"),
        value: false,
        default: true
      }
    ]}
                    .value=${this.instance?.failureResult}
                >
                </ak-radio>
                <p class="pf-c-form__helper-text">
                    ${msg("Result used when policy execution fails.")}
                </p>
            </ak-form-element-horizontal>`;
  }
};
__decorateClass([
  n()
], PolicyBindingForm.prototype, "targetPk", 2);
__decorateClass([
  r()
], PolicyBindingForm.prototype, "policyGroupUser", 2);
__decorateClass([
  n({ type: Boolean })
], PolicyBindingForm.prototype, "policyOnly", 2);
__decorateClass([
  r()
], PolicyBindingForm.prototype, "defaultOrder", 2);
PolicyBindingForm = __decorateClass([
  t("ak-policy-binding-form")
], PolicyBindingForm);

// src/admin/policies/BoundPoliciesList.ts
var BoundPoliciesList = class extends Table {
  constructor() {
    super(...arguments);
    this.policyOnly = false;
    this.checkbox = true;
    this.clearOnRefresh = true;
    this.order = "order";
  }
  async apiEndpoint(page) {
    return new PoliciesApi(DEFAULT_CONFIG).policiesBindingsList({
      target: this.target || "",
      ordering: this.order,
      page,
      pageSize: (await uiConfig()).pagination.perPage
    });
  }
  columns() {
    return [
      new TableColumn(msg("Order"), "order"),
      new TableColumn(msg("Policy / User / Group")),
      new TableColumn(msg("Enabled"), "enabled"),
      new TableColumn(msg("Timeout"), "timeout"),
      new TableColumn(msg("Actions"))
    ];
  }
  getPolicyUserGroupRowLabel(item) {
    if (item.policy) {
      return msg(str`Policy ${item.policyObj?.name}`);
    } else if (item.group) {
      return msg(str`Group ${item.groupObj?.name}`);
    } else if (item.user) {
      return msg(str`User ${item.userObj?.name}`);
    } else {
      return msg("-");
    }
  }
  getPolicyUserGroupRow(item) {
    const label = this.getPolicyUserGroupRowLabel(item);
    if (item.user) {
      return x` <a href=${`#/identity/users/${item.user}`}> ${label} </a> `;
    }
    if (item.group) {
      return x` <a href=${`#/identity/groups/${item.group}`}> ${label} </a> `;
    }
    return x`${label}`;
  }
  getObjectEditButton(item) {
    if (item.policy) {
      return x`<ak-forms-modal>
                <span slot="submit"> ${msg("Update")} </span>
                <span slot="header"> ${msg(str`Update ${item.policyObj?.name}`)} </span>
                <ak-proxy-form
                    slot="form"
                    .args=${{
        instancePk: item.policyObj?.pk
      }}
                    type=${o(item.policyObj?.component)}
                >
                </ak-proxy-form>
                <button slot="trigger" class="pf-c-button pf-m-secondary">
                    ${msg("Edit Policy")}
                </button>
            </ak-forms-modal>`;
    } else if (item.group) {
      return x`<ak-forms-modal>
                <span slot="submit"> ${msg("Update")} </span>
                <span slot="header"> ${msg("Update Group")} </span>
                <ak-group-form slot="form" .instancePk=${item.groupObj?.pk}> </ak-group-form>
                <button slot="trigger" class="pf-c-button pf-m-secondary">
                    ${msg("Edit Group")}
                </button>
            </ak-forms-modal>`;
    } else if (item.user) {
      return x`<ak-forms-modal>
                <span slot="submit"> ${msg("Update")} </span>
                <span slot="header"> ${msg("Update User")} </span>
                <ak-user-form slot="form" .instancePk=${item.userObj?.pk}> </ak-user-form>
                <button slot="trigger" class="pf-c-button pf-m-secondary">
                    ${msg("Edit User")}
                </button>
            </ak-forms-modal>`;
    } else {
      return x``;
    }
  }
  renderToolbarSelected() {
    const disabled = this.selectedElements.length < 1;
    return x`<ak-forms-delete-bulk
            objectLabel=${msg("Policy binding(s)")}
            .objects=${this.selectedElements}
            .metadata=${(item) => {
      return [
        { key: msg("Order"), value: item.order.toString() },
        {
          key: msg("Policy / User / Group"),
          value: this.getPolicyUserGroupRowLabel(item)
        }
      ];
    }}
            .usedBy=${(item) => {
      return new PoliciesApi(DEFAULT_CONFIG).policiesBindingsUsedByList({
        policyBindingUuid: item.pk
      });
    }}
            .delete=${(item) => {
      return new PoliciesApi(DEFAULT_CONFIG).policiesBindingsDestroy({
        policyBindingUuid: item.pk
      });
    }}
        >
            <button ?disabled=${disabled} slot="trigger" class="pf-c-button pf-m-danger">
                ${msg("Delete")}
            </button>
        </ak-forms-delete-bulk>`;
  }
  row(item) {
    return [
      x`<pre>${item.order}</pre>`,
      x`${this.getPolicyUserGroupRow(item)}`,
      x`<ak-status-label type="warning" ?good=${item.enabled}></ak-status-label>`,
      x`${item.timeout}`,
      x` ${this.getObjectEditButton(item)}
                <ak-forms-modal size=${"pf-m-md" /* Medium */}>
                    <span slot="submit"> ${msg("Update")} </span>
                    <span slot="header"> ${msg("Update Binding")} </span>
                    <ak-policy-binding-form
                        slot="form"
                        .instancePk=${item.pk}
                        targetPk=${o(this.target)}
                        ?policyOnly=${this.policyOnly}
                    >
                    </ak-policy-binding-form>
                    <button slot="trigger" class="pf-c-button pf-m-secondary">
                        ${msg("Edit Binding")}
                    </button>
                </ak-forms-modal>`
    ];
  }
  renderEmpty() {
    return super.renderEmpty(
      x`<ak-empty-state header=${msg("No Policies bound.")} icon="pf-icon-module">
                <div slot="body">${msg("No policies are currently bound to this object.")}</div>
                <div slot="primary">
                    <ak-forms-modal size=${"pf-m-md" /* Medium */}>
                        <span slot="submit"> ${msg("Create")} </span>
                        <span slot="header"> ${msg("Create Binding")} </span>
                        <ak-policy-binding-form
                            slot="form"
                            targetPk=${o(this.target)}
                            ?policyOnly=${this.policyOnly}
                        >
                        </ak-policy-binding-form>
                        <button slot="trigger" class="pf-c-button pf-m-primary">
                            ${msg("Create Binding")}
                        </button>
                    </ak-forms-modal>
                </div>
            </ak-empty-state>`
    );
  }
  renderToolbar() {
    return x`<ak-policy-wizard
                createText=${msg("Create and bind Policy")}
                ?showBindingPage=${true}
                bindingTarget=${o(this.target)}
            ></ak-policy-wizard>
            <ak-forms-modal size=${"pf-m-md" /* Medium */}>
                <span slot="submit"> ${msg("Create")} </span>
                <span slot="header"> ${msg("Create Binding")} </span>
                <ak-policy-binding-form
                    slot="form"
                    targetPk=${o(this.target)}
                    ?policyOnly=${this.policyOnly}
                >
                </ak-policy-binding-form>
                <button slot="trigger" class="pf-c-button pf-m-primary">
                    ${msg("Bind existing policy")}
                </button>
            </ak-forms-modal> `;
  }
};
__decorateClass([
  n()
], BoundPoliciesList.prototype, "target", 2);
__decorateClass([
  n({ type: Boolean })
], BoundPoliciesList.prototype, "policyOnly", 2);
BoundPoliciesList = __decorateClass([
  t("ak-bound-policies-list")
], BoundPoliciesList);
//# sourceMappingURL=chunk-RYAWZLUH.js.map
