import {
  progress_stepper_default,
  wizard_default
} from "./chunk-KANCX4AI.js";
import {
  ModalButton
} from "./chunk-GOIBY4UW.js";
import {
  bullseye_default
} from "./chunk-OOB7B3ZK.js";
import {
  empty_state_default,
  title_default
} from "./chunk-5MMRTU65.js";
import {
  AKElement,
  EVENT_REFRESH,
  ResponseError,
  n,
  patternfly_base_default,
  r,
  t
} from "./chunk-EOF5OWT7.js";
import {
  msg,
  x
} from "./chunk-MDYFRBOX.js";
import {
  __decorateClass
} from "./chunk-6IFWU6BM.js";

// src/elements/wizard/WizardPage.ts
var WizardPage = class extends AKElement {
  constructor() {
    super(...arguments);
    this.sidebarLabel = () => {
      return "UNNAMED";
    };
    /**
     * Called when this is the page brought into view
     */
    this.activeCallback = async () => {
      this.host.isValid = false;
    };
    /**
     * Called when the `next` button on the wizard is pressed. For forms, results in the submission
     * of the current form to the back-end before being allowed to proceed to the next page. This is
     * sub-optimal if we want to collect multiple bits of data before finishing the whole course.
     */
    this.nextCallback = async () => {
      return true;
    };
  }
  static get styles() {
    return [patternfly_base_default];
  }
  get host() {
    return this.parentElement;
  }
  requestUpdate(name, oldValue, options) {
    this.querySelectorAll("*").forEach((el) => {
      if ("requestUpdate" in el) {
        el.requestUpdate();
      }
    });
    return super.requestUpdate(name, oldValue, options);
  }
  render() {
    return x`<slot></slot>`;
  }
};
__decorateClass([
  n()
], WizardPage.prototype, "sidebarLabel", 2);
WizardPage = __decorateClass([
  t("ak-wizard-page")
], WizardPage);

// src/elements/wizard/FormWizardPage.ts
var FormWizardPage = class extends WizardPage {
  constructor() {
    super(...arguments);
    this.activePageCallback = async () => {
      return Promise.resolve();
    };
    this.activeCallback = async () => {
      this.host.isValid = true;
      this.activePageCallback(this);
    };
    this.nextCallback = async () => {
      const form = this.querySelector("*");
      if (!form) {
        return Promise.reject(msg("No form found"));
      }
      const formPromise = form.submit(new Event("submit"));
      if (!formPromise) {
        return Promise.reject(msg("Form didn't return a promise for submitting"));
      }
      return formPromise.then((data) => {
        this.host.state[this.slot] = data;
        this.host.canBack = false;
        return true;
      }).catch(() => {
        return false;
      });
    };
  }
};
FormWizardPage = __decorateClass([
  t("ak-wizard-page-form")
], FormWizardPage);

// src/elements/wizard/ActionWizardPage.ts
var ActionWizardPage = class extends WizardPage {
  constructor() {
    super(...arguments);
    this.states = [];
    this.activeCallback = async () => {
      this.states = [];
      this.host.actions.map((act, idx) => {
        this.states.push({
          action: act,
          state: "pending" /* pending */,
          idx
        });
      });
      this.host.canBack = false;
      this.host.canCancel = false;
      await this.run();
      this.host.isValid = true;
    };
    this.sidebarLabel = () => msg("Apply changes");
  }
  static get styles() {
    return [patternfly_base_default, bullseye_default, empty_state_default, title_default, progress_stepper_default];
  }
  async run() {
    this.currentStep = this.states[0];
    await new Promise((r2) => setTimeout(r2, 500));
    for await (const bundle of this.states) {
      this.currentStep = bundle;
      this.currentStep.state = "running" /* running */;
      this.requestUpdate();
      try {
        await bundle.action.run();
        await new Promise((r2) => setTimeout(r2, 500));
        this.currentStep.state = "done" /* done */;
        this.requestUpdate();
      } catch (exc) {
        if (exc instanceof ResponseError) {
          this.currentStep.action.subText = await exc.response.text();
        } else {
          this.currentStep.action.subText = exc.toString();
        }
        this.currentStep.state = "failed" /* failed */;
        this.requestUpdate();
        return;
      }
    }
    this.host.isValid = true;
    this.dispatchEvent(
      new CustomEvent(EVENT_REFRESH, {
        bubbles: true,
        composed: true
      })
    );
  }
  render() {
    return x`<div class="pf-l-bullseye">
            <div class="pf-c-empty-state pf-m-lg">
                <div class="pf-c-empty-state__content">
                    <i class="fas fa- fa-cogs pf-c-empty-state__icon" aria-hidden="true"></i>
                    <h1 class="pf-c-title pf-m-lg">${this.currentStep?.action.displayName}</h1>
                    <div class="pf-c-empty-state__body">
                        <ol class="pf-c-progress-stepper pf-m-vertical">
                            ${this.states.map((state) => {
      let cls = "";
      switch (state.state) {
        case "pending" /* pending */:
          cls = "pf-m-pending";
          break;
        case "done" /* done */:
          cls = "pf-m-success";
          break;
        case "running" /* running */:
          cls = "pf-m-info";
          break;
        case "failed" /* failed */:
          cls = "pf-m-danger";
          break;
      }
      if (state.idx === this.currentStep?.idx) {
        cls += " pf-m-current";
      }
      return x` <li class="pf-c-progress-stepper__step ${cls}">
                                    <div class="pf-c-progress-stepper__step-connector">
                                        <span class="pf-c-progress-stepper__step-icon">
                                            <i class="fas fa-check-circle" aria-hidden="true"></i>
                                        </span>
                                    </div>
                                    <div class="pf-c-progress-stepper__step-main">
                                        <div class="pf-c-progress-stepper__step-title">
                                            ${state.action.displayName}
                                        </div>
                                        ${state.action.subText ? x`<div
                                                  class="pf-c-progress-stepper__step-description"
                                              >
                                                  ${state.action.subText}
                                              </div>` : x``}
                                    </div>
                                </li>`;
    })}
                        </ol>
                    </div>
                </div>
            </div>
        </div>`;
  }
};
__decorateClass([
  n({ attribute: false })
], ActionWizardPage.prototype, "states", 2);
__decorateClass([
  n({ attribute: false })
], ActionWizardPage.prototype, "currentStep", 2);
ActionWizardPage = __decorateClass([
  t("ak-wizard-page-action")
], ActionWizardPage);

// src/elements/wizard/Wizard.ts
var ApplyActionsSlot = "apply-actions";
var Wizard = class extends ModalButton {
  constructor() {
    super(...arguments);
    this.canCancel = true;
    this.canBack = true;
    this.isValid = false;
    this._steps = [];
    this._initialSteps = [];
    this.actions = [];
    this.finalHandler = () => {
      return Promise.resolve();
    };
    this.state = {};
  }
  static get styles() {
    return super.styles.concat(wizard_default);
  }
  get steps() {
    return this._steps;
  }
  set steps(steps) {
    const addApplyActionsSlot = this.steps.includes(ApplyActionsSlot);
    this._steps = steps;
    if (addApplyActionsSlot) {
      this.steps.push(ApplyActionsSlot);
    }
    this.steps.forEach((step) => {
      const exists = this.querySelector(`[slot=${step}]`) !== null;
      if (!exists) {
        const el = document.createElement(step);
        el.slot = step;
        el.dataset["wizardmanaged"] = "true";
        this.appendChild(el);
      }
    });
    this.requestUpdate();
  }
  set currentStep(value) {
    this._currentStep = value;
    if (this._currentStep) {
      this._currentStep.activeCallback();
      this._currentStep.requestUpdate();
    }
  }
  get currentStep() {
    return this._currentStep;
  }
  firstUpdated() {
    this._initialSteps = this._steps;
  }
  /**
   * Add action to the beginning of the list
   */
  addActionBefore(displayName, run) {
    this.actions.unshift({
      displayName,
      run
    });
  }
  /**
   * Add action at the end of the list
   */
  addActionAfter(displayName, run) {
    this.actions.push({
      displayName,
      run
    });
  }
  renderModalInner() {
    const firstPage = this.querySelector(`[slot=${this.steps[0]}]`);
    if (!this.currentStep && firstPage) {
      this.currentStep = firstPage;
    }
    const currentIndex = this.currentStep ? this.steps.indexOf(this.currentStep.slot) : 0;
    let lastPage = currentIndex === this.steps.length - 1;
    if (lastPage && !this.steps.includes("ak-wizard-page-action") && this.actions.length > 0) {
      this.steps = this.steps.concat("ak-wizard-page-action");
      lastPage = currentIndex === this.steps.length - 1;
    }
    return x`<div class="pf-c-wizard">
            <div class="pf-c-wizard__header">
                ${this.canCancel ? x`<button
                          class="pf-c-button pf-m-plain pf-c-wizard__close"
                          type="button"
                          aria-label="${msg("Close")}"
                          @click=${() => {
      this.reset();
    }}
                      >
                          <i class="fas fa-times" aria-hidden="true"></i>
                      </button>` : x``}
                <h1 class="pf-c-title pf-m-3xl pf-c-wizard__title">${this.header}</h1>
                <p class="pf-c-wizard__description">${this.description}</p>
            </div>
            <div class="pf-c-wizard__outer-wrap">
                <div class="pf-c-wizard__inner-wrap">
                    <nav class="pf-c-wizard__nav">
                        <ol class="pf-c-wizard__nav-list">
                            ${this.steps.map((step, idx) => {
      const currentIdx = this.currentStep ? this.steps.indexOf(this.currentStep.slot) : 0;
      return x`
                                    <li class="pf-c-wizard__nav-item">
                                        <button
                                            class="pf-c-wizard__nav-link ${idx === currentIdx ? "pf-m-current" : ""}"
                                            ?disabled=${currentIdx < idx}
                                            @click=${() => {
        const stepEl = this.querySelector(
          `[slot=${step}]`
        );
        if (stepEl) {
          this.currentStep = stepEl;
        }
      }}
                                        >
                                            ${this.querySelector(
        `[slot=${step}]`
      )?.sidebarLabel()}
                                        </button>
                                    </li>
                                `;
    })}
                        </ol>
                    </nav>
                    <main class="pf-c-wizard__main">
                        <div class="pf-c-wizard__main-body">
                            <slot name=${this.currentStep?.slot || this.steps[0]}></slot>
                        </div>
                    </main>
                </div>
                <footer class="pf-c-wizard__footer">
                    <button
                        class="pf-c-button pf-m-primary"
                        type="submit"
                        ?disabled=${!this.isValid}
                        @click=${async () => {
      const cb = await this.currentStep?.nextCallback();
      if (!cb) {
        return;
      }
      if (lastPage) {
        await this.finalHandler();
        this.reset();
      } else {
        const nextPage = this.querySelector(
          `[slot=${this.steps[currentIndex + 1]}]`
        );
        if (nextPage) {
          this.currentStep = nextPage;
        }
      }
    }}
                    >
                        ${lastPage ? msg("Finish") : msg("Next")}
                    </button>
                    ${(this.currentStep ? this.steps.indexOf(this.currentStep.slot) : 0) > 0 && this.canBack ? x`
                              <button
                                  class="pf-c-button pf-m-secondary"
                                  type="button"
                                  @click=${() => {
      const prevPage = this.querySelector(
        `[slot=${this.steps[currentIndex - 1]}]`
      );
      if (prevPage) {
        this.currentStep = prevPage;
      }
    }}
                              >
                                  ${msg("Back")}
                              </button>
                          ` : x``}
                    ${this.canCancel ? x`<div class="pf-c-wizard__footer-cancel">
                              <button
                                  class="pf-c-button pf-m-link"
                                  type="button"
                                  @click=${() => {
      this.reset();
    }}
                              >
                                  ${msg("Cancel")}
                              </button>
                          </div>` : x``}
                </footer>
            </div>
        </div>`;
  }
  reset() {
    this.open = false;
    this.querySelectorAll("[data-wizardmanaged=true]").forEach((el) => {
      el.remove();
    });
    this.steps = this._initialSteps;
    this.actions = [];
    this.state = {};
    this.currentStep = void 0;
    this.canBack = true;
    this.canCancel = true;
  }
};
__decorateClass([
  n({ type: Boolean })
], Wizard.prototype, "canCancel", 2);
__decorateClass([
  n({ type: Boolean })
], Wizard.prototype, "canBack", 2);
__decorateClass([
  n()
], Wizard.prototype, "header", 2);
__decorateClass([
  n()
], Wizard.prototype, "description", 2);
__decorateClass([
  n({ type: Boolean })
], Wizard.prototype, "isValid", 2);
__decorateClass([
  r()
], Wizard.prototype, "_steps", 2);
__decorateClass([
  n({ attribute: false })
], Wizard.prototype, "actions", 2);
__decorateClass([
  r()
], Wizard.prototype, "_currentStep", 2);
__decorateClass([
  n({ attribute: false })
], Wizard.prototype, "finalHandler", 2);
__decorateClass([
  n({ attribute: false })
], Wizard.prototype, "state", 2);
Wizard = __decorateClass([
  t("ak-wizard")
], Wizard);

export {
  WizardPage
};
//# sourceMappingURL=chunk-WGDMKZIG.js.map
