import {
  EventUser
} from "./chunk-YNQN4LE7.js";
import {
  actionToLabel
} from "./chunk-BEFPUR3G.js";
import {
  Form
} from "./chunk-PSPR3SUN.js";
import {
  Table,
  TableColumn,
  uiConfig
} from "./chunk-OOB7B3ZK.js";
import {
  o
} from "./chunk-5MMRTU65.js";
import {
  CoreApi,
  DEFAULT_CONFIG,
  EventsApi,
  getRelativeTime,
  n,
  r,
  t
} from "./chunk-EOF5OWT7.js";
import {
  msg,
  str,
  x
} from "./chunk-MDYFRBOX.js";
import {
  __decorateClass
} from "./chunk-6IFWU6BM.js";

// src/admin/groups/RelatedGroupList.ts
var RelatedGroupAdd = class extends Form {
  constructor() {
    super(...arguments);
    this.groupsToAdd = [];
  }
  getSuccessMessage() {
    return msg("Successfully added user to group(s).");
  }
  async send(data) {
    await Promise.all(
      data.groups.map((group) => {
        return new CoreApi(DEFAULT_CONFIG).coreGroupsAddUserCreate({
          groupUuid: group,
          userAccountRequest: {
            pk: this.user?.pk || 0
          }
        });
      })
    );
    return data;
  }
  renderForm() {
    return x`<ak-form-element-horizontal label=${msg("Groups to add")} name="groups">
            <div class="pf-c-input-group">
                <ak-user-group-select-table
                    .confirm=${(items) => {
      this.groupsToAdd = items;
      this.requestUpdate();
      return Promise.resolve();
    }}
                >
                    <button slot="trigger" class="pf-c-button pf-m-control" type="button">
                        <pf-tooltip position="top" content=${msg("Add group")}>
                            <i class="fas fa-plus" aria-hidden="true"></i>
                        </pf-tooltip>
                    </button>
                </ak-user-group-select-table>
                <div class="pf-c-form-control">
                    <ak-chip-group>
                        ${this.groupsToAdd.map((group) => {
      return x`<ak-chip
                                .removable=${true}
                                value=${o(group.pk)}
                                @remove=${() => {
        const idx = this.groupsToAdd.indexOf(group);
        this.groupsToAdd.splice(idx, 1);
        this.requestUpdate();
      }}
                            >
                                ${group.name}
                            </ak-chip>`;
    })}
                    </ak-chip-group>
                </div>
            </div>
        </ak-form-element-horizontal>`;
  }
};
__decorateClass([
  n({ attribute: false })
], RelatedGroupAdd.prototype, "user", 2);
__decorateClass([
  r()
], RelatedGroupAdd.prototype, "groupsToAdd", 2);
RelatedGroupAdd = __decorateClass([
  t("ak-group-related-add")
], RelatedGroupAdd);
var RelatedGroupList = class extends Table {
  constructor() {
    super(...arguments);
    this.checkbox = true;
    this.clearOnRefresh = true;
    this.order = "name";
  }
  searchEnabled() {
    return true;
  }
  async apiEndpoint(page) {
    return new CoreApi(DEFAULT_CONFIG).coreGroupsList({
      ordering: this.order,
      page,
      pageSize: (await uiConfig()).pagination.perPage,
      search: this.search || "",
      membersByPk: this.targetUser ? [this.targetUser.pk] : [],
      includeUsers: false
    });
  }
  columns() {
    return [
      new TableColumn(msg("Name"), "name"),
      new TableColumn(msg("Parent"), "parent"),
      new TableColumn(msg("Superuser privileges?")),
      new TableColumn(msg("Actions"))
    ];
  }
  renderToolbarSelected() {
    const disabled = this.selectedElements.length < 1;
    return x`<ak-forms-delete-bulk
            objectLabel=${msg("Group(s)")}
            actionLabel=${msg("Remove from Group(s)")}
            actionSubtext=${msg(
      str`Are you sure you want to remove user ${this.targetUser?.username} from the following groups?`
    )}
            buttonLabel=${msg("Remove")}
            .objects=${this.selectedElements}
            .delete=${(item) => {
      if (!this.targetUser)
        return;
      return new CoreApi(DEFAULT_CONFIG).coreGroupsRemoveUserCreate({
        groupUuid: item.pk,
        userAccountRequest: {
          pk: this.targetUser?.pk || 0
        }
      });
    }}
        >
            <button ?disabled=${disabled} slot="trigger" class="pf-c-button pf-m-danger">
                ${msg("Remove")}
            </button>
        </ak-forms-delete-bulk>`;
  }
  row(item) {
    return [
      x`<a href="#/identity/groups/${item.pk}">${item.name}</a>`,
      x`${item.parentName || msg("-")}`,
      x`<ak-label type="info" ?good=${item.isSuperuser}></ak-label>`,
      x` <ak-forms-modal>
                <span slot="submit"> ${msg("Update")} </span>
                <span slot="header"> ${msg("Update Group")} </span>
                <ak-group-form slot="form" .instancePk=${item.pk}> </ak-group-form>
                <button slot="trigger" class="pf-c-button pf-m-plain">
                    <pf-tooltip position="top" content=${msg("Edit")}>
                        <i class="fas fa-edit"></i>
                    </pf-tooltip>
                </button>
            </ak-forms-modal>`
    ];
  }
  renderToolbar() {
    return x`
            ${this.targetUser ? x`<ak-forms-modal>
                      <span slot="submit"> ${msg("Add")} </span>
                      <span slot="header"> ${msg("Add Group")} </span>
                      <ak-group-related-add .user=${this.targetUser} slot="form">
                      </ak-group-related-add>
                      <button slot="trigger" class="pf-c-button pf-m-primary">
                          ${msg("Add to existing group")}
                      </button>
                  </ak-forms-modal>` : x``}
            <ak-forms-modal>
                <span slot="submit"> ${msg("Create")} </span>
                <span slot="header"> ${msg("Create Group")} </span>
                <ak-group-form slot="form"> </ak-group-form>
                <button slot="trigger" class="pf-c-button pf-m-secondary">
                    ${msg("Add new group")}
                </button>
            </ak-forms-modal>
            ${super.renderToolbar()}
        `;
  }
};
__decorateClass([
  n()
], RelatedGroupList.prototype, "order", 2);
__decorateClass([
  n({ attribute: false })
], RelatedGroupList.prototype, "targetUser", 2);
RelatedGroupList = __decorateClass([
  t("ak-group-related-list")
], RelatedGroupList);

// src/components/events/UserEvents.ts
var UserEvents = class extends Table {
  constructor() {
    super(...arguments);
    this.expandable = true;
    this.order = "-created";
  }
  async apiEndpoint(page) {
    return new EventsApi(DEFAULT_CONFIG).eventsEventsList({
      page,
      ordering: this.order,
      pageSize: (await uiConfig()).pagination.perPage,
      username: this.targetUser
    });
  }
  columns() {
    return [
      new TableColumn(msg("Action"), "action"),
      new TableColumn(msg("User"), "enabled"),
      new TableColumn(msg("Creation Date"), "created"),
      new TableColumn(msg("Client IP"), "client_ip")
    ];
  }
  row(item) {
    return [
      x`${actionToLabel(item.action)}`,
      EventUser(item),
      x`<div>${getRelativeTime(item.created)}</div>
                <small>${item.created.toLocaleString()}</small>`,
      x`<span>${item.clientIp || msg("-")}</span>`
    ];
  }
  renderExpanded(item) {
    return x` <td role="cell" colspan="4">
                <div class="pf-c-table__expandable-row-content">
                    <ak-event-info .event=${item}></ak-event-info>
                </div>
            </td>
            <td></td>
            <td></td>
            <td></td>`;
  }
  renderEmpty() {
    return super.renderEmpty(
      x`<ak-empty-state header=${msg("No Events found.")}>
                <div slot="body">${msg("No matching events could be found.")}</div>
            </ak-empty-state>`
    );
  }
};
__decorateClass([
  n()
], UserEvents.prototype, "order", 2);
__decorateClass([
  n()
], UserEvents.prototype, "targetUser", 2);
UserEvents = __decorateClass([
  t("ak-events-user")
], UserEvents);
//# sourceMappingURL=chunk-Z4SZIGNK.js.map
