import {
  PlexAPIClient,
  popupCenterScreen
} from "./chunk-CQKVQBLB.js";
import {
  PropertymappingsApi
} from "./chunk-G6FYWANS.js";
import {
  FlowSearch_default
} from "./chunk-JMBXTRNL.js";
import {
  iconHelperText,
  placeholderHelperText
} from "./chunk-2XSPVNET.js";
import {
  ModelForm
} from "./chunk-ZVKXJXN6.js";
import {
  BindingTypeEnum,
  NameIdPolicyEnum,
  ProviderTypeEnum,
  SourcesApi,
  UserMatchingModeEnum
} from "./chunk-XSB422CX.js";
import {
  WithCapabilitiesConfig
} from "./chunk-3CKWSC2S.js";
import {
  FlowsInstancesListDesignationEnum
} from "./chunk-2G3GM457.js";
import {
  o
} from "./chunk-5MMRTU65.js";
import {
  CapabilitiesEnum,
  CoreApi,
  DEFAULT_CONFIG,
  DigestAlgorithmEnum,
  SignatureAlgorithmEnum,
  ascii_letters,
  config,
  digits,
  first,
  n,
  r,
  randomString,
  t
} from "./chunk-EOF5OWT7.js";
import {
  msg,
  x
} from "./chunk-MDYFRBOX.js";
import {
  __decorateClass
} from "./chunk-6IFWU6BM.js";

// src/admin/sources/BaseSourceForm.ts
var BaseSourceForm = class extends ModelForm {
  getSuccessMessage() {
    return this.instance ? msg("Successfully updated source.") : msg("Successfully created source.");
  }
};

// src/admin/sources/ldap/LDAPSourceForm.ts
var LDAPSourceForm = class extends BaseSourceForm {
  loadInstance(pk) {
    return new SourcesApi(DEFAULT_CONFIG).sourcesLdapRetrieve({
      slug: pk
    });
  }
  async load() {
    this.propertyMappings = await new PropertymappingsApi(
      DEFAULT_CONFIG
    ).propertymappingsLdapList({
      ordering: "managed,object_field"
    });
  }
  async send(data) {
    if (this.instance) {
      return new SourcesApi(DEFAULT_CONFIG).sourcesLdapPartialUpdate({
        slug: this.instance.slug,
        patchedLDAPSourceRequest: data
      });
    } else {
      return new SourcesApi(DEFAULT_CONFIG).sourcesLdapCreate({
        lDAPSourceRequest: data
      });
    }
  }
  renderForm() {
    return x` <ak-form-element-horizontal label=${msg("Name")} ?required=${true} name="name">
                <input
                    type="text"
                    value="${o(this.instance?.name)}"
                    class="pf-c-form-control"
                    required
                />
            </ak-form-element-horizontal>
            <ak-form-element-horizontal label=${msg("Slug")} ?required=${true} name="slug">
                <input
                    type="text"
                    value="${o(this.instance?.slug)}"
                    class="pf-c-form-control"
                    required
                />
            </ak-form-element-horizontal>
            <ak-form-element-horizontal name="enabled">
                <label class="pf-c-switch">
                    <input
                        class="pf-c-switch__input"
                        type="checkbox"
                        ?checked=${first(this.instance?.enabled, true)}
                    />
                    <span class="pf-c-switch__toggle">
                        <span class="pf-c-switch__toggle-icon">
                            <i class="fas fa-check" aria-hidden="true"></i>
                        </span>
                    </span>
                    <span class="pf-c-switch__label">${msg("Enabled")}</span>
                </label>
            </ak-form-element-horizontal>
            <ak-form-element-horizontal name="passwordLoginUpdateInternalPassword">
                <label class="pf-c-switch">
                    <input
                        class="pf-c-switch__input"
                        type="checkbox"
                        ?checked=${first(this.instance?.passwordLoginUpdateInternalPassword, false)}
                    />
                    <span class="pf-c-switch__toggle">
                        <span class="pf-c-switch__toggle-icon">
                            <i class="fas fa-check" aria-hidden="true"></i>
                        </span>
                    </span>
                    <span class="pf-c-switch__label"
                        >${msg("Update internal password on login")}</span
                    >
                </label>
                <p class="pf-c-form__helper-text">
                    ${msg(
      "When the user logs in to authentik using this source password backend, update their credentials in authentik."
    )}
                </p>
            </ak-form-element-horizontal>
            <ak-form-element-horizontal name="syncUsers">
                <label class="pf-c-switch">
                    <input
                        class="pf-c-switch__input"
                        type="checkbox"
                        ?checked=${first(this.instance?.syncUsers, true)}
                    />
                    <span class="pf-c-switch__toggle">
                        <span class="pf-c-switch__toggle-icon">
                            <i class="fas fa-check" aria-hidden="true"></i>
                        </span>
                    </span>
                    <span class="pf-c-switch__label">${msg("Sync users")}</span>
                </label>
            </ak-form-element-horizontal>
            <ak-form-element-horizontal name="syncUsersPassword">
                <label class="pf-c-switch">
                    <input
                        class="pf-c-switch__input"
                        type="checkbox"
                        ?checked=${first(this.instance?.syncUsersPassword, true)}
                    />
                    <span class="pf-c-switch__toggle">
                        <span class="pf-c-switch__toggle-icon">
                            <i class="fas fa-check" aria-hidden="true"></i>
                        </span>
                    </span>
                    <span class="pf-c-switch__label">${msg("User password writeback")}</span>
                </label>
                <p class="pf-c-form__helper-text">
                    ${msg(
      "Login password is synced from LDAP into authentik automatically. Enable this option only to write password changes in authentik back to LDAP."
    )}
                </p>
            </ak-form-element-horizontal>
            <ak-form-element-horizontal name="syncGroups">
                <label class="pf-c-switch">
                    <input
                        class="pf-c-switch__input"
                        type="checkbox"
                        ?checked=${first(this.instance?.syncGroups, true)}
                    />
                    <span class="pf-c-switch__toggle">
                        <span class="pf-c-switch__toggle-icon">
                            <i class="fas fa-check" aria-hidden="true"></i>
                        </span>
                    </span>
                    <span class="pf-c-switch__label">${msg("Sync groups")}</span>
                </label>
            </ak-form-element-horizontal>
            <ak-form-group .expanded=${true}>
                <span slot="header"> ${msg("Connection settings")} </span>
                <div slot="body" class="pf-c-form">
                    <ak-form-element-horizontal
                        label=${msg("Server URI")}
                        ?required=${true}
                        name="serverUri"
                    >
                        <input
                            type="text"
                            placeholder="ldap://1.2.3.4"
                            value="${o(this.instance?.serverUri)}"
                            class="pf-c-form-control"
                            required
                        />
                        <p class="pf-c-form__helper-text">
                            ${msg("Specify multiple server URIs by separating them with a comma.")}
                        </p>
                    </ak-form-element-horizontal>
                    <ak-form-element-horizontal name="startTls">
                        <label class="pf-c-switch">
                            <input
                                class="pf-c-switch__input"
                                type="checkbox"
                                ?checked=${first(this.instance?.startTls, true)}
                            />
                            <span class="pf-c-switch__toggle">
                                <span class="pf-c-switch__toggle-icon">
                                    <i class="fas fa-check" aria-hidden="true"></i>
                                </span>
                            </span>
                            <span class="pf-c-switch__label">${msg("Enable StartTLS")}</span>
                        </label>
                        <p class="pf-c-form__helper-text">
                            ${msg("To use SSL instead, use 'ldaps://' and disable this option.")}
                        </p>
                    </ak-form-element-horizontal>
                    <ak-form-element-horizontal name="sni">
                        <label class="pf-c-switch">
                            <input
                                class="pf-c-switch__input"
                                type="checkbox"
                                ?checked=${first(this.instance?.sni, false)}
                            />
                            <span class="pf-c-switch__toggle">
                                <span class="pf-c-switch__toggle-icon">
                                    <i class="fas fa-check" aria-hidden="true"></i>
                                </span>
                            </span>
                            <span class="pf-c-switch__label"
                                >${msg("Use Server URI for SNI verification")}</span
                            >
                        </label>
                        <p class="pf-c-form__helper-text">
                            ${msg("Required for servers using TLS 1.3+")}
                        </p>
                    </ak-form-element-horizontal>
                    <ak-form-element-horizontal
                        label=${msg("TLS Verification Certificate")}
                        name="peerCertificate"
                    >
                        <ak-crypto-certificate-search
                            .certificate=${this.instance?.peerCertificate}
                            nokey
                        ></ak-crypto-certificate-search>
                        <p class="pf-c-form__helper-text">
                            ${msg(
      "When connecting to an LDAP Server with TLS, certificates are not checked by default. Specify a keypair to validate the remote certificate."
    )}
                        </p>
                    </ak-form-element-horizontal>
                    <ak-form-element-horizontal
                        label=${msg("TLS Client authentication certificate")}
                        name="clientCertificate"
                    >
                        <ak-crypto-certificate-search
                            .certificate=${this.instance?.clientCertificate}
                        ></ak-crypto-certificate-search>
                        <p class="pf-c-form__helper-text">
                            ${msg(
      "Client certificate keypair to authenticate against the LDAP Server's Certificate."
    )}
                        </p>
                    </ak-form-element-horizontal>
                    <ak-form-element-horizontal label=${msg("Bind CN")} name="bindCn">
                        <input
                            type="text"
                            value="${o(this.instance?.bindCn)}"
                            class="pf-c-form-control"
                        />
                    </ak-form-element-horizontal>
                    <ak-form-element-horizontal
                        label=${msg("Bind Password")}
                        ?writeOnly=${this.instance !== void 0}
                        name="bindPassword"
                    >
                        <input type="text" value="" class="pf-c-form-control" />
                    </ak-form-element-horizontal>
                    <ak-form-element-horizontal
                        label=${msg("Base DN")}
                        ?required=${true}
                        name="baseDn"
                    >
                        <input
                            type="text"
                            value="${o(this.instance?.baseDn)}"
                            class="pf-c-form-control"
                            required
                        />
                    </ak-form-element-horizontal>
                </div>
            </ak-form-group>
            <ak-form-group ?expanded=${true}>
                <span slot="header"> ${msg("LDAP Attribute mapping")} </span>
                <div slot="body" class="pf-c-form">
                    <ak-form-element-horizontal
                        label=${msg("User Property Mappings")}
                        name="propertyMappings"
                    >
                        <select class="pf-c-form-control" multiple>
                            ${this.propertyMappings?.results.map((mapping) => {
      let selected = false;
      if (!this.instance?.propertyMappings) {
        selected = mapping.managed?.startsWith(
          "goauthentik.io/sources/ldap/default"
        ) || mapping.managed?.startsWith(
          "goauthentik.io/sources/ldap/ms"
        ) || false;
      } else {
        selected = Array.from(this.instance?.propertyMappings).some(
          (su) => {
            return su == mapping.pk;
          }
        );
      }
      return x`<option
                                    value=${o(mapping.pk)}
                                    ?selected=${selected}
                                >
                                    ${mapping.name}
                                </option>`;
    })}
                        </select>
                        <p class="pf-c-form__helper-text">
                            ${msg("Property mappings used to user creation.")}
                        </p>
                        <p class="pf-c-form__helper-text">
                            ${msg("Hold control/command to select multiple items.")}
                        </p>
                    </ak-form-element-horizontal>
                    <ak-form-element-horizontal
                        label=${msg("Group Property Mappings")}
                        name="propertyMappingsGroup"
                    >
                        <select class="pf-c-form-control" multiple>
                            ${this.propertyMappings?.results.map((mapping) => {
      let selected = false;
      if (!this.instance?.propertyMappingsGroup) {
        selected = mapping.managed === "goauthentik.io/sources/ldap/default-name";
      } else {
        selected = Array.from(
          this.instance?.propertyMappingsGroup
        ).some((su) => {
          return su == mapping.pk;
        });
      }
      return x`<option
                                    value=${o(mapping.pk)}
                                    ?selected=${selected}
                                >
                                    ${mapping.name}
                                </option>`;
    })}
                        </select>
                        <p class="pf-c-form__helper-text">
                            ${msg("Property mappings used to group creation.")}
                        </p>
                        <p class="pf-c-form__helper-text">
                            ${msg("Hold control/command to select multiple items.")}
                        </p>
                    </ak-form-element-horizontal>
                </div>
            </ak-form-group>
            <ak-form-group>
                <span slot="header"> ${msg("Additional settings")} </span>
                <div slot="body" class="pf-c-form">
                    <ak-form-element-horizontal label=${msg("Group")} name="syncParentGroup">
                        <ak-search-select
                            .fetchObjects=${async (query) => {
      const args = {
        ordering: "name"
      };
      if (query !== void 0) {
        args.search = query;
      }
      const groups = await new CoreApi(DEFAULT_CONFIG).coreGroupsList(
        args
      );
      return groups.results;
    }}
                            .renderElement=${(group) => {
      return group.name;
    }}
                            .value=${(group) => {
      return group ? group.pk : void 0;
    }}
                            .selected=${(group) => {
      return group.pk === this.instance?.syncParentGroup;
    }}
                            ?blankable=${true}
                        >
                        </ak-search-select>
                        <p class="pf-c-form__helper-text">
                            ${msg("Parent group for all the groups imported from LDAP.")}
                        </p>
                    </ak-form-element-horizontal>
                    <ak-form-element-horizontal label=${msg("User path")} name="userPathTemplate">
                        <input
                            type="text"
                            value="${first(
      this.instance?.userPathTemplate,
      "goauthentik.io/sources/%(slug)s"
    )}"
                            class="pf-c-form-control"
                        />
                        <p class="pf-c-form__helper-text">${placeholderHelperText}</p>
                    </ak-form-element-horizontal>
                    <ak-form-element-horizontal
                        label=${msg("Addition User DN")}
                        name="additionalUserDn"
                    >
                        <input
                            type="text"
                            value="${o(this.instance?.additionalUserDn)}"
                            class="pf-c-form-control"
                        />
                        <p class="pf-c-form__helper-text">
                            ${msg("Additional user DN, prepended to the Base DN.")}
                        </p>
                    </ak-form-element-horizontal>
                    <ak-form-element-horizontal
                        label=${msg("Addition Group DN")}
                        name="additionalGroupDn"
                    >
                        <input
                            type="text"
                            value="${o(this.instance?.additionalGroupDn)}"
                            class="pf-c-form-control"
                        />
                        <p class="pf-c-form__helper-text">
                            ${msg("Additional group DN, prepended to the Base DN.")}
                        </p>
                    </ak-form-element-horizontal>
                    <ak-form-element-horizontal
                        label=${msg("User object filter")}
                        ?required=${true}
                        name="userObjectFilter"
                    >
                        <input
                            type="text"
                            value="${this.instance?.userObjectFilter || "(objectClass=person)"}"
                            class="pf-c-form-control"
                            required
                        />
                        <p class="pf-c-form__helper-text">
                            ${msg("Consider Objects matching this filter to be Users.")}
                        </p>
                    </ak-form-element-horizontal>
                    <ak-form-element-horizontal
                        label=${msg("Group object filter")}
                        ?required=${true}
                        name="groupObjectFilter"
                    >
                        <input
                            type="text"
                            value="${this.instance?.groupObjectFilter || "(objectClass=group)"}"
                            class="pf-c-form-control"
                            required
                        />
                        <p class="pf-c-form__helper-text">
                            ${msg("Consider Objects matching this filter to be Groups.")}
                        </p>
                    </ak-form-element-horizontal>
                    <ak-form-element-horizontal
                        label=${msg("Group membership field")}
                        ?required=${true}
                        name="groupMembershipField"
                    >
                        <input
                            type="text"
                            value="${this.instance?.groupMembershipField || "member"}"
                            class="pf-c-form-control"
                            required
                        />
                        <p class="pf-c-form__helper-text">
                            ${msg(
      `Field which contains members of a group. Note that if using the "memberUid" field, the value is assumed to contain a relative distinguished name. e.g. 'memberUid=some-user' instead of 'memberUid=cn=some-user,ou=groups,...'`
    )}
                        </p>
                    </ak-form-element-horizontal>
                    <ak-form-element-horizontal
                        label=${msg("Object uniqueness field")}
                        ?required=${true}
                        name="objectUniquenessField"
                    >
                        <input
                            type="text"
                            value="${this.instance?.objectUniquenessField || "objectSid"}"
                            class="pf-c-form-control"
                            required
                        />
                        <p class="pf-c-form__helper-text">
                            ${msg("Field which contains a unique Identifier.")}
                        </p>
                    </ak-form-element-horizontal>
                </div>
            </ak-form-group>`;
  }
};
LDAPSourceForm = __decorateClass([
  t("ak-source-ldap-form")
], LDAPSourceForm);

// src/admin/common/ak-flow-search/ak-source-flow-search.ts
var AkSourceFlowSearch = class extends FlowSearch_default {
  constructor() {
    super();
    this.selected = this.selected.bind(this);
  }
  // If there's no instance or no currentFlowId for it and the flow resembles the fallback,
  // otherwise defer to the parent class.
  selected(flow) {
    return !this.instanceId && !this.currentFlow && flow.slug === this.fallback || super.selected(flow);
  }
};
__decorateClass([
  n({ type: String })
], AkSourceFlowSearch.prototype, "fallback", 2);
__decorateClass([
  n({ type: String })
], AkSourceFlowSearch.prototype, "instanceId", 2);
AkSourceFlowSearch = __decorateClass([
  t("ak-source-flow-search")
], AkSourceFlowSearch);

// src/admin/sources/oauth/utils.ts
function UserMatchingModeToLabel(mode) {
  if (!mode)
    return "";
  switch (mode) {
    case UserMatchingModeEnum.Identifier:
      return msg("Link users on unique identifier");
    case UserMatchingModeEnum.EmailLink:
      return msg(
        "Link to a user with identical email address. Can have security implications when a source doesn't validate email addresses"
      );
    case UserMatchingModeEnum.EmailDeny:
      return msg(
        "Use the user's email address, but deny enrollment when the email address already exists"
      );
    case UserMatchingModeEnum.UsernameLink:
      return msg(
        "Link to a user with identical username. Can have security implications when a username is used with another source"
      );
    case UserMatchingModeEnum.UsernameDeny:
      return msg(
        "Use the user's username, but deny enrollment when the username already exists"
      );
    case UserMatchingModeEnum.UnknownDefaultOpenApi:
      return msg("Unknown user matching mode");
  }
}

// src/admin/sources/oauth/OAuthSourceForm.ts
var OAuthSourceForm = class extends WithCapabilitiesConfig(BaseSourceForm) {
  constructor() {
    super(...arguments);
    this.providerType = null;
    this.clearIcon = false;
  }
  async loadInstance(pk) {
    const source = await new SourcesApi(DEFAULT_CONFIG).sourcesOauthRetrieve({
      slug: pk
    });
    this.providerType = source.type;
    this.clearIcon = false;
    return source;
  }
  async send(data) {
    data.providerType = this.providerType?.name || "";
    let source;
    if (this.instance) {
      source = await new SourcesApi(DEFAULT_CONFIG).sourcesOauthPartialUpdate({
        slug: this.instance.slug,
        patchedOAuthSourceRequest: data
      });
    } else {
      source = await new SourcesApi(DEFAULT_CONFIG).sourcesOauthCreate({
        oAuthSourceRequest: data
      });
    }
    const c = await config();
    if (c.capabilities.includes(CapabilitiesEnum.CanSaveMedia)) {
      const icon = this.getFormFiles()["icon"];
      if (icon || this.clearIcon) {
        await new SourcesApi(DEFAULT_CONFIG).sourcesAllSetIconCreate({
          slug: source.slug,
          file: icon,
          clear: this.clearIcon
        });
      }
    } else {
      await new SourcesApi(DEFAULT_CONFIG).sourcesAllSetIconUrlCreate({
        slug: source.slug,
        filePathRequest: {
          url: data.icon || ""
        }
      });
    }
    return source;
  }
  fetchProviderType(v) {
    new SourcesApi(DEFAULT_CONFIG).sourcesOauthSourceTypesList({
      name: v?.replace("oauthsource", "")
    }).then((type) => {
      this.providerType = type[0];
    });
  }
  willUpdate(changedProperties) {
    if (changedProperties.has("modelName")) {
      this.fetchProviderType(this.modelName);
    }
  }
  renderUrlOptions() {
    if (!this.providerType?.urlsCustomizable) {
      return x``;
    }
    return x` <ak-form-group .expanded=${true}>
            <span slot="header"> ${msg("URL settings")} </span>
            <div slot="body" class="pf-c-form">
                <ak-form-element-horizontal
                    label=${msg("Authorization URL")}
                    name="authorizationUrl"
                >
                    <input
                        type="text"
                        value="${first(
      this.instance?.authorizationUrl,
      this.providerType.authorizationUrl,
      ""
    )}"
                        class="pf-c-form-control"
                    />
                    <p class="pf-c-form__helper-text">
                        ${msg("URL the user is redirect to to consent the authorization.")}
                    </p>
                </ak-form-element-horizontal>
                <ak-form-element-horizontal label=${msg("Access token URL")} name="accessTokenUrl">
                    <input
                        type="text"
                        value="${first(
      this.instance?.accessTokenUrl,
      this.providerType.accessTokenUrl,
      ""
    )}"
                        class="pf-c-form-control"
                    />
                    <p class="pf-c-form__helper-text">
                        ${msg("URL used by authentik to retrieve tokens.")}
                    </p>
                </ak-form-element-horizontal>
                <ak-form-element-horizontal label=${msg("Profile URL")} name="profileUrl">
                    <input
                        type="text"
                        value="${first(
      this.instance?.profileUrl,
      this.providerType.profileUrl,
      ""
    )}"
                        class="pf-c-form-control"
                    />
                    <p class="pf-c-form__helper-text">
                        ${msg("URL used by authentik to get user information.")}
                    </p>
                </ak-form-element-horizontal>
                ${this.providerType.requestTokenUrl ? x`<ak-form-element-horizontal
                          label=${msg("Request token URL")}
                          name="requestTokenUrl"
                      >
                          <input
                              type="text"
                              value="${first(this.instance?.requestTokenUrl, "")}"
                              class="pf-c-form-control"
                          />
                          <p class="pf-c-form__helper-text">
                              ${msg(
      "URL used to request the initial token. This URL is only required for OAuth 1."
    )}
                          </p>
                      </ak-form-element-horizontal> ` : x``}
                ${this.providerType.name === ProviderTypeEnum.Openidconnect || this.providerType.oidcWellKnownUrl !== "" ? x`<ak-form-element-horizontal
                          label=${msg("OIDC Well-known URL")}
                          name="oidcWellKnownUrl"
                      >
                          <input
                              type="text"
                              value="${first(
      this.instance?.oidcWellKnownUrl,
      this.providerType.oidcWellKnownUrl,
      ""
    )}"
                              class="pf-c-form-control"
                          />
                          <p class="pf-c-form__helper-text">
                              ${msg(
      "OIDC well-known configuration URL. Can be used to automatically configure the URLs above."
    )}
                          </p>
                      </ak-form-element-horizontal>` : x``}
                ${this.providerType.name === ProviderTypeEnum.Openidconnect || this.providerType.oidcJwksUrl !== "" ? x`<ak-form-element-horizontal
                              label=${msg("OIDC JWKS URL")}
                              name="oidcJwksUrl"
                          >
                              <input
                                  type="text"
                                  value="${first(
      this.instance?.oidcJwksUrl,
      this.providerType.oidcJwksUrl,
      ""
    )}"
                                  class="pf-c-form-control"
                              />
                              <p class="pf-c-form__helper-text">
                                  ${msg(
      "JSON Web Key URL. Keys from the URL will be used to validate JWTs from this source."
    )}
                              </p>
                          </ak-form-element-horizontal>
                          <ak-form-element-horizontal label=${msg("OIDC JWKS")} name="oidcJwks">
                              <ak-codemirror
                                  mode=${"javascript" /* JavaScript */}
                                  value="${JSON.stringify(first(this.instance?.oidcJwks, {}))}"
                              >
                              </ak-codemirror>
                              <p class="pf-c-form__helper-text">${msg("Raw JWKS data.")}</p>
                          </ak-form-element-horizontal>` : x``}
            </div>
        </ak-form-group>`;
  }
  renderForm() {
    return x` <ak-form-element-horizontal label=${msg("Name")} ?required=${true} name="name">
                <input
                    type="text"
                    value="${o(this.instance?.name)}"
                    class="pf-c-form-control"
                    required
                />
            </ak-form-element-horizontal>
            <ak-form-element-horizontal label=${msg("Slug")} ?required=${true} name="slug">
                <input
                    type="text"
                    value="${o(this.instance?.slug)}"
                    class="pf-c-form-control"
                    required
                />
            </ak-form-element-horizontal>
            <ak-form-element-horizontal name="enabled">
                <label class="pf-c-switch">
                    <input
                        class="pf-c-switch__input"
                        type="checkbox"
                        ?checked=${first(this.instance?.enabled, true)}
                    />
                    <span class="pf-c-switch__toggle">
                        <span class="pf-c-switch__toggle-icon">
                            <i class="fas fa-check" aria-hidden="true"></i>
                        </span>
                    </span>
                    <span class="pf-c-switch__label">${msg("Enabled")}</span>
                </label>
            </ak-form-element-horizontal>
            <ak-form-element-horizontal
                label=${msg("User matching mode")}
                ?required=${true}
                name="userMatchingMode"
            >
                <select class="pf-c-form-control">
                    <option
                        value=${UserMatchingModeEnum.Identifier}
                        ?selected=${this.instance?.userMatchingMode === UserMatchingModeEnum.Identifier}
                    >
                        ${UserMatchingModeToLabel(UserMatchingModeEnum.Identifier)}
                    </option>
                    <option
                        value=${UserMatchingModeEnum.EmailLink}
                        ?selected=${this.instance?.userMatchingMode === UserMatchingModeEnum.EmailLink}
                    >
                        ${UserMatchingModeToLabel(UserMatchingModeEnum.EmailLink)}
                    </option>
                    <option
                        value=${UserMatchingModeEnum.EmailDeny}
                        ?selected=${this.instance?.userMatchingMode === UserMatchingModeEnum.EmailDeny}
                    >
                        ${UserMatchingModeToLabel(UserMatchingModeEnum.EmailDeny)}
                    </option>
                    <option
                        value=${UserMatchingModeEnum.UsernameLink}
                        ?selected=${this.instance?.userMatchingMode === UserMatchingModeEnum.UsernameLink}
                    >
                        ${UserMatchingModeToLabel(UserMatchingModeEnum.UsernameLink)}
                    </option>
                    <option
                        value=${UserMatchingModeEnum.UsernameDeny}
                        ?selected=${this.instance?.userMatchingMode === UserMatchingModeEnum.UsernameDeny}
                    >
                        ${UserMatchingModeToLabel(UserMatchingModeEnum.UsernameDeny)}
                    </option>
                </select>
            </ak-form-element-horizontal>
            <ak-form-element-horizontal label=${msg("User path")} name="userPathTemplate">
                <input
                    type="text"
                    value="${first(
      this.instance?.userPathTemplate,
      "goauthentik.io/sources/%(slug)s"
    )}"
                    class="pf-c-form-control"
                />
                <p class="pf-c-form__helper-text">${placeholderHelperText}</p>
            </ak-form-element-horizontal>
            ${this.can(CapabilitiesEnum.CanSaveMedia) ? x`<ak-form-element-horizontal label=${msg("Icon")} name="icon">
                          <input type="file" value="" class="pf-c-form-control" />
                          ${this.instance?.icon ? x`
                                    <p class="pf-c-form__helper-text">
                                        ${msg("Currently set to:")} ${this.instance?.icon}
                                    </p>
                                ` : x``}
                      </ak-form-element-horizontal>
                      ${this.instance?.icon ? x`
                                <ak-form-element-horizontal>
                                    <label class="pf-c-switch">
                                        <input
                                            class="pf-c-switch__input"
                                            type="checkbox"
                                            @change=${(ev) => {
      const target = ev.target;
      this.clearIcon = target.checked;
    }}
                                        />
                                        <span class="pf-c-switch__toggle">
                                            <span class="pf-c-switch__toggle-icon">
                                                <i class="fas fa-check" aria-hidden="true"></i>
                                            </span>
                                        </span>
                                        <span class="pf-c-switch__label">
                                            ${msg("Clear icon")}
                                        </span>
                                    </label>
                                    <p class="pf-c-form__helper-text">
                                        ${msg("Delete currently set icon.")}
                                    </p>
                                </ak-form-element-horizontal>
                            ` : x``}` : x`<ak-form-element-horizontal label=${msg("Icon")} name="icon">
                      <input
                          type="text"
                          value="${first(this.instance?.icon, "")}"
                          class="pf-c-form-control"
                      />
                      <p class="pf-c-form__helper-text">${iconHelperText}</p>
                  </ak-form-element-horizontal>`}

            <ak-form-group .expanded=${true}>
                <span slot="header"> ${msg("Protocol settings")} </span>
                <div slot="body" class="pf-c-form">
                    <ak-form-element-horizontal
                        label=${msg("Consumer key")}
                        ?required=${true}
                        name="consumerKey"
                    >
                        <input
                            type="text"
                            value="${o(this.instance?.consumerKey)}"
                            class="pf-c-form-control"
                            required
                        />
                        <p class="pf-c-form__helper-text">${msg("Also known as Client ID.")}</p>
                    </ak-form-element-horizontal>
                    <ak-form-element-horizontal
                        label=${msg("Consumer secret")}
                        ?required=${true}
                        ?writeOnly=${this.instance !== void 0}
                        name="consumerSecret"
                    >
                        <textarea class="pf-c-form-control"></textarea>
                        <p class="pf-c-form__helper-text">${msg("Also known as Client Secret.")}</p>
                    </ak-form-element-horizontal>
                    <ak-form-element-horizontal label=${msg("Scopes")} name="additionalScopes">
                        <input
                            type="text"
                            value="${first(this.instance?.additionalScopes, "")}"
                            class="pf-c-form-control"
                        />
                        <p class="pf-c-form__helper-text">
                            ${msg(
      "Additional scopes to be passed to the OAuth Provider, separated by space. To replace existing scopes, prefix with *."
    )}
                        </p>
                    </ak-form-element-horizontal>
                </div>
            </ak-form-group>
            ${this.renderUrlOptions()}
            <ak-form-group>
                <span slot="header"> ${msg("Flow settings")} </span>
                <div slot="body" class="pf-c-form">
                    <ak-form-element-horizontal
                        label=${msg("Authentication flow")}
                        ?required=${true}
                        name="authenticationFlow"
                    >
                        <ak-source-flow-search
                            flowType=${FlowsInstancesListDesignationEnum.Authentication}
                            .currentFlow=${this.instance?.authenticationFlow}
                            .instanceId=${this.instance?.pk}
                            fallback="default-source-authentication"
                        ></ak-source-flow-search>
                        <p class="pf-c-form__helper-text">
                            ${msg("Flow to use when authenticating existing users.")}
                        </p>
                    </ak-form-element-horizontal>
                    <ak-form-element-horizontal
                        label=${msg("Enrollment flow")}
                        ?required=${true}
                        name="enrollmentFlow"
                    >
                        <ak-source-flow-search
                            flowType=${FlowsInstancesListDesignationEnum.Enrollment}
                            .currentFlow=${this.instance?.enrollmentFlow}
                            .instanceId=${this.instance?.pk}
                            fallback="default-source-enrollment"
                        ></ak-source-flow-search>
                        <p class="pf-c-form__helper-text">
                            ${msg("Flow to use when enrolling new users.")}
                        </p>
                    </ak-form-element-horizontal>
                </div>
            </ak-form-group>`;
  }
};
__decorateClass([
  n()
], OAuthSourceForm.prototype, "modelName", 2);
__decorateClass([
  n({ attribute: false })
], OAuthSourceForm.prototype, "providerType", 2);
__decorateClass([
  r()
], OAuthSourceForm.prototype, "clearIcon", 2);
OAuthSourceForm = __decorateClass([
  t("ak-source-oauth-form")
], OAuthSourceForm);

// src/admin/sources/plex/PlexSourceForm.ts
var PlexSourceForm = class extends WithCapabilitiesConfig(BaseSourceForm) {
  constructor() {
    super(...arguments);
    this.clearIcon = false;
  }
  async loadInstance(pk) {
    const source = await new SourcesApi(DEFAULT_CONFIG).sourcesPlexRetrieve({
      slug: pk
    });
    this.plexToken = source.plexToken;
    this.loadServers();
    this.clearIcon = false;
    return source;
  }
  get defaultInstance() {
    return {
      clientId: randomString(40, ascii_letters + digits)
    };
  }
  async send(data) {
    data.plexToken = this.plexToken || "";
    let source;
    if (this.instance?.pk) {
      source = await new SourcesApi(DEFAULT_CONFIG).sourcesPlexUpdate({
        slug: this.instance.slug,
        plexSourceRequest: data
      });
    } else {
      source = await new SourcesApi(DEFAULT_CONFIG).sourcesPlexCreate({
        plexSourceRequest: data
      });
    }
    if (this.can(CapabilitiesEnum.CanSaveMedia)) {
      const icon = this.getFormFiles()["icon"];
      if (icon || this.clearIcon) {
        await new SourcesApi(DEFAULT_CONFIG).sourcesAllSetIconCreate({
          slug: source.slug,
          file: icon,
          clear: this.clearIcon
        });
      }
    } else {
      await new SourcesApi(DEFAULT_CONFIG).sourcesAllSetIconUrlCreate({
        slug: source.slug,
        filePathRequest: {
          url: data.icon || ""
        }
      });
    }
    return source;
  }
  async doAuth() {
    const authInfo = await PlexAPIClient.getPin(this.instance?.clientId || "");
    const authWindow = await popupCenterScreen(authInfo.authUrl, "plex auth", 550, 700);
    PlexAPIClient.pinPoll(this.instance?.clientId || "", authInfo.pin.id).then((token) => {
      authWindow?.close();
      this.plexToken = token;
      this.loadServers();
    });
  }
  async loadServers() {
    if (!this.plexToken) {
      return;
    }
    this.plexResources = await new PlexAPIClient(this.plexToken).getServers();
  }
  renderSettings() {
    if (!this.plexToken) {
      return x` <button
                class="pf-c-button pf-m-primary"
                type="button"
                @click=${() => {
        this.doAuth();
      }}
            >
                ${msg("Load servers")}
            </button>`;
    }
    return x` <button
                class="pf-c-button pf-m-secondary"
                type="button"
                @click=${() => {
      this.doAuth();
    }}
            >
                ${msg("Re-authenticate with plex")}
            </button>
            <ak-form-element-horizontal name="allowFriends">
                <label class="pf-c-switch">
                    <input
                        class="pf-c-switch__input"
                        type="checkbox"
                        ?checked=${first(this.instance?.allowFriends, true)}
                    />
                    <span class="pf-c-switch__toggle">
                        <span class="pf-c-switch__toggle-icon">
                            <i class="fas fa-check" aria-hidden="true"></i>
                        </span>
                    </span>
                    <span class="pf-c-switch__label"
                        >${msg(
      "Allow friends to authenticate via Plex, even if you don't share any servers"
    )}</span
                    >
                </label>
            </ak-form-element-horizontal>
            <ak-form-element-horizontal
                label=${msg("Allowed servers")}
                ?required=${true}
                name="allowedServers"
            >
                <select class="pf-c-form-control" multiple>
                    ${this.plexResources?.map((r2) => {
      const selected = Array.from(this.instance?.allowedServers || []).some(
        (server) => {
          return server == r2.clientIdentifier;
        }
      );
      return x`<option value=${r2.clientIdentifier} ?selected=${selected}>
                            ${r2.name}
                        </option>`;
    })}
                </select>
                <p class="pf-c-form__helper-text">
                    ${msg(
      "Select which server a user has to be a member of to be allowed to authenticate."
    )}
                </p>
                <p class="pf-c-form__helper-text">
                    ${msg("Hold control/command to select multiple items.")}
                </p>
            </ak-form-element-horizontal>`;
  }
  renderForm() {
    return x` <ak-form-element-horizontal label=${msg("Name")} ?required=${true} name="name">
                <input
                    type="text"
                    value="${o(this.instance?.name)}"
                    class="pf-c-form-control"
                    required
                />
            </ak-form-element-horizontal>
            <ak-form-element-horizontal label=${msg("Slug")} ?required=${true} name="slug">
                <input
                    type="text"
                    value="${o(this.instance?.slug)}"
                    class="pf-c-form-control"
                    required
                />
            </ak-form-element-horizontal>
            <ak-form-element-horizontal name="enabled">
                <label class="pf-c-switch">
                    <input
                        class="pf-c-switch__input"
                        type="checkbox"
                        ?checked=${first(this.instance?.enabled, true)}
                    />
                    <span class="pf-c-switch__toggle">
                        <span class="pf-c-switch__toggle-icon">
                            <i class="fas fa-check" aria-hidden="true"></i>
                        </span>
                    </span>
                    <span class="pf-c-switch__label">${msg("Enabled")}</span>
                </label>
            </ak-form-element-horizontal>
            <ak-form-element-horizontal
                label=${msg("User matching mode")}
                ?required=${true}
                name="userMatchingMode"
            >
                <select class="pf-c-form-control">
                    <option
                        value=${UserMatchingModeEnum.Identifier}
                        ?selected=${this.instance?.userMatchingMode === UserMatchingModeEnum.Identifier}
                    >
                        ${UserMatchingModeToLabel(UserMatchingModeEnum.Identifier)}
                    </option>
                    <option
                        value=${UserMatchingModeEnum.EmailLink}
                        ?selected=${this.instance?.userMatchingMode === UserMatchingModeEnum.EmailLink}
                    >
                        ${UserMatchingModeToLabel(UserMatchingModeEnum.EmailLink)}
                    </option>
                    <option
                        value=${UserMatchingModeEnum.EmailDeny}
                        ?selected=${this.instance?.userMatchingMode === UserMatchingModeEnum.EmailDeny}
                    >
                        ${UserMatchingModeToLabel(UserMatchingModeEnum.EmailDeny)}
                    </option>
                    <option
                        value=${UserMatchingModeEnum.UsernameLink}
                        ?selected=${this.instance?.userMatchingMode === UserMatchingModeEnum.UsernameLink}
                    >
                        ${UserMatchingModeToLabel(UserMatchingModeEnum.UsernameLink)}
                    </option>
                    <option
                        value=${UserMatchingModeEnum.UsernameDeny}
                        ?selected=${this.instance?.userMatchingMode === UserMatchingModeEnum.UsernameDeny}
                    >
                        ${UserMatchingModeToLabel(UserMatchingModeEnum.UsernameDeny)}
                    </option>
                </select>
            </ak-form-element-horizontal>
            <ak-form-element-horizontal label=${msg("User path")} name="userPathTemplate">
                <input
                    type="text"
                    value="${first(
      this.instance?.userPathTemplate,
      "goauthentik.io/sources/%(slug)s"
    )}"
                    class="pf-c-form-control"
                />
                <p class="pf-c-form__helper-text">${placeholderHelperText}</p>
            </ak-form-element-horizontal>
            ${this.can(CapabilitiesEnum.CanSaveMedia) ? x`<ak-form-element-horizontal label=${msg("Icon")} name="icon">
                          <input type="file" value="" class="pf-c-form-control" />
                          ${this.instance?.icon ? x`
                                    <p class="pf-c-form__helper-text">
                                        ${msg("Currently set to:")} ${this.instance?.icon}
                                    </p>
                                ` : x``}
                      </ak-form-element-horizontal>
                      ${this.instance?.icon ? x`
                                <ak-form-element-horizontal>
                                    <label class="pf-c-switch">
                                        <input
                                            class="pf-c-switch__input"
                                            type="checkbox"
                                            @change=${(ev) => {
      const target = ev.target;
      this.clearIcon = target.checked;
    }}
                                        />
                                        <span class="pf-c-switch__toggle">
                                            <span class="pf-c-switch__toggle-icon">
                                                <i class="fas fa-check" aria-hidden="true"></i>
                                            </span>
                                        </span>
                                        <span class="pf-c-switch__label">
                                            ${msg("Clear icon")}
                                        </span>
                                    </label>
                                    <p class="pf-c-form__helper-text">
                                        ${msg("Delete currently set icon.")}
                                    </p>
                                </ak-form-element-horizontal>
                            ` : x``}` : x`<ak-form-element-horizontal label=${msg("Icon")} name="icon">
                      <input
                          type="text"
                          value="${first(this.instance?.icon, "")}"
                          class="pf-c-form-control"
                      />
                      <p class="pf-c-form__helper-text">${iconHelperText}</p>
                  </ak-form-element-horizontal>`}
            <ak-form-group .expanded=${true}>
                <span slot="header"> ${msg("Protocol settings")} </span>
                <div slot="body" class="pf-c-form">
                    <ak-form-element-horizontal
                        label=${msg("Client ID")}
                        ?required=${true}
                        name="clientId"
                    >
                        <input
                            type="text"
                            value="${first(this.instance?.clientId, "")}"
                            class="pf-c-form-control"
                            required
                        />
                    </ak-form-element-horizontal>
                    ${this.renderSettings()}
                </div>
            </ak-form-group>
            <ak-form-group>
                <span slot="header"> ${msg("Flow settings")} </span>
                <div slot="body" class="pf-c-form">
                    <ak-form-element-horizontal
                        label=${msg("Authentication flow")}
                        ?required=${true}
                        name="authenticationFlow"
                    >
                        <ak-source-flow-search
                            flowType=${FlowsInstancesListDesignationEnum.Authentication}
                            .currentFlow=${this.instance?.authenticationFlow}
                            .instanceId=${this.instance?.pk}
                            fallback="default-source-authentication"
                        ></ak-source-flow-search>
                        <p class="pf-c-form__helper-text">
                            ${msg("Flow to use when authenticating existing users.")}
                        </p>
                    </ak-form-element-horizontal>
                    <ak-form-element-horizontal
                        label=${msg("Enrollment flow")}
                        ?required=${true}
                        name="enrollmentFlow"
                    >
                        <ak-source-flow-search
                            flowType=${FlowsInstancesListDesignationEnum.Enrollment}
                            .currentFlow=${this.instance?.enrollmentFlow}
                            .instanceId=${this.instance?.pk}
                            fallback="default-source-enrollment"
                        ></ak-source-flow-search>
                        <p class="pf-c-form__helper-text">
                            ${msg("Flow to use when enrolling new users.")}
                        </p>
                    </ak-form-element-horizontal>
                </div>
            </ak-form-group>`;
  }
};
__decorateClass([
  r()
], PlexSourceForm.prototype, "clearIcon", 2);
__decorateClass([
  n()
], PlexSourceForm.prototype, "plexToken", 2);
__decorateClass([
  n({ attribute: false })
], PlexSourceForm.prototype, "plexResources", 2);
PlexSourceForm = __decorateClass([
  t("ak-source-plex-form")
], PlexSourceForm);

// src/admin/sources/saml/SAMLSourceForm.ts
var SAMLSourceForm = class extends WithCapabilitiesConfig(BaseSourceForm) {
  constructor() {
    super(...arguments);
    this.clearIcon = false;
  }
  async loadInstance(pk) {
    const source = await new SourcesApi(DEFAULT_CONFIG).sourcesSamlRetrieve({
      slug: pk
    });
    this.clearIcon = false;
    return source;
  }
  async send(data) {
    let source;
    if (this.instance) {
      source = await new SourcesApi(DEFAULT_CONFIG).sourcesSamlUpdate({
        slug: this.instance.slug,
        sAMLSourceRequest: data
      });
    } else {
      source = await new SourcesApi(DEFAULT_CONFIG).sourcesSamlCreate({
        sAMLSourceRequest: data
      });
    }
    const c = await config();
    if (c.capabilities.includes(CapabilitiesEnum.CanSaveMedia)) {
      const icon = this.getFormFiles()["icon"];
      if (icon || this.clearIcon) {
        await new SourcesApi(DEFAULT_CONFIG).sourcesAllSetIconCreate({
          slug: source.slug,
          file: icon,
          clear: this.clearIcon
        });
      }
    } else {
      await new SourcesApi(DEFAULT_CONFIG).sourcesAllSetIconUrlCreate({
        slug: source.slug,
        filePathRequest: {
          url: data.icon || ""
        }
      });
    }
    return source;
  }
  renderForm() {
    return x` <ak-form-element-horizontal label=${msg("Name")} ?required=${true} name="name">
                <input
                    type="text"
                    value="${o(this.instance?.name)}"
                    class="pf-c-form-control"
                    required
                />
            </ak-form-element-horizontal>
            <ak-form-element-horizontal label=${msg("Slug")} ?required=${true} name="slug">
                <input
                    type="text"
                    value="${o(this.instance?.slug)}"
                    class="pf-c-form-control"
                    required
                />
            </ak-form-element-horizontal>
            <ak-form-element-horizontal name="enabled">
                <label class="pf-c-switch">
                    <input
                        class="pf-c-switch__input"
                        type="checkbox"
                        ?checked=${first(this.instance?.enabled, true)}
                    />
                    <span class="pf-c-switch__toggle">
                        <span class="pf-c-switch__toggle-icon">
                            <i class="fas fa-check" aria-hidden="true"></i>
                        </span>
                    </span>
                    <span class="pf-c-switch__label">${msg("Enabled")}</span>
                </label>
            </ak-form-element-horizontal>
            <ak-form-element-horizontal
                label=${msg("User matching mode")}
                ?required=${true}
                name="userMatchingMode"
            >
                <select class="pf-c-form-control">
                    <option
                        value=${UserMatchingModeEnum.Identifier}
                        ?selected=${this.instance?.userMatchingMode === UserMatchingModeEnum.Identifier}
                    >
                        ${UserMatchingModeToLabel(UserMatchingModeEnum.Identifier)}
                    </option>
                    <option
                        value=${UserMatchingModeEnum.EmailLink}
                        ?selected=${this.instance?.userMatchingMode === UserMatchingModeEnum.EmailLink}
                    >
                        ${UserMatchingModeToLabel(UserMatchingModeEnum.EmailLink)}
                    </option>
                    <option
                        value=${UserMatchingModeEnum.EmailDeny}
                        ?selected=${this.instance?.userMatchingMode === UserMatchingModeEnum.EmailDeny}
                    >
                        ${UserMatchingModeToLabel(UserMatchingModeEnum.EmailDeny)}
                    </option>
                    <option
                        value=${UserMatchingModeEnum.UsernameLink}
                        ?selected=${this.instance?.userMatchingMode === UserMatchingModeEnum.UsernameLink}
                    >
                        ${UserMatchingModeToLabel(UserMatchingModeEnum.UsernameLink)}
                    </option>
                    <option
                        value=${UserMatchingModeEnum.UsernameDeny}
                        ?selected=${this.instance?.userMatchingMode === UserMatchingModeEnum.UsernameDeny}
                    >
                        ${UserMatchingModeToLabel(UserMatchingModeEnum.UsernameDeny)}
                    </option>
                </select>
            </ak-form-element-horizontal>
            ${this.can(CapabilitiesEnum.CanSaveMedia) ? x`<ak-form-element-horizontal label=${msg("Icon")} name="icon">
                          <input type="file" value="" class="pf-c-form-control" />
                          ${this.instance?.icon ? x`
                                    <p class="pf-c-form__helper-text">
                                        ${msg("Currently set to:")} ${this.instance?.icon}
                                    </p>
                                ` : x``}
                      </ak-form-element-horizontal>
                      ${this.instance?.icon ? x`
                                <ak-form-element-horizontal>
                                    <label class="pf-c-switch">
                                        <input
                                            class="pf-c-switch__input"
                                            type="checkbox"
                                            @change=${(ev) => {
      const target = ev.target;
      this.clearIcon = target.checked;
    }}
                                        />
                                        <span class="pf-c-switch__toggle">
                                            <span class="pf-c-switch__toggle-icon">
                                                <i class="fas fa-check" aria-hidden="true"></i>
                                            </span>
                                        </span>
                                        <span class="pf-c-switch__label">
                                            ${msg("Clear icon")}
                                        </span>
                                    </label>
                                    <p class="pf-c-form__helper-text">
                                        ${msg("Delete currently set icon.")}
                                    </p>
                                </ak-form-element-horizontal>
                            ` : x``}` : x`<ak-form-element-horizontal label=${msg("Icon")} name="icon">
                      <input
                          type="text"
                          value="${first(this.instance?.icon, "")}"
                          class="pf-c-form-control"
                      />
                      <p class="pf-c-form__helper-text">${iconHelperText}</p>
                  </ak-form-element-horizontal>`}

            <ak-form-group .expanded=${true}>
                <span slot="header"> ${msg("Protocol settings")} </span>
                <div slot="body" class="pf-c-form">
                    <ak-form-element-horizontal
                        label=${msg("SSO URL")}
                        ?required=${true}
                        name="ssoUrl"
                    >
                        <input
                            type="text"
                            value="${o(this.instance?.ssoUrl)}"
                            class="pf-c-form-control"
                            required
                        />
                        <p class="pf-c-form__helper-text">
                            ${msg("URL that the initial Login request is sent to.")}
                        </p>
                    </ak-form-element-horizontal>
                    <ak-form-element-horizontal label=${msg("SLO URL")} name="sloUrl">
                        <input
                            type="text"
                            value="${o(this.instance?.sloUrl || "")}"
                            class="pf-c-form-control"
                        />
                        <p class="pf-c-form__helper-text">
                            ${msg("Optional URL if the IDP supports Single-Logout.")}
                        </p>
                    </ak-form-element-horizontal>
                    <ak-form-element-horizontal label=${msg("Issuer")} name="issuer">
                        <input
                            type="text"
                            value="${o(this.instance?.issuer)}"
                            class="pf-c-form-control"
                        />
                        <p class="pf-c-form__helper-text">
                            ${msg("Also known as Entity ID. Defaults the Metadata URL.")}
                        </p>
                    </ak-form-element-horizontal>
                    <ak-form-element-horizontal
                        label=${msg("Binding Type")}
                        ?required=${true}
                        name="bindingType"
                    >
                        <ak-radio
                            .options=${[
      {
        label: msg("Redirect binding"),
        value: BindingTypeEnum.Redirect,
        default: true
      },
      {
        label: msg("Post-auto binding"),
        value: BindingTypeEnum.PostAuto,
        description: x`${msg(
          "Post binding but the request is automatically sent and the user doesn't have to confirm."
        )}`
      },
      {
        label: msg("Post binding"),
        value: BindingTypeEnum.Post
      }
    ]}
                            .value=${this.instance?.bindingType}
                        >
                        </ak-radio>
                    </ak-form-element-horizontal>
                    <ak-form-element-horizontal label=${msg("Signing keypair")} name="signingKp">
                        <ak-crypto-certificate-search
                            .certificate=${this.instance?.signingKp}
                        ></ak-crypto-certificate-search>
                        <p class="pf-c-form__helper-text">
                            ${msg(
      "Keypair which is used to sign outgoing requests. Leave empty to disable signing."
    )}
                        </p>
                    </ak-form-element-horizontal>
                    <ak-form-element-horizontal
                        label=${msg("Verification Certificate")}
                        name="verificationKp"
                    >
                        <ak-crypto-certificate-search
                            .certificate=${this.instance?.verificationKp}
                            nokey
                        ></ak-crypto-certificate-search>
                        <p class="pf-c-form__helper-text">
                            ${msg(
      "When selected, incoming assertion's Signatures will be validated against this certificate. To allow unsigned Requests, leave on default."
    )}
                        </p>
                    </ak-form-element-horizontal>
                </div>
            </ak-form-group>
            <ak-form-group>
                <span slot="header"> ${msg("Advanced protocol settings")} </span>
                <div slot="body" class="pf-c-form">
                    <ak-form-element-horizontal name="allowIdpInitiated">
                        <label class="pf-c-switch">
                            <input
                                class="pf-c-switch__input"
                                type="checkbox"
                                ?checked=${first(this.instance?.allowIdpInitiated, false)}
                            />
                            <span class="pf-c-switch__toggle">
                                <span class="pf-c-switch__toggle-icon">
                                    <i class="fas fa-check" aria-hidden="true"></i>
                                </span>
                            </span>
                            <span class="pf-c-switch__label"
                                >${msg(" Allow IDP-initiated logins")}</span
                            >
                        </label>
                        <p class="pf-c-form__helper-text">
                            ${msg(
      "Allows authentication flows initiated by the IdP. This can be a security risk, as no validation of the request ID is done."
    )}
                        </p>
                    </ak-form-element-horizontal>
                    <ak-form-element-horizontal
                        label=${msg("NameID Policy")}
                        ?required=${true}
                        name="nameIdPolicy"
                    >
                        <select class="pf-c-form-control">
                            <option
                                value=${NameIdPolicyEnum._20nameidFormatpersistent}
                                ?selected=${this.instance?.nameIdPolicy === NameIdPolicyEnum._20nameidFormatpersistent}
                            >
                                ${msg("Persistent")}
                            </option>
                            <option
                                value=${NameIdPolicyEnum._11nameidFormatemailAddress}
                                ?selected=${this.instance?.nameIdPolicy === NameIdPolicyEnum._11nameidFormatemailAddress}
                            >
                                ${msg("Email address")}
                            </option>
                            <option
                                value=${NameIdPolicyEnum._20nameidFormatWindowsDomainQualifiedName}
                                ?selected=${this.instance?.nameIdPolicy === NameIdPolicyEnum._20nameidFormatWindowsDomainQualifiedName}
                            >
                                ${msg("Windows")}
                            </option>
                            <option
                                value=${NameIdPolicyEnum._20nameidFormatX509SubjectName}
                                ?selected=${this.instance?.nameIdPolicy === NameIdPolicyEnum._20nameidFormatX509SubjectName}
                            >
                                ${msg("X509 Subject")}
                            </option>
                            <option
                                value=${NameIdPolicyEnum._20nameidFormattransient}
                                ?selected=${this.instance?.nameIdPolicy === NameIdPolicyEnum._20nameidFormattransient}
                            >
                                ${msg("Transient")}
                            </option>
                        </select>
                    </ak-form-element-horizontal>
                    <ak-form-element-horizontal label=${msg("User path")} name="userPathTemplate">
                        <input
                            type="text"
                            value="${first(
      this.instance?.userPathTemplate,
      "goauthentik.io/sources/%(slug)s"
    )}"
                            class="pf-c-form-control"
                        />
                        <p class="pf-c-form__helper-text">${placeholderHelperText}</p>
                    </ak-form-element-horizontal>
                    <ak-form-element-horizontal
                        label=${msg("Delete temporary users after")}
                        ?required=${true}
                        name="temporaryUserDeleteAfter"
                    >
                        <input
                            type="text"
                            value="${this.instance?.temporaryUserDeleteAfter || "days=1"}"
                            class="pf-c-form-control"
                            required
                        />
                        <p class="pf-c-form__helper-text">
                            ${msg(
      "Time offset when temporary users should be deleted. This only applies if your IDP uses the NameID Format 'transient', and the user doesn't log out manually."
    )}
                        </p>
                        <ak-utils-time-delta-help></ak-utils-time-delta-help>
                    </ak-form-element-horizontal>
                    <ak-form-element-horizontal
                        label=${msg("Digest algorithm")}
                        ?required=${true}
                        name="digestAlgorithm"
                    >
                        <ak-radio
                            .options=${[
      {
        label: "SHA1",
        value: DigestAlgorithmEnum._200009Xmldsigsha1
      },
      {
        label: "SHA256",
        value: DigestAlgorithmEnum._200104Xmlencsha256,
        default: true
      },
      {
        label: "SHA384",
        value: DigestAlgorithmEnum._200104XmldsigMoresha384
      },
      {
        label: "SHA512",
        value: DigestAlgorithmEnum._200104Xmlencsha512
      }
    ]}
                            .value=${this.instance?.digestAlgorithm}
                        >
                        </ak-radio>
                    </ak-form-element-horizontal>
                    <ak-form-element-horizontal
                        label=${msg("Signature algorithm")}
                        ?required=${true}
                        name="signatureAlgorithm"
                    >
                        <ak-radio
                            .options=${[
      {
        label: "RSA-SHA1",
        value: SignatureAlgorithmEnum._200009XmldsigrsaSha1
      },
      {
        label: "RSA-SHA256",
        value: SignatureAlgorithmEnum._200104XmldsigMorersaSha256,
        default: true
      },
      {
        label: "RSA-SHA384",
        value: SignatureAlgorithmEnum._200104XmldsigMorersaSha384
      },
      {
        label: "RSA-SHA512",
        value: SignatureAlgorithmEnum._200104XmldsigMorersaSha512
      },
      {
        label: "DSA-SHA1",
        value: SignatureAlgorithmEnum._200009XmldsigdsaSha1
      }
    ]}
                            .value=${this.instance?.signatureAlgorithm}
                        >
                        </ak-radio>
                    </ak-form-element-horizontal>
                </div>
            </ak-form-group>
            <ak-form-group>
                <span slot="header"> ${msg("Flow settings")} </span>
                <div slot="body" class="pf-c-form">
                    <ak-form-element-horizontal
                        label=${msg("Pre-authentication flow")}
                        ?required=${true}
                        name="preAuthenticationFlow"
                    >
                        <ak-source-flow-search
                            flowType=${FlowsInstancesListDesignationEnum.StageConfiguration}
                            .currentFlow=${this.instance?.preAuthenticationFlow}
                            .instanceId=${this.instance?.pk}
                            fallback="default-source-pre-authentication"
                        ></ak-source-flow-search>
                        <p class="pf-c-form__helper-text">
                            ${msg("Flow used before authentication.")}
                        </p>
                    </ak-form-element-horizontal>
                    <ak-form-element-horizontal
                        label=${msg("Authentication flow")}
                        ?required=${true}
                        name="authenticationFlow"
                    >
                        <ak-source-flow-search
                            flowType=${FlowsInstancesListDesignationEnum.Authentication}
                            .currentFlow=${this.instance?.authenticationFlow}
                            .instanceId=${this.instance?.pk}
                            fallback="default-source-authentication"
                        ></ak-source-flow-search>
                        <p class="pf-c-form__helper-text">
                            ${msg("Flow to use when authenticating existing users.")}
                        </p>
                    </ak-form-element-horizontal>
                    <ak-form-element-horizontal
                        label=${msg("Enrollment flow")}
                        ?required=${true}
                        name="enrollmentFlow"
                    >
                        <ak-source-flow-search
                            flowType=${FlowsInstancesListDesignationEnum.Enrollment}
                            .currentFlow=${this.instance?.enrollmentFlow}
                            .instanceId=${this.instance?.pk}
                            fallback="default-source-enrollment"
                        ></ak-source-flow-search>
                        <p class="pf-c-form__helper-text">
                            ${msg("Flow to use when enrolling new users.")}
                        </p>
                    </ak-form-element-horizontal>
                </div>
            </ak-form-group>`;
  }
};
__decorateClass([
  r()
], SAMLSourceForm.prototype, "clearIcon", 2);
SAMLSourceForm = __decorateClass([
  t("ak-source-saml-form")
], SAMLSourceForm);

// src/admin/sources/scim/SCIMSourceForm.ts
var SCIMSourceForm = class extends BaseSourceForm {
  async loadInstance(pk) {
    return new SourcesApi(DEFAULT_CONFIG).sourcesScimRetrieve({
      slug: pk
    }).then((source) => {
      return source;
    });
  }
  async send(data) {
    if (this.instance?.slug) {
      return new SourcesApi(DEFAULT_CONFIG).sourcesScimPartialUpdate({
        slug: this.instance.slug,
        patchedSCIMSourceRequest: data
      });
    } else {
      return new SourcesApi(DEFAULT_CONFIG).sourcesScimCreate({
        sCIMSourceRequest: data
      });
    }
  }
  renderForm() {
    return x`<form class="pf-c-form pf-m-horizontal">
            <ak-form-element-horizontal label=${msg("Name")} ?required=${true} name="name">
                <input
                    type="text"
                    value="${o(this.instance?.name)}"
                    class="pf-c-form-control"
                    required
                />
            </ak-form-element-horizontal>
            <ak-form-element-horizontal label=${msg("Slug")} ?required=${true} name="slug">
                <input
                    type="text"
                    value="${o(this.instance?.slug)}"
                    class="pf-c-form-control"
                    required
                />
            </ak-form-element-horizontal>
            <ak-form-element-horizontal name="enabled">
                <div class="pf-c-check">
                    <input
                        type="checkbox"
                        class="pf-c-check__input"
                        ?checked=${first(this.instance?.enabled, true)}
                    />
                    <label class="pf-c-check__label"> ${msg("Enabled")} </label>
                </div>
            </ak-form-element-horizontal>
            <ak-form-group>
                <span slot="header"> ${msg("Advanced protocol settings")} </span>
                <div slot="body" class="pf-c-form">
                    <ak-form-element-horizontal label=${msg("User path")} name="userPathTemplate">
                        <input
                            type="text"
                            value="${first(
      this.instance?.userPathTemplate,
      "goauthentik.io/sources/%(slug)s"
    )}"
                            class="pf-c-form-control"
                        />
                        <p class="pf-c-form__helper-text">${placeholderHelperText}</p>
                    </ak-form-element-horizontal>
                </div>
            </ak-form-group>
        </form>`;
  }
};
SCIMSourceForm = __decorateClass([
  t("ak-source-scim-form")
], SCIMSourceForm);

export {
  UserMatchingModeToLabel
};
//# sourceMappingURL=chunk-ZF4XK2A3.js.map
