import {
  spacing_default
} from "./chunk-2NVIDWTP.js";
import {
  list_default
} from "./chunk-Y3LWCCWK.js";
import {
  button_default
} from "./chunk-E4FQAZYR.js";
import "./chunk-AVL64ZZC.js";
import {
  form_control_default,
  form_default,
  login_default
} from "./chunk-RVW7F5SR.js";
import {
  BaseStage,
  o,
  title_default
} from "./chunk-FP6OVRLA.js";
import {
  patternfly_base_default,
  t
} from "./chunk-DOEX53UY.js";
import {
  msg,
  x
} from "./chunk-QY7RAEC6.js";
import {
  __decorateClass
} from "./chunk-PNTXHIFL.js";

// src/flow/stages/consent/ConsentStage.ts
var ConsentStage = class extends BaseStage {
  static get styles() {
    return [patternfly_base_default, login_default, list_default, form_default, spacing_default, form_control_default, title_default, button_default];
  }
  renderPermissions(perms) {
    return x`${perms.map((permission) => {
      if (permission.name === "") {
        return x``;
      }
      if (permission.id === "openid") {
        return x``;
      }
      return x`<li data-permission-code="${permission.id}">${permission.name}</li>`;
    })}`;
  }
  renderNoPrevious() {
    return x`
            <div class="pf-c-form__group">
                <h3 id="header-text" class="pf-c-title pf-m-xl pf-u-mb-xl">
                    ${this.challenge.headerText}
                </h3>
                ${this.challenge.permissions.length > 0 ? x`
                          <p class="pf-u-mb-sm">
                              ${msg("Application requires following permissions:")}
                          </p>
                          <ul class="pf-c-list" id="permissions">
                              ${this.renderPermissions(this.challenge.permissions)}
                          </ul>
                      ` : x``}
            </div>
        `;
  }
  renderAdditional() {
    return x`
            <div class="pf-c-form__group">
                <h3 id="header-text" class="pf-c-title pf-m-xl pf-u-mb-xl">
                    ${this.challenge.headerText}
                </h3>
                ${this.challenge.permissions.length > 0 ? x`
                          <p class="pf-u-mb-sm">
                              ${msg("Application already has access to the following permissions:")}
                          </p>
                          <ul class="pf-c-list" id="permissions">
                              ${this.renderPermissions(this.challenge.permissions)}
                          </ul>
                      ` : x``}
            </div>
            <div class="pf-c-form__group pf-u-mt-md">
                ${this.challenge.additionalPermissions.length > 0 ? x`
                          <strong class="pf-u-mb-sm">
                              ${msg("Application requires following new permissions:")}
                          </strong>
                          <ul class="pf-c-list" id="permissions">
                              ${this.renderPermissions(this.challenge.additionalPermissions)}
                          </ul>
                      ` : x``}
            </div>
        `;
  }
  render() {
    if (!this.challenge) {
      return x`<ak-empty-state ?loading="${true}" header=${msg("Loading")}>
            </ak-empty-state>`;
    }
    return x`<header class="pf-c-login__main-header">
                <h1 class="pf-c-title pf-m-3xl">${this.challenge.flowInfo?.title}</h1>
            </header>
            <div class="pf-c-login__main-body">
                <form
                    class="pf-c-form"
                    @submit=${(e) => {
      this.submitForm(e, {
        token: this.challenge.token
      });
    }}
                >
                    <ak-form-static
                        class="pf-c-form__group"
                        userAvatar="${this.challenge.pendingUserAvatar}"
                        user=${this.challenge.pendingUser}
                    >
                        <div slot="link">
                            <a href="${o(this.challenge.flowInfo?.cancelUrl)}"
                                >${msg("Not you?")}</a
                            >
                        </div>
                    </ak-form-static>
                    ${this.challenge.additionalPermissions.length > 0 ? this.renderAdditional() : this.renderNoPrevious()}

                    <div class="pf-c-form__group pf-m-action">
                        <button type="submit" class="pf-c-button pf-m-primary pf-m-block">
                            ${msg("Continue")}
                        </button>
                    </div>
                </form>
            </div>
            <footer class="pf-c-login__main-footer">
                <ul class="pf-c-login__main-footer-links"></ul>
            </footer>`;
  }
};
ConsentStage = __decorateClass([
  t("ak-stage-consent")
], ConsentStage);
export {
  ConsentStage
};
//# sourceMappingURL=ConsentStage-XSZ2VW27.js.map
