import {
  UserFieldsEnum
} from "./chunk-BL2UJB63.js";
import {
  FlowDesignationEnum
} from "./chunk-DQRFNGLW.js";
import {
  alert_default
} from "./chunk-DVT5R7IG.js";
import {
  button_default
} from "./chunk-E4FQAZYR.js";
import {
  form_control_default,
  form_default,
  login_default
} from "./chunk-RVW7F5SR.js";
import {
  BaseStage,
  title_default
} from "./chunk-FP6OVRLA.js";
import {
  patternfly_base_default,
  t
} from "./chunk-DOEX53UY.js";
import {
  T,
  i,
  msg,
  str,
  x
} from "./chunk-QY7RAEC6.js";
import {
  __decorateClass
} from "./chunk-PNTXHIFL.js";

// src/admin/sources/utils.ts
function renderSourceIcon(name, iconUrl) {
  const icon = x`<i class="fas fa-share-square" title="${name}"></i>`;
  if (iconUrl) {
    if (iconUrl.startsWith("fa://")) {
      const url = iconUrl.replaceAll("fa://", "");
      return x`<i class="fas ${url}" title="${name}"></i>`;
    }
    return x`<img src="${iconUrl}" alt="${name}" />`;
  }
  return icon;
}

// src/flow/stages/identification/IdentificationStage.ts
var PasswordManagerPrefill = {
  password: void 0,
  totp: void 0
};
var OR_LIST_FORMATTERS = new Intl.ListFormat("default", {
  style: "short",
  type: "disjunction"
});
var IdentificationStage = class extends BaseStage {
  static get styles() {
    return [patternfly_base_default, alert_default, login_default, form_default, form_control_default, title_default, button_default].concat(i`
            /* login page's icons */
            .pf-c-login__main-footer-links-item button {
                background-color: transparent;
                border: 0;
                display: flex;
                align-items: stretch;
            }
            .pf-c-login__main-footer-links-item img {
                fill: var(--pf-c-login__main-footer-links-item-link-svg--Fill);
                width: 100px;
                max-width: var(--pf-c-login__main-footer-links-item-link-svg--Width);
                height: 100%;
                max-height: var(--pf-c-login__main-footer-links-item-link-svg--Height);
            }
        `);
  }
  firstUpdated() {
    this.autoRedirect();
    this.createHelperForm();
  }
  autoRedirect() {
    if (!this.challenge)
      return;
    if (this.challenge.sources?.length !== 1)
      return;
    if ((this.challenge.userFields || []).length !== 0)
      return;
    if (this.challenge.passwordlessUrl)
      return;
    const source = this.challenge.sources[0];
    this.host.challenge = source.challenge;
  }
  createHelperForm() {
    const compatMode = "ShadyDOM" in window;
    this.form = document.createElement("form");
    document.documentElement.appendChild(this.form);
    if (!compatMode) {
      const username = document.createElement("input");
      username.setAttribute("type", "text");
      username.setAttribute("name", "username");
      username.setAttribute("autocomplete", "username");
      username.onkeyup = (ev) => {
        const el = ev.target;
        (this.shadowRoot || this).querySelectorAll("input[name=uidField]").forEach((input) => {
          input.value = el.value;
          input.focus();
        });
      };
      this.form.appendChild(username);
    }
    if (!compatMode && !this.challenge.passwordFields) {
      const password = document.createElement("input");
      password.setAttribute("type", "password");
      password.setAttribute("name", "password");
      password.setAttribute("autocomplete", "current-password");
      password.onkeyup = (ev) => {
        if (ev.key == "Enter") {
          this.submitForm(ev);
        }
        const el = ev.target;
        PasswordManagerPrefill.password = el.value;
        (this.shadowRoot || this).querySelectorAll("input[name=uidField]").forEach((input) => {
          input.focus();
        });
      };
      this.form.appendChild(password);
    }
    const totp = document.createElement("input");
    totp.setAttribute("type", "text");
    totp.setAttribute("name", "code");
    totp.setAttribute("autocomplete", "one-time-code");
    totp.onkeyup = (ev) => {
      if (ev.key == "Enter") {
        this.submitForm(ev);
      }
      const el = ev.target;
      PasswordManagerPrefill.totp = el.value;
      (this.shadowRoot || this).querySelectorAll("input[name=uidField]").forEach((input) => {
        input.focus();
      });
    };
    this.form.appendChild(totp);
  }
  cleanup() {
    if (this.form) {
      this.form.remove();
    }
  }
  renderSource(source) {
    const icon = renderSourceIcon(source.name, source.iconUrl);
    return x`<li class="pf-c-login__main-footer-links-item">
            <button
                type="button"
                @click=${() => {
      if (!this.host)
        return;
      this.host.challenge = source.challenge;
    }}
                class=${this.challenge.showSourceLabels ? "pf-c-button pf-m-link" : ""}
            >
                <span class="pf-c-button__icon pf-m-start">${icon}</span>
                ${this.challenge.showSourceLabels ? source.name : ""}
            </button>
        </li>`;
  }
  renderFooter() {
    if (!this.challenge?.enrollUrl && !this.challenge?.recoveryUrl) {
      return x``;
    }
    return x`<div class="pf-c-login__main-footer-band">
            ${this.challenge.enrollUrl ? x`<p class="pf-c-login__main-footer-band-item">
                      ${msg("Need an account?")}
                      <a id="enroll" href="${this.challenge.enrollUrl}">${msg("Sign up.")}</a>
                  </p>` : T}
            ${this.challenge.recoveryUrl ? x`<p class="pf-c-login__main-footer-band-item">
                      <a id="recovery" href="${this.challenge.recoveryUrl}"
                          >${msg("Forgot username or password?")}</a
                      >
                  </p>` : T}
        </div>`;
  }
  renderInput() {
    let type = "text";
    if (!this.challenge?.userFields || this.challenge.userFields.length === 0) {
      return x`<p>${msg("Select one of the options below to continue.")}</p>`;
    }
    const fields = (this.challenge?.userFields || []).sort();
    if (fields.includes(UserFieldsEnum.Email) && fields.length === 1) {
      type = "email";
    }
    const uiFields = {
      [UserFieldsEnum.Username]: msg("Username"),
      [UserFieldsEnum.Email]: msg("Email"),
      [UserFieldsEnum.Upn]: msg("UPN")
    };
    const label = OR_LIST_FORMATTERS.format(fields.map((f) => uiFields[f]));
    return x`${this.challenge.flowDesignation === FlowDesignationEnum.Recovery ? x`
                      <p>
                          ${msg(
      "Enter the email associated with your account, and we'll send you a link to reset your password."
    )}
                      </p>
                  ` : T}
            <ak-form-element
                label=${label}
                ?required="${true}"
                class="pf-c-form__group"
                .errors=${(this.challenge.responseErrors || {})["uid_field"]}
            >
                <input
                    type=${type}
                    name="uidField"
                    placeholder=${label}
                    autofocus=""
                    autocomplete="username"
                    class="pf-c-form-control"
                    required
                />
            </ak-form-element>
            ${this.challenge.passwordFields ? x`
                      <ak-form-element
                          label="${msg("Password")}"
                          ?required="${true}"
                          class="pf-c-form__group"
                          .errors=${(this.challenge.responseErrors || {})["password"]}
                      >
                          <input
                              type="password"
                              name="password"
                              placeholder="${msg("Password")}"
                              autocomplete="current-password"
                              class="pf-c-form-control"
                              required
                              value=${PasswordManagerPrefill.password || ""}
                          />
                      </ak-form-element>
                  ` : T}
            ${"non_field_errors" in (this.challenge?.responseErrors || {}) ? this.renderNonFieldErrors(this.challenge?.responseErrors?.non_field_errors || []) : T}
            <div class="pf-c-form__group pf-m-action">
                <button type="submit" class="pf-c-button pf-m-primary pf-m-block">
                    ${this.challenge.primaryAction}
                </button>
            </div>
            ${this.challenge.passwordlessUrl ? x`<ak-divider>${msg("Or")}</ak-divider>` : T}`;
  }
  render() {
    if (!this.challenge) {
      return x`<ak-empty-state ?loading="${true}" header=${msg("Loading")}>
            </ak-empty-state>`;
    }
    return x`<header class="pf-c-login__main-header">
                <h1 class="pf-c-title pf-m-3xl">${this.challenge.flowInfo?.title}</h1>
            </header>
            <div class="pf-c-login__main-body">
                <form
                    class="pf-c-form"
                    @submit=${(e) => {
      this.submitForm(e);
    }}
                >
                    ${this.challenge.applicationPre ? x`<p>
                              ${msg(str`Login to continue to ${this.challenge.applicationPre}.`)}
                          </p>` : T}
                    ${this.renderInput()}
                    ${this.challenge.passwordlessUrl ? x`
                              <div>
                                  <a
                                      href=${this.challenge.passwordlessUrl}
                                      class="pf-c-button pf-m-secondary pf-m-block"
                                  >
                                      ${msg("Use a security key")}
                                  </a>
                              </div>
                          ` : T}
                </form>
            </div>
            <footer class="pf-c-login__main-footer">
                <ul class="pf-c-login__main-footer-links">
                    ${(this.challenge.sources || []).map((source) => {
      return this.renderSource(source);
    })}
                </ul>
                ${this.renderFooter()}
            </footer>`;
  }
};
IdentificationStage = __decorateClass([
  t("ak-stage-identification")
], IdentificationStage);

export {
  PasswordManagerPrefill,
  OR_LIST_FORMATTERS,
  IdentificationStage
};
//# sourceMappingURL=chunk-3B6GWZRW.js.map
