import {
  button_default
} from "./chunk-E4FQAZYR.js";
import {
  form_control_default,
  form_default,
  login_default
} from "./chunk-RVW7F5SR.js";
import {
  BaseStage,
  o,
  title_default
} from "./chunk-FP6OVRLA.js";
import {
  patternfly_base_default,
  r,
  t
} from "./chunk-DOEX53UY.js";
import {
  msg,
  x
} from "./chunk-QY7RAEC6.js";
import {
  __decorateClass
} from "./chunk-PNTXHIFL.js";

// src/flow/stages/captcha/CaptchaStage.ts
var captchaContainerID = "captcha-container";
var CaptchaStage = class extends BaseStage {
  constructor() {
    super();
    this.handlers = [this.handleGReCaptcha, this.handleHCaptcha, this.handleTurnstile];
    this.captchaInteractive = true;
    this.captchaContainer = document.createElement("div");
    this.captchaContainer.id = captchaContainerID;
  }
  static get styles() {
    return [patternfly_base_default, login_default, form_default, form_control_default, title_default, button_default];
  }
  firstUpdated() {
    const script = document.createElement("script");
    script.src = this.challenge.jsUrl;
    script.async = true;
    script.defer = true;
    script.onload = () => {
      console.debug("authentik/stages/captcha: script loaded");
      let found = false;
      let lastError = void 0;
      this.handlers.forEach((handler) => {
        let handlerFound = false;
        try {
          console.debug(`authentik/stages/captcha[${handler.name}]: trying handler`);
          handlerFound = handler.apply(this);
          if (handlerFound) {
            console.debug(
              `authentik/stages/captcha[${handler.name}]: handler succeeded`
            );
            found = true;
          }
        } catch (exc) {
          console.debug(
            `authentik/stages/captcha[${handler.name}]: handler failed: ${exc}`
          );
          if (handlerFound) {
            lastError = exc;
          }
        }
      });
      if (!found && lastError) {
        this.error = lastError.toString();
      }
    };
    document.head.appendChild(script);
  }
  handleGReCaptcha() {
    if (!Object.hasOwn(window, "grecaptcha")) {
      return false;
    }
    this.captchaInteractive = false;
    document.body.appendChild(this.captchaContainer);
    grecaptcha.ready(() => {
      const captchaId = grecaptcha.render(this.captchaContainer, {
        sitekey: this.challenge.siteKey,
        callback: (token) => {
          this.host?.submit({
            token
          });
        },
        size: "invisible"
      });
      grecaptcha.execute(captchaId);
    });
    return true;
  }
  handleHCaptcha() {
    if (!Object.hasOwn(window, "hcaptcha")) {
      return false;
    }
    this.captchaInteractive = false;
    document.body.appendChild(this.captchaContainer);
    const captchaId = hcaptcha.render(this.captchaContainer, {
      sitekey: this.challenge.siteKey,
      size: "invisible",
      callback: (token) => {
        this.host?.submit({
          token
        });
      }
    });
    hcaptcha.execute(captchaId);
    return true;
  }
  handleTurnstile() {
    if (!Object.hasOwn(window, "turnstile")) {
      return false;
    }
    this.captchaInteractive = false;
    document.body.appendChild(this.captchaContainer);
    window.turnstile.render(`#${captchaContainerID}`, {
      sitekey: this.challenge.siteKey,
      callback: (token) => {
        this.host?.submit({
          token
        });
      }
    });
    return true;
  }
  renderBody() {
    if (this.error) {
      return x`<ak-empty-state icon="fa-times" header=${this.error}> </ak-empty-state>`;
    }
    if (this.captchaInteractive) {
      return x`${this.captchaContainer}`;
    }
    return x`<ak-empty-state
            ?loading=${true}
            header=${msg("Verifying...")}
        ></ak-empty-state>`;
  }
  render() {
    if (!this.challenge) {
      return x`<ak-empty-state ?loading="${true}" header=${msg("Loading")}>
            </ak-empty-state>`;
    }
    return x`<header class="pf-c-login__main-header">
                <h1 class="pf-c-title pf-m-3xl">${this.challenge.flowInfo?.title}</h1>
            </header>
            <div class="pf-c-login__main-body">
                <form class="pf-c-form">
                    <ak-form-static
                        class="pf-c-form__group"
                        userAvatar="${this.challenge.pendingUserAvatar}"
                        user=${this.challenge.pendingUser}
                    >
                        <div slot="link">
                            <a href="${o(this.challenge.flowInfo?.cancelUrl)}"
                                >${msg("Not you?")}</a
                            >
                        </div>
                    </ak-form-static>
                    ${this.renderBody()}
                </form>
            </div>
            <footer class="pf-c-login__main-footer">
                <ul class="pf-c-login__main-footer-links"></ul>
            </footer>`;
  }
};
__decorateClass([
  r()
], CaptchaStage.prototype, "error", 2);
__decorateClass([
  r()
], CaptchaStage.prototype, "captchaInteractive", 2);
__decorateClass([
  r()
], CaptchaStage.prototype, "captchaContainer", 2);
CaptchaStage = __decorateClass([
  t("ak-stage-captcha")
], CaptchaStage);

export {
  CaptchaStage
};
//# sourceMappingURL=chunk-57T2AV4K.js.map
