import {
  PasswordManagerPrefill
} from "./chunk-3B6GWZRW.js";
import {
  button_default
} from "./chunk-E4FQAZYR.js";
import {
  form_control_default,
  form_default,
  login_default
} from "./chunk-RVW7F5SR.js";
import {
  BaseStage,
  o,
  title_default
} from "./chunk-FP6OVRLA.js";
import {
  patternfly_base_default,
  t
} from "./chunk-DOEX53UY.js";
import {
  msg,
  x
} from "./chunk-QY7RAEC6.js";
import {
  __decorateClass
} from "./chunk-PNTXHIFL.js";

// src/flow/stages/password/PasswordStage.ts
var PasswordStage = class extends BaseStage {
  static get styles() {
    return [patternfly_base_default, login_default, form_default, form_control_default, button_default, title_default];
  }
  hasError(field) {
    const errors = (this.challenge?.responseErrors || {})[field];
    return (errors || []).length > 0;
  }
  renderInput() {
    this.input = document.createElement("input");
    this.input.type = "password";
    this.input.name = "password";
    this.input.placeholder = msg("Please enter your password");
    this.input.autofocus = true;
    this.input.autocomplete = "current-password";
    this.input.classList.add("pf-c-form-control");
    this.input.required = true;
    this.input.value = PasswordManagerPrefill.password || "";
    this.input.setAttribute("aria-invalid", this.hasError("password").toString());
    this.timer = window.setInterval(() => {
      if (!this.input) {
        return;
      }
      const rootEl = document.activeElement;
      const isActive = (el) => {
        if (!rootEl)
          return false;
        if (!("shadowRoot" in rootEl))
          return false;
        if (rootEl.shadowRoot === null)
          return false;
        if (rootEl.shadowRoot.activeElement === el)
          return true;
        return isActive(rootEl.shadowRoot.activeElement);
      };
      if (isActive(this.input)) {
        this.cleanup();
      }
      this.input.focus();
    }, 10);
    console.debug("authentik/stages/password: started focus timer");
    return this.input;
  }
  cleanup() {
    if (this.timer) {
      console.debug("authentik/stages/password: cleared focus timer");
      window.clearInterval(this.timer);
      this.timer = void 0;
    }
  }
  render() {
    if (!this.challenge) {
      return x`<ak-empty-state ?loading="${true}" header=${msg("Loading")}>
            </ak-empty-state>`;
    }
    return x`<header class="pf-c-login__main-header">
                <h1 class="pf-c-title pf-m-3xl">${this.challenge.flowInfo?.title}</h1>
            </header>
            <div class="pf-c-login__main-body">
                <form
                    class="pf-c-form"
                    @submit=${(e) => {
      this.submitForm(e);
    }}
                >
                    <ak-form-static
                        class="pf-c-form__group"
                        userAvatar="${this.challenge.pendingUserAvatar}"
                        user=${this.challenge.pendingUser}
                    >
                        <div slot="link">
                            <a href="${o(this.challenge.flowInfo?.cancelUrl)}"
                                >${msg("Not you?")}</a
                            >
                        </div>
                    </ak-form-static>
                    <input
                        name="username"
                        autocomplete="username"
                        type="hidden"
                        value="${this.challenge.pendingUser}"
                    />
                    <ak-form-element
                        label="${msg("Password")}"
                        ?required="${true}"
                        class="pf-c-form__group"
                        .errors=${(this.challenge?.responseErrors || {})["password"]}
                    >
                        ${this.renderInput()}
                    </ak-form-element>

                    ${this.challenge.recoveryUrl ? x`<a href="${this.challenge.recoveryUrl}">
                              ${msg("Forgot password?")}</a
                          >` : ""}

                    <div class="pf-c-form__group pf-m-action">
                        <button type="submit" class="pf-c-button pf-m-primary pf-m-block">
                            ${msg("Continue")}
                        </button>
                    </div>
                </form>
            </div>
            <footer class="pf-c-login__main-footer">
                <ul class="pf-c-login__main-footer-links"></ul>
            </footer>`;
  }
};
PasswordStage = __decorateClass([
  t("ak-stage-password")
], PasswordStage);

export {
  PasswordStage
};
//# sourceMappingURL=chunk-XN7X7VCX.js.map
