import {
  BaseProviderForm
} from "./chunk-EINGTETQ.js";
import {
  PropertymappingsApi
} from "./chunk-G6FYWANS.js";
import {
  browser_default
} from "./chunk-CH5LDOJ6.js";
import {
  ModelForm
} from "./chunk-ZVKXJXN6.js";
import {
  ProvidersApi
} from "./chunk-SFAGFFHP.js";
import {
  SourcesApi
} from "./chunk-XSB422CX.js";
import {
  FlowsInstancesListDesignationEnum
} from "./chunk-2G3GM457.js";
import {
  list_default
} from "./chunk-WPHOZTKQ.js";
import {
  o
} from "./chunk-5MMRTU65.js";
import {
  CoreApi,
  DEFAULT_CONFIG,
  DigestAlgorithmEnum,
  LDAPAPIAccessMode,
  ProxyMode,
  SignatureAlgorithmEnum,
  SpBindingEnum,
  WithBrandConfig,
  ascii_letters,
  content_default,
  digits,
  first,
  r,
  randomString,
  t
} from "./chunk-EOF5OWT7.js";
import {
  msg,
  x
} from "./chunk-MDYFRBOX.js";
import {
  __decorateClass
} from "./chunk-6IFWU6BM.js";

// src/admin/providers/ldap/LDAPProviderForm.ts
var LDAPProviderFormPage = class extends WithBrandConfig(BaseProviderForm) {
  async loadInstance(pk) {
    return new ProvidersApi(DEFAULT_CONFIG).providersLdapRetrieve({
      id: pk
    });
  }
  async send(data) {
    if (this.instance) {
      return new ProvidersApi(DEFAULT_CONFIG).providersLdapUpdate({
        id: this.instance.pk || 0,
        lDAPProviderRequest: data
      });
    } else {
      return new ProvidersApi(DEFAULT_CONFIG).providersLdapCreate({
        lDAPProviderRequest: data
      });
    }
  }
  // All Provider objects have an Authorization flow, but not all providers have an Authentication
  // flow. LDAP needs only one field, but it is not an Authorization field, it is an
  // Authentication field. So, yeah, we're using the authorization field to store the
  // authentication information, which is why the ak-branded-flow-search call down there looks so
  // weird-- we're looking up Authentication flows, but we're storing them in the Authorization
  // field of the target Provider.
  renderForm() {
    return x` <ak-form-element-horizontal label=${msg("Name")} ?required=${true} name="name">
                <input
                    type="text"
                    value="${o(this.instance?.name)}"
                    class="pf-c-form-control"
                    required
                />
            </ak-form-element-horizontal>
            <ak-form-element-horizontal
                label=${msg("Bind flow")}
                ?required=${true}
                name="authorizationFlow"
            >
                <ak-branded-flow-search
                    flowType=${FlowsInstancesListDesignationEnum.Authentication}
                    .currentFlow=${this.instance?.authorizationFlow}
                    .brandFlow=${this.brand?.flowAuthentication}
                    required
                ></ak-branded-flow-search>
                <p class="pf-c-form__helper-text">${msg("Flow used for users to authenticate.")}</p>
            </ak-form-element-horizontal>
            <ak-form-element-horizontal label=${msg("Search group")} name="searchGroup">
                <ak-search-select
                    .fetchObjects=${async (query) => {
      const args = {
        ordering: "name"
      };
      if (query !== void 0) {
        args.search = query;
      }
      const groups = await new CoreApi(DEFAULT_CONFIG).coreGroupsList(args);
      return groups.results;
    }}
                    .renderElement=${(group) => {
      return group.name;
    }}
                    .value=${(group) => {
      return group?.pk;
    }}
                    .selected=${(group) => {
      return group.pk === this.instance?.searchGroup;
    }}
                    ?blankable=${true}
                >
                </ak-search-select>
                <p class="pf-c-form__helper-text">
                    ${msg(
      "Users in the selected group can do search queries. If no group is selected, no LDAP Searches are allowed."
    )}
                </p>
            </ak-form-element-horizontal>
            <ak-form-element-horizontal label=${msg("Bind mode")} name="bindMode">
                <ak-radio
                    .options=${[
      {
        label: msg("Cached binding"),
        value: LDAPAPIAccessMode.Cached,
        default: true,
        description: x`${msg(
          "Flow is executed and session is cached in memory. Flow is executed when session expires"
        )}`
      },
      {
        label: msg("Direct binding"),
        value: LDAPAPIAccessMode.Direct,
        description: x`${msg(
          "Always execute the configured bind flow to authenticate the user"
        )}`
      }
    ]}
                    .value=${this.instance?.bindMode}
                >
                </ak-radio>
                <p class="pf-c-form__helper-text">
                    ${msg("Configure how the outpost authenticates requests.")}
                </p>
            </ak-form-element-horizontal>
            <ak-form-element-horizontal label=${msg("Search mode")} name="searchMode">
                <ak-radio
                    .options=${[
      {
        label: msg("Cached querying"),
        value: LDAPAPIAccessMode.Cached,
        default: true,
        description: x`${msg(
          "The outpost holds all users and groups in-memory and will refresh every 5 Minutes"
        )}`
      },
      {
        label: msg("Direct querying"),
        value: LDAPAPIAccessMode.Direct,
        description: x`${msg(
          "Always returns the latest data, but slower than cached querying"
        )}`
      }
    ]}
                    .value=${this.instance?.searchMode}
                >
                </ak-radio>
                <p class="pf-c-form__helper-text">
                    ${msg("Configure how the outpost queries the core authentik server's users.")}
                </p>
            </ak-form-element-horizontal>
            <ak-form-element-horizontal name="mfaSupport">
                <label class="pf-c-switch">
                    <input
                        class="pf-c-switch__input"
                        type="checkbox"
                        ?checked=${first(this.instance?.mfaSupport, true)}
                    />
                    <span class="pf-c-switch__toggle">
                        <span class="pf-c-switch__toggle-icon">
                            <i class="fas fa-check" aria-hidden="true"></i>
                        </span>
                    </span>
                    <span class="pf-c-switch__label">${msg("Code-based MFA Support")}</span>
                </label>
                <p class="pf-c-form__helper-text">
                    ${msg(
      "When enabled, code-based multi-factor authentication can be used by appending a semicolon and the TOTP code to the password. This should only be enabled if all users that will bind to this provider have a TOTP device configured, as otherwise a password may incorrectly be rejected if it contains a semicolon."
    )}
                </p>
            </ak-form-element-horizontal>

            <ak-form-group .expanded=${true}>
                <span slot="header"> ${msg("Protocol settings")} </span>
                <div slot="body" class="pf-c-form">
                    <ak-form-element-horizontal
                        label=${msg("Base DN")}
                        ?required=${true}
                        name="baseDn"
                    >
                        <input
                            type="text"
                            value="${first(this.instance?.baseDn, "DC=ldap,DC=goauthentik,DC=io")}"
                            class="pf-c-form-control"
                            required
                        />
                        <p class="pf-c-form__helper-text">
                            ${msg(
      "LDAP DN under which bind requests and search requests can be made."
    )}
                        </p>
                    </ak-form-element-horizontal>
                    <ak-form-element-horizontal label=${msg("Certificate")} name="certificate">
                        <ak-crypto-certificate-search
                            .certificate=${this.instance?.certificate}
                        ></ak-crypto-certificate-search>
                        <p class="pf-c-form__helper-text">
                            ${msg(
      "The certificate for the above configured Base DN. As a fallback, the provider uses a self-signed certificate."
    )}
                        </p>
                    </ak-form-element-horizontal>
                    <ak-form-element-horizontal
                        label=${msg("TLS Server name")}
                        name="tlsServerName"
                    >
                        <input
                            type="text"
                            value="${first(this.instance?.tlsServerName, "")}"
                            class="pf-c-form-control"
                            required
                        />
                        <p class="pf-c-form__helper-text">
                            ${msg(
      "DNS name for which the above configured certificate should be used. The certificate cannot be detected based on the base DN, as the SSL/TLS negotiation happens before such data is exchanged."
    )}
                        </p>
                    </ak-form-element-horizontal>
                    <ak-form-element-horizontal
                        label=${msg("UID start number")}
                        ?required=${true}
                        name="uidStartNumber"
                    >
                        <input
                            type="number"
                            value="${first(this.instance?.uidStartNumber, 2e3)}"
                            class="pf-c-form-control"
                            required
                        />
                        <p class="pf-c-form__helper-text">
                            ${msg(
      "The start for uidNumbers, this number is added to the user.Pk to make sure that the numbers aren't too low for POSIX users. Default is 2000 to ensure that we don't collide with local users uidNumber"
    )}
                        </p>
                    </ak-form-element-horizontal>
                    <ak-form-element-horizontal
                        label=${msg("GID start number")}
                        ?required=${true}
                        name="gidStartNumber"
                    >
                        <input
                            type="number"
                            value="${first(this.instance?.gidStartNumber, 4e3)}"
                            class="pf-c-form-control"
                            required
                        />
                        <p class="pf-c-form__helper-text">
                            ${msg(
      "The start for gidNumbers, this number is added to a number generated from the group.Pk to make sure that the numbers aren't too low for POSIX groups. Default is 4000 to ensure that we don't collide with local groups or users primary groups gidNumber"
    )}
                        </p>
                    </ak-form-element-horizontal>
                </div>
            </ak-form-group>`;
  }
};
LDAPProviderFormPage = __decorateClass([
  t("ak-provider-ldap-form")
], LDAPProviderFormPage);

// node_modules/@patternfly/patternfly/utilities/Spacing/spacing.css
var spacing_default = ".pf-u-m-auto {\n  margin: auto !important;\n}\n\n.pf-u-m-0 {\n  margin: 0 !important;\n}\n\n.pf-u-m-xs {\n  margin: var(--pf-global--spacer--xs) !important;\n}\n\n.pf-u-m-sm {\n  margin: var(--pf-global--spacer--sm) !important;\n}\n\n.pf-u-m-md {\n  margin: var(--pf-global--spacer--md) !important;\n}\n\n.pf-u-m-lg {\n  margin: var(--pf-global--spacer--lg) !important;\n}\n\n.pf-u-m-xl {\n  margin: var(--pf-global--spacer--xl) !important;\n}\n\n.pf-u-m-2xl {\n  margin: var(--pf-global--spacer--2xl) !important;\n}\n\n.pf-u-m-3xl {\n  margin: var(--pf-global--spacer--3xl) !important;\n}\n\n.pf-u-m-4xl {\n  margin: var(--pf-global--spacer--4xl) !important;\n}\n\n.pf-u-mt-auto {\n  margin-top: auto !important;\n}\n\n.pf-u-mt-0 {\n  margin-top: 0 !important;\n}\n\n.pf-u-mt-xs {\n  margin-top: var(--pf-global--spacer--xs) !important;\n}\n\n.pf-u-mt-sm {\n  margin-top: var(--pf-global--spacer--sm) !important;\n}\n\n.pf-u-mt-md {\n  margin-top: var(--pf-global--spacer--md) !important;\n}\n\n.pf-u-mt-lg {\n  margin-top: var(--pf-global--spacer--lg) !important;\n}\n\n.pf-u-mt-xl {\n  margin-top: var(--pf-global--spacer--xl) !important;\n}\n\n.pf-u-mt-2xl {\n  margin-top: var(--pf-global--spacer--2xl) !important;\n}\n\n.pf-u-mt-3xl {\n  margin-top: var(--pf-global--spacer--3xl) !important;\n}\n\n.pf-u-mt-4xl {\n  margin-top: var(--pf-global--spacer--4xl) !important;\n}\n\n.pf-u-mr-auto {\n  margin-right: auto !important;\n}\n\n.pf-u-mr-0 {\n  margin-right: 0 !important;\n}\n\n.pf-u-mr-xs {\n  margin-right: var(--pf-global--spacer--xs) !important;\n}\n\n.pf-u-mr-sm {\n  margin-right: var(--pf-global--spacer--sm) !important;\n}\n\n.pf-u-mr-md {\n  margin-right: var(--pf-global--spacer--md) !important;\n}\n\n.pf-u-mr-lg {\n  margin-right: var(--pf-global--spacer--lg) !important;\n}\n\n.pf-u-mr-xl {\n  margin-right: var(--pf-global--spacer--xl) !important;\n}\n\n.pf-u-mr-2xl {\n  margin-right: var(--pf-global--spacer--2xl) !important;\n}\n\n.pf-u-mr-3xl {\n  margin-right: var(--pf-global--spacer--3xl) !important;\n}\n\n.pf-u-mr-4xl {\n  margin-right: var(--pf-global--spacer--4xl) !important;\n}\n\n.pf-u-mb-auto {\n  margin-bottom: auto !important;\n}\n\n.pf-u-mb-0 {\n  margin-bottom: 0 !important;\n}\n\n.pf-u-mb-xs {\n  margin-bottom: var(--pf-global--spacer--xs) !important;\n}\n\n.pf-u-mb-sm {\n  margin-bottom: var(--pf-global--spacer--sm) !important;\n}\n\n.pf-u-mb-md {\n  margin-bottom: var(--pf-global--spacer--md) !important;\n}\n\n.pf-u-mb-lg {\n  margin-bottom: var(--pf-global--spacer--lg) !important;\n}\n\n.pf-u-mb-xl {\n  margin-bottom: var(--pf-global--spacer--xl) !important;\n}\n\n.pf-u-mb-2xl {\n  margin-bottom: var(--pf-global--spacer--2xl) !important;\n}\n\n.pf-u-mb-3xl {\n  margin-bottom: var(--pf-global--spacer--3xl) !important;\n}\n\n.pf-u-mb-4xl {\n  margin-bottom: var(--pf-global--spacer--4xl) !important;\n}\n\n.pf-u-ml-auto {\n  margin-left: auto !important;\n}\n\n.pf-u-ml-0 {\n  margin-left: 0 !important;\n}\n\n.pf-u-ml-xs {\n  margin-left: var(--pf-global--spacer--xs) !important;\n}\n\n.pf-u-ml-sm {\n  margin-left: var(--pf-global--spacer--sm) !important;\n}\n\n.pf-u-ml-md {\n  margin-left: var(--pf-global--spacer--md) !important;\n}\n\n.pf-u-ml-lg {\n  margin-left: var(--pf-global--spacer--lg) !important;\n}\n\n.pf-u-ml-xl {\n  margin-left: var(--pf-global--spacer--xl) !important;\n}\n\n.pf-u-ml-2xl {\n  margin-left: var(--pf-global--spacer--2xl) !important;\n}\n\n.pf-u-ml-3xl {\n  margin-left: var(--pf-global--spacer--3xl) !important;\n}\n\n.pf-u-ml-4xl {\n  margin-left: var(--pf-global--spacer--4xl) !important;\n}\n\n.pf-u-mx-auto {\n  margin-right: auto !important;\n  margin-left: auto !important;\n}\n\n.pf-u-mx-0 {\n  margin-right: 0 !important;\n  margin-left: 0 !important;\n}\n\n.pf-u-mx-xs {\n  margin-right: var(--pf-global--spacer--xs) !important;\n  margin-left: var(--pf-global--spacer--xs) !important;\n}\n\n.pf-u-mx-sm {\n  margin-right: var(--pf-global--spacer--sm) !important;\n  margin-left: var(--pf-global--spacer--sm) !important;\n}\n\n.pf-u-mx-md {\n  margin-right: var(--pf-global--spacer--md) !important;\n  margin-left: var(--pf-global--spacer--md) !important;\n}\n\n.pf-u-mx-lg {\n  margin-right: var(--pf-global--spacer--lg) !important;\n  margin-left: var(--pf-global--spacer--lg) !important;\n}\n\n.pf-u-mx-xl {\n  margin-right: var(--pf-global--spacer--xl) !important;\n  margin-left: var(--pf-global--spacer--xl) !important;\n}\n\n.pf-u-mx-2xl {\n  margin-right: var(--pf-global--spacer--2xl) !important;\n  margin-left: var(--pf-global--spacer--2xl) !important;\n}\n\n.pf-u-mx-3xl {\n  margin-right: var(--pf-global--spacer--3xl) !important;\n  margin-left: var(--pf-global--spacer--3xl) !important;\n}\n\n.pf-u-mx-4xl {\n  margin-right: var(--pf-global--spacer--4xl) !important;\n  margin-left: var(--pf-global--spacer--4xl) !important;\n}\n\n.pf-u-my-auto {\n  margin-top: auto !important;\n  margin-bottom: auto !important;\n}\n\n.pf-u-my-0 {\n  margin-top: 0 !important;\n  margin-bottom: 0 !important;\n}\n\n.pf-u-my-xs {\n  margin-top: var(--pf-global--spacer--xs) !important;\n  margin-bottom: var(--pf-global--spacer--xs) !important;\n}\n\n.pf-u-my-sm {\n  margin-top: var(--pf-global--spacer--sm) !important;\n  margin-bottom: var(--pf-global--spacer--sm) !important;\n}\n\n.pf-u-my-md {\n  margin-top: var(--pf-global--spacer--md) !important;\n  margin-bottom: var(--pf-global--spacer--md) !important;\n}\n\n.pf-u-my-lg {\n  margin-top: var(--pf-global--spacer--lg) !important;\n  margin-bottom: var(--pf-global--spacer--lg) !important;\n}\n\n.pf-u-my-xl {\n  margin-top: var(--pf-global--spacer--xl) !important;\n  margin-bottom: var(--pf-global--spacer--xl) !important;\n}\n\n.pf-u-my-2xl {\n  margin-top: var(--pf-global--spacer--2xl) !important;\n  margin-bottom: var(--pf-global--spacer--2xl) !important;\n}\n\n.pf-u-my-3xl {\n  margin-top: var(--pf-global--spacer--3xl) !important;\n  margin-bottom: var(--pf-global--spacer--3xl) !important;\n}\n\n.pf-u-my-4xl {\n  margin-top: var(--pf-global--spacer--4xl) !important;\n  margin-bottom: var(--pf-global--spacer--4xl) !important;\n}\n\n.pf-u-p-auto {\n  padding: auto !important;\n}\n\n.pf-u-p-0 {\n  padding: 0 !important;\n}\n\n.pf-u-p-xs {\n  padding: var(--pf-global--spacer--xs) !important;\n}\n\n.pf-u-p-sm {\n  padding: var(--pf-global--spacer--sm) !important;\n}\n\n.pf-u-p-md {\n  padding: var(--pf-global--spacer--md) !important;\n}\n\n.pf-u-p-lg {\n  padding: var(--pf-global--spacer--lg) !important;\n}\n\n.pf-u-p-xl {\n  padding: var(--pf-global--spacer--xl) !important;\n}\n\n.pf-u-p-2xl {\n  padding: var(--pf-global--spacer--2xl) !important;\n}\n\n.pf-u-p-3xl {\n  padding: var(--pf-global--spacer--3xl) !important;\n}\n\n.pf-u-p-4xl {\n  padding: var(--pf-global--spacer--4xl) !important;\n}\n\n.pf-u-pt-auto {\n  padding-top: auto !important;\n}\n\n.pf-u-pt-0 {\n  padding-top: 0 !important;\n}\n\n.pf-u-pt-xs {\n  padding-top: var(--pf-global--spacer--xs) !important;\n}\n\n.pf-u-pt-sm {\n  padding-top: var(--pf-global--spacer--sm) !important;\n}\n\n.pf-u-pt-md {\n  padding-top: var(--pf-global--spacer--md) !important;\n}\n\n.pf-u-pt-lg {\n  padding-top: var(--pf-global--spacer--lg) !important;\n}\n\n.pf-u-pt-xl {\n  padding-top: var(--pf-global--spacer--xl) !important;\n}\n\n.pf-u-pt-2xl {\n  padding-top: var(--pf-global--spacer--2xl) !important;\n}\n\n.pf-u-pt-3xl {\n  padding-top: var(--pf-global--spacer--3xl) !important;\n}\n\n.pf-u-pt-4xl {\n  padding-top: var(--pf-global--spacer--4xl) !important;\n}\n\n.pf-u-pr-auto {\n  padding-right: auto !important;\n}\n\n.pf-u-pr-0 {\n  padding-right: 0 !important;\n}\n\n.pf-u-pr-xs {\n  padding-right: var(--pf-global--spacer--xs) !important;\n}\n\n.pf-u-pr-sm {\n  padding-right: var(--pf-global--spacer--sm) !important;\n}\n\n.pf-u-pr-md {\n  padding-right: var(--pf-global--spacer--md) !important;\n}\n\n.pf-u-pr-lg {\n  padding-right: var(--pf-global--spacer--lg) !important;\n}\n\n.pf-u-pr-xl {\n  padding-right: var(--pf-global--spacer--xl) !important;\n}\n\n.pf-u-pr-2xl {\n  padding-right: var(--pf-global--spacer--2xl) !important;\n}\n\n.pf-u-pr-3xl {\n  padding-right: var(--pf-global--spacer--3xl) !important;\n}\n\n.pf-u-pr-4xl {\n  padding-right: var(--pf-global--spacer--4xl) !important;\n}\n\n.pf-u-pb-auto {\n  padding-bottom: auto !important;\n}\n\n.pf-u-pb-0 {\n  padding-bottom: 0 !important;\n}\n\n.pf-u-pb-xs {\n  padding-bottom: var(--pf-global--spacer--xs) !important;\n}\n\n.pf-u-pb-sm {\n  padding-bottom: var(--pf-global--spacer--sm) !important;\n}\n\n.pf-u-pb-md {\n  padding-bottom: var(--pf-global--spacer--md) !important;\n}\n\n.pf-u-pb-lg {\n  padding-bottom: var(--pf-global--spacer--lg) !important;\n}\n\n.pf-u-pb-xl {\n  padding-bottom: var(--pf-global--spacer--xl) !important;\n}\n\n.pf-u-pb-2xl {\n  padding-bottom: var(--pf-global--spacer--2xl) !important;\n}\n\n.pf-u-pb-3xl {\n  padding-bottom: var(--pf-global--spacer--3xl) !important;\n}\n\n.pf-u-pb-4xl {\n  padding-bottom: var(--pf-global--spacer--4xl) !important;\n}\n\n.pf-u-pl-auto {\n  padding-left: auto !important;\n}\n\n.pf-u-pl-0 {\n  padding-left: 0 !important;\n}\n\n.pf-u-pl-xs {\n  padding-left: var(--pf-global--spacer--xs) !important;\n}\n\n.pf-u-pl-sm {\n  padding-left: var(--pf-global--spacer--sm) !important;\n}\n\n.pf-u-pl-md {\n  padding-left: var(--pf-global--spacer--md) !important;\n}\n\n.pf-u-pl-lg {\n  padding-left: var(--pf-global--spacer--lg) !important;\n}\n\n.pf-u-pl-xl {\n  padding-left: var(--pf-global--spacer--xl) !important;\n}\n\n.pf-u-pl-2xl {\n  padding-left: var(--pf-global--spacer--2xl) !important;\n}\n\n.pf-u-pl-3xl {\n  padding-left: var(--pf-global--spacer--3xl) !important;\n}\n\n.pf-u-pl-4xl {\n  padding-left: var(--pf-global--spacer--4xl) !important;\n}\n\n.pf-u-px-auto {\n  padding-right: auto !important;\n  padding-left: auto !important;\n}\n\n.pf-u-px-0 {\n  padding-right: 0 !important;\n  padding-left: 0 !important;\n}\n\n.pf-u-px-xs {\n  padding-right: var(--pf-global--spacer--xs) !important;\n  padding-left: var(--pf-global--spacer--xs) !important;\n}\n\n.pf-u-px-sm {\n  padding-right: var(--pf-global--spacer--sm) !important;\n  padding-left: var(--pf-global--spacer--sm) !important;\n}\n\n.pf-u-px-md {\n  padding-right: var(--pf-global--spacer--md) !important;\n  padding-left: var(--pf-global--spacer--md) !important;\n}\n\n.pf-u-px-lg {\n  padding-right: var(--pf-global--spacer--lg) !important;\n  padding-left: var(--pf-global--spacer--lg) !important;\n}\n\n.pf-u-px-xl {\n  padding-right: var(--pf-global--spacer--xl) !important;\n  padding-left: var(--pf-global--spacer--xl) !important;\n}\n\n.pf-u-px-2xl {\n  padding-right: var(--pf-global--spacer--2xl) !important;\n  padding-left: var(--pf-global--spacer--2xl) !important;\n}\n\n.pf-u-px-3xl {\n  padding-right: var(--pf-global--spacer--3xl) !important;\n  padding-left: var(--pf-global--spacer--3xl) !important;\n}\n\n.pf-u-px-4xl {\n  padding-right: var(--pf-global--spacer--4xl) !important;\n  padding-left: var(--pf-global--spacer--4xl) !important;\n}\n\n.pf-u-py-auto {\n  padding-top: auto !important;\n  padding-bottom: auto !important;\n}\n\n.pf-u-py-0 {\n  padding-top: 0 !important;\n  padding-bottom: 0 !important;\n}\n\n.pf-u-py-xs {\n  padding-top: var(--pf-global--spacer--xs) !important;\n  padding-bottom: var(--pf-global--spacer--xs) !important;\n}\n\n.pf-u-py-sm {\n  padding-top: var(--pf-global--spacer--sm) !important;\n  padding-bottom: var(--pf-global--spacer--sm) !important;\n}\n\n.pf-u-py-md {\n  padding-top: var(--pf-global--spacer--md) !important;\n  padding-bottom: var(--pf-global--spacer--md) !important;\n}\n\n.pf-u-py-lg {\n  padding-top: var(--pf-global--spacer--lg) !important;\n  padding-bottom: var(--pf-global--spacer--lg) !important;\n}\n\n.pf-u-py-xl {\n  padding-top: var(--pf-global--spacer--xl) !important;\n  padding-bottom: var(--pf-global--spacer--xl) !important;\n}\n\n.pf-u-py-2xl {\n  padding-top: var(--pf-global--spacer--2xl) !important;\n  padding-bottom: var(--pf-global--spacer--2xl) !important;\n}\n\n.pf-u-py-3xl {\n  padding-top: var(--pf-global--spacer--3xl) !important;\n  padding-bottom: var(--pf-global--spacer--3xl) !important;\n}\n\n.pf-u-py-4xl {\n  padding-top: var(--pf-global--spacer--4xl) !important;\n  padding-bottom: var(--pf-global--spacer--4xl) !important;\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-m-auto-on-sm {\n    margin: auto !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-m-0-on-sm {\n    margin: 0 !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-m-xs-on-sm {\n    margin: var(--pf-global--spacer--xs) !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-m-sm-on-sm {\n    margin: var(--pf-global--spacer--sm) !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-m-md-on-sm {\n    margin: var(--pf-global--spacer--md) !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-m-lg-on-sm {\n    margin: var(--pf-global--spacer--lg) !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-m-xl-on-sm {\n    margin: var(--pf-global--spacer--xl) !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-m-2xl-on-sm {\n    margin: var(--pf-global--spacer--2xl) !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-m-3xl-on-sm {\n    margin: var(--pf-global--spacer--3xl) !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-m-4xl-on-sm {\n    margin: var(--pf-global--spacer--4xl) !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-mt-auto-on-sm {\n    margin-top: auto !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-mt-0-on-sm {\n    margin-top: 0 !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-mt-xs-on-sm {\n    margin-top: var(--pf-global--spacer--xs) !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-mt-sm-on-sm {\n    margin-top: var(--pf-global--spacer--sm) !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-mt-md-on-sm {\n    margin-top: var(--pf-global--spacer--md) !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-mt-lg-on-sm {\n    margin-top: var(--pf-global--spacer--lg) !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-mt-xl-on-sm {\n    margin-top: var(--pf-global--spacer--xl) !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-mt-2xl-on-sm {\n    margin-top: var(--pf-global--spacer--2xl) !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-mt-3xl-on-sm {\n    margin-top: var(--pf-global--spacer--3xl) !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-mt-4xl-on-sm {\n    margin-top: var(--pf-global--spacer--4xl) !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-mr-auto-on-sm {\n    margin-right: auto !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-mr-0-on-sm {\n    margin-right: 0 !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-mr-xs-on-sm {\n    margin-right: var(--pf-global--spacer--xs) !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-mr-sm-on-sm {\n    margin-right: var(--pf-global--spacer--sm) !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-mr-md-on-sm {\n    margin-right: var(--pf-global--spacer--md) !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-mr-lg-on-sm {\n    margin-right: var(--pf-global--spacer--lg) !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-mr-xl-on-sm {\n    margin-right: var(--pf-global--spacer--xl) !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-mr-2xl-on-sm {\n    margin-right: var(--pf-global--spacer--2xl) !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-mr-3xl-on-sm {\n    margin-right: var(--pf-global--spacer--3xl) !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-mr-4xl-on-sm {\n    margin-right: var(--pf-global--spacer--4xl) !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-mb-auto-on-sm {\n    margin-bottom: auto !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-mb-0-on-sm {\n    margin-bottom: 0 !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-mb-xs-on-sm {\n    margin-bottom: var(--pf-global--spacer--xs) !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-mb-sm-on-sm {\n    margin-bottom: var(--pf-global--spacer--sm) !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-mb-md-on-sm {\n    margin-bottom: var(--pf-global--spacer--md) !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-mb-lg-on-sm {\n    margin-bottom: var(--pf-global--spacer--lg) !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-mb-xl-on-sm {\n    margin-bottom: var(--pf-global--spacer--xl) !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-mb-2xl-on-sm {\n    margin-bottom: var(--pf-global--spacer--2xl) !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-mb-3xl-on-sm {\n    margin-bottom: var(--pf-global--spacer--3xl) !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-mb-4xl-on-sm {\n    margin-bottom: var(--pf-global--spacer--4xl) !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-ml-auto-on-sm {\n    margin-left: auto !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-ml-0-on-sm {\n    margin-left: 0 !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-ml-xs-on-sm {\n    margin-left: var(--pf-global--spacer--xs) !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-ml-sm-on-sm {\n    margin-left: var(--pf-global--spacer--sm) !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-ml-md-on-sm {\n    margin-left: var(--pf-global--spacer--md) !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-ml-lg-on-sm {\n    margin-left: var(--pf-global--spacer--lg) !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-ml-xl-on-sm {\n    margin-left: var(--pf-global--spacer--xl) !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-ml-2xl-on-sm {\n    margin-left: var(--pf-global--spacer--2xl) !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-ml-3xl-on-sm {\n    margin-left: var(--pf-global--spacer--3xl) !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-ml-4xl-on-sm {\n    margin-left: var(--pf-global--spacer--4xl) !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-mx-auto-on-sm {\n    margin-right: auto !important;\n    margin-left: auto !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-mx-0-on-sm {\n    margin-right: 0 !important;\n    margin-left: 0 !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-mx-xs-on-sm {\n    margin-right: var(--pf-global--spacer--xs) !important;\n    margin-left: var(--pf-global--spacer--xs) !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-mx-sm-on-sm {\n    margin-right: var(--pf-global--spacer--sm) !important;\n    margin-left: var(--pf-global--spacer--sm) !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-mx-md-on-sm {\n    margin-right: var(--pf-global--spacer--md) !important;\n    margin-left: var(--pf-global--spacer--md) !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-mx-lg-on-sm {\n    margin-right: var(--pf-global--spacer--lg) !important;\n    margin-left: var(--pf-global--spacer--lg) !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-mx-xl-on-sm {\n    margin-right: var(--pf-global--spacer--xl) !important;\n    margin-left: var(--pf-global--spacer--xl) !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-mx-2xl-on-sm {\n    margin-right: var(--pf-global--spacer--2xl) !important;\n    margin-left: var(--pf-global--spacer--2xl) !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-mx-3xl-on-sm {\n    margin-right: var(--pf-global--spacer--3xl) !important;\n    margin-left: var(--pf-global--spacer--3xl) !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-mx-4xl-on-sm {\n    margin-right: var(--pf-global--spacer--4xl) !important;\n    margin-left: var(--pf-global--spacer--4xl) !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-my-auto-on-sm {\n    margin-top: auto !important;\n    margin-bottom: auto !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-my-0-on-sm {\n    margin-top: 0 !important;\n    margin-bottom: 0 !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-my-xs-on-sm {\n    margin-top: var(--pf-global--spacer--xs) !important;\n    margin-bottom: var(--pf-global--spacer--xs) !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-my-sm-on-sm {\n    margin-top: var(--pf-global--spacer--sm) !important;\n    margin-bottom: var(--pf-global--spacer--sm) !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-my-md-on-sm {\n    margin-top: var(--pf-global--spacer--md) !important;\n    margin-bottom: var(--pf-global--spacer--md) !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-my-lg-on-sm {\n    margin-top: var(--pf-global--spacer--lg) !important;\n    margin-bottom: var(--pf-global--spacer--lg) !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-my-xl-on-sm {\n    margin-top: var(--pf-global--spacer--xl) !important;\n    margin-bottom: var(--pf-global--spacer--xl) !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-my-2xl-on-sm {\n    margin-top: var(--pf-global--spacer--2xl) !important;\n    margin-bottom: var(--pf-global--spacer--2xl) !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-my-3xl-on-sm {\n    margin-top: var(--pf-global--spacer--3xl) !important;\n    margin-bottom: var(--pf-global--spacer--3xl) !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-my-4xl-on-sm {\n    margin-top: var(--pf-global--spacer--4xl) !important;\n    margin-bottom: var(--pf-global--spacer--4xl) !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-p-auto-on-sm {\n    padding: auto !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-p-0-on-sm {\n    padding: 0 !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-p-xs-on-sm {\n    padding: var(--pf-global--spacer--xs) !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-p-sm-on-sm {\n    padding: var(--pf-global--spacer--sm) !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-p-md-on-sm {\n    padding: var(--pf-global--spacer--md) !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-p-lg-on-sm {\n    padding: var(--pf-global--spacer--lg) !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-p-xl-on-sm {\n    padding: var(--pf-global--spacer--xl) !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-p-2xl-on-sm {\n    padding: var(--pf-global--spacer--2xl) !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-p-3xl-on-sm {\n    padding: var(--pf-global--spacer--3xl) !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-p-4xl-on-sm {\n    padding: var(--pf-global--spacer--4xl) !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-pt-auto-on-sm {\n    padding-top: auto !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-pt-0-on-sm {\n    padding-top: 0 !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-pt-xs-on-sm {\n    padding-top: var(--pf-global--spacer--xs) !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-pt-sm-on-sm {\n    padding-top: var(--pf-global--spacer--sm) !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-pt-md-on-sm {\n    padding-top: var(--pf-global--spacer--md) !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-pt-lg-on-sm {\n    padding-top: var(--pf-global--spacer--lg) !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-pt-xl-on-sm {\n    padding-top: var(--pf-global--spacer--xl) !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-pt-2xl-on-sm {\n    padding-top: var(--pf-global--spacer--2xl) !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-pt-3xl-on-sm {\n    padding-top: var(--pf-global--spacer--3xl) !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-pt-4xl-on-sm {\n    padding-top: var(--pf-global--spacer--4xl) !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-pr-auto-on-sm {\n    padding-right: auto !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-pr-0-on-sm {\n    padding-right: 0 !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-pr-xs-on-sm {\n    padding-right: var(--pf-global--spacer--xs) !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-pr-sm-on-sm {\n    padding-right: var(--pf-global--spacer--sm) !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-pr-md-on-sm {\n    padding-right: var(--pf-global--spacer--md) !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-pr-lg-on-sm {\n    padding-right: var(--pf-global--spacer--lg) !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-pr-xl-on-sm {\n    padding-right: var(--pf-global--spacer--xl) !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-pr-2xl-on-sm {\n    padding-right: var(--pf-global--spacer--2xl) !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-pr-3xl-on-sm {\n    padding-right: var(--pf-global--spacer--3xl) !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-pr-4xl-on-sm {\n    padding-right: var(--pf-global--spacer--4xl) !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-pb-auto-on-sm {\n    padding-bottom: auto !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-pb-0-on-sm {\n    padding-bottom: 0 !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-pb-xs-on-sm {\n    padding-bottom: var(--pf-global--spacer--xs) !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-pb-sm-on-sm {\n    padding-bottom: var(--pf-global--spacer--sm) !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-pb-md-on-sm {\n    padding-bottom: var(--pf-global--spacer--md) !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-pb-lg-on-sm {\n    padding-bottom: var(--pf-global--spacer--lg) !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-pb-xl-on-sm {\n    padding-bottom: var(--pf-global--spacer--xl) !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-pb-2xl-on-sm {\n    padding-bottom: var(--pf-global--spacer--2xl) !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-pb-3xl-on-sm {\n    padding-bottom: var(--pf-global--spacer--3xl) !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-pb-4xl-on-sm {\n    padding-bottom: var(--pf-global--spacer--4xl) !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-pl-auto-on-sm {\n    padding-left: auto !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-pl-0-on-sm {\n    padding-left: 0 !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-pl-xs-on-sm {\n    padding-left: var(--pf-global--spacer--xs) !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-pl-sm-on-sm {\n    padding-left: var(--pf-global--spacer--sm) !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-pl-md-on-sm {\n    padding-left: var(--pf-global--spacer--md) !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-pl-lg-on-sm {\n    padding-left: var(--pf-global--spacer--lg) !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-pl-xl-on-sm {\n    padding-left: var(--pf-global--spacer--xl) !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-pl-2xl-on-sm {\n    padding-left: var(--pf-global--spacer--2xl) !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-pl-3xl-on-sm {\n    padding-left: var(--pf-global--spacer--3xl) !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-pl-4xl-on-sm {\n    padding-left: var(--pf-global--spacer--4xl) !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-px-auto-on-sm {\n    padding-right: auto !important;\n    padding-left: auto !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-px-0-on-sm {\n    padding-right: 0 !important;\n    padding-left: 0 !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-px-xs-on-sm {\n    padding-right: var(--pf-global--spacer--xs) !important;\n    padding-left: var(--pf-global--spacer--xs) !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-px-sm-on-sm {\n    padding-right: var(--pf-global--spacer--sm) !important;\n    padding-left: var(--pf-global--spacer--sm) !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-px-md-on-sm {\n    padding-right: var(--pf-global--spacer--md) !important;\n    padding-left: var(--pf-global--spacer--md) !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-px-lg-on-sm {\n    padding-right: var(--pf-global--spacer--lg) !important;\n    padding-left: var(--pf-global--spacer--lg) !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-px-xl-on-sm {\n    padding-right: var(--pf-global--spacer--xl) !important;\n    padding-left: var(--pf-global--spacer--xl) !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-px-2xl-on-sm {\n    padding-right: var(--pf-global--spacer--2xl) !important;\n    padding-left: var(--pf-global--spacer--2xl) !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-px-3xl-on-sm {\n    padding-right: var(--pf-global--spacer--3xl) !important;\n    padding-left: var(--pf-global--spacer--3xl) !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-px-4xl-on-sm {\n    padding-right: var(--pf-global--spacer--4xl) !important;\n    padding-left: var(--pf-global--spacer--4xl) !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-py-auto-on-sm {\n    padding-top: auto !important;\n    padding-bottom: auto !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-py-0-on-sm {\n    padding-top: 0 !important;\n    padding-bottom: 0 !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-py-xs-on-sm {\n    padding-top: var(--pf-global--spacer--xs) !important;\n    padding-bottom: var(--pf-global--spacer--xs) !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-py-sm-on-sm {\n    padding-top: var(--pf-global--spacer--sm) !important;\n    padding-bottom: var(--pf-global--spacer--sm) !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-py-md-on-sm {\n    padding-top: var(--pf-global--spacer--md) !important;\n    padding-bottom: var(--pf-global--spacer--md) !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-py-lg-on-sm {\n    padding-top: var(--pf-global--spacer--lg) !important;\n    padding-bottom: var(--pf-global--spacer--lg) !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-py-xl-on-sm {\n    padding-top: var(--pf-global--spacer--xl) !important;\n    padding-bottom: var(--pf-global--spacer--xl) !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-py-2xl-on-sm {\n    padding-top: var(--pf-global--spacer--2xl) !important;\n    padding-bottom: var(--pf-global--spacer--2xl) !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-py-3xl-on-sm {\n    padding-top: var(--pf-global--spacer--3xl) !important;\n    padding-bottom: var(--pf-global--spacer--3xl) !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-py-4xl-on-sm {\n    padding-top: var(--pf-global--spacer--4xl) !important;\n    padding-bottom: var(--pf-global--spacer--4xl) !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-m-auto-on-md {\n    margin: auto !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-m-0-on-md {\n    margin: 0 !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-m-xs-on-md {\n    margin: var(--pf-global--spacer--xs) !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-m-sm-on-md {\n    margin: var(--pf-global--spacer--sm) !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-m-md-on-md {\n    margin: var(--pf-global--spacer--md) !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-m-lg-on-md {\n    margin: var(--pf-global--spacer--lg) !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-m-xl-on-md {\n    margin: var(--pf-global--spacer--xl) !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-m-2xl-on-md {\n    margin: var(--pf-global--spacer--2xl) !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-m-3xl-on-md {\n    margin: var(--pf-global--spacer--3xl) !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-m-4xl-on-md {\n    margin: var(--pf-global--spacer--4xl) !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-mt-auto-on-md {\n    margin-top: auto !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-mt-0-on-md {\n    margin-top: 0 !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-mt-xs-on-md {\n    margin-top: var(--pf-global--spacer--xs) !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-mt-sm-on-md {\n    margin-top: var(--pf-global--spacer--sm) !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-mt-md-on-md {\n    margin-top: var(--pf-global--spacer--md) !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-mt-lg-on-md {\n    margin-top: var(--pf-global--spacer--lg) !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-mt-xl-on-md {\n    margin-top: var(--pf-global--spacer--xl) !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-mt-2xl-on-md {\n    margin-top: var(--pf-global--spacer--2xl) !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-mt-3xl-on-md {\n    margin-top: var(--pf-global--spacer--3xl) !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-mt-4xl-on-md {\n    margin-top: var(--pf-global--spacer--4xl) !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-mr-auto-on-md {\n    margin-right: auto !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-mr-0-on-md {\n    margin-right: 0 !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-mr-xs-on-md {\n    margin-right: var(--pf-global--spacer--xs) !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-mr-sm-on-md {\n    margin-right: var(--pf-global--spacer--sm) !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-mr-md-on-md {\n    margin-right: var(--pf-global--spacer--md) !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-mr-lg-on-md {\n    margin-right: var(--pf-global--spacer--lg) !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-mr-xl-on-md {\n    margin-right: var(--pf-global--spacer--xl) !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-mr-2xl-on-md {\n    margin-right: var(--pf-global--spacer--2xl) !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-mr-3xl-on-md {\n    margin-right: var(--pf-global--spacer--3xl) !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-mr-4xl-on-md {\n    margin-right: var(--pf-global--spacer--4xl) !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-mb-auto-on-md {\n    margin-bottom: auto !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-mb-0-on-md {\n    margin-bottom: 0 !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-mb-xs-on-md {\n    margin-bottom: var(--pf-global--spacer--xs) !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-mb-sm-on-md {\n    margin-bottom: var(--pf-global--spacer--sm) !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-mb-md-on-md {\n    margin-bottom: var(--pf-global--spacer--md) !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-mb-lg-on-md {\n    margin-bottom: var(--pf-global--spacer--lg) !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-mb-xl-on-md {\n    margin-bottom: var(--pf-global--spacer--xl) !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-mb-2xl-on-md {\n    margin-bottom: var(--pf-global--spacer--2xl) !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-mb-3xl-on-md {\n    margin-bottom: var(--pf-global--spacer--3xl) !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-mb-4xl-on-md {\n    margin-bottom: var(--pf-global--spacer--4xl) !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-ml-auto-on-md {\n    margin-left: auto !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-ml-0-on-md {\n    margin-left: 0 !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-ml-xs-on-md {\n    margin-left: var(--pf-global--spacer--xs) !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-ml-sm-on-md {\n    margin-left: var(--pf-global--spacer--sm) !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-ml-md-on-md {\n    margin-left: var(--pf-global--spacer--md) !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-ml-lg-on-md {\n    margin-left: var(--pf-global--spacer--lg) !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-ml-xl-on-md {\n    margin-left: var(--pf-global--spacer--xl) !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-ml-2xl-on-md {\n    margin-left: var(--pf-global--spacer--2xl) !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-ml-3xl-on-md {\n    margin-left: var(--pf-global--spacer--3xl) !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-ml-4xl-on-md {\n    margin-left: var(--pf-global--spacer--4xl) !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-mx-auto-on-md {\n    margin-right: auto !important;\n    margin-left: auto !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-mx-0-on-md {\n    margin-right: 0 !important;\n    margin-left: 0 !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-mx-xs-on-md {\n    margin-right: var(--pf-global--spacer--xs) !important;\n    margin-left: var(--pf-global--spacer--xs) !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-mx-sm-on-md {\n    margin-right: var(--pf-global--spacer--sm) !important;\n    margin-left: var(--pf-global--spacer--sm) !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-mx-md-on-md {\n    margin-right: var(--pf-global--spacer--md) !important;\n    margin-left: var(--pf-global--spacer--md) !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-mx-lg-on-md {\n    margin-right: var(--pf-global--spacer--lg) !important;\n    margin-left: var(--pf-global--spacer--lg) !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-mx-xl-on-md {\n    margin-right: var(--pf-global--spacer--xl) !important;\n    margin-left: var(--pf-global--spacer--xl) !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-mx-2xl-on-md {\n    margin-right: var(--pf-global--spacer--2xl) !important;\n    margin-left: var(--pf-global--spacer--2xl) !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-mx-3xl-on-md {\n    margin-right: var(--pf-global--spacer--3xl) !important;\n    margin-left: var(--pf-global--spacer--3xl) !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-mx-4xl-on-md {\n    margin-right: var(--pf-global--spacer--4xl) !important;\n    margin-left: var(--pf-global--spacer--4xl) !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-my-auto-on-md {\n    margin-top: auto !important;\n    margin-bottom: auto !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-my-0-on-md {\n    margin-top: 0 !important;\n    margin-bottom: 0 !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-my-xs-on-md {\n    margin-top: var(--pf-global--spacer--xs) !important;\n    margin-bottom: var(--pf-global--spacer--xs) !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-my-sm-on-md {\n    margin-top: var(--pf-global--spacer--sm) !important;\n    margin-bottom: var(--pf-global--spacer--sm) !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-my-md-on-md {\n    margin-top: var(--pf-global--spacer--md) !important;\n    margin-bottom: var(--pf-global--spacer--md) !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-my-lg-on-md {\n    margin-top: var(--pf-global--spacer--lg) !important;\n    margin-bottom: var(--pf-global--spacer--lg) !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-my-xl-on-md {\n    margin-top: var(--pf-global--spacer--xl) !important;\n    margin-bottom: var(--pf-global--spacer--xl) !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-my-2xl-on-md {\n    margin-top: var(--pf-global--spacer--2xl) !important;\n    margin-bottom: var(--pf-global--spacer--2xl) !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-my-3xl-on-md {\n    margin-top: var(--pf-global--spacer--3xl) !important;\n    margin-bottom: var(--pf-global--spacer--3xl) !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-my-4xl-on-md {\n    margin-top: var(--pf-global--spacer--4xl) !important;\n    margin-bottom: var(--pf-global--spacer--4xl) !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-p-auto-on-md {\n    padding: auto !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-p-0-on-md {\n    padding: 0 !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-p-xs-on-md {\n    padding: var(--pf-global--spacer--xs) !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-p-sm-on-md {\n    padding: var(--pf-global--spacer--sm) !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-p-md-on-md {\n    padding: var(--pf-global--spacer--md) !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-p-lg-on-md {\n    padding: var(--pf-global--spacer--lg) !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-p-xl-on-md {\n    padding: var(--pf-global--spacer--xl) !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-p-2xl-on-md {\n    padding: var(--pf-global--spacer--2xl) !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-p-3xl-on-md {\n    padding: var(--pf-global--spacer--3xl) !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-p-4xl-on-md {\n    padding: var(--pf-global--spacer--4xl) !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-pt-auto-on-md {\n    padding-top: auto !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-pt-0-on-md {\n    padding-top: 0 !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-pt-xs-on-md {\n    padding-top: var(--pf-global--spacer--xs) !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-pt-sm-on-md {\n    padding-top: var(--pf-global--spacer--sm) !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-pt-md-on-md {\n    padding-top: var(--pf-global--spacer--md) !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-pt-lg-on-md {\n    padding-top: var(--pf-global--spacer--lg) !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-pt-xl-on-md {\n    padding-top: var(--pf-global--spacer--xl) !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-pt-2xl-on-md {\n    padding-top: var(--pf-global--spacer--2xl) !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-pt-3xl-on-md {\n    padding-top: var(--pf-global--spacer--3xl) !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-pt-4xl-on-md {\n    padding-top: var(--pf-global--spacer--4xl) !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-pr-auto-on-md {\n    padding-right: auto !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-pr-0-on-md {\n    padding-right: 0 !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-pr-xs-on-md {\n    padding-right: var(--pf-global--spacer--xs) !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-pr-sm-on-md {\n    padding-right: var(--pf-global--spacer--sm) !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-pr-md-on-md {\n    padding-right: var(--pf-global--spacer--md) !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-pr-lg-on-md {\n    padding-right: var(--pf-global--spacer--lg) !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-pr-xl-on-md {\n    padding-right: var(--pf-global--spacer--xl) !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-pr-2xl-on-md {\n    padding-right: var(--pf-global--spacer--2xl) !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-pr-3xl-on-md {\n    padding-right: var(--pf-global--spacer--3xl) !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-pr-4xl-on-md {\n    padding-right: var(--pf-global--spacer--4xl) !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-pb-auto-on-md {\n    padding-bottom: auto !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-pb-0-on-md {\n    padding-bottom: 0 !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-pb-xs-on-md {\n    padding-bottom: var(--pf-global--spacer--xs) !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-pb-sm-on-md {\n    padding-bottom: var(--pf-global--spacer--sm) !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-pb-md-on-md {\n    padding-bottom: var(--pf-global--spacer--md) !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-pb-lg-on-md {\n    padding-bottom: var(--pf-global--spacer--lg) !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-pb-xl-on-md {\n    padding-bottom: var(--pf-global--spacer--xl) !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-pb-2xl-on-md {\n    padding-bottom: var(--pf-global--spacer--2xl) !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-pb-3xl-on-md {\n    padding-bottom: var(--pf-global--spacer--3xl) !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-pb-4xl-on-md {\n    padding-bottom: var(--pf-global--spacer--4xl) !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-pl-auto-on-md {\n    padding-left: auto !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-pl-0-on-md {\n    padding-left: 0 !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-pl-xs-on-md {\n    padding-left: var(--pf-global--spacer--xs) !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-pl-sm-on-md {\n    padding-left: var(--pf-global--spacer--sm) !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-pl-md-on-md {\n    padding-left: var(--pf-global--spacer--md) !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-pl-lg-on-md {\n    padding-left: var(--pf-global--spacer--lg) !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-pl-xl-on-md {\n    padding-left: var(--pf-global--spacer--xl) !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-pl-2xl-on-md {\n    padding-left: var(--pf-global--spacer--2xl) !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-pl-3xl-on-md {\n    padding-left: var(--pf-global--spacer--3xl) !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-pl-4xl-on-md {\n    padding-left: var(--pf-global--spacer--4xl) !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-px-auto-on-md {\n    padding-right: auto !important;\n    padding-left: auto !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-px-0-on-md {\n    padding-right: 0 !important;\n    padding-left: 0 !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-px-xs-on-md {\n    padding-right: var(--pf-global--spacer--xs) !important;\n    padding-left: var(--pf-global--spacer--xs) !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-px-sm-on-md {\n    padding-right: var(--pf-global--spacer--sm) !important;\n    padding-left: var(--pf-global--spacer--sm) !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-px-md-on-md {\n    padding-right: var(--pf-global--spacer--md) !important;\n    padding-left: var(--pf-global--spacer--md) !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-px-lg-on-md {\n    padding-right: var(--pf-global--spacer--lg) !important;\n    padding-left: var(--pf-global--spacer--lg) !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-px-xl-on-md {\n    padding-right: var(--pf-global--spacer--xl) !important;\n    padding-left: var(--pf-global--spacer--xl) !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-px-2xl-on-md {\n    padding-right: var(--pf-global--spacer--2xl) !important;\n    padding-left: var(--pf-global--spacer--2xl) !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-px-3xl-on-md {\n    padding-right: var(--pf-global--spacer--3xl) !important;\n    padding-left: var(--pf-global--spacer--3xl) !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-px-4xl-on-md {\n    padding-right: var(--pf-global--spacer--4xl) !important;\n    padding-left: var(--pf-global--spacer--4xl) !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-py-auto-on-md {\n    padding-top: auto !important;\n    padding-bottom: auto !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-py-0-on-md {\n    padding-top: 0 !important;\n    padding-bottom: 0 !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-py-xs-on-md {\n    padding-top: var(--pf-global--spacer--xs) !important;\n    padding-bottom: var(--pf-global--spacer--xs) !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-py-sm-on-md {\n    padding-top: var(--pf-global--spacer--sm) !important;\n    padding-bottom: var(--pf-global--spacer--sm) !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-py-md-on-md {\n    padding-top: var(--pf-global--spacer--md) !important;\n    padding-bottom: var(--pf-global--spacer--md) !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-py-lg-on-md {\n    padding-top: var(--pf-global--spacer--lg) !important;\n    padding-bottom: var(--pf-global--spacer--lg) !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-py-xl-on-md {\n    padding-top: var(--pf-global--spacer--xl) !important;\n    padding-bottom: var(--pf-global--spacer--xl) !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-py-2xl-on-md {\n    padding-top: var(--pf-global--spacer--2xl) !important;\n    padding-bottom: var(--pf-global--spacer--2xl) !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-py-3xl-on-md {\n    padding-top: var(--pf-global--spacer--3xl) !important;\n    padding-bottom: var(--pf-global--spacer--3xl) !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-py-4xl-on-md {\n    padding-top: var(--pf-global--spacer--4xl) !important;\n    padding-bottom: var(--pf-global--spacer--4xl) !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-m-auto-on-lg {\n    margin: auto !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-m-0-on-lg {\n    margin: 0 !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-m-xs-on-lg {\n    margin: var(--pf-global--spacer--xs) !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-m-sm-on-lg {\n    margin: var(--pf-global--spacer--sm) !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-m-md-on-lg {\n    margin: var(--pf-global--spacer--md) !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-m-lg-on-lg {\n    margin: var(--pf-global--spacer--lg) !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-m-xl-on-lg {\n    margin: var(--pf-global--spacer--xl) !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-m-2xl-on-lg {\n    margin: var(--pf-global--spacer--2xl) !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-m-3xl-on-lg {\n    margin: var(--pf-global--spacer--3xl) !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-m-4xl-on-lg {\n    margin: var(--pf-global--spacer--4xl) !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-mt-auto-on-lg {\n    margin-top: auto !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-mt-0-on-lg {\n    margin-top: 0 !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-mt-xs-on-lg {\n    margin-top: var(--pf-global--spacer--xs) !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-mt-sm-on-lg {\n    margin-top: var(--pf-global--spacer--sm) !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-mt-md-on-lg {\n    margin-top: var(--pf-global--spacer--md) !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-mt-lg-on-lg {\n    margin-top: var(--pf-global--spacer--lg) !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-mt-xl-on-lg {\n    margin-top: var(--pf-global--spacer--xl) !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-mt-2xl-on-lg {\n    margin-top: var(--pf-global--spacer--2xl) !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-mt-3xl-on-lg {\n    margin-top: var(--pf-global--spacer--3xl) !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-mt-4xl-on-lg {\n    margin-top: var(--pf-global--spacer--4xl) !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-mr-auto-on-lg {\n    margin-right: auto !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-mr-0-on-lg {\n    margin-right: 0 !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-mr-xs-on-lg {\n    margin-right: var(--pf-global--spacer--xs) !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-mr-sm-on-lg {\n    margin-right: var(--pf-global--spacer--sm) !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-mr-md-on-lg {\n    margin-right: var(--pf-global--spacer--md) !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-mr-lg-on-lg {\n    margin-right: var(--pf-global--spacer--lg) !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-mr-xl-on-lg {\n    margin-right: var(--pf-global--spacer--xl) !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-mr-2xl-on-lg {\n    margin-right: var(--pf-global--spacer--2xl) !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-mr-3xl-on-lg {\n    margin-right: var(--pf-global--spacer--3xl) !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-mr-4xl-on-lg {\n    margin-right: var(--pf-global--spacer--4xl) !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-mb-auto-on-lg {\n    margin-bottom: auto !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-mb-0-on-lg {\n    margin-bottom: 0 !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-mb-xs-on-lg {\n    margin-bottom: var(--pf-global--spacer--xs) !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-mb-sm-on-lg {\n    margin-bottom: var(--pf-global--spacer--sm) !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-mb-md-on-lg {\n    margin-bottom: var(--pf-global--spacer--md) !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-mb-lg-on-lg {\n    margin-bottom: var(--pf-global--spacer--lg) !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-mb-xl-on-lg {\n    margin-bottom: var(--pf-global--spacer--xl) !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-mb-2xl-on-lg {\n    margin-bottom: var(--pf-global--spacer--2xl) !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-mb-3xl-on-lg {\n    margin-bottom: var(--pf-global--spacer--3xl) !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-mb-4xl-on-lg {\n    margin-bottom: var(--pf-global--spacer--4xl) !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-ml-auto-on-lg {\n    margin-left: auto !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-ml-0-on-lg {\n    margin-left: 0 !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-ml-xs-on-lg {\n    margin-left: var(--pf-global--spacer--xs) !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-ml-sm-on-lg {\n    margin-left: var(--pf-global--spacer--sm) !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-ml-md-on-lg {\n    margin-left: var(--pf-global--spacer--md) !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-ml-lg-on-lg {\n    margin-left: var(--pf-global--spacer--lg) !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-ml-xl-on-lg {\n    margin-left: var(--pf-global--spacer--xl) !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-ml-2xl-on-lg {\n    margin-left: var(--pf-global--spacer--2xl) !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-ml-3xl-on-lg {\n    margin-left: var(--pf-global--spacer--3xl) !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-ml-4xl-on-lg {\n    margin-left: var(--pf-global--spacer--4xl) !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-mx-auto-on-lg {\n    margin-right: auto !important;\n    margin-left: auto !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-mx-0-on-lg {\n    margin-right: 0 !important;\n    margin-left: 0 !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-mx-xs-on-lg {\n    margin-right: var(--pf-global--spacer--xs) !important;\n    margin-left: var(--pf-global--spacer--xs) !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-mx-sm-on-lg {\n    margin-right: var(--pf-global--spacer--sm) !important;\n    margin-left: var(--pf-global--spacer--sm) !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-mx-md-on-lg {\n    margin-right: var(--pf-global--spacer--md) !important;\n    margin-left: var(--pf-global--spacer--md) !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-mx-lg-on-lg {\n    margin-right: var(--pf-global--spacer--lg) !important;\n    margin-left: var(--pf-global--spacer--lg) !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-mx-xl-on-lg {\n    margin-right: var(--pf-global--spacer--xl) !important;\n    margin-left: var(--pf-global--spacer--xl) !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-mx-2xl-on-lg {\n    margin-right: var(--pf-global--spacer--2xl) !important;\n    margin-left: var(--pf-global--spacer--2xl) !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-mx-3xl-on-lg {\n    margin-right: var(--pf-global--spacer--3xl) !important;\n    margin-left: var(--pf-global--spacer--3xl) !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-mx-4xl-on-lg {\n    margin-right: var(--pf-global--spacer--4xl) !important;\n    margin-left: var(--pf-global--spacer--4xl) !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-my-auto-on-lg {\n    margin-top: auto !important;\n    margin-bottom: auto !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-my-0-on-lg {\n    margin-top: 0 !important;\n    margin-bottom: 0 !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-my-xs-on-lg {\n    margin-top: var(--pf-global--spacer--xs) !important;\n    margin-bottom: var(--pf-global--spacer--xs) !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-my-sm-on-lg {\n    margin-top: var(--pf-global--spacer--sm) !important;\n    margin-bottom: var(--pf-global--spacer--sm) !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-my-md-on-lg {\n    margin-top: var(--pf-global--spacer--md) !important;\n    margin-bottom: var(--pf-global--spacer--md) !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-my-lg-on-lg {\n    margin-top: var(--pf-global--spacer--lg) !important;\n    margin-bottom: var(--pf-global--spacer--lg) !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-my-xl-on-lg {\n    margin-top: var(--pf-global--spacer--xl) !important;\n    margin-bottom: var(--pf-global--spacer--xl) !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-my-2xl-on-lg {\n    margin-top: var(--pf-global--spacer--2xl) !important;\n    margin-bottom: var(--pf-global--spacer--2xl) !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-my-3xl-on-lg {\n    margin-top: var(--pf-global--spacer--3xl) !important;\n    margin-bottom: var(--pf-global--spacer--3xl) !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-my-4xl-on-lg {\n    margin-top: var(--pf-global--spacer--4xl) !important;\n    margin-bottom: var(--pf-global--spacer--4xl) !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-p-auto-on-lg {\n    padding: auto !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-p-0-on-lg {\n    padding: 0 !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-p-xs-on-lg {\n    padding: var(--pf-global--spacer--xs) !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-p-sm-on-lg {\n    padding: var(--pf-global--spacer--sm) !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-p-md-on-lg {\n    padding: var(--pf-global--spacer--md) !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-p-lg-on-lg {\n    padding: var(--pf-global--spacer--lg) !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-p-xl-on-lg {\n    padding: var(--pf-global--spacer--xl) !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-p-2xl-on-lg {\n    padding: var(--pf-global--spacer--2xl) !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-p-3xl-on-lg {\n    padding: var(--pf-global--spacer--3xl) !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-p-4xl-on-lg {\n    padding: var(--pf-global--spacer--4xl) !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-pt-auto-on-lg {\n    padding-top: auto !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-pt-0-on-lg {\n    padding-top: 0 !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-pt-xs-on-lg {\n    padding-top: var(--pf-global--spacer--xs) !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-pt-sm-on-lg {\n    padding-top: var(--pf-global--spacer--sm) !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-pt-md-on-lg {\n    padding-top: var(--pf-global--spacer--md) !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-pt-lg-on-lg {\n    padding-top: var(--pf-global--spacer--lg) !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-pt-xl-on-lg {\n    padding-top: var(--pf-global--spacer--xl) !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-pt-2xl-on-lg {\n    padding-top: var(--pf-global--spacer--2xl) !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-pt-3xl-on-lg {\n    padding-top: var(--pf-global--spacer--3xl) !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-pt-4xl-on-lg {\n    padding-top: var(--pf-global--spacer--4xl) !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-pr-auto-on-lg {\n    padding-right: auto !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-pr-0-on-lg {\n    padding-right: 0 !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-pr-xs-on-lg {\n    padding-right: var(--pf-global--spacer--xs) !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-pr-sm-on-lg {\n    padding-right: var(--pf-global--spacer--sm) !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-pr-md-on-lg {\n    padding-right: var(--pf-global--spacer--md) !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-pr-lg-on-lg {\n    padding-right: var(--pf-global--spacer--lg) !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-pr-xl-on-lg {\n    padding-right: var(--pf-global--spacer--xl) !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-pr-2xl-on-lg {\n    padding-right: var(--pf-global--spacer--2xl) !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-pr-3xl-on-lg {\n    padding-right: var(--pf-global--spacer--3xl) !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-pr-4xl-on-lg {\n    padding-right: var(--pf-global--spacer--4xl) !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-pb-auto-on-lg {\n    padding-bottom: auto !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-pb-0-on-lg {\n    padding-bottom: 0 !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-pb-xs-on-lg {\n    padding-bottom: var(--pf-global--spacer--xs) !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-pb-sm-on-lg {\n    padding-bottom: var(--pf-global--spacer--sm) !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-pb-md-on-lg {\n    padding-bottom: var(--pf-global--spacer--md) !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-pb-lg-on-lg {\n    padding-bottom: var(--pf-global--spacer--lg) !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-pb-xl-on-lg {\n    padding-bottom: var(--pf-global--spacer--xl) !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-pb-2xl-on-lg {\n    padding-bottom: var(--pf-global--spacer--2xl) !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-pb-3xl-on-lg {\n    padding-bottom: var(--pf-global--spacer--3xl) !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-pb-4xl-on-lg {\n    padding-bottom: var(--pf-global--spacer--4xl) !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-pl-auto-on-lg {\n    padding-left: auto !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-pl-0-on-lg {\n    padding-left: 0 !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-pl-xs-on-lg {\n    padding-left: var(--pf-global--spacer--xs) !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-pl-sm-on-lg {\n    padding-left: var(--pf-global--spacer--sm) !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-pl-md-on-lg {\n    padding-left: var(--pf-global--spacer--md) !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-pl-lg-on-lg {\n    padding-left: var(--pf-global--spacer--lg) !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-pl-xl-on-lg {\n    padding-left: var(--pf-global--spacer--xl) !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-pl-2xl-on-lg {\n    padding-left: var(--pf-global--spacer--2xl) !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-pl-3xl-on-lg {\n    padding-left: var(--pf-global--spacer--3xl) !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-pl-4xl-on-lg {\n    padding-left: var(--pf-global--spacer--4xl) !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-px-auto-on-lg {\n    padding-right: auto !important;\n    padding-left: auto !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-px-0-on-lg {\n    padding-right: 0 !important;\n    padding-left: 0 !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-px-xs-on-lg {\n    padding-right: var(--pf-global--spacer--xs) !important;\n    padding-left: var(--pf-global--spacer--xs) !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-px-sm-on-lg {\n    padding-right: var(--pf-global--spacer--sm) !important;\n    padding-left: var(--pf-global--spacer--sm) !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-px-md-on-lg {\n    padding-right: var(--pf-global--spacer--md) !important;\n    padding-left: var(--pf-global--spacer--md) !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-px-lg-on-lg {\n    padding-right: var(--pf-global--spacer--lg) !important;\n    padding-left: var(--pf-global--spacer--lg) !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-px-xl-on-lg {\n    padding-right: var(--pf-global--spacer--xl) !important;\n    padding-left: var(--pf-global--spacer--xl) !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-px-2xl-on-lg {\n    padding-right: var(--pf-global--spacer--2xl) !important;\n    padding-left: var(--pf-global--spacer--2xl) !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-px-3xl-on-lg {\n    padding-right: var(--pf-global--spacer--3xl) !important;\n    padding-left: var(--pf-global--spacer--3xl) !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-px-4xl-on-lg {\n    padding-right: var(--pf-global--spacer--4xl) !important;\n    padding-left: var(--pf-global--spacer--4xl) !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-py-auto-on-lg {\n    padding-top: auto !important;\n    padding-bottom: auto !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-py-0-on-lg {\n    padding-top: 0 !important;\n    padding-bottom: 0 !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-py-xs-on-lg {\n    padding-top: var(--pf-global--spacer--xs) !important;\n    padding-bottom: var(--pf-global--spacer--xs) !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-py-sm-on-lg {\n    padding-top: var(--pf-global--spacer--sm) !important;\n    padding-bottom: var(--pf-global--spacer--sm) !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-py-md-on-lg {\n    padding-top: var(--pf-global--spacer--md) !important;\n    padding-bottom: var(--pf-global--spacer--md) !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-py-lg-on-lg {\n    padding-top: var(--pf-global--spacer--lg) !important;\n    padding-bottom: var(--pf-global--spacer--lg) !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-py-xl-on-lg {\n    padding-top: var(--pf-global--spacer--xl) !important;\n    padding-bottom: var(--pf-global--spacer--xl) !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-py-2xl-on-lg {\n    padding-top: var(--pf-global--spacer--2xl) !important;\n    padding-bottom: var(--pf-global--spacer--2xl) !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-py-3xl-on-lg {\n    padding-top: var(--pf-global--spacer--3xl) !important;\n    padding-bottom: var(--pf-global--spacer--3xl) !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-py-4xl-on-lg {\n    padding-top: var(--pf-global--spacer--4xl) !important;\n    padding-bottom: var(--pf-global--spacer--4xl) !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-m-auto-on-xl {\n    margin: auto !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-m-0-on-xl {\n    margin: 0 !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-m-xs-on-xl {\n    margin: var(--pf-global--spacer--xs) !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-m-sm-on-xl {\n    margin: var(--pf-global--spacer--sm) !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-m-md-on-xl {\n    margin: var(--pf-global--spacer--md) !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-m-lg-on-xl {\n    margin: var(--pf-global--spacer--lg) !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-m-xl-on-xl {\n    margin: var(--pf-global--spacer--xl) !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-m-2xl-on-xl {\n    margin: var(--pf-global--spacer--2xl) !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-m-3xl-on-xl {\n    margin: var(--pf-global--spacer--3xl) !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-m-4xl-on-xl {\n    margin: var(--pf-global--spacer--4xl) !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-mt-auto-on-xl {\n    margin-top: auto !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-mt-0-on-xl {\n    margin-top: 0 !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-mt-xs-on-xl {\n    margin-top: var(--pf-global--spacer--xs) !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-mt-sm-on-xl {\n    margin-top: var(--pf-global--spacer--sm) !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-mt-md-on-xl {\n    margin-top: var(--pf-global--spacer--md) !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-mt-lg-on-xl {\n    margin-top: var(--pf-global--spacer--lg) !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-mt-xl-on-xl {\n    margin-top: var(--pf-global--spacer--xl) !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-mt-2xl-on-xl {\n    margin-top: var(--pf-global--spacer--2xl) !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-mt-3xl-on-xl {\n    margin-top: var(--pf-global--spacer--3xl) !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-mt-4xl-on-xl {\n    margin-top: var(--pf-global--spacer--4xl) !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-mr-auto-on-xl {\n    margin-right: auto !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-mr-0-on-xl {\n    margin-right: 0 !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-mr-xs-on-xl {\n    margin-right: var(--pf-global--spacer--xs) !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-mr-sm-on-xl {\n    margin-right: var(--pf-global--spacer--sm) !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-mr-md-on-xl {\n    margin-right: var(--pf-global--spacer--md) !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-mr-lg-on-xl {\n    margin-right: var(--pf-global--spacer--lg) !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-mr-xl-on-xl {\n    margin-right: var(--pf-global--spacer--xl) !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-mr-2xl-on-xl {\n    margin-right: var(--pf-global--spacer--2xl) !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-mr-3xl-on-xl {\n    margin-right: var(--pf-global--spacer--3xl) !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-mr-4xl-on-xl {\n    margin-right: var(--pf-global--spacer--4xl) !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-mb-auto-on-xl {\n    margin-bottom: auto !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-mb-0-on-xl {\n    margin-bottom: 0 !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-mb-xs-on-xl {\n    margin-bottom: var(--pf-global--spacer--xs) !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-mb-sm-on-xl {\n    margin-bottom: var(--pf-global--spacer--sm) !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-mb-md-on-xl {\n    margin-bottom: var(--pf-global--spacer--md) !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-mb-lg-on-xl {\n    margin-bottom: var(--pf-global--spacer--lg) !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-mb-xl-on-xl {\n    margin-bottom: var(--pf-global--spacer--xl) !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-mb-2xl-on-xl {\n    margin-bottom: var(--pf-global--spacer--2xl) !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-mb-3xl-on-xl {\n    margin-bottom: var(--pf-global--spacer--3xl) !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-mb-4xl-on-xl {\n    margin-bottom: var(--pf-global--spacer--4xl) !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-ml-auto-on-xl {\n    margin-left: auto !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-ml-0-on-xl {\n    margin-left: 0 !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-ml-xs-on-xl {\n    margin-left: var(--pf-global--spacer--xs) !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-ml-sm-on-xl {\n    margin-left: var(--pf-global--spacer--sm) !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-ml-md-on-xl {\n    margin-left: var(--pf-global--spacer--md) !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-ml-lg-on-xl {\n    margin-left: var(--pf-global--spacer--lg) !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-ml-xl-on-xl {\n    margin-left: var(--pf-global--spacer--xl) !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-ml-2xl-on-xl {\n    margin-left: var(--pf-global--spacer--2xl) !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-ml-3xl-on-xl {\n    margin-left: var(--pf-global--spacer--3xl) !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-ml-4xl-on-xl {\n    margin-left: var(--pf-global--spacer--4xl) !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-mx-auto-on-xl {\n    margin-right: auto !important;\n    margin-left: auto !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-mx-0-on-xl {\n    margin-right: 0 !important;\n    margin-left: 0 !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-mx-xs-on-xl {\n    margin-right: var(--pf-global--spacer--xs) !important;\n    margin-left: var(--pf-global--spacer--xs) !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-mx-sm-on-xl {\n    margin-right: var(--pf-global--spacer--sm) !important;\n    margin-left: var(--pf-global--spacer--sm) !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-mx-md-on-xl {\n    margin-right: var(--pf-global--spacer--md) !important;\n    margin-left: var(--pf-global--spacer--md) !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-mx-lg-on-xl {\n    margin-right: var(--pf-global--spacer--lg) !important;\n    margin-left: var(--pf-global--spacer--lg) !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-mx-xl-on-xl {\n    margin-right: var(--pf-global--spacer--xl) !important;\n    margin-left: var(--pf-global--spacer--xl) !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-mx-2xl-on-xl {\n    margin-right: var(--pf-global--spacer--2xl) !important;\n    margin-left: var(--pf-global--spacer--2xl) !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-mx-3xl-on-xl {\n    margin-right: var(--pf-global--spacer--3xl) !important;\n    margin-left: var(--pf-global--spacer--3xl) !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-mx-4xl-on-xl {\n    margin-right: var(--pf-global--spacer--4xl) !important;\n    margin-left: var(--pf-global--spacer--4xl) !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-my-auto-on-xl {\n    margin-top: auto !important;\n    margin-bottom: auto !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-my-0-on-xl {\n    margin-top: 0 !important;\n    margin-bottom: 0 !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-my-xs-on-xl {\n    margin-top: var(--pf-global--spacer--xs) !important;\n    margin-bottom: var(--pf-global--spacer--xs) !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-my-sm-on-xl {\n    margin-top: var(--pf-global--spacer--sm) !important;\n    margin-bottom: var(--pf-global--spacer--sm) !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-my-md-on-xl {\n    margin-top: var(--pf-global--spacer--md) !important;\n    margin-bottom: var(--pf-global--spacer--md) !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-my-lg-on-xl {\n    margin-top: var(--pf-global--spacer--lg) !important;\n    margin-bottom: var(--pf-global--spacer--lg) !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-my-xl-on-xl {\n    margin-top: var(--pf-global--spacer--xl) !important;\n    margin-bottom: var(--pf-global--spacer--xl) !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-my-2xl-on-xl {\n    margin-top: var(--pf-global--spacer--2xl) !important;\n    margin-bottom: var(--pf-global--spacer--2xl) !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-my-3xl-on-xl {\n    margin-top: var(--pf-global--spacer--3xl) !important;\n    margin-bottom: var(--pf-global--spacer--3xl) !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-my-4xl-on-xl {\n    margin-top: var(--pf-global--spacer--4xl) !important;\n    margin-bottom: var(--pf-global--spacer--4xl) !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-p-auto-on-xl {\n    padding: auto !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-p-0-on-xl {\n    padding: 0 !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-p-xs-on-xl {\n    padding: var(--pf-global--spacer--xs) !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-p-sm-on-xl {\n    padding: var(--pf-global--spacer--sm) !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-p-md-on-xl {\n    padding: var(--pf-global--spacer--md) !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-p-lg-on-xl {\n    padding: var(--pf-global--spacer--lg) !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-p-xl-on-xl {\n    padding: var(--pf-global--spacer--xl) !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-p-2xl-on-xl {\n    padding: var(--pf-global--spacer--2xl) !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-p-3xl-on-xl {\n    padding: var(--pf-global--spacer--3xl) !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-p-4xl-on-xl {\n    padding: var(--pf-global--spacer--4xl) !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-pt-auto-on-xl {\n    padding-top: auto !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-pt-0-on-xl {\n    padding-top: 0 !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-pt-xs-on-xl {\n    padding-top: var(--pf-global--spacer--xs) !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-pt-sm-on-xl {\n    padding-top: var(--pf-global--spacer--sm) !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-pt-md-on-xl {\n    padding-top: var(--pf-global--spacer--md) !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-pt-lg-on-xl {\n    padding-top: var(--pf-global--spacer--lg) !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-pt-xl-on-xl {\n    padding-top: var(--pf-global--spacer--xl) !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-pt-2xl-on-xl {\n    padding-top: var(--pf-global--spacer--2xl) !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-pt-3xl-on-xl {\n    padding-top: var(--pf-global--spacer--3xl) !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-pt-4xl-on-xl {\n    padding-top: var(--pf-global--spacer--4xl) !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-pr-auto-on-xl {\n    padding-right: auto !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-pr-0-on-xl {\n    padding-right: 0 !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-pr-xs-on-xl {\n    padding-right: var(--pf-global--spacer--xs) !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-pr-sm-on-xl {\n    padding-right: var(--pf-global--spacer--sm) !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-pr-md-on-xl {\n    padding-right: var(--pf-global--spacer--md) !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-pr-lg-on-xl {\n    padding-right: var(--pf-global--spacer--lg) !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-pr-xl-on-xl {\n    padding-right: var(--pf-global--spacer--xl) !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-pr-2xl-on-xl {\n    padding-right: var(--pf-global--spacer--2xl) !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-pr-3xl-on-xl {\n    padding-right: var(--pf-global--spacer--3xl) !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-pr-4xl-on-xl {\n    padding-right: var(--pf-global--spacer--4xl) !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-pb-auto-on-xl {\n    padding-bottom: auto !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-pb-0-on-xl {\n    padding-bottom: 0 !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-pb-xs-on-xl {\n    padding-bottom: var(--pf-global--spacer--xs) !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-pb-sm-on-xl {\n    padding-bottom: var(--pf-global--spacer--sm) !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-pb-md-on-xl {\n    padding-bottom: var(--pf-global--spacer--md) !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-pb-lg-on-xl {\n    padding-bottom: var(--pf-global--spacer--lg) !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-pb-xl-on-xl {\n    padding-bottom: var(--pf-global--spacer--xl) !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-pb-2xl-on-xl {\n    padding-bottom: var(--pf-global--spacer--2xl) !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-pb-3xl-on-xl {\n    padding-bottom: var(--pf-global--spacer--3xl) !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-pb-4xl-on-xl {\n    padding-bottom: var(--pf-global--spacer--4xl) !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-pl-auto-on-xl {\n    padding-left: auto !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-pl-0-on-xl {\n    padding-left: 0 !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-pl-xs-on-xl {\n    padding-left: var(--pf-global--spacer--xs) !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-pl-sm-on-xl {\n    padding-left: var(--pf-global--spacer--sm) !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-pl-md-on-xl {\n    padding-left: var(--pf-global--spacer--md) !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-pl-lg-on-xl {\n    padding-left: var(--pf-global--spacer--lg) !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-pl-xl-on-xl {\n    padding-left: var(--pf-global--spacer--xl) !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-pl-2xl-on-xl {\n    padding-left: var(--pf-global--spacer--2xl) !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-pl-3xl-on-xl {\n    padding-left: var(--pf-global--spacer--3xl) !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-pl-4xl-on-xl {\n    padding-left: var(--pf-global--spacer--4xl) !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-px-auto-on-xl {\n    padding-right: auto !important;\n    padding-left: auto !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-px-0-on-xl {\n    padding-right: 0 !important;\n    padding-left: 0 !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-px-xs-on-xl {\n    padding-right: var(--pf-global--spacer--xs) !important;\n    padding-left: var(--pf-global--spacer--xs) !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-px-sm-on-xl {\n    padding-right: var(--pf-global--spacer--sm) !important;\n    padding-left: var(--pf-global--spacer--sm) !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-px-md-on-xl {\n    padding-right: var(--pf-global--spacer--md) !important;\n    padding-left: var(--pf-global--spacer--md) !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-px-lg-on-xl {\n    padding-right: var(--pf-global--spacer--lg) !important;\n    padding-left: var(--pf-global--spacer--lg) !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-px-xl-on-xl {\n    padding-right: var(--pf-global--spacer--xl) !important;\n    padding-left: var(--pf-global--spacer--xl) !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-px-2xl-on-xl {\n    padding-right: var(--pf-global--spacer--2xl) !important;\n    padding-left: var(--pf-global--spacer--2xl) !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-px-3xl-on-xl {\n    padding-right: var(--pf-global--spacer--3xl) !important;\n    padding-left: var(--pf-global--spacer--3xl) !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-px-4xl-on-xl {\n    padding-right: var(--pf-global--spacer--4xl) !important;\n    padding-left: var(--pf-global--spacer--4xl) !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-py-auto-on-xl {\n    padding-top: auto !important;\n    padding-bottom: auto !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-py-0-on-xl {\n    padding-top: 0 !important;\n    padding-bottom: 0 !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-py-xs-on-xl {\n    padding-top: var(--pf-global--spacer--xs) !important;\n    padding-bottom: var(--pf-global--spacer--xs) !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-py-sm-on-xl {\n    padding-top: var(--pf-global--spacer--sm) !important;\n    padding-bottom: var(--pf-global--spacer--sm) !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-py-md-on-xl {\n    padding-top: var(--pf-global--spacer--md) !important;\n    padding-bottom: var(--pf-global--spacer--md) !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-py-lg-on-xl {\n    padding-top: var(--pf-global--spacer--lg) !important;\n    padding-bottom: var(--pf-global--spacer--lg) !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-py-xl-on-xl {\n    padding-top: var(--pf-global--spacer--xl) !important;\n    padding-bottom: var(--pf-global--spacer--xl) !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-py-2xl-on-xl {\n    padding-top: var(--pf-global--spacer--2xl) !important;\n    padding-bottom: var(--pf-global--spacer--2xl) !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-py-3xl-on-xl {\n    padding-top: var(--pf-global--spacer--3xl) !important;\n    padding-bottom: var(--pf-global--spacer--3xl) !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-py-4xl-on-xl {\n    padding-top: var(--pf-global--spacer--4xl) !important;\n    padding-bottom: var(--pf-global--spacer--4xl) !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-m-auto-on-2xl {\n    margin: auto !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-m-0-on-2xl {\n    margin: 0 !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-m-xs-on-2xl {\n    margin: var(--pf-global--spacer--xs) !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-m-sm-on-2xl {\n    margin: var(--pf-global--spacer--sm) !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-m-md-on-2xl {\n    margin: var(--pf-global--spacer--md) !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-m-lg-on-2xl {\n    margin: var(--pf-global--spacer--lg) !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-m-xl-on-2xl {\n    margin: var(--pf-global--spacer--xl) !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-m-2xl-on-2xl {\n    margin: var(--pf-global--spacer--2xl) !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-m-3xl-on-2xl {\n    margin: var(--pf-global--spacer--3xl) !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-m-4xl-on-2xl {\n    margin: var(--pf-global--spacer--4xl) !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-mt-auto-on-2xl {\n    margin-top: auto !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-mt-0-on-2xl {\n    margin-top: 0 !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-mt-xs-on-2xl {\n    margin-top: var(--pf-global--spacer--xs) !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-mt-sm-on-2xl {\n    margin-top: var(--pf-global--spacer--sm) !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-mt-md-on-2xl {\n    margin-top: var(--pf-global--spacer--md) !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-mt-lg-on-2xl {\n    margin-top: var(--pf-global--spacer--lg) !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-mt-xl-on-2xl {\n    margin-top: var(--pf-global--spacer--xl) !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-mt-2xl-on-2xl {\n    margin-top: var(--pf-global--spacer--2xl) !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-mt-3xl-on-2xl {\n    margin-top: var(--pf-global--spacer--3xl) !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-mt-4xl-on-2xl {\n    margin-top: var(--pf-global--spacer--4xl) !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-mr-auto-on-2xl {\n    margin-right: auto !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-mr-0-on-2xl {\n    margin-right: 0 !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-mr-xs-on-2xl {\n    margin-right: var(--pf-global--spacer--xs) !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-mr-sm-on-2xl {\n    margin-right: var(--pf-global--spacer--sm) !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-mr-md-on-2xl {\n    margin-right: var(--pf-global--spacer--md) !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-mr-lg-on-2xl {\n    margin-right: var(--pf-global--spacer--lg) !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-mr-xl-on-2xl {\n    margin-right: var(--pf-global--spacer--xl) !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-mr-2xl-on-2xl {\n    margin-right: var(--pf-global--spacer--2xl) !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-mr-3xl-on-2xl {\n    margin-right: var(--pf-global--spacer--3xl) !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-mr-4xl-on-2xl {\n    margin-right: var(--pf-global--spacer--4xl) !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-mb-auto-on-2xl {\n    margin-bottom: auto !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-mb-0-on-2xl {\n    margin-bottom: 0 !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-mb-xs-on-2xl {\n    margin-bottom: var(--pf-global--spacer--xs) !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-mb-sm-on-2xl {\n    margin-bottom: var(--pf-global--spacer--sm) !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-mb-md-on-2xl {\n    margin-bottom: var(--pf-global--spacer--md) !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-mb-lg-on-2xl {\n    margin-bottom: var(--pf-global--spacer--lg) !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-mb-xl-on-2xl {\n    margin-bottom: var(--pf-global--spacer--xl) !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-mb-2xl-on-2xl {\n    margin-bottom: var(--pf-global--spacer--2xl) !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-mb-3xl-on-2xl {\n    margin-bottom: var(--pf-global--spacer--3xl) !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-mb-4xl-on-2xl {\n    margin-bottom: var(--pf-global--spacer--4xl) !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-ml-auto-on-2xl {\n    margin-left: auto !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-ml-0-on-2xl {\n    margin-left: 0 !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-ml-xs-on-2xl {\n    margin-left: var(--pf-global--spacer--xs) !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-ml-sm-on-2xl {\n    margin-left: var(--pf-global--spacer--sm) !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-ml-md-on-2xl {\n    margin-left: var(--pf-global--spacer--md) !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-ml-lg-on-2xl {\n    margin-left: var(--pf-global--spacer--lg) !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-ml-xl-on-2xl {\n    margin-left: var(--pf-global--spacer--xl) !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-ml-2xl-on-2xl {\n    margin-left: var(--pf-global--spacer--2xl) !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-ml-3xl-on-2xl {\n    margin-left: var(--pf-global--spacer--3xl) !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-ml-4xl-on-2xl {\n    margin-left: var(--pf-global--spacer--4xl) !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-mx-auto-on-2xl {\n    margin-right: auto !important;\n    margin-left: auto !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-mx-0-on-2xl {\n    margin-right: 0 !important;\n    margin-left: 0 !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-mx-xs-on-2xl {\n    margin-right: var(--pf-global--spacer--xs) !important;\n    margin-left: var(--pf-global--spacer--xs) !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-mx-sm-on-2xl {\n    margin-right: var(--pf-global--spacer--sm) !important;\n    margin-left: var(--pf-global--spacer--sm) !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-mx-md-on-2xl {\n    margin-right: var(--pf-global--spacer--md) !important;\n    margin-left: var(--pf-global--spacer--md) !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-mx-lg-on-2xl {\n    margin-right: var(--pf-global--spacer--lg) !important;\n    margin-left: var(--pf-global--spacer--lg) !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-mx-xl-on-2xl {\n    margin-right: var(--pf-global--spacer--xl) !important;\n    margin-left: var(--pf-global--spacer--xl) !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-mx-2xl-on-2xl {\n    margin-right: var(--pf-global--spacer--2xl) !important;\n    margin-left: var(--pf-global--spacer--2xl) !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-mx-3xl-on-2xl {\n    margin-right: var(--pf-global--spacer--3xl) !important;\n    margin-left: var(--pf-global--spacer--3xl) !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-mx-4xl-on-2xl {\n    margin-right: var(--pf-global--spacer--4xl) !important;\n    margin-left: var(--pf-global--spacer--4xl) !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-my-auto-on-2xl {\n    margin-top: auto !important;\n    margin-bottom: auto !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-my-0-on-2xl {\n    margin-top: 0 !important;\n    margin-bottom: 0 !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-my-xs-on-2xl {\n    margin-top: var(--pf-global--spacer--xs) !important;\n    margin-bottom: var(--pf-global--spacer--xs) !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-my-sm-on-2xl {\n    margin-top: var(--pf-global--spacer--sm) !important;\n    margin-bottom: var(--pf-global--spacer--sm) !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-my-md-on-2xl {\n    margin-top: var(--pf-global--spacer--md) !important;\n    margin-bottom: var(--pf-global--spacer--md) !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-my-lg-on-2xl {\n    margin-top: var(--pf-global--spacer--lg) !important;\n    margin-bottom: var(--pf-global--spacer--lg) !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-my-xl-on-2xl {\n    margin-top: var(--pf-global--spacer--xl) !important;\n    margin-bottom: var(--pf-global--spacer--xl) !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-my-2xl-on-2xl {\n    margin-top: var(--pf-global--spacer--2xl) !important;\n    margin-bottom: var(--pf-global--spacer--2xl) !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-my-3xl-on-2xl {\n    margin-top: var(--pf-global--spacer--3xl) !important;\n    margin-bottom: var(--pf-global--spacer--3xl) !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-my-4xl-on-2xl {\n    margin-top: var(--pf-global--spacer--4xl) !important;\n    margin-bottom: var(--pf-global--spacer--4xl) !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-p-auto-on-2xl {\n    padding: auto !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-p-0-on-2xl {\n    padding: 0 !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-p-xs-on-2xl {\n    padding: var(--pf-global--spacer--xs) !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-p-sm-on-2xl {\n    padding: var(--pf-global--spacer--sm) !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-p-md-on-2xl {\n    padding: var(--pf-global--spacer--md) !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-p-lg-on-2xl {\n    padding: var(--pf-global--spacer--lg) !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-p-xl-on-2xl {\n    padding: var(--pf-global--spacer--xl) !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-p-2xl-on-2xl {\n    padding: var(--pf-global--spacer--2xl) !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-p-3xl-on-2xl {\n    padding: var(--pf-global--spacer--3xl) !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-p-4xl-on-2xl {\n    padding: var(--pf-global--spacer--4xl) !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-pt-auto-on-2xl {\n    padding-top: auto !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-pt-0-on-2xl {\n    padding-top: 0 !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-pt-xs-on-2xl {\n    padding-top: var(--pf-global--spacer--xs) !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-pt-sm-on-2xl {\n    padding-top: var(--pf-global--spacer--sm) !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-pt-md-on-2xl {\n    padding-top: var(--pf-global--spacer--md) !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-pt-lg-on-2xl {\n    padding-top: var(--pf-global--spacer--lg) !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-pt-xl-on-2xl {\n    padding-top: var(--pf-global--spacer--xl) !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-pt-2xl-on-2xl {\n    padding-top: var(--pf-global--spacer--2xl) !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-pt-3xl-on-2xl {\n    padding-top: var(--pf-global--spacer--3xl) !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-pt-4xl-on-2xl {\n    padding-top: var(--pf-global--spacer--4xl) !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-pr-auto-on-2xl {\n    padding-right: auto !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-pr-0-on-2xl {\n    padding-right: 0 !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-pr-xs-on-2xl {\n    padding-right: var(--pf-global--spacer--xs) !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-pr-sm-on-2xl {\n    padding-right: var(--pf-global--spacer--sm) !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-pr-md-on-2xl {\n    padding-right: var(--pf-global--spacer--md) !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-pr-lg-on-2xl {\n    padding-right: var(--pf-global--spacer--lg) !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-pr-xl-on-2xl {\n    padding-right: var(--pf-global--spacer--xl) !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-pr-2xl-on-2xl {\n    padding-right: var(--pf-global--spacer--2xl) !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-pr-3xl-on-2xl {\n    padding-right: var(--pf-global--spacer--3xl) !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-pr-4xl-on-2xl {\n    padding-right: var(--pf-global--spacer--4xl) !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-pb-auto-on-2xl {\n    padding-bottom: auto !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-pb-0-on-2xl {\n    padding-bottom: 0 !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-pb-xs-on-2xl {\n    padding-bottom: var(--pf-global--spacer--xs) !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-pb-sm-on-2xl {\n    padding-bottom: var(--pf-global--spacer--sm) !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-pb-md-on-2xl {\n    padding-bottom: var(--pf-global--spacer--md) !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-pb-lg-on-2xl {\n    padding-bottom: var(--pf-global--spacer--lg) !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-pb-xl-on-2xl {\n    padding-bottom: var(--pf-global--spacer--xl) !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-pb-2xl-on-2xl {\n    padding-bottom: var(--pf-global--spacer--2xl) !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-pb-3xl-on-2xl {\n    padding-bottom: var(--pf-global--spacer--3xl) !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-pb-4xl-on-2xl {\n    padding-bottom: var(--pf-global--spacer--4xl) !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-pl-auto-on-2xl {\n    padding-left: auto !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-pl-0-on-2xl {\n    padding-left: 0 !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-pl-xs-on-2xl {\n    padding-left: var(--pf-global--spacer--xs) !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-pl-sm-on-2xl {\n    padding-left: var(--pf-global--spacer--sm) !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-pl-md-on-2xl {\n    padding-left: var(--pf-global--spacer--md) !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-pl-lg-on-2xl {\n    padding-left: var(--pf-global--spacer--lg) !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-pl-xl-on-2xl {\n    padding-left: var(--pf-global--spacer--xl) !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-pl-2xl-on-2xl {\n    padding-left: var(--pf-global--spacer--2xl) !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-pl-3xl-on-2xl {\n    padding-left: var(--pf-global--spacer--3xl) !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-pl-4xl-on-2xl {\n    padding-left: var(--pf-global--spacer--4xl) !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-px-auto-on-2xl {\n    padding-right: auto !important;\n    padding-left: auto !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-px-0-on-2xl {\n    padding-right: 0 !important;\n    padding-left: 0 !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-px-xs-on-2xl {\n    padding-right: var(--pf-global--spacer--xs) !important;\n    padding-left: var(--pf-global--spacer--xs) !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-px-sm-on-2xl {\n    padding-right: var(--pf-global--spacer--sm) !important;\n    padding-left: var(--pf-global--spacer--sm) !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-px-md-on-2xl {\n    padding-right: var(--pf-global--spacer--md) !important;\n    padding-left: var(--pf-global--spacer--md) !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-px-lg-on-2xl {\n    padding-right: var(--pf-global--spacer--lg) !important;\n    padding-left: var(--pf-global--spacer--lg) !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-px-xl-on-2xl {\n    padding-right: var(--pf-global--spacer--xl) !important;\n    padding-left: var(--pf-global--spacer--xl) !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-px-2xl-on-2xl {\n    padding-right: var(--pf-global--spacer--2xl) !important;\n    padding-left: var(--pf-global--spacer--2xl) !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-px-3xl-on-2xl {\n    padding-right: var(--pf-global--spacer--3xl) !important;\n    padding-left: var(--pf-global--spacer--3xl) !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-px-4xl-on-2xl {\n    padding-right: var(--pf-global--spacer--4xl) !important;\n    padding-left: var(--pf-global--spacer--4xl) !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-py-auto-on-2xl {\n    padding-top: auto !important;\n    padding-bottom: auto !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-py-0-on-2xl {\n    padding-top: 0 !important;\n    padding-bottom: 0 !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-py-xs-on-2xl {\n    padding-top: var(--pf-global--spacer--xs) !important;\n    padding-bottom: var(--pf-global--spacer--xs) !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-py-sm-on-2xl {\n    padding-top: var(--pf-global--spacer--sm) !important;\n    padding-bottom: var(--pf-global--spacer--sm) !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-py-md-on-2xl {\n    padding-top: var(--pf-global--spacer--md) !important;\n    padding-bottom: var(--pf-global--spacer--md) !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-py-lg-on-2xl {\n    padding-top: var(--pf-global--spacer--lg) !important;\n    padding-bottom: var(--pf-global--spacer--lg) !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-py-xl-on-2xl {\n    padding-top: var(--pf-global--spacer--xl) !important;\n    padding-bottom: var(--pf-global--spacer--xl) !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-py-2xl-on-2xl {\n    padding-top: var(--pf-global--spacer--2xl) !important;\n    padding-bottom: var(--pf-global--spacer--2xl) !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-py-3xl-on-2xl {\n    padding-top: var(--pf-global--spacer--3xl) !important;\n    padding-bottom: var(--pf-global--spacer--3xl) !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-py-4xl-on-2xl {\n    padding-top: var(--pf-global--spacer--4xl) !important;\n    padding-bottom: var(--pf-global--spacer--4xl) !important;\n  }\n}";

// src/admin/providers/proxy/ProxyProviderForm.ts
var ProxyProviderFormPage = class extends BaseProviderForm {
  constructor() {
    super(...arguments);
    this.showHttpBasic = true;
    this.mode = ProxyMode.Proxy;
  }
  static get styles() {
    return [...super.styles, content_default, list_default, spacing_default];
  }
  async loadInstance(pk) {
    const provider = await new ProvidersApi(DEFAULT_CONFIG).providersProxyRetrieve({
      id: pk
    });
    this.showHttpBasic = first(provider.basicAuthEnabled, true);
    this.mode = first(provider.mode, ProxyMode.Proxy);
    return provider;
  }
  async load() {
    this.propertyMappings = await new PropertymappingsApi(
      DEFAULT_CONFIG
    ).propertymappingsScopeList({
      ordering: "scope_name"
    });
    this.oauthSources = await new SourcesApi(DEFAULT_CONFIG).sourcesOauthList({
      ordering: "name",
      hasJwks: true
    });
  }
  async send(data) {
    data.mode = this.mode;
    if (this.mode !== ProxyMode.ForwardDomain) {
      data.cookieDomain = "";
    }
    if (this.instance) {
      return new ProvidersApi(DEFAULT_CONFIG).providersProxyUpdate({
        id: this.instance.pk || 0,
        proxyProviderRequest: data
      });
    } else {
      return new ProvidersApi(DEFAULT_CONFIG).providersProxyCreate({
        proxyProviderRequest: data
      });
    }
  }
  renderHttpBasic() {
    return x`<ak-text-input
                name="basicAuthUserAttribute"
                label=${msg("HTTP-Basic Username Key")}
                value="${o(this.instance?.basicAuthUserAttribute)}"
                help=${msg(
      "User/Group Attribute used for the user part of the HTTP-Basic Header. If not set, the user's Email address is used."
    )}
            >
            </ak-text-input>

            <ak-text-input
                name="basicAuthPasswordAttribute"
                label=${msg("HTTP-Basic Password Key")}
                value="${o(this.instance?.basicAuthPasswordAttribute)}"
                help=${msg(
      "User/Group Attribute used for the password part of the HTTP-Basic Header."
    )}
            >
            </ak-text-input>`;
  }
  renderModeSelector() {
    const setMode = (ev) => {
      this.mode = ev.detail.value;
    };
    return x`
            <ak-toggle-group value=${this.mode} @ak-toggle=${setMode}>
                <option value=${ProxyMode.Proxy}>${msg("Proxy")}</option>
                <option value=${ProxyMode.ForwardSingle}>${msg("Forward auth (single application)")}</option>
                <option value=${ProxyMode.ForwardDomain}>${msg("Forward auth (domain level)")}</option>
            </ak-toggle-group>
        `;
  }
  renderSettings() {
    switch (this.mode) {
      case ProxyMode.Proxy:
        return x`<p class="pf-u-mb-xl">
                        ${msg(
          "This provider will behave like a transparent reverse-proxy, except requests must be authenticated. If your upstream application uses HTTPS, make sure to connect to the outpost using HTTPS as well."
        )}
                    </p>
                    <ak-form-element-horizontal
                        label=${msg("External host")}
                        ?required=${true}
                        name="externalHost"
                    >
                        <input
                            type="text"
                            value="${o(this.instance?.externalHost)}"
                            class="pf-c-form-control"
                            required
                        />
                        <p class="pf-c-form__helper-text">
                            ${msg(
          "The external URL you'll access the application at. Include any non-standard port."
        )}
                        </p>
                    </ak-form-element-horizontal>
                    <ak-form-element-horizontal
                        label=${msg("Internal host")}
                        ?required=${true}
                        name="internalHost"
                    >
                        <input
                            type="text"
                            value="${o(this.instance?.internalHost)}"
                            class="pf-c-form-control"
                            required
                        />
                        <p class="pf-c-form__helper-text">
                            ${msg("Upstream host that the requests are forwarded to.")}
                        </p>
                    </ak-form-element-horizontal>
                    <ak-form-element-horizontal name="internalHostSslValidation">
                        <label class="pf-c-switch">
                            <input
                                class="pf-c-switch__input"
                                type="checkbox"
                                ?checked=${first(this.instance?.internalHostSslValidation, true)}
                            />
                            <span class="pf-c-switch__toggle">
                                <span class="pf-c-switch__toggle-icon">
                                    <i class="fas fa-check" aria-hidden="true"></i>
                                </span>
                            </span>
                            <span class="pf-c-switch__label"
                                >${msg("Internal host SSL Validation")}</span
                            >
                        </label>
                        <p class="pf-c-form__helper-text">
                            ${msg("Validate SSL Certificates of upstream servers.")}
                        </p>
                    </ak-form-element-horizontal>`;
      case ProxyMode.ForwardSingle:
        return x`<p class="pf-u-mb-xl">
                        ${msg(
          "Use this provider with nginx's auth_request or traefik's forwardAuth. Each application/domain needs its own provider. Additionally, on each domain, /outpost.goauthentik.io must be routed to the outpost (when using a managed outpost, this is done for you)."
        )}
                    </p>
                    <ak-form-element-horizontal
                        label=${msg("External host")}
                        ?required=${true}
                        name="externalHost"
                    >
                        <input
                            type="text"
                            value="${o(this.instance?.externalHost)}"
                            class="pf-c-form-control"
                            required
                        />
                        <p class="pf-c-form__helper-text">
                            ${msg(
          "The external URL you'll access the application at. Include any non-standard port."
        )}
                        </p>
                    </ak-form-element-horizontal>`;
      case ProxyMode.ForwardDomain:
        return x`<p class="pf-u-mb-xl">
                        ${msg(
          "Use this provider with nginx's auth_request or traefik's forwardAuth. Only a single provider is required per root domain. You can't do per-application authorization, but you don't have to create a provider for each application."
        )}
                    </p>
                    <div class="pf-u-mb-xl">
                        ${msg("An example setup can look like this:")}
                        <ul class="pf-c-list">
                            <li>${msg("authentik running on auth.example.com")}</li>
                            <li>${msg("app1 running on app1.example.com")}</li>
                        </ul>
                        ${msg(
          "In this case, you'd set the Authentication URL to auth.example.com and Cookie domain to example.com."
        )}
                    </div>
                    <ak-form-element-horizontal
                        label=${msg("Authentication URL")}
                        ?required=${true}
                        name="externalHost"
                    >
                        <input
                            type="text"
                            value="${first(this.instance?.externalHost, window.location.origin)}"
                            class="pf-c-form-control"
                            required
                        />
                        <p class="pf-c-form__helper-text">
                            ${msg(
          "The external URL you'll authenticate at. The authentik core server should be reachable under this URL."
        )}
                        </p>
                    </ak-form-element-horizontal>
                    <ak-form-element-horizontal
                        label=${msg("Cookie domain")}
                        name="cookieDomain"
                        ?required=${true}
                    >
                        <input
                            type="text"
                            value="${o(this.instance?.cookieDomain)}"
                            class="pf-c-form-control"
                            required
                        />
                        <p class="pf-c-form__helper-text">
                            ${msg(
          "Set this to the domain you wish the authentication to be valid for. Must be a parent domain of the URL above. If you're running applications as app1.domain.tld, app2.domain.tld, set this to 'domain.tld'."
        )}
                        </p>
                    </ak-form-element-horizontal>`;
      case ProxyMode.UnknownDefaultOpenApi:
        return x`<p>${msg("Unknown proxy mode")}</p>`;
    }
  }
  renderForm() {
    return x` <ak-form-element-horizontal label=${msg("Name")} ?required=${true} name="name">
                <input
                    type="text"
                    value="${o(this.instance?.name)}"
                    class="pf-c-form-control"
                    required
                />
            </ak-form-element-horizontal>
            <ak-form-element-horizontal
                label=${msg("Authentication flow")}
                ?required=${false}
                name="authenticationFlow"
            >
                <ak-flow-search
                    flowType=${FlowsInstancesListDesignationEnum.Authentication}
                    .currentFlow=${this.instance?.authenticationFlow}
                    required
                ></ak-flow-search>
                <p class="pf-c-form__helper-text">
                    ${msg("Flow used when a user access this provider and is not authenticated.")}
                </p>
            </ak-form-element-horizontal>
            <ak-form-element-horizontal
                label=${msg("Authorization flow")}
                ?required=${true}
                name="authorizationFlow"
            >
                <ak-flow-search
                    flowType=${FlowsInstancesListDesignationEnum.Authorization}
                    .currentFlow=${this.instance?.authorizationFlow}
                    required
                ></ak-flow-search>
                <p class="pf-c-form__helper-text">
                    ${msg("Flow used when authorizing this provider.")}
                </p>
            </ak-form-element-horizontal>

            <div class="pf-c-card pf-m-selectable pf-m-selected">
                <div class="pf-c-card__body">${this.renderModeSelector()}</div>
                <div class="pf-c-card__footer">${this.renderSettings()}</div>
            </div>
            <ak-form-element-horizontal label=${msg("Token validity")} name="accessTokenValidity">
                <input
                    type="text"
                    value="${first(this.instance?.accessTokenValidity, "hours=24")}"
                    class="pf-c-form-control"
                />
                <p class="pf-c-form__helper-text">
                    ${msg("Configure how long tokens are valid for.")}
                </p>
                <ak-utils-time-delta-help></ak-utils-time-delta-help>
            </ak-form-element-horizontal>

            <ak-form-group>
                <span slot="header">${msg("Advanced protocol settings")}</span>
                <div slot="body" class="pf-c-form">
                    <ak-form-element-horizontal label=${msg("Certificate")} name="certificate">
                        <ak-crypto-certificate-search
                            .certificate=${this.instance?.certificate}
                        ></ak-crypto-certificate-search>
                    </ak-form-element-horizontal>
                    <ak-form-element-horizontal
                        label=${msg("Additional scopes")}
                        name="propertyMappings"
                    >
                        <select class="pf-c-form-control" multiple>
                            ${this.propertyMappings?.results.filter((scope) => {
      return !scope.managed?.startsWith("goauthentik.io/providers");
    }).map((scope) => {
      const selected = (this.instance?.propertyMappings || []).some(
        (su) => {
          return su == scope.pk;
        }
      );
      return x`<option
                                        value=${o(scope.pk)}
                                        ?selected=${selected}
                                    >
                                        ${scope.name}
                                    </option>`;
    })}
                        </select>
                        <p class="pf-c-form__helper-text">
                            ${msg("Additional scope mappings, which are passed to the proxy.")}
                        </p>
                        <p class="pf-c-form__helper-text">
                            ${msg("Hold control/command to select multiple items.")}
                        </p>
                    </ak-form-element-horizontal>

                    <ak-form-element-horizontal
                        label="${this.mode === ProxyMode.ForwardDomain ? msg("Unauthenticated URLs") : msg("Unauthenticated Paths")}"
                        name="skipPathRegex"
                    >
                        <textarea class="pf-c-form-control">
${this.instance?.skipPathRegex}</textarea
                        >
                        <p class="pf-c-form__helper-text">
                            ${msg(
      "Regular expressions for which authentication is not required. Each new line is interpreted as a new expression."
    )}
                        </p>
                        <p class="pf-c-form__helper-text">
                            ${msg(
      "When using proxy or forward auth (single application) mode, the requested URL Path is checked against the regular expressions. When using forward auth (domain mode), the full requested URL including scheme and host is matched against the regular expressions."
    )}
                        </p>
                    </ak-form-element-horizontal>
                </div>
            </ak-form-group>
            <ak-form-group>
                <span slot="header">${msg("Authentication settings")}</span>
                <div slot="body" class="pf-c-form">
                    <ak-form-element-horizontal name="interceptHeaderAuth">
                        <label class="pf-c-switch">
                            <input
                                class="pf-c-switch__input"
                                type="checkbox"
                                ?checked=${first(this.instance?.interceptHeaderAuth, true)}
                            />
                            <span class="pf-c-switch__toggle">
                                <span class="pf-c-switch__toggle-icon">
                                    <i class="fas fa-check" aria-hidden="true"></i>
                                </span>
                            </span>
                            <span class="pf-c-switch__label"
                                >${msg("Intercept header authentication")}</span
                            >
                        </label>
                        <p class="pf-c-form__helper-text">
                            ${msg(
      "When enabled, authentik will intercept the Authorization header to authenticate the request."
    )}
                        </p>
                    </ak-form-element-horizontal>
                    <ak-form-element-horizontal name="basicAuthEnabled">
                        <label class="pf-c-switch">
                            <input
                                class="pf-c-switch__input"
                                type="checkbox"
                                ?checked=${first(this.instance?.basicAuthEnabled, false)}
                                @change=${(ev) => {
      const el = ev.target;
      this.showHttpBasic = el.checked;
    }}
                            />
                            <span class="pf-c-switch__toggle">
                                <span class="pf-c-switch__toggle-icon">
                                    <i class="fas fa-check" aria-hidden="true"></i>
                                </span>
                            </span>
                            <span class="pf-c-switch__label"
                                >${msg("Send HTTP-Basic Authentication")}</span
                            >
                        </label>
                        <p class="pf-c-form__helper-text">
                            ${msg(
      "Send a custom HTTP-Basic Authentication header based on values from authentik."
    )}
                        </p>
                    </ak-form-element-horizontal>
                    ${this.showHttpBasic ? this.renderHttpBasic() : x``}
                    <ak-form-element-horizontal
                        label=${msg("Trusted OIDC Sources")}
                        name="jwksSources"
                    >
                        <select class="pf-c-form-control" multiple>
                            ${this.oauthSources?.results.map((source) => {
      const selected = (this.instance?.jwksSources || []).some((su) => {
        return su == source.pk;
      });
      return x`<option value=${source.pk} ?selected=${selected}>
                                    ${source.name} (${source.slug})
                                </option>`;
    })}
                        </select>
                        <p class="pf-c-form__helper-text">
                            ${msg(
      "JWTs signed by certificates configured in the selected sources can be used to authenticate to this provider."
    )}
                        </p>
                        <p class="pf-c-form__helper-text">
                            ${msg("Hold control/command to select multiple items.")}
                        </p>
                    </ak-form-element-horizontal>
                </div>
            </ak-form-group>`;
  }
};
__decorateClass([
  r()
], ProxyProviderFormPage.prototype, "showHttpBasic", 2);
__decorateClass([
  r()
], ProxyProviderFormPage.prototype, "mode", 2);
ProxyProviderFormPage = __decorateClass([
  t("ak-provider-proxy-form")
], ProxyProviderFormPage);

// src/admin/providers/saml/SAMLProviderForm.ts
var SAMLProviderFormPage = class extends BaseProviderForm {
  loadInstance(pk) {
    return new ProvidersApi(DEFAULT_CONFIG).providersSamlRetrieve({
      id: pk
    });
  }
  async load() {
    this.propertyMappings = await new PropertymappingsApi(
      DEFAULT_CONFIG
    ).propertymappingsSamlList({
      ordering: "saml_name"
    });
  }
  async send(data) {
    if (this.instance) {
      return new ProvidersApi(DEFAULT_CONFIG).providersSamlUpdate({
        id: this.instance.pk || 0,
        sAMLProviderRequest: data
      });
    } else {
      return new ProvidersApi(DEFAULT_CONFIG).providersSamlCreate({
        sAMLProviderRequest: data
      });
    }
  }
  renderForm() {
    return x` <ak-form-element-horizontal label=${msg("Name")} ?required=${true} name="name">
                <input
                    type="text"
                    value="${o(this.instance?.name)}"
                    class="pf-c-form-control"
                    required
                />
            </ak-form-element-horizontal>
            <ak-form-element-horizontal
                label=${msg("Authentication flow")}
                ?required=${false}
                name="authenticationFlow"
            >
                <ak-flow-search
                    flowType=${FlowsInstancesListDesignationEnum.Authentication}
                    .currentFlow=${this.instance?.authenticationFlow}
                    required
                ></ak-flow-search>
                <p class="pf-c-form__helper-text">
                    ${msg("Flow used when a user access this provider and is not authenticated.")}
                </p>
            </ak-form-element-horizontal>
            <ak-form-element-horizontal
                label=${msg("Authorization flow")}
                ?required=${true}
                name="authorizationFlow"
            >
                <ak-flow-search
                    flowType=${FlowsInstancesListDesignationEnum.Authorization}
                    .currentFlow=${this.instance?.authorizationFlow}
                    required
                ></ak-flow-search>
                <p class="pf-c-form__helper-text">
                    ${msg("Flow used when authorizing this provider.")}
                </p>
            </ak-form-element-horizontal>

            <ak-form-group .expanded=${true}>
                <span slot="header"> ${msg("Protocol settings")} </span>
                <div slot="body" class="pf-c-form">
                    <ak-form-element-horizontal
                        label=${msg("ACS URL")}
                        ?required=${true}
                        name="acsUrl"
                    >
                        <input
                            type="text"
                            value="${o(this.instance?.acsUrl)}"
                            class="pf-c-form-control"
                            required
                        />
                    </ak-form-element-horizontal>
                    <ak-form-element-horizontal
                        label=${msg("Issuer")}
                        ?required=${true}
                        name="issuer"
                    >
                        <input
                            type="text"
                            value="${this.instance?.issuer || "authentik"}"
                            class="pf-c-form-control"
                            required
                        />
                        <p class="pf-c-form__helper-text">${msg("Also known as EntityID.")}</p>
                    </ak-form-element-horizontal>
                    <ak-form-element-horizontal
                        label=${msg("Service Provider Binding")}
                        ?required=${true}
                        name="spBinding"
                    >
                        <ak-radio
                            .options=${[
      {
        label: msg("Redirect"),
        value: SpBindingEnum.Redirect,
        default: true
      },
      {
        label: msg("Post"),
        value: SpBindingEnum.Post
      }
    ]}
                            .value=${this.instance?.spBinding}
                        >
                        </ak-radio>
                        <p class="pf-c-form__helper-text">
                            ${msg(
      "Determines how authentik sends the response back to the Service Provider."
    )}
                        </p>
                    </ak-form-element-horizontal>
                    <ak-form-element-horizontal label=${msg("Audience")} name="audience">
                        <input
                            type="text"
                            value="${o(this.instance?.audience)}"
                            class="pf-c-form-control"
                        />
                    </ak-form-element-horizontal>
                </div>
            </ak-form-group>

            <ak-form-group>
                <span slot="header"> ${msg("Advanced protocol settings")} </span>
                <div slot="body" class="pf-c-form">
                    <ak-form-element-horizontal
                        label=${msg("Signing Certificate")}
                        name="signingKp"
                    >
                        <ak-crypto-certificate-search
                            .certificate=${this.instance?.signingKp}
                        ></ak-crypto-certificate-search>
                        <p class="pf-c-form__helper-text">
                            ${msg(
      "Certificate used to sign outgoing Responses going to the Service Provider."
    )}
                        </p>
                    </ak-form-element-horizontal>
                    <ak-form-element-horizontal
                        label=${msg("Verification Certificate")}
                        name="verificationKp"
                    >
                        <ak-crypto-certificate-search
                            .certificate=${this.instance?.verificationKp}
                            nokey
                        ></ak-crypto-certificate-search>
                        <p class="pf-c-form__helper-text">
                            ${msg(
      "When selected, incoming assertion's Signatures will be validated against this certificate. To allow unsigned Requests, leave on default."
    )}
                        </p>
                    </ak-form-element-horizontal>
                    <ak-form-element-horizontal
                        label=${msg("Property mappings")}
                        name="propertyMappings"
                    >
                        <select class="pf-c-form-control" multiple>
                            ${this.propertyMappings?.results.map((mapping) => {
      let selected = false;
      if (!this.instance?.propertyMappings) {
        selected = mapping.managed?.startsWith(
          "goauthentik.io/providers/saml"
        ) || false;
      } else {
        selected = Array.from(this.instance?.propertyMappings).some(
          (su) => {
            return su == mapping.pk;
          }
        );
      }
      return x`<option
                                    value=${o(mapping.pk)}
                                    ?selected=${selected}
                                >
                                    ${mapping.name}
                                </option>`;
    })}
                        </select>
                        <p class="pf-c-form__helper-text">
                            ${msg("Hold control/command to select multiple items.")}
                        </p>
                    </ak-form-element-horizontal>
                    <ak-form-element-horizontal
                        label=${msg("NameID Property Mapping")}
                        name="nameIdMapping"
                    >
                        <ak-search-select
                            .fetchObjects=${async (query) => {
      const args = {
        ordering: "saml_name"
      };
      if (query !== void 0) {
        args.search = query;
      }
      const items = await new PropertymappingsApi(
        DEFAULT_CONFIG
      ).propertymappingsSamlList(args);
      return items.results;
    }}
                            .renderElement=${(item) => {
      return item.name;
    }}
                            .value=${(item) => {
      return item?.pk;
    }}
                            .selected=${(item) => {
      return this.instance?.nameIdMapping === item.pk;
    }}
                            ?blankable=${true}
                        >
                        </ak-search-select>
                        <p class="pf-c-form__helper-text">
                            ${msg(
      "Configure how the NameID value will be created. When left empty, the NameIDPolicy of the incoming request will be respected."
    )}
                        </p>
                    </ak-form-element-horizontal>

                    <ak-form-element-horizontal
                        label=${msg("Assertion valid not before")}
                        ?required=${true}
                        name="assertionValidNotBefore"
                    >
                        <input
                            type="text"
                            value="${this.instance?.assertionValidNotBefore || "minutes=-5"}"
                            class="pf-c-form-control"
                            required
                        />
                        <p class="pf-c-form__helper-text">
                            ${msg("Configure the maximum allowed time drift for an assertion.")}
                        </p>
                        <ak-utils-time-delta-help></ak-utils-time-delta-help>
                    </ak-form-element-horizontal>
                    <ak-form-element-horizontal
                        label=${msg("Assertion valid not on or after")}
                        ?required=${true}
                        name="assertionValidNotOnOrAfter"
                    >
                        <input
                            type="text"
                            value="${this.instance?.assertionValidNotOnOrAfter || "minutes=5"}"
                            class="pf-c-form-control"
                            required
                        />
                        <p class="pf-c-form__helper-text">
                            ${msg("Assertion not valid on or after current time + this value.")}
                        </p>
                        <ak-utils-time-delta-help></ak-utils-time-delta-help>
                    </ak-form-element-horizontal>
                    <ak-form-element-horizontal
                        label=${msg("Session valid not on or after")}
                        ?required=${true}
                        name="sessionValidNotOnOrAfter"
                    >
                        <input
                            type="text"
                            value="${this.instance?.sessionValidNotOnOrAfter || "minutes=86400"}"
                            class="pf-c-form-control"
                            required
                        />
                        <p class="pf-c-form__helper-text">
                            ${msg("Session not valid on or after current time + this value.")}
                        </p>
                        <ak-utils-time-delta-help></ak-utils-time-delta-help>
                    </ak-form-element-horizontal>
                    <ak-form-element-horizontal
                        label=${msg("Default relay state")}
                        ?required=${true}
                        name="defaultRelayState"
                    >
                        <input
                            type="text"
                            value="${this.instance?.defaultRelayState || ""}"
                            class="pf-c-form-control"
                            required
                        />
                        <p class="pf-c-form__helper-text">
                            ${msg(
      "When using IDP-initiated logins, the relay state will be set to this value."
    )}
                        </p>
                        <ak-utils-time-delta-help></ak-utils-time-delta-help>
                    </ak-form-element-horizontal>

                    <ak-form-element-horizontal
                        label=${msg("Digest algorithm")}
                        ?required=${true}
                        name="digestAlgorithm"
                    >
                        <ak-radio
                            .options=${[
      {
        label: "SHA1",
        value: DigestAlgorithmEnum._200009Xmldsigsha1
      },
      {
        label: "SHA256",
        value: DigestAlgorithmEnum._200104Xmlencsha256,
        default: true
      },
      {
        label: "SHA384",
        value: DigestAlgorithmEnum._200104XmldsigMoresha384
      },
      {
        label: "SHA512",
        value: DigestAlgorithmEnum._200104Xmlencsha512
      }
    ]}
                            .value=${this.instance?.digestAlgorithm}
                        >
                        </ak-radio>
                    </ak-form-element-horizontal>
                    <ak-form-element-horizontal
                        label=${msg("Signature algorithm")}
                        ?required=${true}
                        name="signatureAlgorithm"
                    >
                        <ak-radio
                            .options=${[
      {
        label: "RSA-SHA1",
        value: SignatureAlgorithmEnum._200009XmldsigrsaSha1
      },
      {
        label: "RSA-SHA256",
        value: SignatureAlgorithmEnum._200104XmldsigMorersaSha256,
        default: true
      },
      {
        label: "RSA-SHA384",
        value: SignatureAlgorithmEnum._200104XmldsigMorersaSha384
      },
      {
        label: "RSA-SHA512",
        value: SignatureAlgorithmEnum._200104XmldsigMorersaSha512
      },
      {
        label: "DSA-SHA1",
        value: SignatureAlgorithmEnum._200009XmldsigdsaSha1
      }
    ]}
                            .value=${this.instance?.signatureAlgorithm}
                        >
                        </ak-radio>
                    </ak-form-element-horizontal>
                </div>
            </ak-form-group>`;
  }
};
SAMLProviderFormPage = __decorateClass([
  t("ak-provider-saml-form")
], SAMLProviderFormPage);

// src/admin/providers/rac/RACProviderForm.ts
var RACProviderFormPage = class extends ModelForm {
  async load() {
    this.propertyMappings = await new PropertymappingsApi(
      DEFAULT_CONFIG
    ).propertymappingsRacList({
      ordering: "name"
    });
  }
  async loadInstance(pk) {
    return new ProvidersApi(DEFAULT_CONFIG).providersRacRetrieve({
      id: pk
    });
  }
  getSuccessMessage() {
    if (this.instance) {
      return msg("Successfully updated provider.");
    } else {
      return msg("Successfully created provider.");
    }
  }
  async send(data) {
    if (this.instance) {
      return new ProvidersApi(DEFAULT_CONFIG).providersRacUpdate({
        id: this.instance.pk || 0,
        rACProviderRequest: data
      });
    } else {
      return new ProvidersApi(DEFAULT_CONFIG).providersRacCreate({
        rACProviderRequest: data
      });
    }
  }
  renderForm() {
    return x`
            <ak-form-element-horizontal label=${msg("Name")} ?required=${true} name="name">
                <input
                    type="text"
                    value="${o(this.instance?.name)}"
                    class="pf-c-form-control"
                    required
                />
            </ak-form-element-horizontal>

            <ak-form-element-horizontal
                name="authorizationFlow"
                label=${msg("Authorization flow")}
                ?required=${true}
            >
                <ak-flow-search
                    flowType=${FlowsInstancesListDesignationEnum.Authorization}
                    .currentFlow=${this.instance?.authorizationFlow}
                    required
                ></ak-flow-search>
                <p class="pf-c-form__helper-text">
                    ${msg("Flow used when authorizing this provider.")}
                </p>
            </ak-form-element-horizontal>
            <ak-form-element-horizontal
                label=${msg("Connection expiry")}
                ?required=${true}
                name="connectionExpiry"
            >
                <input
                    type="text"
                    value="${first(this.instance?.connectionExpiry, "hours=8")}"
                    class="pf-c-form-control"
                    required
                />
                <p class="pf-c-form__helper-text">
                    ${msg(
      "Determines how long a session lasts before being disconnected and requiring re-authorization."
    )}
                </p>
                <ak-utils-time-delta-help></ak-utils-time-delta-help>
            </ak-form-element-horizontal>
            <ak-form-element-horizontal name="deleteTokenOnDisconnect">
                <label class="pf-c-switch">
                    <input
                        class="pf-c-switch__input"
                        type="checkbox"
                        ?checked=${first(this.instance?.deleteTokenOnDisconnect, false)}
                    />
                    <span class="pf-c-switch__toggle">
                        <span class="pf-c-switch__toggle-icon">
                            <i class="fas fa-check" aria-hidden="true"></i>
                        </span>
                    </span>
                    <span class="pf-c-switch__label"
                        >${msg("Delete authorization on disconnect")}</span
                    >
                </label>
                <p class="pf-c-form__helper-text">
                    ${msg(
      "When enabled, connection authorizations will be deleted when a client disconnects. This will force clients with flaky internet connections to re-authorize the endpoint."
    )}
                </p>
            </ak-form-element-horizontal>

            <ak-form-group .expanded=${true}>
                <span slot="header"> ${msg("Protocol settings")} </span>
                <div slot="body" class="pf-c-form">
                    <ak-form-element-horizontal
                        label=${msg("Property mappings")}
                        name="propertyMappings"
                    >
                        <select class="pf-c-form-control" multiple>
                            ${this.propertyMappings?.results.map((mapping) => {
      let selected = false;
      if (this.instance?.propertyMappings) {
        selected = Array.from(this.instance?.propertyMappings).some(
          (su) => {
            return su == mapping.pk;
          }
        );
      }
      return x`<option
                                    value=${o(mapping.pk)}
                                    ?selected=${selected}
                                >
                                    ${mapping.name}
                                </option>`;
    })}
                        </select>
                        <p class="pf-c-form__helper-text">
                            ${msg("Hold control/command to select multiple items.")}
                        </p>
                    </ak-form-element-horizontal>
                    <ak-form-element-horizontal label=${msg("Settings")} name="settings">
                        <ak-codemirror
                            mode="yaml"
                            value="${browser_default.stringify(first(this.instance?.settings, {}))}"
                        >
                        </ak-codemirror>
                        <p class="pf-c-form__helper-text">${msg("Connection settings.")}</p>
                    </ak-form-element-horizontal>
                </div>
            </ak-form-group>
        `;
  }
};
__decorateClass([
  r()
], RACProviderFormPage.prototype, "propertyMappings", 2);
RACProviderFormPage = __decorateClass([
  t("ak-provider-rac-form")
], RACProviderFormPage);

// node_modules/lit-html/lit-html.js
var t2;
var i = window;
var s = i.trustedTypes;
var e = s ? s.createPolicy("lit-html", { createHTML: (t3) => t3 }) : void 0;
var o2 = "$lit$";
var n = `lit$${(Math.random() + "").slice(9)}$`;
var l = "?" + n;
var h = `<${l}>`;
var r2 = document;
var u = () => r2.createComment("");
var d = (t3) => null === t3 || "object" != typeof t3 && "function" != typeof t3;
var c = Array.isArray;
var v = (t3) => c(t3) || "function" == typeof (null == t3 ? void 0 : t3[Symbol.iterator]);
var a = "[ 	\n\f\r]";
var f = /<(?:(!--|\/[^a-zA-Z])|(\/?[a-zA-Z][^>\s]*)|(\/?$))/g;
var _ = /-->/g;
var m = />/g;
var p = RegExp(`>|${a}(?:([^\\s"'>=/]+)(${a}*=${a}*(?:[^ 	
\f\r"'\`<>=]|("|')|))|$)`, "g");
var g = /'/g;
var $ = /"/g;
var y = /^(?:script|style|textarea|title)$/i;
var w = (t3) => (i2, ...s2) => ({ _$litType$: t3, strings: i2, values: s2 });
var x2 = w(1);
var b = w(2);
var T = Symbol.for("lit-noChange");
var A = Symbol.for("lit-nothing");
var E = /* @__PURE__ */ new WeakMap();
var C = r2.createTreeWalker(r2, 129, null, false);
function P(t3, i2) {
  if (!Array.isArray(t3) || !t3.hasOwnProperty("raw"))
    throw Error("invalid template strings array");
  return void 0 !== e ? e.createHTML(i2) : i2;
}
var V = (t3, i2) => {
  const s2 = t3.length - 1, e2 = [];
  let l3, r3 = 2 === i2 ? "<svg>" : "", u2 = f;
  for (let i3 = 0; i3 < s2; i3++) {
    const s3 = t3[i3];
    let d2, c2, v2 = -1, a2 = 0;
    for (; a2 < s3.length && (u2.lastIndex = a2, c2 = u2.exec(s3), null !== c2); )
      a2 = u2.lastIndex, u2 === f ? "!--" === c2[1] ? u2 = _ : void 0 !== c2[1] ? u2 = m : void 0 !== c2[2] ? (y.test(c2[2]) && (l3 = RegExp("</" + c2[2], "g")), u2 = p) : void 0 !== c2[3] && (u2 = p) : u2 === p ? ">" === c2[0] ? (u2 = null != l3 ? l3 : f, v2 = -1) : void 0 === c2[1] ? v2 = -2 : (v2 = u2.lastIndex - c2[2].length, d2 = c2[1], u2 = void 0 === c2[3] ? p : '"' === c2[3] ? $ : g) : u2 === $ || u2 === g ? u2 = p : u2 === _ || u2 === m ? u2 = f : (u2 = p, l3 = void 0);
    const w2 = u2 === p && t3[i3 + 1].startsWith("/>") ? " " : "";
    r3 += u2 === f ? s3 + h : v2 >= 0 ? (e2.push(d2), s3.slice(0, v2) + o2 + s3.slice(v2) + n + w2) : s3 + n + (-2 === v2 ? (e2.push(void 0), i3) : w2);
  }
  return [P(t3, r3 + (t3[s2] || "<?>") + (2 === i2 ? "</svg>" : "")), e2];
};
var N = class _N {
  constructor({ strings: t3, _$litType$: i2 }, e2) {
    let h2;
    this.parts = [];
    let r3 = 0, d2 = 0;
    const c2 = t3.length - 1, v2 = this.parts, [a2, f2] = V(t3, i2);
    if (this.el = _N.createElement(a2, e2), C.currentNode = this.el.content, 2 === i2) {
      const t4 = this.el.content, i3 = t4.firstChild;
      i3.remove(), t4.append(...i3.childNodes);
    }
    for (; null !== (h2 = C.nextNode()) && v2.length < c2; ) {
      if (1 === h2.nodeType) {
        if (h2.hasAttributes()) {
          const t4 = [];
          for (const i3 of h2.getAttributeNames())
            if (i3.endsWith(o2) || i3.startsWith(n)) {
              const s2 = f2[d2++];
              if (t4.push(i3), void 0 !== s2) {
                const t5 = h2.getAttribute(s2.toLowerCase() + o2).split(n), i4 = /([.?@])?(.*)/.exec(s2);
                v2.push({ type: 1, index: r3, name: i4[2], strings: t5, ctor: "." === i4[1] ? H : "?" === i4[1] ? L : "@" === i4[1] ? z : k });
              } else
                v2.push({ type: 6, index: r3 });
            }
          for (const i3 of t4)
            h2.removeAttribute(i3);
        }
        if (y.test(h2.tagName)) {
          const t4 = h2.textContent.split(n), i3 = t4.length - 1;
          if (i3 > 0) {
            h2.textContent = s ? s.emptyScript : "";
            for (let s2 = 0; s2 < i3; s2++)
              h2.append(t4[s2], u()), C.nextNode(), v2.push({ type: 2, index: ++r3 });
            h2.append(t4[i3], u());
          }
        }
      } else if (8 === h2.nodeType)
        if (h2.data === l)
          v2.push({ type: 2, index: r3 });
        else {
          let t4 = -1;
          for (; -1 !== (t4 = h2.data.indexOf(n, t4 + 1)); )
            v2.push({ type: 7, index: r3 }), t4 += n.length - 1;
        }
      r3++;
    }
  }
  static createElement(t3, i2) {
    const s2 = r2.createElement("template");
    return s2.innerHTML = t3, s2;
  }
};
function S(t3, i2, s2 = t3, e2) {
  var o3, n2, l3, h2;
  if (i2 === T)
    return i2;
  let r3 = void 0 !== e2 ? null === (o3 = s2._$Co) || void 0 === o3 ? void 0 : o3[e2] : s2._$Cl;
  const u2 = d(i2) ? void 0 : i2._$litDirective$;
  return (null == r3 ? void 0 : r3.constructor) !== u2 && (null === (n2 = null == r3 ? void 0 : r3._$AO) || void 0 === n2 || n2.call(r3, false), void 0 === u2 ? r3 = void 0 : (r3 = new u2(t3), r3._$AT(t3, s2, e2)), void 0 !== e2 ? (null !== (l3 = (h2 = s2)._$Co) && void 0 !== l3 ? l3 : h2._$Co = [])[e2] = r3 : s2._$Cl = r3), void 0 !== r3 && (i2 = S(t3, r3._$AS(t3, i2.values), r3, e2)), i2;
}
var M = class {
  constructor(t3, i2) {
    this._$AV = [], this._$AN = void 0, this._$AD = t3, this._$AM = i2;
  }
  get parentNode() {
    return this._$AM.parentNode;
  }
  get _$AU() {
    return this._$AM._$AU;
  }
  u(t3) {
    var i2;
    const { el: { content: s2 }, parts: e2 } = this._$AD, o3 = (null !== (i2 = null == t3 ? void 0 : t3.creationScope) && void 0 !== i2 ? i2 : r2).importNode(s2, true);
    C.currentNode = o3;
    let n2 = C.nextNode(), l3 = 0, h2 = 0, u2 = e2[0];
    for (; void 0 !== u2; ) {
      if (l3 === u2.index) {
        let i3;
        2 === u2.type ? i3 = new R(n2, n2.nextSibling, this, t3) : 1 === u2.type ? i3 = new u2.ctor(n2, u2.name, u2.strings, this, t3) : 6 === u2.type && (i3 = new Z(n2, this, t3)), this._$AV.push(i3), u2 = e2[++h2];
      }
      l3 !== (null == u2 ? void 0 : u2.index) && (n2 = C.nextNode(), l3++);
    }
    return C.currentNode = r2, o3;
  }
  v(t3) {
    let i2 = 0;
    for (const s2 of this._$AV)
      void 0 !== s2 && (void 0 !== s2.strings ? (s2._$AI(t3, s2, i2), i2 += s2.strings.length - 2) : s2._$AI(t3[i2])), i2++;
  }
};
var R = class _R {
  constructor(t3, i2, s2, e2) {
    var o3;
    this.type = 2, this._$AH = A, this._$AN = void 0, this._$AA = t3, this._$AB = i2, this._$AM = s2, this.options = e2, this._$Cp = null === (o3 = null == e2 ? void 0 : e2.isConnected) || void 0 === o3 || o3;
  }
  get _$AU() {
    var t3, i2;
    return null !== (i2 = null === (t3 = this._$AM) || void 0 === t3 ? void 0 : t3._$AU) && void 0 !== i2 ? i2 : this._$Cp;
  }
  get parentNode() {
    let t3 = this._$AA.parentNode;
    const i2 = this._$AM;
    return void 0 !== i2 && 11 === (null == t3 ? void 0 : t3.nodeType) && (t3 = i2.parentNode), t3;
  }
  get startNode() {
    return this._$AA;
  }
  get endNode() {
    return this._$AB;
  }
  _$AI(t3, i2 = this) {
    t3 = S(this, t3, i2), d(t3) ? t3 === A || null == t3 || "" === t3 ? (this._$AH !== A && this._$AR(), this._$AH = A) : t3 !== this._$AH && t3 !== T && this._(t3) : void 0 !== t3._$litType$ ? this.g(t3) : void 0 !== t3.nodeType ? this.$(t3) : v(t3) ? this.T(t3) : this._(t3);
  }
  k(t3) {
    return this._$AA.parentNode.insertBefore(t3, this._$AB);
  }
  $(t3) {
    this._$AH !== t3 && (this._$AR(), this._$AH = this.k(t3));
  }
  _(t3) {
    this._$AH !== A && d(this._$AH) ? this._$AA.nextSibling.data = t3 : this.$(r2.createTextNode(t3)), this._$AH = t3;
  }
  g(t3) {
    var i2;
    const { values: s2, _$litType$: e2 } = t3, o3 = "number" == typeof e2 ? this._$AC(t3) : (void 0 === e2.el && (e2.el = N.createElement(P(e2.h, e2.h[0]), this.options)), e2);
    if ((null === (i2 = this._$AH) || void 0 === i2 ? void 0 : i2._$AD) === o3)
      this._$AH.v(s2);
    else {
      const t4 = new M(o3, this), i3 = t4.u(this.options);
      t4.v(s2), this.$(i3), this._$AH = t4;
    }
  }
  _$AC(t3) {
    let i2 = E.get(t3.strings);
    return void 0 === i2 && E.set(t3.strings, i2 = new N(t3)), i2;
  }
  T(t3) {
    c(this._$AH) || (this._$AH = [], this._$AR());
    const i2 = this._$AH;
    let s2, e2 = 0;
    for (const o3 of t3)
      e2 === i2.length ? i2.push(s2 = new _R(this.k(u()), this.k(u()), this, this.options)) : s2 = i2[e2], s2._$AI(o3), e2++;
    e2 < i2.length && (this._$AR(s2 && s2._$AB.nextSibling, e2), i2.length = e2);
  }
  _$AR(t3 = this._$AA.nextSibling, i2) {
    var s2;
    for (null === (s2 = this._$AP) || void 0 === s2 || s2.call(this, false, true, i2); t3 && t3 !== this._$AB; ) {
      const i3 = t3.nextSibling;
      t3.remove(), t3 = i3;
    }
  }
  setConnected(t3) {
    var i2;
    void 0 === this._$AM && (this._$Cp = t3, null === (i2 = this._$AP) || void 0 === i2 || i2.call(this, t3));
  }
};
var k = class {
  constructor(t3, i2, s2, e2, o3) {
    this.type = 1, this._$AH = A, this._$AN = void 0, this.element = t3, this.name = i2, this._$AM = e2, this.options = o3, s2.length > 2 || "" !== s2[0] || "" !== s2[1] ? (this._$AH = Array(s2.length - 1).fill(new String()), this.strings = s2) : this._$AH = A;
  }
  get tagName() {
    return this.element.tagName;
  }
  get _$AU() {
    return this._$AM._$AU;
  }
  _$AI(t3, i2 = this, s2, e2) {
    const o3 = this.strings;
    let n2 = false;
    if (void 0 === o3)
      t3 = S(this, t3, i2, 0), n2 = !d(t3) || t3 !== this._$AH && t3 !== T, n2 && (this._$AH = t3);
    else {
      const e3 = t3;
      let l3, h2;
      for (t3 = o3[0], l3 = 0; l3 < o3.length - 1; l3++)
        h2 = S(this, e3[s2 + l3], i2, l3), h2 === T && (h2 = this._$AH[l3]), n2 || (n2 = !d(h2) || h2 !== this._$AH[l3]), h2 === A ? t3 = A : t3 !== A && (t3 += (null != h2 ? h2 : "") + o3[l3 + 1]), this._$AH[l3] = h2;
    }
    n2 && !e2 && this.j(t3);
  }
  j(t3) {
    t3 === A ? this.element.removeAttribute(this.name) : this.element.setAttribute(this.name, null != t3 ? t3 : "");
  }
};
var H = class extends k {
  constructor() {
    super(...arguments), this.type = 3;
  }
  j(t3) {
    this.element[this.name] = t3 === A ? void 0 : t3;
  }
};
var I = s ? s.emptyScript : "";
var L = class extends k {
  constructor() {
    super(...arguments), this.type = 4;
  }
  j(t3) {
    t3 && t3 !== A ? this.element.setAttribute(this.name, I) : this.element.removeAttribute(this.name);
  }
};
var z = class extends k {
  constructor(t3, i2, s2, e2, o3) {
    super(t3, i2, s2, e2, o3), this.type = 5;
  }
  _$AI(t3, i2 = this) {
    var s2;
    if ((t3 = null !== (s2 = S(this, t3, i2, 0)) && void 0 !== s2 ? s2 : A) === T)
      return;
    const e2 = this._$AH, o3 = t3 === A && e2 !== A || t3.capture !== e2.capture || t3.once !== e2.once || t3.passive !== e2.passive, n2 = t3 !== A && (e2 === A || o3);
    o3 && this.element.removeEventListener(this.name, this, e2), n2 && this.element.addEventListener(this.name, this, t3), this._$AH = t3;
  }
  handleEvent(t3) {
    var i2, s2;
    "function" == typeof this._$AH ? this._$AH.call(null !== (s2 = null === (i2 = this.options) || void 0 === i2 ? void 0 : i2.host) && void 0 !== s2 ? s2 : this.element, t3) : this._$AH.handleEvent(t3);
  }
};
var Z = class {
  constructor(t3, i2, s2) {
    this.element = t3, this.type = 6, this._$AN = void 0, this._$AM = i2, this.options = s2;
  }
  get _$AU() {
    return this._$AM._$AU;
  }
  _$AI(t3) {
    S(this, t3);
  }
};
var B = i.litHtmlPolyfillSupport;
null == B || B(N, R), (null !== (t2 = i.litHtmlVersions) && void 0 !== t2 ? t2 : i.litHtmlVersions = []).push("2.8.0");

// node_modules/lit-html/directives/if-defined.js
var l2 = (l3) => null != l3 ? l3 : A;

// src/admin/providers/radius/RadiusProviderForm.ts
var RadiusProviderFormPage = class extends WithBrandConfig(BaseProviderForm) {
  loadInstance(pk) {
    return new ProvidersApi(DEFAULT_CONFIG).providersRadiusRetrieve({
      id: pk
    });
  }
  async send(data) {
    if (this.instance) {
      return new ProvidersApi(DEFAULT_CONFIG).providersRadiusUpdate({
        id: this.instance.pk || 0,
        radiusProviderRequest: data
      });
    } else {
      return new ProvidersApi(DEFAULT_CONFIG).providersRadiusCreate({
        radiusProviderRequest: data
      });
    }
  }
  // All Provider objects have an Authorization flow, but not all providers have an Authentication
  // flow. Radius needs only one field, but it is not the Authorization field, it is an
  // Authentication field. So, yeah, we're using the authorization field to store the
  // authentication information, which is why the ak-branded-flow-search call down there looks so
  // weird-- we're looking up Authentication flows, but we're storing them in the Authorization
  // field of the target Provider.
  renderForm() {
    return x` <ak-form-element-horizontal label=${msg("Name")} ?required=${true} name="name">
                <input
                    type="text"
                    value="${l2(this.instance?.name)}"
                    class="pf-c-form-control"
                    required
                />
            </ak-form-element-horizontal>
            <ak-form-element-horizontal
                label=${msg("Authentication flow")}
                ?required=${true}
                name="authorizationFlow"
            >
                <ak-branded-flow-search
                    flowType=${FlowsInstancesListDesignationEnum.Authentication}
                    .currentFlow=${this.instance?.authorizationFlow}
                    .brandFlow=${this.brand?.flowAuthentication}
                    required
                ></ak-branded-flow-search>
                <p class="pf-c-form__helper-text">${msg("Flow used for users to authenticate.")}</p>
            </ak-form-element-horizontal>
            <ak-form-element-horizontal name="mfaSupport">
                <label class="pf-c-switch">
                    <input
                        class="pf-c-switch__input"
                        type="checkbox"
                        ?checked=${first(this.instance?.mfaSupport, true)}
                    />
                    <span class="pf-c-switch__toggle">
                        <span class="pf-c-switch__toggle-icon">
                            <i class="fas fa-check" aria-hidden="true"></i>
                        </span>
                    </span>
                    <span class="pf-c-switch__label">${msg("Code-based MFA Support")}</span>
                </label>
                <p class="pf-c-form__helper-text">
                    ${msg(
      "When enabled, code-based multi-factor authentication can be used by appending a semicolon and the TOTP code to the password. This should only be enabled if all users that will bind to this provider have a TOTP device configured, as otherwise a password may incorrectly be rejected if it contains a semicolon."
    )}
                </p>
            </ak-form-element-horizontal>

            <ak-form-group .expanded=${true}>
                <span slot="header"> ${msg("Protocol settings")} </span>
                <div slot="body" class="pf-c-form">
                    <ak-form-element-horizontal
                        label=${msg("Shared secret")}
                        ?required=${true}
                        name="sharedSecret"
                    >
                        <input
                            type="text"
                            value="${first(
      this.instance?.sharedSecret,
      randomString(128, ascii_letters + digits)
    )}"
                            class="pf-c-form-control"
                            required
                        />
                    </ak-form-element-horizontal>
                    <ak-form-element-horizontal
                        label=${msg("Client Networks")}
                        ?required=${true}
                        name="clientNetworks"
                    >
                        <input
                            type="text"
                            value="${first(this.instance?.clientNetworks, "0.0.0.0/0, ::/0")}"
                            class="pf-c-form-control"
                            required
                        />
                        <p class="pf-c-form__helper-text">
                            ${msg(`List of CIDRs (comma-seperated) that clients can connect from. A more specific
                            CIDR will match before a looser one. Clients connecting from a non-specified CIDR
                            will be dropped.`)}
                        </p>
                    </ak-form-element-horizontal>
                </div>
            </ak-form-group>`;
  }
};
RadiusProviderFormPage = __decorateClass([
  t("ak-provider-radius-form")
], RadiusProviderFormPage);

// src/admin/providers/scim/SCIMProviderForm.ts
var SCIMProviderFormPage = class extends BaseProviderForm {
  loadInstance(pk) {
    return new ProvidersApi(DEFAULT_CONFIG).providersScimRetrieve({
      id: pk
    });
  }
  async load() {
    this.propertyMappings = await new PropertymappingsApi(
      DEFAULT_CONFIG
    ).propertymappingsScimList({
      ordering: "managed"
    });
  }
  async send(data) {
    if (this.instance) {
      return new ProvidersApi(DEFAULT_CONFIG).providersScimUpdate({
        id: this.instance.pk || 0,
        sCIMProviderRequest: data
      });
    } else {
      return new ProvidersApi(DEFAULT_CONFIG).providersScimCreate({
        sCIMProviderRequest: data
      });
    }
  }
  renderForm() {
    return x` <ak-form-element-horizontal label=${msg("Name")} ?required=${true} name="name">
                <input
                    type="text"
                    value="${o(this.instance?.name)}"
                    class="pf-c-form-control"
                    required
                />
            </ak-form-element-horizontal>
            <ak-form-group .expanded=${true}>
                <span slot="header"> ${msg("Protocol settings")} </span>
                <div slot="body" class="pf-c-form">
                    <ak-form-element-horizontal label=${msg("URL")} ?required=${true} name="url">
                        <input
                            type="text"
                            value="${first(this.instance?.url, "")}"
                            class="pf-c-form-control"
                            required
                        />
                        <p class="pf-c-form__helper-text">
                            ${msg("SCIM base url, usually ends in /v2.")}
                        </p>
                    </ak-form-element-horizontal>
                    <ak-form-element-horizontal
                        label=${msg("Token")}
                        ?required=${true}
                        name="token"
                    >
                        <input
                            type="text"
                            value="${first(this.instance?.token, "")}"
                            class="pf-c-form-control"
                            required
                        />
                        <p class="pf-c-form__helper-text">
                            ${msg(
      "Token to authenticate with. Currently only bearer authentication is supported."
    )}
                        </p>
                    </ak-form-element-horizontal>
                </div>
            </ak-form-group>
            <ak-form-group ?expanded=${true}>
                <span slot="header">${msg("User filtering")}</span>
                <div slot="body" class="pf-c-form">
                    <ak-form-element-horizontal name="excludeUsersServiceAccount">
                        <label class="pf-c-switch">
                            <input
                                class="pf-c-switch__input"
                                type="checkbox"
                                ?checked=${first(this.instance?.excludeUsersServiceAccount, true)}
                            />
                            <span class="pf-c-switch__toggle">
                                <span class="pf-c-switch__toggle-icon">
                                    <i class="fas fa-check" aria-hidden="true"></i>
                                </span>
                            </span>
                            <span class="pf-c-switch__label"
                                >${msg("Exclude service accounts")}</span
                            >
                        </label>
                    </ak-form-element-horizontal>
                    <ak-form-element-horizontal label=${msg("Group")} name="filterGroup">
                        <ak-search-select
                            .fetchObjects=${async (query) => {
      const args = {
        ordering: "name"
      };
      if (query !== void 0) {
        args.search = query;
      }
      const groups = await new CoreApi(DEFAULT_CONFIG).coreGroupsList(
        args
      );
      return groups.results;
    }}
                            .renderElement=${(group) => {
      return group.name;
    }}
                            .value=${(group) => {
      return group ? group.pk : void 0;
    }}
                            .selected=${(group) => {
      return group.pk === this.instance?.filterGroup;
    }}
                            ?blankable=${true}
                        >
                        </ak-search-select>
                        <p class="pf-c-form__helper-text">
                            ${msg("Only sync users within the selected group.")}
                        </p>
                    </ak-form-element-horizontal>
                </div>
            </ak-form-group>
            <ak-form-group ?expanded=${true}>
                <span slot="header"> ${msg("Attribute mapping")} </span>
                <div slot="body" class="pf-c-form">
                    <ak-form-element-horizontal
                        label=${msg("User Property Mappings")}
                        name="propertyMappings"
                    >
                        <select class="pf-c-form-control" multiple>
                            ${this.propertyMappings?.results.map((mapping) => {
      let selected = false;
      if (!this.instance?.propertyMappings) {
        selected = mapping.managed === "goauthentik.io/providers/scim/user" || false;
      } else {
        selected = Array.from(this.instance?.propertyMappings).some(
          (su) => {
            return su == mapping.pk;
          }
        );
      }
      return x`<option
                                    value=${o(mapping.pk)}
                                    ?selected=${selected}
                                >
                                    ${mapping.name}
                                </option>`;
    })}
                        </select>
                        <p class="pf-c-form__helper-text">
                            ${msg("Property mappings used to user mapping.")}
                        </p>
                        <p class="pf-c-form__helper-text">
                            ${msg("Hold control/command to select multiple items.")}
                        </p>
                    </ak-form-element-horizontal>
                    <ak-form-element-horizontal
                        label=${msg("Group Property Mappings")}
                        name="propertyMappingsGroup"
                    >
                        <select class="pf-c-form-control" multiple>
                            ${this.propertyMappings?.results.map((mapping) => {
      let selected = false;
      if (!this.instance?.propertyMappingsGroup) {
        selected = mapping.managed === "goauthentik.io/providers/scim/group";
      } else {
        selected = Array.from(
          this.instance?.propertyMappingsGroup
        ).some((su) => {
          return su == mapping.pk;
        });
      }
      return x`<option
                                    value=${o(mapping.pk)}
                                    ?selected=${selected}
                                >
                                    ${mapping.name}
                                </option>`;
    })}
                        </select>
                        <p class="pf-c-form__helper-text">
                            ${msg("Property mappings used to group creation.")}
                        </p>
                        <p class="pf-c-form__helper-text">
                            ${msg("Hold control/command to select multiple items.")}
                        </p>
                    </ak-form-element-horizontal>
                </div>
            </ak-form-group>`;
  }
};
SCIMProviderFormPage = __decorateClass([
  t("ak-provider-scim-form")
], SCIMProviderFormPage);
/*! Bundled license information:

lit-html/lit-html.js:
  (**
   * @license
   * Copyright 2017 Google LLC
   * SPDX-License-Identifier: BSD-3-Clause
   *)

lit-html/directives/if-defined.js:
  (**
   * @license
   * Copyright 2018 Google LLC
   * SPDX-License-Identifier: BSD-3-Clause
   *)
*/
//# sourceMappingURL=chunk-57INHOPR.js.map
