import {
  __decorateClass
} from "./chunk-CFVQSSMR.js";

// src/common/constants.ts
var VERSION = "2024.4.3";
var TITLE_DEFAULT = "authentik";
var EVENT_REFRESH = "ak-refresh";
var EVENT_LOCALE_REQUEST = "ak-locale-request";
var EVENT_REQUEST_POST = "ak-request-post";
var EVENT_THEME_CHANGE = "ak-theme-change";
var EVENT_REFRESH_ENTERPRISE = "ak-refresh-enterprise";

// node_modules/@goauthentik/api/dist/esm/runtime.js
var __awaiter = function(thisArg, _arguments, P2, generator) {
  function adopt(value) {
    return value instanceof P2 ? value : new P2(function(resolve) {
      resolve(value);
    });
  }
  return new (P2 || (P2 = Promise))(function(resolve, reject) {
    function fulfilled(value) {
      try {
        step(generator.next(value));
      } catch (e7) {
        reject(e7);
      }
    }
    function rejected(value) {
      try {
        step(generator["throw"](value));
      } catch (e7) {
        reject(e7);
      }
    }
    function step(result) {
      result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected);
    }
    step((generator = generator.apply(thisArg, _arguments || [])).next());
  });
};
var BASE_PATH = "http://localhost/api/v3".replace(/\/+$/, "");
var Configuration = class {
  constructor(configuration = {}) {
    this.configuration = configuration;
  }
  set config(configuration) {
    this.configuration = configuration;
  }
  get basePath() {
    return this.configuration.basePath != null ? this.configuration.basePath : BASE_PATH;
  }
  get fetchApi() {
    return this.configuration.fetchApi;
  }
  get middleware() {
    return this.configuration.middleware || [];
  }
  get queryParamsStringify() {
    return this.configuration.queryParamsStringify || querystring;
  }
  get username() {
    return this.configuration.username;
  }
  get password() {
    return this.configuration.password;
  }
  get apiKey() {
    const apiKey = this.configuration.apiKey;
    if (apiKey) {
      return typeof apiKey === "function" ? apiKey : () => apiKey;
    }
    return void 0;
  }
  get accessToken() {
    const accessToken = this.configuration.accessToken;
    if (accessToken) {
      return typeof accessToken === "function" ? accessToken : () => __awaiter(this, void 0, void 0, function* () {
        return accessToken;
      });
    }
    return void 0;
  }
  get headers() {
    return this.configuration.headers;
  }
  get credentials() {
    return this.configuration.credentials;
  }
};
var DefaultConfig = new Configuration();
var BaseAPI = class _BaseAPI {
  constructor(configuration = DefaultConfig) {
    this.configuration = configuration;
    this.fetchApi = (url, init) => __awaiter(this, void 0, void 0, function* () {
      let fetchParams = { url, init };
      for (const middleware of this.middleware) {
        if (middleware.pre) {
          fetchParams = (yield middleware.pre(Object.assign({ fetch: this.fetchApi }, fetchParams))) || fetchParams;
        }
      }
      let response = void 0;
      try {
        response = yield (this.configuration.fetchApi || fetch)(fetchParams.url, fetchParams.init);
      } catch (e7) {
        for (const middleware of this.middleware) {
          if (middleware.onError) {
            response = (yield middleware.onError({
              fetch: this.fetchApi,
              url: fetchParams.url,
              init: fetchParams.init,
              error: e7,
              response: response ? response.clone() : void 0
            })) || response;
          }
        }
        if (response === void 0) {
          if (e7 instanceof Error) {
            throw new FetchError(e7, "The request failed and the interceptors did not return an alternative response");
          } else {
            throw e7;
          }
        }
      }
      for (const middleware of this.middleware) {
        if (middleware.post) {
          response = (yield middleware.post({
            fetch: this.fetchApi,
            url: fetchParams.url,
            init: fetchParams.init,
            response: response.clone()
          })) || response;
        }
      }
      return response;
    });
    this.middleware = configuration.middleware;
  }
  withMiddleware(...middlewares) {
    const next = this.clone();
    next.middleware = next.middleware.concat(...middlewares);
    return next;
  }
  withPreMiddleware(...preMiddlewares) {
    const middlewares = preMiddlewares.map((pre) => ({ pre }));
    return this.withMiddleware(...middlewares);
  }
  withPostMiddleware(...postMiddlewares) {
    const middlewares = postMiddlewares.map((post) => ({ post }));
    return this.withMiddleware(...middlewares);
  }
  /**
   * Check if the given MIME is a JSON MIME.
   * JSON MIME examples:
   *   application/json
   *   application/json; charset=UTF8
   *   APPLICATION/JSON
   *   application/vnd.company+json
   * @param mime - MIME (Multipurpose Internet Mail Extensions)
   * @return True if the given MIME is JSON, false otherwise.
   */
  isJsonMime(mime) {
    if (!mime) {
      return false;
    }
    return _BaseAPI.jsonRegex.test(mime);
  }
  request(context, initOverrides) {
    return __awaiter(this, void 0, void 0, function* () {
      const { url, init } = yield this.createFetchParams(context, initOverrides);
      const response = yield this.fetchApi(url, init);
      if (response && (response.status >= 200 && response.status < 300)) {
        return response;
      }
      throw new ResponseError(response, "Response returned an error code");
    });
  }
  createFetchParams(context, initOverrides) {
    return __awaiter(this, void 0, void 0, function* () {
      let url = this.configuration.basePath + context.path;
      if (context.query !== void 0 && Object.keys(context.query).length !== 0) {
        url += "?" + this.configuration.queryParamsStringify(context.query);
      }
      const headers = Object.assign({}, this.configuration.headers, context.headers);
      Object.keys(headers).forEach((key) => headers[key] === void 0 ? delete headers[key] : {});
      const initOverrideFn = typeof initOverrides === "function" ? initOverrides : () => __awaiter(this, void 0, void 0, function* () {
        return initOverrides;
      });
      const initParams = {
        method: context.method,
        headers,
        body: context.body,
        credentials: this.configuration.credentials
      };
      const overriddenInit = Object.assign(Object.assign({}, initParams), yield initOverrideFn({
        init: initParams,
        context
      }));
      const init = Object.assign(Object.assign({}, overriddenInit), { body: isFormData(overriddenInit.body) || overriddenInit.body instanceof URLSearchParams || isBlob(overriddenInit.body) ? overriddenInit.body : JSON.stringify(overriddenInit.body) });
      return { url, init };
    });
  }
  /**
   * Create a shallow clone of `this` by constructing a new instance
   * and then shallow cloning data members.
   */
  clone() {
    const constructor = this.constructor;
    const next = new constructor(this.configuration);
    next.middleware = this.middleware.slice();
    return next;
  }
};
BaseAPI.jsonRegex = new RegExp("^(:?application/json|[^;/ 	]+/[^;/ 	]+[+]json)[ 	]*(:?;.*)?$", "i");
function isBlob(value) {
  return typeof Blob !== "undefined" && value instanceof Blob;
}
function isFormData(value) {
  return typeof FormData !== "undefined" && value instanceof FormData;
}
var ResponseError = class extends Error {
  constructor(response, msg2) {
    super(msg2);
    this.response = response;
    this.name = "ResponseError";
  }
};
var FetchError = class extends Error {
  constructor(cause, msg2) {
    super(msg2);
    this.cause = cause;
    this.name = "FetchError";
  }
};
var RequiredError = class extends Error {
  constructor(field, msg2) {
    super(msg2);
    this.field = field;
    this.name = "RequiredError";
  }
};
function exists(json, key) {
  const value = json[key];
  return value !== null && value !== void 0;
}
function querystring(params, prefix = "") {
  return Object.keys(params).map((key) => querystringSingleKey(key, params[key], prefix)).filter((part) => part.length > 0).join("&");
}
function querystringSingleKey(key, value, keyPrefix = "") {
  const fullKey = keyPrefix + (keyPrefix.length ? `[${key}]` : key);
  if (value instanceof Array) {
    const multiValue = value.map((singleValue) => encodeURIComponent(String(singleValue))).join(`&${encodeURIComponent(fullKey)}=`);
    return `${encodeURIComponent(fullKey)}=${multiValue}`;
  }
  if (value instanceof Set) {
    const valueAsArray = Array.from(value);
    return querystringSingleKey(key, valueAsArray, keyPrefix);
  }
  if (value instanceof Date) {
    return `${encodeURIComponent(fullKey)}=${encodeURIComponent(value.toISOString())}`;
  }
  if (value instanceof Object) {
    return querystring(value, fullKey);
  }
  return `${encodeURIComponent(fullKey)}=${encodeURIComponent(String(value))}`;
}
function canConsumeForm(consumes) {
  for (const consume of consumes) {
    if ("multipart/form-data" === consume.contentType) {
      return true;
    }
  }
  return false;
}
var JSONApiResponse = class {
  constructor(raw, transformer = (jsonValue) => jsonValue) {
    this.raw = raw;
    this.transformer = transformer;
  }
  value() {
    return __awaiter(this, void 0, void 0, function* () {
      return this.transformer(yield this.raw.json());
    });
  }
};
var VoidApiResponse = class {
  constructor(raw) {
    this.raw = raw;
  }
  value() {
    return __awaiter(this, void 0, void 0, function* () {
      return void 0;
    });
  }
};

// node_modules/@goauthentik/api/dist/esm/models/PolicyEngineMode.js
function PolicyEngineModeFromJSON(json) {
  return PolicyEngineModeFromJSONTyped(json, false);
}
function PolicyEngineModeFromJSONTyped(json, ignoreDiscriminator) {
  return json;
}
function PolicyEngineModeToJSON(value) {
  return value;
}

// node_modules/@goauthentik/api/dist/esm/models/Provider.js
function ProviderFromJSON(json) {
  return ProviderFromJSONTyped(json, false);
}
function ProviderFromJSONTyped(json, ignoreDiscriminator) {
  if (json === void 0 || json === null) {
    return json;
  }
  return {
    "pk": json["pk"],
    "name": json["name"],
    "authenticationFlow": !exists(json, "authentication_flow") ? void 0 : json["authentication_flow"],
    "authorizationFlow": json["authorization_flow"],
    "propertyMappings": !exists(json, "property_mappings") ? void 0 : json["property_mappings"],
    "component": json["component"],
    "assignedApplicationSlug": json["assigned_application_slug"],
    "assignedApplicationName": json["assigned_application_name"],
    "assignedBackchannelApplicationSlug": json["assigned_backchannel_application_slug"],
    "assignedBackchannelApplicationName": json["assigned_backchannel_application_name"],
    "verboseName": json["verbose_name"],
    "verboseNamePlural": json["verbose_name_plural"],
    "metaModelName": json["meta_model_name"]
  };
}

// node_modules/@goauthentik/api/dist/esm/models/Application.js
function ApplicationFromJSON(json) {
  return ApplicationFromJSONTyped(json, false);
}
function ApplicationFromJSONTyped(json, ignoreDiscriminator) {
  if (json === void 0 || json === null) {
    return json;
  }
  return {
    "pk": json["pk"],
    "name": json["name"],
    "slug": json["slug"],
    "provider": !exists(json, "provider") ? void 0 : json["provider"],
    "providerObj": ProviderFromJSON(json["provider_obj"]),
    "backchannelProviders": !exists(json, "backchannel_providers") ? void 0 : json["backchannel_providers"],
    "backchannelProvidersObj": json["backchannel_providers_obj"].map(ProviderFromJSON),
    "launchUrl": json["launch_url"],
    "openInNewTab": !exists(json, "open_in_new_tab") ? void 0 : json["open_in_new_tab"],
    "metaLaunchUrl": !exists(json, "meta_launch_url") ? void 0 : json["meta_launch_url"],
    "metaIcon": json["meta_icon"],
    "metaDescription": !exists(json, "meta_description") ? void 0 : json["meta_description"],
    "metaPublisher": !exists(json, "meta_publisher") ? void 0 : json["meta_publisher"],
    "policyEngineMode": !exists(json, "policy_engine_mode") ? void 0 : PolicyEngineModeFromJSON(json["policy_engine_mode"]),
    "group": !exists(json, "group") ? void 0 : json["group"]
  };
}

// node_modules/@goauthentik/api/dist/esm/models/ApplicationRequest.js
function ApplicationRequestToJSON(value) {
  if (value === void 0) {
    return void 0;
  }
  if (value === null) {
    return null;
  }
  return {
    "name": value.name,
    "slug": value.slug,
    "provider": value.provider,
    "backchannel_providers": value.backchannelProviders,
    "open_in_new_tab": value.openInNewTab,
    "meta_launch_url": value.metaLaunchUrl,
    "meta_description": value.metaDescription,
    "meta_publisher": value.metaPublisher,
    "policy_engine_mode": PolicyEngineModeToJSON(value.policyEngineMode),
    "group": value.group
  };
}

// node_modules/@goauthentik/api/dist/esm/models/AuthenticatedSessionAsn.js
function AuthenticatedSessionAsnFromJSON(json) {
  return AuthenticatedSessionAsnFromJSONTyped(json, false);
}
function AuthenticatedSessionAsnFromJSONTyped(json, ignoreDiscriminator) {
  if (json === void 0 || json === null) {
    return json;
  }
  return {
    "asn": json["asn"],
    "asOrg": json["as_org"],
    "network": json["network"]
  };
}

// node_modules/@goauthentik/api/dist/esm/models/AuthenticatedSessionGeoIp.js
function AuthenticatedSessionGeoIpFromJSON(json) {
  return AuthenticatedSessionGeoIpFromJSONTyped(json, false);
}
function AuthenticatedSessionGeoIpFromJSONTyped(json, ignoreDiscriminator) {
  if (json === void 0 || json === null) {
    return json;
  }
  return {
    "continent": json["continent"],
    "country": json["country"],
    "lat": json["lat"],
    "_long": json["long"],
    "city": json["city"]
  };
}

// node_modules/@goauthentik/api/dist/esm/models/AuthenticatedSessionUserAgentDevice.js
function AuthenticatedSessionUserAgentDeviceFromJSON(json) {
  return AuthenticatedSessionUserAgentDeviceFromJSONTyped(json, false);
}
function AuthenticatedSessionUserAgentDeviceFromJSONTyped(json, ignoreDiscriminator) {
  if (json === void 0 || json === null) {
    return json;
  }
  return {
    "brand": json["brand"],
    "family": json["family"],
    "model": json["model"]
  };
}

// node_modules/@goauthentik/api/dist/esm/models/AuthenticatedSessionUserAgentOs.js
function AuthenticatedSessionUserAgentOsFromJSON(json) {
  return AuthenticatedSessionUserAgentOsFromJSONTyped(json, false);
}
function AuthenticatedSessionUserAgentOsFromJSONTyped(json, ignoreDiscriminator) {
  if (json === void 0 || json === null) {
    return json;
  }
  return {
    "family": json["family"],
    "major": json["major"],
    "minor": json["minor"],
    "patch": json["patch"],
    "patchMinor": json["patch_minor"]
  };
}

// node_modules/@goauthentik/api/dist/esm/models/AuthenticatedSessionUserAgentUserAgent.js
function AuthenticatedSessionUserAgentUserAgentFromJSON(json) {
  return AuthenticatedSessionUserAgentUserAgentFromJSONTyped(json, false);
}
function AuthenticatedSessionUserAgentUserAgentFromJSONTyped(json, ignoreDiscriminator) {
  if (json === void 0 || json === null) {
    return json;
  }
  return {
    "family": json["family"],
    "major": json["major"],
    "minor": json["minor"],
    "patch": json["patch"]
  };
}

// node_modules/@goauthentik/api/dist/esm/models/AuthenticatedSessionUserAgent.js
function AuthenticatedSessionUserAgentFromJSON(json) {
  return AuthenticatedSessionUserAgentFromJSONTyped(json, false);
}
function AuthenticatedSessionUserAgentFromJSONTyped(json, ignoreDiscriminator) {
  if (json === void 0 || json === null) {
    return json;
  }
  return {
    "device": AuthenticatedSessionUserAgentDeviceFromJSON(json["device"]),
    "os": AuthenticatedSessionUserAgentOsFromJSON(json["os"]),
    "userAgent": AuthenticatedSessionUserAgentUserAgentFromJSON(json["user_agent"]),
    "string": json["string"]
  };
}

// node_modules/@goauthentik/api/dist/esm/models/AuthenticatedSession.js
function AuthenticatedSessionFromJSON(json) {
  return AuthenticatedSessionFromJSONTyped(json, false);
}
function AuthenticatedSessionFromJSONTyped(json, ignoreDiscriminator) {
  if (json === void 0 || json === null) {
    return json;
  }
  return {
    "uuid": !exists(json, "uuid") ? void 0 : json["uuid"],
    "current": json["current"],
    "userAgent": AuthenticatedSessionUserAgentFromJSON(json["user_agent"]),
    "geoIp": AuthenticatedSessionGeoIpFromJSON(json["geo_ip"]),
    "asn": AuthenticatedSessionAsnFromJSON(json["asn"]),
    "user": json["user"],
    "lastIp": json["last_ip"],
    "lastUserAgent": !exists(json, "last_user_agent") ? void 0 : json["last_user_agent"],
    "lastUsed": new Date(json["last_used"]),
    "expires": !exists(json, "expires") ? void 0 : json["expires"] === null ? null : new Date(json["expires"])
  };
}

// node_modules/@goauthentik/api/dist/esm/models/Brand.js
function BrandFromJSON(json) {
  return BrandFromJSONTyped(json, false);
}
function BrandFromJSONTyped(json, ignoreDiscriminator) {
  if (json === void 0 || json === null) {
    return json;
  }
  return {
    "brandUuid": json["brand_uuid"],
    "domain": json["domain"],
    "_default": !exists(json, "default") ? void 0 : json["default"],
    "brandingTitle": !exists(json, "branding_title") ? void 0 : json["branding_title"],
    "brandingLogo": !exists(json, "branding_logo") ? void 0 : json["branding_logo"],
    "brandingFavicon": !exists(json, "branding_favicon") ? void 0 : json["branding_favicon"],
    "flowAuthentication": !exists(json, "flow_authentication") ? void 0 : json["flow_authentication"],
    "flowInvalidation": !exists(json, "flow_invalidation") ? void 0 : json["flow_invalidation"],
    "flowRecovery": !exists(json, "flow_recovery") ? void 0 : json["flow_recovery"],
    "flowUnenrollment": !exists(json, "flow_unenrollment") ? void 0 : json["flow_unenrollment"],
    "flowUserSettings": !exists(json, "flow_user_settings") ? void 0 : json["flow_user_settings"],
    "flowDeviceCode": !exists(json, "flow_device_code") ? void 0 : json["flow_device_code"],
    "webCertificate": !exists(json, "web_certificate") ? void 0 : json["web_certificate"],
    "attributes": !exists(json, "attributes") ? void 0 : json["attributes"]
  };
}

// node_modules/@goauthentik/api/dist/esm/models/BrandRequest.js
function BrandRequestToJSON(value) {
  if (value === void 0) {
    return void 0;
  }
  if (value === null) {
    return null;
  }
  return {
    "domain": value.domain,
    "default": value._default,
    "branding_title": value.brandingTitle,
    "branding_logo": value.brandingLogo,
    "branding_favicon": value.brandingFavicon,
    "flow_authentication": value.flowAuthentication,
    "flow_invalidation": value.flowInvalidation,
    "flow_recovery": value.flowRecovery,
    "flow_unenrollment": value.flowUnenrollment,
    "flow_user_settings": value.flowUserSettings,
    "flow_device_code": value.flowDeviceCode,
    "web_certificate": value.webCertificate,
    "attributes": value.attributes
  };
}

// node_modules/@goauthentik/api/dist/esm/models/CapabilitiesEnum.js
function CapabilitiesEnumFromJSON(json) {
  return CapabilitiesEnumFromJSONTyped(json, false);
}
function CapabilitiesEnumFromJSONTyped(json, ignoreDiscriminator) {
  return json;
}

// node_modules/@goauthentik/api/dist/esm/models/ClientTypeEnum.js
function ClientTypeEnumToJSON(value) {
  return value;
}

// node_modules/@goauthentik/api/dist/esm/models/ErrorReportingConfig.js
function ErrorReportingConfigFromJSON(json) {
  return ErrorReportingConfigFromJSONTyped(json, false);
}
function ErrorReportingConfigFromJSONTyped(json, ignoreDiscriminator) {
  if (json === void 0 || json === null) {
    return json;
  }
  return {
    "enabled": json["enabled"],
    "sentryDsn": json["sentry_dsn"],
    "environment": json["environment"],
    "sendPii": json["send_pii"],
    "tracesSampleRate": json["traces_sample_rate"]
  };
}

// node_modules/@goauthentik/api/dist/esm/models/Config.js
function ConfigFromJSON(json) {
  return ConfigFromJSONTyped(json, false);
}
function ConfigFromJSONTyped(json, ignoreDiscriminator) {
  if (json === void 0 || json === null) {
    return json;
  }
  return {
    "errorReporting": ErrorReportingConfigFromJSON(json["error_reporting"]),
    "capabilities": json["capabilities"].map(CapabilitiesEnumFromJSON),
    "cacheTimeout": json["cache_timeout"],
    "cacheTimeoutFlows": json["cache_timeout_flows"],
    "cacheTimeoutPolicies": json["cache_timeout_policies"],
    "cacheTimeoutReputation": json["cache_timeout_reputation"]
  };
}

// node_modules/@goauthentik/api/dist/esm/models/GroupMember.js
function GroupMemberFromJSON(json) {
  return GroupMemberFromJSONTyped(json, false);
}
function GroupMemberFromJSONTyped(json, ignoreDiscriminator) {
  if (json === void 0 || json === null) {
    return json;
  }
  return {
    "pk": json["pk"],
    "username": json["username"],
    "name": json["name"],
    "isActive": !exists(json, "is_active") ? void 0 : json["is_active"],
    "lastLogin": !exists(json, "last_login") ? void 0 : json["last_login"] === null ? null : new Date(json["last_login"]),
    "email": !exists(json, "email") ? void 0 : json["email"],
    "attributes": !exists(json, "attributes") ? void 0 : json["attributes"],
    "uid": json["uid"]
  };
}

// node_modules/@goauthentik/api/dist/esm/models/Coordinate.js
function CoordinateFromJSON(json) {
  return CoordinateFromJSONTyped(json, false);
}
function CoordinateFromJSONTyped(json, ignoreDiscriminator) {
  if (json === void 0 || json === null) {
    return json;
  }
  return {
    "xCord": json["x_cord"],
    "yCord": json["y_cord"]
  };
}

// node_modules/@goauthentik/api/dist/esm/models/FooterLink.js
function FooterLinkFromJSON(json) {
  return FooterLinkFromJSONTyped(json, false);
}
function FooterLinkFromJSONTyped(json, ignoreDiscriminator) {
  if (json === void 0 || json === null) {
    return json;
  }
  return {
    "href": json["href"],
    "name": json["name"]
  };
}

// node_modules/@goauthentik/api/dist/esm/models/UiThemeEnum.js
var UiThemeEnum = {
  Automatic: "automatic",
  Light: "light",
  Dark: "dark",
  UnknownDefaultOpenApi: "11184809"
};
function UiThemeEnumFromJSON(json) {
  return UiThemeEnumFromJSONTyped(json, false);
}
function UiThemeEnumFromJSONTyped(json, ignoreDiscriminator) {
  return json;
}

// node_modules/@goauthentik/api/dist/esm/models/CurrentBrand.js
function CurrentBrandFromJSON(json) {
  return CurrentBrandFromJSONTyped(json, false);
}
function CurrentBrandFromJSONTyped(json, ignoreDiscriminator) {
  if (json === void 0 || json === null) {
    return json;
  }
  return {
    "matchedDomain": json["matched_domain"],
    "brandingTitle": json["branding_title"],
    "brandingLogo": json["branding_logo"],
    "brandingFavicon": json["branding_favicon"],
    "uiFooterLinks": json["ui_footer_links"].map(FooterLinkFromJSON),
    "uiTheme": UiThemeEnumFromJSON(json["ui_theme"]),
    "flowAuthentication": !exists(json, "flow_authentication") ? void 0 : json["flow_authentication"],
    "flowInvalidation": !exists(json, "flow_invalidation") ? void 0 : json["flow_invalidation"],
    "flowRecovery": !exists(json, "flow_recovery") ? void 0 : json["flow_recovery"],
    "flowUnenrollment": !exists(json, "flow_unenrollment") ? void 0 : json["flow_unenrollment"],
    "flowUserSettings": !exists(json, "flow_user_settings") ? void 0 : json["flow_user_settings"],
    "flowDeviceCode": !exists(json, "flow_device_code") ? void 0 : json["flow_device_code"],
    "defaultLocale": json["default_locale"]
  };
}

// node_modules/@goauthentik/api/dist/esm/models/DigestAlgorithmEnum.js
function DigestAlgorithmEnumToJSON(value) {
  return value;
}

// node_modules/@goauthentik/api/dist/esm/models/IssuerModeEnum.js
function IssuerModeEnumToJSON(value) {
  return value;
}

// node_modules/@goauthentik/api/dist/esm/models/SubModeEnum.js
function SubModeEnumToJSON(value) {
  return value;
}

// node_modules/@goauthentik/api/dist/esm/models/UserGroup.js
function UserGroupFromJSON(json) {
  return UserGroupFromJSONTyped(json, false);
}
function UserGroupFromJSONTyped(json, ignoreDiscriminator) {
  if (json === void 0 || json === null) {
    return json;
  }
  return {
    "pk": json["pk"],
    "numPk": json["num_pk"],
    "name": json["name"],
    "isSuperuser": !exists(json, "is_superuser") ? void 0 : json["is_superuser"],
    "parent": !exists(json, "parent") ? void 0 : json["parent"],
    "parentName": json["parent_name"],
    "attributes": !exists(json, "attributes") ? void 0 : json["attributes"]
  };
}

// node_modules/@goauthentik/api/dist/esm/models/UserTypeEnum.js
function UserTypeEnumFromJSON(json) {
  return UserTypeEnumFromJSONTyped(json, false);
}
function UserTypeEnumFromJSONTyped(json, ignoreDiscriminator) {
  return json;
}
function UserTypeEnumToJSON(value) {
  return value;
}

// node_modules/@goauthentik/api/dist/esm/models/User.js
function UserFromJSON(json) {
  return UserFromJSONTyped(json, false);
}
function UserFromJSONTyped(json, ignoreDiscriminator) {
  if (json === void 0 || json === null) {
    return json;
  }
  return {
    "pk": json["pk"],
    "username": json["username"],
    "name": json["name"],
    "isActive": !exists(json, "is_active") ? void 0 : json["is_active"],
    "lastLogin": !exists(json, "last_login") ? void 0 : json["last_login"] === null ? null : new Date(json["last_login"]),
    "isSuperuser": json["is_superuser"],
    "groups": !exists(json, "groups") ? void 0 : json["groups"],
    "groupsObj": json["groups_obj"] === null ? null : json["groups_obj"].map(UserGroupFromJSON),
    "email": !exists(json, "email") ? void 0 : json["email"],
    "avatar": json["avatar"],
    "attributes": !exists(json, "attributes") ? void 0 : json["attributes"],
    "uid": json["uid"],
    "path": !exists(json, "path") ? void 0 : json["path"],
    "type": !exists(json, "type") ? void 0 : UserTypeEnumFromJSON(json["type"]),
    "uuid": json["uuid"]
  };
}

// node_modules/@goauthentik/api/dist/esm/models/FilePathRequest.js
function FilePathRequestToJSON(value) {
  if (value === void 0) {
    return void 0;
  }
  if (value === null) {
    return null;
  }
  return {
    "url": value.url
  };
}

// node_modules/@goauthentik/api/dist/esm/models/LogLevelEnum.js
function LogLevelEnumFromJSON(json) {
  return LogLevelEnumFromJSONTyped(json, false);
}
function LogLevelEnumFromJSONTyped(json, ignoreDiscriminator) {
  return json;
}

// node_modules/@goauthentik/api/dist/esm/models/LogEvent.js
function LogEventFromJSON(json) {
  return LogEventFromJSONTyped(json, false);
}
function LogEventFromJSONTyped(json, ignoreDiscriminator) {
  if (json === void 0 || json === null) {
    return json;
  }
  return {
    "timestamp": new Date(json["timestamp"]),
    "logLevel": LogLevelEnumFromJSON(json["log_level"]),
    "logger": json["logger"],
    "event": json["event"],
    "attributes": json["attributes"]
  };
}

// node_modules/@goauthentik/api/dist/esm/models/Role.js
function RoleFromJSON(json) {
  return RoleFromJSONTyped(json, false);
}
function RoleFromJSONTyped(json, ignoreDiscriminator) {
  if (json === void 0 || json === null) {
    return json;
  }
  return {
    "pk": json["pk"],
    "name": json["name"]
  };
}

// node_modules/@goauthentik/api/dist/esm/models/Group.js
function GroupFromJSON(json) {
  return GroupFromJSONTyped(json, false);
}
function GroupFromJSONTyped(json, ignoreDiscriminator) {
  if (json === void 0 || json === null) {
    return json;
  }
  return {
    "pk": json["pk"],
    "numPk": json["num_pk"],
    "name": json["name"],
    "isSuperuser": !exists(json, "is_superuser") ? void 0 : json["is_superuser"],
    "parent": !exists(json, "parent") ? void 0 : json["parent"],
    "parentName": json["parent_name"],
    "users": !exists(json, "users") ? void 0 : json["users"],
    "usersObj": json["users_obj"] === null ? null : json["users_obj"].map(GroupMemberFromJSON),
    "attributes": !exists(json, "attributes") ? void 0 : json["attributes"],
    "roles": !exists(json, "roles") ? void 0 : json["roles"],
    "rolesObj": json["roles_obj"].map(RoleFromJSON)
  };
}

// node_modules/@goauthentik/api/dist/esm/models/GroupRequest.js
function GroupRequestToJSON(value) {
  if (value === void 0) {
    return void 0;
  }
  if (value === null) {
    return null;
  }
  return {
    "name": value.name,
    "is_superuser": value.isSuperuser,
    "parent": value.parent,
    "users": value.users,
    "attributes": value.attributes,
    "roles": value.roles
  };
}

// node_modules/@goauthentik/api/dist/esm/models/InstallID.js
function InstallIDFromJSON(json) {
  return InstallIDFromJSONTyped(json, false);
}
function InstallIDFromJSONTyped(json, ignoreDiscriminator) {
  if (json === void 0 || json === null) {
    return json;
  }
  return {
    "installId": json["install_id"]
  };
}

// node_modules/@goauthentik/api/dist/esm/models/IntentEnum.js
function IntentEnumFromJSON(json) {
  return IntentEnumFromJSONTyped(json, false);
}
function IntentEnumFromJSONTyped(json, ignoreDiscriminator) {
  return json;
}
function IntentEnumToJSON(value) {
  return value;
}

// node_modules/@goauthentik/api/dist/esm/models/LDAPAPIAccessMode.js
function LDAPAPIAccessModeToJSON(value) {
  return value;
}

// node_modules/@goauthentik/api/dist/esm/models/LDAPProviderRequest.js
function LDAPProviderRequestToJSON(value) {
  if (value === void 0) {
    return void 0;
  }
  if (value === null) {
    return null;
  }
  return {
    "name": value.name,
    "authentication_flow": value.authenticationFlow,
    "authorization_flow": value.authorizationFlow,
    "property_mappings": value.propertyMappings,
    "base_dn": value.baseDn,
    "search_group": value.searchGroup,
    "certificate": value.certificate,
    "tls_server_name": value.tlsServerName,
    "uid_start_number": value.uidStartNumber,
    "gid_start_number": value.gidStartNumber,
    "search_mode": LDAPAPIAccessModeToJSON(value.searchMode),
    "bind_mode": LDAPAPIAccessModeToJSON(value.bindMode),
    "mfa_support": value.mfaSupport
  };
}

// node_modules/@goauthentik/api/dist/esm/models/License.js
function LicenseFromJSON(json) {
  return LicenseFromJSONTyped(json, false);
}
function LicenseFromJSONTyped(json, ignoreDiscriminator) {
  if (json === void 0 || json === null) {
    return json;
  }
  return {
    "licenseUuid": json["license_uuid"],
    "name": json["name"],
    "key": json["key"],
    "expiry": new Date(json["expiry"]),
    "internalUsers": json["internal_users"],
    "externalUsers": json["external_users"]
  };
}

// node_modules/@goauthentik/api/dist/esm/models/LicenseForecast.js
function LicenseForecastFromJSON(json) {
  return LicenseForecastFromJSONTyped(json, false);
}
function LicenseForecastFromJSONTyped(json, ignoreDiscriminator) {
  if (json === void 0 || json === null) {
    return json;
  }
  return {
    "internalUsers": json["internal_users"],
    "externalUsers": json["external_users"],
    "forecastedInternalUsers": json["forecasted_internal_users"],
    "forecastedExternalUsers": json["forecasted_external_users"]
  };
}

// node_modules/@goauthentik/api/dist/esm/models/LicenseRequest.js
function LicenseRequestToJSON(value) {
  if (value === void 0) {
    return void 0;
  }
  if (value === null) {
    return null;
  }
  return {
    "key": value.key
  };
}

// node_modules/@goauthentik/api/dist/esm/models/LicenseSummary.js
function LicenseSummaryFromJSON(json) {
  return LicenseSummaryFromJSONTyped(json, false);
}
function LicenseSummaryFromJSONTyped(json, ignoreDiscriminator) {
  if (json === void 0 || json === null) {
    return json;
  }
  return {
    "internalUsers": json["internal_users"],
    "externalUsers": json["external_users"],
    "valid": json["valid"],
    "showAdminWarning": json["show_admin_warning"],
    "showUserWarning": json["show_user_warning"],
    "readOnly": json["read_only"],
    "latestValid": new Date(json["latest_valid"]),
    "hasLicense": json["has_license"]
  };
}

// node_modules/@goauthentik/api/dist/esm/models/Link.js
function LinkFromJSON(json) {
  return LinkFromJSONTyped(json, false);
}
function LinkFromJSONTyped(json, ignoreDiscriminator) {
  if (json === void 0 || json === null) {
    return json;
  }
  return {
    "link": json["link"]
  };
}

// node_modules/@goauthentik/api/dist/esm/models/OAuth2ProviderRequest.js
function OAuth2ProviderRequestToJSON(value) {
  if (value === void 0) {
    return void 0;
  }
  if (value === null) {
    return null;
  }
  return {
    "name": value.name,
    "authentication_flow": value.authenticationFlow,
    "authorization_flow": value.authorizationFlow,
    "property_mappings": value.propertyMappings,
    "client_type": ClientTypeEnumToJSON(value.clientType),
    "client_id": value.clientId,
    "client_secret": value.clientSecret,
    "access_code_validity": value.accessCodeValidity,
    "access_token_validity": value.accessTokenValidity,
    "refresh_token_validity": value.refreshTokenValidity,
    "include_claims_in_id_token": value.includeClaimsInIdToken,
    "signing_key": value.signingKey,
    "redirect_uris": value.redirectUris,
    "sub_mode": SubModeEnumToJSON(value.subMode),
    "issuer_mode": IssuerModeEnumToJSON(value.issuerMode),
    "jwks_sources": value.jwksSources
  };
}

// node_modules/@goauthentik/api/dist/esm/models/ProxyMode.js
function ProxyModeToJSON(value) {
  return value;
}

// node_modules/@goauthentik/api/dist/esm/models/ProxyProviderRequest.js
function ProxyProviderRequestToJSON(value) {
  if (value === void 0) {
    return void 0;
  }
  if (value === null) {
    return null;
  }
  return {
    "name": value.name,
    "authentication_flow": value.authenticationFlow,
    "authorization_flow": value.authorizationFlow,
    "property_mappings": value.propertyMappings,
    "internal_host": value.internalHost,
    "external_host": value.externalHost,
    "internal_host_ssl_validation": value.internalHostSslValidation,
    "certificate": value.certificate,
    "skip_path_regex": value.skipPathRegex,
    "basic_auth_enabled": value.basicAuthEnabled,
    "basic_auth_password_attribute": value.basicAuthPasswordAttribute,
    "basic_auth_user_attribute": value.basicAuthUserAttribute,
    "mode": ProxyModeToJSON(value.mode),
    "intercept_header_auth": value.interceptHeaderAuth,
    "cookie_domain": value.cookieDomain,
    "jwks_sources": value.jwksSources,
    "access_token_validity": value.accessTokenValidity,
    "refresh_token_validity": value.refreshTokenValidity
  };
}

// node_modules/@goauthentik/api/dist/esm/models/RACProviderRequest.js
function RACProviderRequestToJSON(value) {
  if (value === void 0) {
    return void 0;
  }
  if (value === null) {
    return null;
  }
  return {
    "name": value.name,
    "authentication_flow": value.authenticationFlow,
    "authorization_flow": value.authorizationFlow,
    "property_mappings": value.propertyMappings,
    "settings": value.settings,
    "connection_expiry": value.connectionExpiry,
    "delete_token_on_disconnect": value.deleteTokenOnDisconnect
  };
}

// node_modules/@goauthentik/api/dist/esm/models/RadiusProviderRequest.js
function RadiusProviderRequestToJSON(value) {
  if (value === void 0) {
    return void 0;
  }
  if (value === null) {
    return null;
  }
  return {
    "name": value.name,
    "authentication_flow": value.authenticationFlow,
    "authorization_flow": value.authorizationFlow,
    "property_mappings": value.propertyMappings,
    "client_networks": value.clientNetworks,
    "shared_secret": value.sharedSecret,
    "mfa_support": value.mfaSupport
  };
}

// node_modules/@goauthentik/api/dist/esm/models/SignatureAlgorithmEnum.js
function SignatureAlgorithmEnumToJSON(value) {
  return value;
}

// node_modules/@goauthentik/api/dist/esm/models/SpBindingEnum.js
function SpBindingEnumToJSON(value) {
  return value;
}

// node_modules/@goauthentik/api/dist/esm/models/SAMLProviderRequest.js
function SAMLProviderRequestToJSON(value) {
  if (value === void 0) {
    return void 0;
  }
  if (value === null) {
    return null;
  }
  return {
    "name": value.name,
    "authentication_flow": value.authenticationFlow,
    "authorization_flow": value.authorizationFlow,
    "property_mappings": value.propertyMappings,
    "acs_url": value.acsUrl,
    "audience": value.audience,
    "issuer": value.issuer,
    "assertion_valid_not_before": value.assertionValidNotBefore,
    "assertion_valid_not_on_or_after": value.assertionValidNotOnOrAfter,
    "session_valid_not_on_or_after": value.sessionValidNotOnOrAfter,
    "name_id_mapping": value.nameIdMapping,
    "digest_algorithm": DigestAlgorithmEnumToJSON(value.digestAlgorithm),
    "signature_algorithm": SignatureAlgorithmEnumToJSON(value.signatureAlgorithm),
    "signing_kp": value.signingKp,
    "verification_kp": value.verificationKp,
    "sp_binding": SpBindingEnumToJSON(value.spBinding),
    "default_relay_state": value.defaultRelayState
  };
}

// node_modules/@goauthentik/api/dist/esm/models/SCIMProviderRequest.js
function SCIMProviderRequestToJSON(value) {
  if (value === void 0) {
    return void 0;
  }
  if (value === null) {
    return null;
  }
  return {
    "name": value.name,
    "property_mappings": value.propertyMappings,
    "property_mappings_group": value.propertyMappingsGroup,
    "url": value.url,
    "token": value.token,
    "exclude_users_service_account": value.excludeUsersServiceAccount,
    "filter_group": value.filterGroup
  };
}

// node_modules/@goauthentik/api/dist/esm/models/ModelRequest.js
function ModelRequestToJSON(value) {
  if (value === void 0) {
    return void 0;
  }
  if (value === null) {
    return null;
  }
  switch (value["providerModel"]) {
    case "authentik_providers_ldap.ldapprovider":
      return LDAPProviderRequestToJSON(value);
    case "authentik_providers_oauth2.oauth2provider":
      return OAuth2ProviderRequestToJSON(value);
    case "authentik_providers_proxy.proxyprovider":
      return ProxyProviderRequestToJSON(value);
    case "authentik_providers_rac.racprovider":
      return RACProviderRequestToJSON(value);
    case "authentik_providers_radius.radiusprovider":
      return RadiusProviderRequestToJSON(value);
    case "authentik_providers_saml.samlprovider":
      return SAMLProviderRequestToJSON(value);
    case "authentik_providers_scim.scimprovider":
      return SCIMProviderRequestToJSON(value);
    default:
      throw new Error(`No variant of ModelRequest exists with 'providerModel=${value["providerModel"]}'`);
  }
}

// node_modules/@goauthentik/api/dist/esm/models/Pagination.js
function PaginationFromJSON(json) {
  return PaginationFromJSONTyped(json, false);
}
function PaginationFromJSONTyped(json, ignoreDiscriminator) {
  if (json === void 0 || json === null) {
    return json;
  }
  return {
    "next": json["next"],
    "previous": json["previous"],
    "count": json["count"],
    "current": json["current"],
    "totalPages": json["total_pages"],
    "startIndex": json["start_index"],
    "endIndex": json["end_index"]
  };
}

// node_modules/@goauthentik/api/dist/esm/models/PaginatedApplicationList.js
function PaginatedApplicationListFromJSON(json) {
  return PaginatedApplicationListFromJSONTyped(json, false);
}
function PaginatedApplicationListFromJSONTyped(json, ignoreDiscriminator) {
  if (json === void 0 || json === null) {
    return json;
  }
  return {
    "pagination": PaginationFromJSON(json["pagination"]),
    "results": json["results"].map(ApplicationFromJSON)
  };
}

// node_modules/@goauthentik/api/dist/esm/models/PaginatedAuthenticatedSessionList.js
function PaginatedAuthenticatedSessionListFromJSON(json) {
  return PaginatedAuthenticatedSessionListFromJSONTyped(json, false);
}
function PaginatedAuthenticatedSessionListFromJSONTyped(json, ignoreDiscriminator) {
  if (json === void 0 || json === null) {
    return json;
  }
  return {
    "pagination": PaginationFromJSON(json["pagination"]),
    "results": json["results"].map(AuthenticatedSessionFromJSON)
  };
}

// node_modules/@goauthentik/api/dist/esm/models/PaginatedBrandList.js
function PaginatedBrandListFromJSON(json) {
  return PaginatedBrandListFromJSONTyped(json, false);
}
function PaginatedBrandListFromJSONTyped(json, ignoreDiscriminator) {
  if (json === void 0 || json === null) {
    return json;
  }
  return {
    "pagination": PaginationFromJSON(json["pagination"]),
    "results": json["results"].map(BrandFromJSON)
  };
}

// node_modules/@goauthentik/api/dist/esm/models/PaginatedGroupList.js
function PaginatedGroupListFromJSON(json) {
  return PaginatedGroupListFromJSONTyped(json, false);
}
function PaginatedGroupListFromJSONTyped(json, ignoreDiscriminator) {
  if (json === void 0 || json === null) {
    return json;
  }
  return {
    "pagination": PaginationFromJSON(json["pagination"]),
    "results": json["results"].map(GroupFromJSON)
  };
}

// node_modules/@goauthentik/api/dist/esm/models/PaginatedLicenseList.js
function PaginatedLicenseListFromJSON(json) {
  return PaginatedLicenseListFromJSONTyped(json, false);
}
function PaginatedLicenseListFromJSONTyped(json, ignoreDiscriminator) {
  if (json === void 0 || json === null) {
    return json;
  }
  return {
    "pagination": PaginationFromJSON(json["pagination"]),
    "results": json["results"].map(LicenseFromJSON)
  };
}

// node_modules/@goauthentik/api/dist/esm/models/Token.js
function TokenFromJSON(json) {
  return TokenFromJSONTyped(json, false);
}
function TokenFromJSONTyped(json, ignoreDiscriminator) {
  if (json === void 0 || json === null) {
    return json;
  }
  return {
    "pk": json["pk"],
    "managed": !exists(json, "managed") ? void 0 : json["managed"],
    "identifier": json["identifier"],
    "intent": !exists(json, "intent") ? void 0 : IntentEnumFromJSON(json["intent"]),
    "user": !exists(json, "user") ? void 0 : json["user"],
    "userObj": UserFromJSON(json["user_obj"]),
    "description": !exists(json, "description") ? void 0 : json["description"],
    "expires": !exists(json, "expires") ? void 0 : json["expires"] === null ? null : new Date(json["expires"]),
    "expiring": !exists(json, "expiring") ? void 0 : json["expiring"]
  };
}

// node_modules/@goauthentik/api/dist/esm/models/PaginatedTokenList.js
function PaginatedTokenListFromJSON(json) {
  return PaginatedTokenListFromJSONTyped(json, false);
}
function PaginatedTokenListFromJSONTyped(json, ignoreDiscriminator) {
  if (json === void 0 || json === null) {
    return json;
  }
  return {
    "pagination": PaginationFromJSON(json["pagination"]),
    "results": json["results"].map(TokenFromJSON)
  };
}

// node_modules/@goauthentik/api/dist/esm/models/UserConsent.js
function UserConsentFromJSON(json) {
  return UserConsentFromJSONTyped(json, false);
}
function UserConsentFromJSONTyped(json, ignoreDiscriminator) {
  if (json === void 0 || json === null) {
    return json;
  }
  return {
    "pk": json["pk"],
    "expires": !exists(json, "expires") ? void 0 : json["expires"] === null ? null : new Date(json["expires"]),
    "expiring": !exists(json, "expiring") ? void 0 : json["expiring"],
    "user": UserFromJSON(json["user"]),
    "application": ApplicationFromJSON(json["application"]),
    "permissions": !exists(json, "permissions") ? void 0 : json["permissions"]
  };
}

// node_modules/@goauthentik/api/dist/esm/models/PaginatedUserConsentList.js
function PaginatedUserConsentListFromJSON(json) {
  return PaginatedUserConsentListFromJSONTyped(json, false);
}
function PaginatedUserConsentListFromJSONTyped(json, ignoreDiscriminator) {
  if (json === void 0 || json === null) {
    return json;
  }
  return {
    "pagination": PaginationFromJSON(json["pagination"]),
    "results": json["results"].map(UserConsentFromJSON)
  };
}

// node_modules/@goauthentik/api/dist/esm/models/PaginatedUserList.js
function PaginatedUserListFromJSON(json) {
  return PaginatedUserListFromJSONTyped(json, false);
}
function PaginatedUserListFromJSONTyped(json, ignoreDiscriminator) {
  if (json === void 0 || json === null) {
    return json;
  }
  return {
    "pagination": PaginationFromJSON(json["pagination"]),
    "results": json["results"].map(UserFromJSON)
  };
}

// node_modules/@goauthentik/api/dist/esm/models/PatchedApplicationRequest.js
function PatchedApplicationRequestToJSON(value) {
  if (value === void 0) {
    return void 0;
  }
  if (value === null) {
    return null;
  }
  return {
    "name": value.name,
    "slug": value.slug,
    "provider": value.provider,
    "backchannel_providers": value.backchannelProviders,
    "open_in_new_tab": value.openInNewTab,
    "meta_launch_url": value.metaLaunchUrl,
    "meta_description": value.metaDescription,
    "meta_publisher": value.metaPublisher,
    "policy_engine_mode": PolicyEngineModeToJSON(value.policyEngineMode),
    "group": value.group
  };
}

// node_modules/@goauthentik/api/dist/esm/models/PatchedBrandRequest.js
function PatchedBrandRequestToJSON(value) {
  if (value === void 0) {
    return void 0;
  }
  if (value === null) {
    return null;
  }
  return {
    "domain": value.domain,
    "default": value._default,
    "branding_title": value.brandingTitle,
    "branding_logo": value.brandingLogo,
    "branding_favicon": value.brandingFavicon,
    "flow_authentication": value.flowAuthentication,
    "flow_invalidation": value.flowInvalidation,
    "flow_recovery": value.flowRecovery,
    "flow_unenrollment": value.flowUnenrollment,
    "flow_user_settings": value.flowUserSettings,
    "flow_device_code": value.flowDeviceCode,
    "web_certificate": value.webCertificate,
    "attributes": value.attributes
  };
}

// node_modules/@goauthentik/api/dist/esm/models/PatchedGroupRequest.js
function PatchedGroupRequestToJSON(value) {
  if (value === void 0) {
    return void 0;
  }
  if (value === null) {
    return null;
  }
  return {
    "name": value.name,
    "is_superuser": value.isSuperuser,
    "parent": value.parent,
    "users": value.users,
    "attributes": value.attributes,
    "roles": value.roles
  };
}

// node_modules/@goauthentik/api/dist/esm/models/PatchedLicenseRequest.js
function PatchedLicenseRequestToJSON(value) {
  if (value === void 0) {
    return void 0;
  }
  if (value === null) {
    return null;
  }
  return {
    "key": value.key
  };
}

// node_modules/@goauthentik/api/dist/esm/models/PatchedTokenRequest.js
function PatchedTokenRequestToJSON(value) {
  if (value === void 0) {
    return void 0;
  }
  if (value === null) {
    return null;
  }
  return {
    "managed": value.managed,
    "identifier": value.identifier,
    "intent": IntentEnumToJSON(value.intent),
    "user": value.user,
    "description": value.description,
    "expires": value.expires === void 0 ? void 0 : value.expires === null ? null : value.expires.toISOString(),
    "expiring": value.expiring
  };
}

// node_modules/@goauthentik/api/dist/esm/models/PatchedUserRequest.js
function PatchedUserRequestToJSON(value) {
  if (value === void 0) {
    return void 0;
  }
  if (value === null) {
    return null;
  }
  return {
    "username": value.username,
    "name": value.name,
    "is_active": value.isActive,
    "last_login": value.lastLogin === void 0 ? void 0 : value.lastLogin === null ? null : value.lastLogin.toISOString(),
    "groups": value.groups,
    "email": value.email,
    "attributes": value.attributes,
    "path": value.path,
    "type": UserTypeEnumToJSON(value.type)
  };
}

// node_modules/@goauthentik/api/dist/esm/models/PolicyTestResult.js
function PolicyTestResultFromJSON(json) {
  return PolicyTestResultFromJSONTyped(json, false);
}
function PolicyTestResultFromJSONTyped(json, ignoreDiscriminator) {
  if (json === void 0 || json === null) {
    return json;
  }
  return {
    "passing": json["passing"],
    "messages": json["messages"],
    "logMessages": json["log_messages"].map(LogEventFromJSON)
  };
}

// node_modules/@goauthentik/api/dist/esm/models/ProviderModelEnum.js
function ProviderModelEnumToJSON(value) {
  return value;
}

// node_modules/@goauthentik/api/dist/esm/models/UserSelfGroups.js
function UserSelfGroupsFromJSON(json) {
  return UserSelfGroupsFromJSONTyped(json, false);
}
function UserSelfGroupsFromJSONTyped(json, ignoreDiscriminator) {
  if (json === void 0 || json === null) {
    return json;
  }
  return {
    "name": json["name"],
    "pk": json["pk"]
  };
}

// node_modules/@goauthentik/api/dist/esm/models/UserSelf.js
function UserSelfFromJSON(json) {
  return UserSelfFromJSONTyped(json, false);
}
function UserSelfFromJSONTyped(json, ignoreDiscriminator) {
  if (json === void 0 || json === null) {
    return json;
  }
  return {
    "pk": json["pk"],
    "username": json["username"],
    "name": json["name"],
    "isActive": json["is_active"],
    "isSuperuser": json["is_superuser"],
    "groups": json["groups"].map(UserSelfGroupsFromJSON),
    "email": !exists(json, "email") ? void 0 : json["email"],
    "avatar": json["avatar"],
    "uid": json["uid"],
    "settings": json["settings"],
    "type": !exists(json, "type") ? void 0 : UserTypeEnumFromJSON(json["type"]),
    "systemPermissions": json["system_permissions"]
  };
}

// node_modules/@goauthentik/api/dist/esm/models/SessionUser.js
function SessionUserFromJSON(json) {
  return SessionUserFromJSONTyped(json, false);
}
function SessionUserFromJSONTyped(json, ignoreDiscriminator) {
  if (json === void 0 || json === null) {
    return json;
  }
  return {
    "user": UserSelfFromJSON(json["user"]),
    "original": !exists(json, "original") ? void 0 : UserSelfFromJSON(json["original"])
  };
}

// node_modules/@goauthentik/api/dist/esm/models/TokenRequest.js
function TokenRequestToJSON(value) {
  if (value === void 0) {
    return void 0;
  }
  if (value === null) {
    return null;
  }
  return {
    "managed": value.managed,
    "identifier": value.identifier,
    "intent": IntentEnumToJSON(value.intent),
    "user": value.user,
    "description": value.description,
    "expires": value.expires === void 0 ? void 0 : value.expires === null ? null : value.expires.toISOString(),
    "expiring": value.expiring
  };
}

// node_modules/@goauthentik/api/dist/esm/models/TokenSetKeyRequest.js
function TokenSetKeyRequestToJSON(value) {
  if (value === void 0) {
    return void 0;
  }
  if (value === null) {
    return null;
  }
  return {
    "key": value.key
  };
}

// node_modules/@goauthentik/api/dist/esm/models/TokenView.js
function TokenViewFromJSON(json) {
  return TokenViewFromJSONTyped(json, false);
}
function TokenViewFromJSONTyped(json, ignoreDiscriminator) {
  if (json === void 0 || json === null) {
    return json;
  }
  return {
    "key": json["key"]
  };
}

// node_modules/@goauthentik/api/dist/esm/models/TransactionApplicationRequest.js
function TransactionApplicationRequestToJSON(value) {
  if (value === void 0) {
    return void 0;
  }
  if (value === null) {
    return null;
  }
  return {
    "app": ApplicationRequestToJSON(value.app),
    "provider_model": ProviderModelEnumToJSON(value.providerModel),
    "provider": ModelRequestToJSON(value.provider)
  };
}

// node_modules/@goauthentik/api/dist/esm/models/TransactionApplicationResponse.js
function TransactionApplicationResponseFromJSON(json) {
  return TransactionApplicationResponseFromJSONTyped(json, false);
}
function TransactionApplicationResponseFromJSONTyped(json, ignoreDiscriminator) {
  if (json === void 0 || json === null) {
    return json;
  }
  return {
    "applied": json["applied"],
    "logs": json["logs"]
  };
}

// node_modules/@goauthentik/api/dist/esm/models/UsedByActionEnum.js
function UsedByActionEnumFromJSON(json) {
  return UsedByActionEnumFromJSONTyped(json, false);
}
function UsedByActionEnumFromJSONTyped(json, ignoreDiscriminator) {
  return json;
}

// node_modules/@goauthentik/api/dist/esm/models/UsedBy.js
function UsedByFromJSON(json) {
  return UsedByFromJSONTyped(json, false);
}
function UsedByFromJSONTyped(json, ignoreDiscriminator) {
  if (json === void 0 || json === null) {
    return json;
  }
  return {
    "app": json["app"],
    "modelName": json["model_name"],
    "pk": json["pk"],
    "name": json["name"],
    "action": UsedByActionEnumFromJSON(json["action"])
  };
}

// node_modules/@goauthentik/api/dist/esm/models/UserAccountRequest.js
function UserAccountRequestToJSON(value) {
  if (value === void 0) {
    return void 0;
  }
  if (value === null) {
    return null;
  }
  return {
    "pk": value.pk
  };
}

// node_modules/@goauthentik/api/dist/esm/models/UserMetrics.js
function UserMetricsFromJSON(json) {
  return UserMetricsFromJSONTyped(json, false);
}
function UserMetricsFromJSONTyped(json, ignoreDiscriminator) {
  if (json === void 0 || json === null) {
    return json;
  }
  return {
    "logins": json["logins"].map(CoordinateFromJSON),
    "loginsFailed": json["logins_failed"].map(CoordinateFromJSON),
    "authorizations": json["authorizations"].map(CoordinateFromJSON)
  };
}

// node_modules/@goauthentik/api/dist/esm/models/UserPasswordSetRequest.js
function UserPasswordSetRequestToJSON(value) {
  if (value === void 0) {
    return void 0;
  }
  if (value === null) {
    return null;
  }
  return {
    "password": value.password
  };
}

// node_modules/@goauthentik/api/dist/esm/models/UserPath.js
function UserPathFromJSON(json) {
  return UserPathFromJSONTyped(json, false);
}
function UserPathFromJSONTyped(json, ignoreDiscriminator) {
  if (json === void 0 || json === null) {
    return json;
  }
  return {
    "paths": json["paths"]
  };
}

// node_modules/@goauthentik/api/dist/esm/models/UserRequest.js
function UserRequestToJSON(value) {
  if (value === void 0) {
    return void 0;
  }
  if (value === null) {
    return null;
  }
  return {
    "username": value.username,
    "name": value.name,
    "is_active": value.isActive,
    "last_login": value.lastLogin === void 0 ? void 0 : value.lastLogin === null ? null : value.lastLogin.toISOString(),
    "groups": value.groups,
    "email": value.email,
    "attributes": value.attributes,
    "path": value.path,
    "type": UserTypeEnumToJSON(value.type)
  };
}

// node_modules/@goauthentik/api/dist/esm/models/UserServiceAccountRequest.js
function UserServiceAccountRequestToJSON(value) {
  if (value === void 0) {
    return void 0;
  }
  if (value === null) {
    return null;
  }
  return {
    "name": value.name,
    "create_group": value.createGroup,
    "expiring": value.expiring,
    "expires": value.expires === void 0 ? void 0 : value.expires.toISOString()
  };
}

// node_modules/@goauthentik/api/dist/esm/models/UserServiceAccountResponse.js
function UserServiceAccountResponseFromJSON(json) {
  return UserServiceAccountResponseFromJSONTyped(json, false);
}
function UserServiceAccountResponseFromJSONTyped(json, ignoreDiscriminator) {
  if (json === void 0 || json === null) {
    return json;
  }
  return {
    "username": json["username"],
    "token": json["token"],
    "userUid": json["user_uid"],
    "userPk": json["user_pk"],
    "groupPk": !exists(json, "group_pk") ? void 0 : json["group_pk"]
  };
}

// node_modules/@goauthentik/api/dist/esm/apis/CoreApi.js
var __awaiter2 = function(thisArg, _arguments, P2, generator) {
  function adopt(value) {
    return value instanceof P2 ? value : new P2(function(resolve) {
      resolve(value);
    });
  }
  return new (P2 || (P2 = Promise))(function(resolve, reject) {
    function fulfilled(value) {
      try {
        step(generator.next(value));
      } catch (e7) {
        reject(e7);
      }
    }
    function rejected(value) {
      try {
        step(generator["throw"](value));
      } catch (e7) {
        reject(e7);
      }
    }
    function step(result) {
      result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected);
    }
    step((generator = generator.apply(thisArg, _arguments || [])).next());
  });
};
var CoreApi = class extends BaseAPI {
  /**
   * Check access to a single application by slug
   */
  coreApplicationsCheckAccessRetrieveRaw(requestParameters, initOverrides) {
    return __awaiter2(this, void 0, void 0, function* () {
      if (requestParameters.slug === null || requestParameters.slug === void 0) {
        throw new RequiredError("slug", "Required parameter requestParameters.slug was null or undefined when calling coreApplicationsCheckAccessRetrieve.");
      }
      const queryParameters = {};
      if (requestParameters.forUser !== void 0) {
        queryParameters["for_user"] = requestParameters.forUser;
      }
      const headerParameters = {};
      if (this.configuration && this.configuration.accessToken) {
        const token = this.configuration.accessToken;
        const tokenString = yield token("authentik", []);
        if (tokenString) {
          headerParameters["Authorization"] = `Bearer ${tokenString}`;
        }
      }
      const response = yield this.request({
        path: `/core/applications/{slug}/check_access/`.replace(`{${"slug"}}`, encodeURIComponent(String(requestParameters.slug))),
        method: "GET",
        headers: headerParameters,
        query: queryParameters
      }, initOverrides);
      return new JSONApiResponse(response, (jsonValue) => PolicyTestResultFromJSON(jsonValue));
    });
  }
  /**
   * Check access to a single application by slug
   */
  coreApplicationsCheckAccessRetrieve(requestParameters, initOverrides) {
    return __awaiter2(this, void 0, void 0, function* () {
      const response = yield this.coreApplicationsCheckAccessRetrieveRaw(requestParameters, initOverrides);
      return yield response.value();
    });
  }
  /**
   * Application Viewset
   */
  coreApplicationsCreateRaw(requestParameters, initOverrides) {
    return __awaiter2(this, void 0, void 0, function* () {
      if (requestParameters.applicationRequest === null || requestParameters.applicationRequest === void 0) {
        throw new RequiredError("applicationRequest", "Required parameter requestParameters.applicationRequest was null or undefined when calling coreApplicationsCreate.");
      }
      const queryParameters = {};
      const headerParameters = {};
      headerParameters["Content-Type"] = "application/json";
      if (this.configuration && this.configuration.accessToken) {
        const token = this.configuration.accessToken;
        const tokenString = yield token("authentik", []);
        if (tokenString) {
          headerParameters["Authorization"] = `Bearer ${tokenString}`;
        }
      }
      const response = yield this.request({
        path: `/core/applications/`,
        method: "POST",
        headers: headerParameters,
        query: queryParameters,
        body: ApplicationRequestToJSON(requestParameters.applicationRequest)
      }, initOverrides);
      return new JSONApiResponse(response, (jsonValue) => ApplicationFromJSON(jsonValue));
    });
  }
  /**
   * Application Viewset
   */
  coreApplicationsCreate(requestParameters, initOverrides) {
    return __awaiter2(this, void 0, void 0, function* () {
      const response = yield this.coreApplicationsCreateRaw(requestParameters, initOverrides);
      return yield response.value();
    });
  }
  /**
   * Application Viewset
   */
  coreApplicationsDestroyRaw(requestParameters, initOverrides) {
    return __awaiter2(this, void 0, void 0, function* () {
      if (requestParameters.slug === null || requestParameters.slug === void 0) {
        throw new RequiredError("slug", "Required parameter requestParameters.slug was null or undefined when calling coreApplicationsDestroy.");
      }
      const queryParameters = {};
      const headerParameters = {};
      if (this.configuration && this.configuration.accessToken) {
        const token = this.configuration.accessToken;
        const tokenString = yield token("authentik", []);
        if (tokenString) {
          headerParameters["Authorization"] = `Bearer ${tokenString}`;
        }
      }
      const response = yield this.request({
        path: `/core/applications/{slug}/`.replace(`{${"slug"}}`, encodeURIComponent(String(requestParameters.slug))),
        method: "DELETE",
        headers: headerParameters,
        query: queryParameters
      }, initOverrides);
      return new VoidApiResponse(response);
    });
  }
  /**
   * Application Viewset
   */
  coreApplicationsDestroy(requestParameters, initOverrides) {
    return __awaiter2(this, void 0, void 0, function* () {
      yield this.coreApplicationsDestroyRaw(requestParameters, initOverrides);
    });
  }
  /**
   * Custom list method that checks Policy based access instead of guardian
   */
  coreApplicationsListRaw(requestParameters, initOverrides) {
    return __awaiter2(this, void 0, void 0, function* () {
      const queryParameters = {};
      if (requestParameters.forUser !== void 0) {
        queryParameters["for_user"] = requestParameters.forUser;
      }
      if (requestParameters.group !== void 0) {
        queryParameters["group"] = requestParameters.group;
      }
      if (requestParameters.metaDescription !== void 0) {
        queryParameters["meta_description"] = requestParameters.metaDescription;
      }
      if (requestParameters.metaLaunchUrl !== void 0) {
        queryParameters["meta_launch_url"] = requestParameters.metaLaunchUrl;
      }
      if (requestParameters.metaPublisher !== void 0) {
        queryParameters["meta_publisher"] = requestParameters.metaPublisher;
      }
      if (requestParameters.name !== void 0) {
        queryParameters["name"] = requestParameters.name;
      }
      if (requestParameters.ordering !== void 0) {
        queryParameters["ordering"] = requestParameters.ordering;
      }
      if (requestParameters.page !== void 0) {
        queryParameters["page"] = requestParameters.page;
      }
      if (requestParameters.pageSize !== void 0) {
        queryParameters["page_size"] = requestParameters.pageSize;
      }
      if (requestParameters.search !== void 0) {
        queryParameters["search"] = requestParameters.search;
      }
      if (requestParameters.slug !== void 0) {
        queryParameters["slug"] = requestParameters.slug;
      }
      if (requestParameters.superuserFullList !== void 0) {
        queryParameters["superuser_full_list"] = requestParameters.superuserFullList;
      }
      const headerParameters = {};
      if (this.configuration && this.configuration.accessToken) {
        const token = this.configuration.accessToken;
        const tokenString = yield token("authentik", []);
        if (tokenString) {
          headerParameters["Authorization"] = `Bearer ${tokenString}`;
        }
      }
      const response = yield this.request({
        path: `/core/applications/`,
        method: "GET",
        headers: headerParameters,
        query: queryParameters
      }, initOverrides);
      return new JSONApiResponse(response, (jsonValue) => PaginatedApplicationListFromJSON(jsonValue));
    });
  }
  /**
   * Custom list method that checks Policy based access instead of guardian
   */
  coreApplicationsList(requestParameters = {}, initOverrides) {
    return __awaiter2(this, void 0, void 0, function* () {
      const response = yield this.coreApplicationsListRaw(requestParameters, initOverrides);
      return yield response.value();
    });
  }
  /**
   * Metrics for application logins
   */
  coreApplicationsMetricsListRaw(requestParameters, initOverrides) {
    return __awaiter2(this, void 0, void 0, function* () {
      if (requestParameters.slug === null || requestParameters.slug === void 0) {
        throw new RequiredError("slug", "Required parameter requestParameters.slug was null or undefined when calling coreApplicationsMetricsList.");
      }
      const queryParameters = {};
      const headerParameters = {};
      if (this.configuration && this.configuration.accessToken) {
        const token = this.configuration.accessToken;
        const tokenString = yield token("authentik", []);
        if (tokenString) {
          headerParameters["Authorization"] = `Bearer ${tokenString}`;
        }
      }
      const response = yield this.request({
        path: `/core/applications/{slug}/metrics/`.replace(`{${"slug"}}`, encodeURIComponent(String(requestParameters.slug))),
        method: "GET",
        headers: headerParameters,
        query: queryParameters
      }, initOverrides);
      return new JSONApiResponse(response, (jsonValue) => jsonValue.map(CoordinateFromJSON));
    });
  }
  /**
   * Metrics for application logins
   */
  coreApplicationsMetricsList(requestParameters, initOverrides) {
    return __awaiter2(this, void 0, void 0, function* () {
      const response = yield this.coreApplicationsMetricsListRaw(requestParameters, initOverrides);
      return yield response.value();
    });
  }
  /**
   * Application Viewset
   */
  coreApplicationsPartialUpdateRaw(requestParameters, initOverrides) {
    return __awaiter2(this, void 0, void 0, function* () {
      if (requestParameters.slug === null || requestParameters.slug === void 0) {
        throw new RequiredError("slug", "Required parameter requestParameters.slug was null or undefined when calling coreApplicationsPartialUpdate.");
      }
      const queryParameters = {};
      const headerParameters = {};
      headerParameters["Content-Type"] = "application/json";
      if (this.configuration && this.configuration.accessToken) {
        const token = this.configuration.accessToken;
        const tokenString = yield token("authentik", []);
        if (tokenString) {
          headerParameters["Authorization"] = `Bearer ${tokenString}`;
        }
      }
      const response = yield this.request({
        path: `/core/applications/{slug}/`.replace(`{${"slug"}}`, encodeURIComponent(String(requestParameters.slug))),
        method: "PATCH",
        headers: headerParameters,
        query: queryParameters,
        body: PatchedApplicationRequestToJSON(requestParameters.patchedApplicationRequest)
      }, initOverrides);
      return new JSONApiResponse(response, (jsonValue) => ApplicationFromJSON(jsonValue));
    });
  }
  /**
   * Application Viewset
   */
  coreApplicationsPartialUpdate(requestParameters, initOverrides) {
    return __awaiter2(this, void 0, void 0, function* () {
      const response = yield this.coreApplicationsPartialUpdateRaw(requestParameters, initOverrides);
      return yield response.value();
    });
  }
  /**
   * Application Viewset
   */
  coreApplicationsRetrieveRaw(requestParameters, initOverrides) {
    return __awaiter2(this, void 0, void 0, function* () {
      if (requestParameters.slug === null || requestParameters.slug === void 0) {
        throw new RequiredError("slug", "Required parameter requestParameters.slug was null or undefined when calling coreApplicationsRetrieve.");
      }
      const queryParameters = {};
      const headerParameters = {};
      if (this.configuration && this.configuration.accessToken) {
        const token = this.configuration.accessToken;
        const tokenString = yield token("authentik", []);
        if (tokenString) {
          headerParameters["Authorization"] = `Bearer ${tokenString}`;
        }
      }
      const response = yield this.request({
        path: `/core/applications/{slug}/`.replace(`{${"slug"}}`, encodeURIComponent(String(requestParameters.slug))),
        method: "GET",
        headers: headerParameters,
        query: queryParameters
      }, initOverrides);
      return new JSONApiResponse(response, (jsonValue) => ApplicationFromJSON(jsonValue));
    });
  }
  /**
   * Application Viewset
   */
  coreApplicationsRetrieve(requestParameters, initOverrides) {
    return __awaiter2(this, void 0, void 0, function* () {
      const response = yield this.coreApplicationsRetrieveRaw(requestParameters, initOverrides);
      return yield response.value();
    });
  }
  /**
   * Set application icon
   */
  coreApplicationsSetIconCreateRaw(requestParameters, initOverrides) {
    return __awaiter2(this, void 0, void 0, function* () {
      if (requestParameters.slug === null || requestParameters.slug === void 0) {
        throw new RequiredError("slug", "Required parameter requestParameters.slug was null or undefined when calling coreApplicationsSetIconCreate.");
      }
      const queryParameters = {};
      const headerParameters = {};
      if (this.configuration && this.configuration.accessToken) {
        const token = this.configuration.accessToken;
        const tokenString = yield token("authentik", []);
        if (tokenString) {
          headerParameters["Authorization"] = `Bearer ${tokenString}`;
        }
      }
      const consumes = [
        { contentType: "multipart/form-data" }
      ];
      const canConsumeForm2 = canConsumeForm(consumes);
      let formParams;
      let useForm = false;
      useForm = canConsumeForm2;
      if (useForm) {
        formParams = new FormData();
      } else {
        formParams = new URLSearchParams();
      }
      if (requestParameters.file !== void 0) {
        formParams.append("file", requestParameters.file);
      }
      if (requestParameters.clear !== void 0) {
        formParams.append("clear", requestParameters.clear);
      }
      const response = yield this.request({
        path: `/core/applications/{slug}/set_icon/`.replace(`{${"slug"}}`, encodeURIComponent(String(requestParameters.slug))),
        method: "POST",
        headers: headerParameters,
        query: queryParameters,
        body: formParams
      }, initOverrides);
      return new VoidApiResponse(response);
    });
  }
  /**
   * Set application icon
   */
  coreApplicationsSetIconCreate(requestParameters, initOverrides) {
    return __awaiter2(this, void 0, void 0, function* () {
      yield this.coreApplicationsSetIconCreateRaw(requestParameters, initOverrides);
    });
  }
  /**
   * Set application icon (as URL)
   */
  coreApplicationsSetIconUrlCreateRaw(requestParameters, initOverrides) {
    return __awaiter2(this, void 0, void 0, function* () {
      if (requestParameters.slug === null || requestParameters.slug === void 0) {
        throw new RequiredError("slug", "Required parameter requestParameters.slug was null or undefined when calling coreApplicationsSetIconUrlCreate.");
      }
      if (requestParameters.filePathRequest === null || requestParameters.filePathRequest === void 0) {
        throw new RequiredError("filePathRequest", "Required parameter requestParameters.filePathRequest was null or undefined when calling coreApplicationsSetIconUrlCreate.");
      }
      const queryParameters = {};
      const headerParameters = {};
      headerParameters["Content-Type"] = "application/json";
      if (this.configuration && this.configuration.accessToken) {
        const token = this.configuration.accessToken;
        const tokenString = yield token("authentik", []);
        if (tokenString) {
          headerParameters["Authorization"] = `Bearer ${tokenString}`;
        }
      }
      const response = yield this.request({
        path: `/core/applications/{slug}/set_icon_url/`.replace(`{${"slug"}}`, encodeURIComponent(String(requestParameters.slug))),
        method: "POST",
        headers: headerParameters,
        query: queryParameters,
        body: FilePathRequestToJSON(requestParameters.filePathRequest)
      }, initOverrides);
      return new VoidApiResponse(response);
    });
  }
  /**
   * Set application icon (as URL)
   */
  coreApplicationsSetIconUrlCreate(requestParameters, initOverrides) {
    return __awaiter2(this, void 0, void 0, function* () {
      yield this.coreApplicationsSetIconUrlCreateRaw(requestParameters, initOverrides);
    });
  }
  /**
   * Application Viewset
   */
  coreApplicationsUpdateRaw(requestParameters, initOverrides) {
    return __awaiter2(this, void 0, void 0, function* () {
      if (requestParameters.slug === null || requestParameters.slug === void 0) {
        throw new RequiredError("slug", "Required parameter requestParameters.slug was null or undefined when calling coreApplicationsUpdate.");
      }
      if (requestParameters.applicationRequest === null || requestParameters.applicationRequest === void 0) {
        throw new RequiredError("applicationRequest", "Required parameter requestParameters.applicationRequest was null or undefined when calling coreApplicationsUpdate.");
      }
      const queryParameters = {};
      const headerParameters = {};
      headerParameters["Content-Type"] = "application/json";
      if (this.configuration && this.configuration.accessToken) {
        const token = this.configuration.accessToken;
        const tokenString = yield token("authentik", []);
        if (tokenString) {
          headerParameters["Authorization"] = `Bearer ${tokenString}`;
        }
      }
      const response = yield this.request({
        path: `/core/applications/{slug}/`.replace(`{${"slug"}}`, encodeURIComponent(String(requestParameters.slug))),
        method: "PUT",
        headers: headerParameters,
        query: queryParameters,
        body: ApplicationRequestToJSON(requestParameters.applicationRequest)
      }, initOverrides);
      return new JSONApiResponse(response, (jsonValue) => ApplicationFromJSON(jsonValue));
    });
  }
  /**
   * Application Viewset
   */
  coreApplicationsUpdate(requestParameters, initOverrides) {
    return __awaiter2(this, void 0, void 0, function* () {
      const response = yield this.coreApplicationsUpdateRaw(requestParameters, initOverrides);
      return yield response.value();
    });
  }
  /**
   * Get a list of all objects that use this object
   */
  coreApplicationsUsedByListRaw(requestParameters, initOverrides) {
    return __awaiter2(this, void 0, void 0, function* () {
      if (requestParameters.slug === null || requestParameters.slug === void 0) {
        throw new RequiredError("slug", "Required parameter requestParameters.slug was null or undefined when calling coreApplicationsUsedByList.");
      }
      const queryParameters = {};
      const headerParameters = {};
      if (this.configuration && this.configuration.accessToken) {
        const token = this.configuration.accessToken;
        const tokenString = yield token("authentik", []);
        if (tokenString) {
          headerParameters["Authorization"] = `Bearer ${tokenString}`;
        }
      }
      const response = yield this.request({
        path: `/core/applications/{slug}/used_by/`.replace(`{${"slug"}}`, encodeURIComponent(String(requestParameters.slug))),
        method: "GET",
        headers: headerParameters,
        query: queryParameters
      }, initOverrides);
      return new JSONApiResponse(response, (jsonValue) => jsonValue.map(UsedByFromJSON));
    });
  }
  /**
   * Get a list of all objects that use this object
   */
  coreApplicationsUsedByList(requestParameters, initOverrides) {
    return __awaiter2(this, void 0, void 0, function* () {
      const response = yield this.coreApplicationsUsedByListRaw(requestParameters, initOverrides);
      return yield response.value();
    });
  }
  /**
   * AuthenticatedSession Viewset
   */
  coreAuthenticatedSessionsDestroyRaw(requestParameters, initOverrides) {
    return __awaiter2(this, void 0, void 0, function* () {
      if (requestParameters.uuid === null || requestParameters.uuid === void 0) {
        throw new RequiredError("uuid", "Required parameter requestParameters.uuid was null or undefined when calling coreAuthenticatedSessionsDestroy.");
      }
      const queryParameters = {};
      const headerParameters = {};
      if (this.configuration && this.configuration.accessToken) {
        const token = this.configuration.accessToken;
        const tokenString = yield token("authentik", []);
        if (tokenString) {
          headerParameters["Authorization"] = `Bearer ${tokenString}`;
        }
      }
      const response = yield this.request({
        path: `/core/authenticated_sessions/{uuid}/`.replace(`{${"uuid"}}`, encodeURIComponent(String(requestParameters.uuid))),
        method: "DELETE",
        headers: headerParameters,
        query: queryParameters
      }, initOverrides);
      return new VoidApiResponse(response);
    });
  }
  /**
   * AuthenticatedSession Viewset
   */
  coreAuthenticatedSessionsDestroy(requestParameters, initOverrides) {
    return __awaiter2(this, void 0, void 0, function* () {
      yield this.coreAuthenticatedSessionsDestroyRaw(requestParameters, initOverrides);
    });
  }
  /**
   * AuthenticatedSession Viewset
   */
  coreAuthenticatedSessionsListRaw(requestParameters, initOverrides) {
    return __awaiter2(this, void 0, void 0, function* () {
      const queryParameters = {};
      if (requestParameters.lastIp !== void 0) {
        queryParameters["last_ip"] = requestParameters.lastIp;
      }
      if (requestParameters.lastUserAgent !== void 0) {
        queryParameters["last_user_agent"] = requestParameters.lastUserAgent;
      }
      if (requestParameters.ordering !== void 0) {
        queryParameters["ordering"] = requestParameters.ordering;
      }
      if (requestParameters.page !== void 0) {
        queryParameters["page"] = requestParameters.page;
      }
      if (requestParameters.pageSize !== void 0) {
        queryParameters["page_size"] = requestParameters.pageSize;
      }
      if (requestParameters.search !== void 0) {
        queryParameters["search"] = requestParameters.search;
      }
      if (requestParameters.userUsername !== void 0) {
        queryParameters["user__username"] = requestParameters.userUsername;
      }
      const headerParameters = {};
      if (this.configuration && this.configuration.accessToken) {
        const token = this.configuration.accessToken;
        const tokenString = yield token("authentik", []);
        if (tokenString) {
          headerParameters["Authorization"] = `Bearer ${tokenString}`;
        }
      }
      const response = yield this.request({
        path: `/core/authenticated_sessions/`,
        method: "GET",
        headers: headerParameters,
        query: queryParameters
      }, initOverrides);
      return new JSONApiResponse(response, (jsonValue) => PaginatedAuthenticatedSessionListFromJSON(jsonValue));
    });
  }
  /**
   * AuthenticatedSession Viewset
   */
  coreAuthenticatedSessionsList(requestParameters = {}, initOverrides) {
    return __awaiter2(this, void 0, void 0, function* () {
      const response = yield this.coreAuthenticatedSessionsListRaw(requestParameters, initOverrides);
      return yield response.value();
    });
  }
  /**
   * AuthenticatedSession Viewset
   */
  coreAuthenticatedSessionsRetrieveRaw(requestParameters, initOverrides) {
    return __awaiter2(this, void 0, void 0, function* () {
      if (requestParameters.uuid === null || requestParameters.uuid === void 0) {
        throw new RequiredError("uuid", "Required parameter requestParameters.uuid was null or undefined when calling coreAuthenticatedSessionsRetrieve.");
      }
      const queryParameters = {};
      const headerParameters = {};
      if (this.configuration && this.configuration.accessToken) {
        const token = this.configuration.accessToken;
        const tokenString = yield token("authentik", []);
        if (tokenString) {
          headerParameters["Authorization"] = `Bearer ${tokenString}`;
        }
      }
      const response = yield this.request({
        path: `/core/authenticated_sessions/{uuid}/`.replace(`{${"uuid"}}`, encodeURIComponent(String(requestParameters.uuid))),
        method: "GET",
        headers: headerParameters,
        query: queryParameters
      }, initOverrides);
      return new JSONApiResponse(response, (jsonValue) => AuthenticatedSessionFromJSON(jsonValue));
    });
  }
  /**
   * AuthenticatedSession Viewset
   */
  coreAuthenticatedSessionsRetrieve(requestParameters, initOverrides) {
    return __awaiter2(this, void 0, void 0, function* () {
      const response = yield this.coreAuthenticatedSessionsRetrieveRaw(requestParameters, initOverrides);
      return yield response.value();
    });
  }
  /**
   * Get a list of all objects that use this object
   */
  coreAuthenticatedSessionsUsedByListRaw(requestParameters, initOverrides) {
    return __awaiter2(this, void 0, void 0, function* () {
      if (requestParameters.uuid === null || requestParameters.uuid === void 0) {
        throw new RequiredError("uuid", "Required parameter requestParameters.uuid was null or undefined when calling coreAuthenticatedSessionsUsedByList.");
      }
      const queryParameters = {};
      const headerParameters = {};
      if (this.configuration && this.configuration.accessToken) {
        const token = this.configuration.accessToken;
        const tokenString = yield token("authentik", []);
        if (tokenString) {
          headerParameters["Authorization"] = `Bearer ${tokenString}`;
        }
      }
      const response = yield this.request({
        path: `/core/authenticated_sessions/{uuid}/used_by/`.replace(`{${"uuid"}}`, encodeURIComponent(String(requestParameters.uuid))),
        method: "GET",
        headers: headerParameters,
        query: queryParameters
      }, initOverrides);
      return new JSONApiResponse(response, (jsonValue) => jsonValue.map(UsedByFromJSON));
    });
  }
  /**
   * Get a list of all objects that use this object
   */
  coreAuthenticatedSessionsUsedByList(requestParameters, initOverrides) {
    return __awaiter2(this, void 0, void 0, function* () {
      const response = yield this.coreAuthenticatedSessionsUsedByListRaw(requestParameters, initOverrides);
      return yield response.value();
    });
  }
  /**
   * Brand Viewset
   */
  coreBrandsCreateRaw(requestParameters, initOverrides) {
    return __awaiter2(this, void 0, void 0, function* () {
      if (requestParameters.brandRequest === null || requestParameters.brandRequest === void 0) {
        throw new RequiredError("brandRequest", "Required parameter requestParameters.brandRequest was null or undefined when calling coreBrandsCreate.");
      }
      const queryParameters = {};
      const headerParameters = {};
      headerParameters["Content-Type"] = "application/json";
      if (this.configuration && this.configuration.accessToken) {
        const token = this.configuration.accessToken;
        const tokenString = yield token("authentik", []);
        if (tokenString) {
          headerParameters["Authorization"] = `Bearer ${tokenString}`;
        }
      }
      const response = yield this.request({
        path: `/core/brands/`,
        method: "POST",
        headers: headerParameters,
        query: queryParameters,
        body: BrandRequestToJSON(requestParameters.brandRequest)
      }, initOverrides);
      return new JSONApiResponse(response, (jsonValue) => BrandFromJSON(jsonValue));
    });
  }
  /**
   * Brand Viewset
   */
  coreBrandsCreate(requestParameters, initOverrides) {
    return __awaiter2(this, void 0, void 0, function* () {
      const response = yield this.coreBrandsCreateRaw(requestParameters, initOverrides);
      return yield response.value();
    });
  }
  /**
   * Get current brand
   */
  coreBrandsCurrentRetrieveRaw(initOverrides) {
    return __awaiter2(this, void 0, void 0, function* () {
      const queryParameters = {};
      const headerParameters = {};
      if (this.configuration && this.configuration.accessToken) {
        const token = this.configuration.accessToken;
        const tokenString = yield token("authentik", []);
        if (tokenString) {
          headerParameters["Authorization"] = `Bearer ${tokenString}`;
        }
      }
      const response = yield this.request({
        path: `/core/brands/current/`,
        method: "GET",
        headers: headerParameters,
        query: queryParameters
      }, initOverrides);
      return new JSONApiResponse(response, (jsonValue) => CurrentBrandFromJSON(jsonValue));
    });
  }
  /**
   * Get current brand
   */
  coreBrandsCurrentRetrieve(initOverrides) {
    return __awaiter2(this, void 0, void 0, function* () {
      const response = yield this.coreBrandsCurrentRetrieveRaw(initOverrides);
      return yield response.value();
    });
  }
  /**
   * Brand Viewset
   */
  coreBrandsDestroyRaw(requestParameters, initOverrides) {
    return __awaiter2(this, void 0, void 0, function* () {
      if (requestParameters.brandUuid === null || requestParameters.brandUuid === void 0) {
        throw new RequiredError("brandUuid", "Required parameter requestParameters.brandUuid was null or undefined when calling coreBrandsDestroy.");
      }
      const queryParameters = {};
      const headerParameters = {};
      if (this.configuration && this.configuration.accessToken) {
        const token = this.configuration.accessToken;
        const tokenString = yield token("authentik", []);
        if (tokenString) {
          headerParameters["Authorization"] = `Bearer ${tokenString}`;
        }
      }
      const response = yield this.request({
        path: `/core/brands/{brand_uuid}/`.replace(`{${"brand_uuid"}}`, encodeURIComponent(String(requestParameters.brandUuid))),
        method: "DELETE",
        headers: headerParameters,
        query: queryParameters
      }, initOverrides);
      return new VoidApiResponse(response);
    });
  }
  /**
   * Brand Viewset
   */
  coreBrandsDestroy(requestParameters, initOverrides) {
    return __awaiter2(this, void 0, void 0, function* () {
      yield this.coreBrandsDestroyRaw(requestParameters, initOverrides);
    });
  }
  /**
   * Brand Viewset
   */
  coreBrandsListRaw(requestParameters, initOverrides) {
    return __awaiter2(this, void 0, void 0, function* () {
      const queryParameters = {};
      if (requestParameters.brandUuid !== void 0) {
        queryParameters["brand_uuid"] = requestParameters.brandUuid;
      }
      if (requestParameters.brandingFavicon !== void 0) {
        queryParameters["branding_favicon"] = requestParameters.brandingFavicon;
      }
      if (requestParameters.brandingLogo !== void 0) {
        queryParameters["branding_logo"] = requestParameters.brandingLogo;
      }
      if (requestParameters.brandingTitle !== void 0) {
        queryParameters["branding_title"] = requestParameters.brandingTitle;
      }
      if (requestParameters._default !== void 0) {
        queryParameters["default"] = requestParameters._default;
      }
      if (requestParameters.domain !== void 0) {
        queryParameters["domain"] = requestParameters.domain;
      }
      if (requestParameters.flowAuthentication !== void 0) {
        queryParameters["flow_authentication"] = requestParameters.flowAuthentication;
      }
      if (requestParameters.flowDeviceCode !== void 0) {
        queryParameters["flow_device_code"] = requestParameters.flowDeviceCode;
      }
      if (requestParameters.flowInvalidation !== void 0) {
        queryParameters["flow_invalidation"] = requestParameters.flowInvalidation;
      }
      if (requestParameters.flowRecovery !== void 0) {
        queryParameters["flow_recovery"] = requestParameters.flowRecovery;
      }
      if (requestParameters.flowUnenrollment !== void 0) {
        queryParameters["flow_unenrollment"] = requestParameters.flowUnenrollment;
      }
      if (requestParameters.flowUserSettings !== void 0) {
        queryParameters["flow_user_settings"] = requestParameters.flowUserSettings;
      }
      if (requestParameters.ordering !== void 0) {
        queryParameters["ordering"] = requestParameters.ordering;
      }
      if (requestParameters.page !== void 0) {
        queryParameters["page"] = requestParameters.page;
      }
      if (requestParameters.pageSize !== void 0) {
        queryParameters["page_size"] = requestParameters.pageSize;
      }
      if (requestParameters.search !== void 0) {
        queryParameters["search"] = requestParameters.search;
      }
      if (requestParameters.webCertificate !== void 0) {
        queryParameters["web_certificate"] = requestParameters.webCertificate;
      }
      const headerParameters = {};
      if (this.configuration && this.configuration.accessToken) {
        const token = this.configuration.accessToken;
        const tokenString = yield token("authentik", []);
        if (tokenString) {
          headerParameters["Authorization"] = `Bearer ${tokenString}`;
        }
      }
      const response = yield this.request({
        path: `/core/brands/`,
        method: "GET",
        headers: headerParameters,
        query: queryParameters
      }, initOverrides);
      return new JSONApiResponse(response, (jsonValue) => PaginatedBrandListFromJSON(jsonValue));
    });
  }
  /**
   * Brand Viewset
   */
  coreBrandsList(requestParameters = {}, initOverrides) {
    return __awaiter2(this, void 0, void 0, function* () {
      const response = yield this.coreBrandsListRaw(requestParameters, initOverrides);
      return yield response.value();
    });
  }
  /**
   * Brand Viewset
   */
  coreBrandsPartialUpdateRaw(requestParameters, initOverrides) {
    return __awaiter2(this, void 0, void 0, function* () {
      if (requestParameters.brandUuid === null || requestParameters.brandUuid === void 0) {
        throw new RequiredError("brandUuid", "Required parameter requestParameters.brandUuid was null or undefined when calling coreBrandsPartialUpdate.");
      }
      const queryParameters = {};
      const headerParameters = {};
      headerParameters["Content-Type"] = "application/json";
      if (this.configuration && this.configuration.accessToken) {
        const token = this.configuration.accessToken;
        const tokenString = yield token("authentik", []);
        if (tokenString) {
          headerParameters["Authorization"] = `Bearer ${tokenString}`;
        }
      }
      const response = yield this.request({
        path: `/core/brands/{brand_uuid}/`.replace(`{${"brand_uuid"}}`, encodeURIComponent(String(requestParameters.brandUuid))),
        method: "PATCH",
        headers: headerParameters,
        query: queryParameters,
        body: PatchedBrandRequestToJSON(requestParameters.patchedBrandRequest)
      }, initOverrides);
      return new JSONApiResponse(response, (jsonValue) => BrandFromJSON(jsonValue));
    });
  }
  /**
   * Brand Viewset
   */
  coreBrandsPartialUpdate(requestParameters, initOverrides) {
    return __awaiter2(this, void 0, void 0, function* () {
      const response = yield this.coreBrandsPartialUpdateRaw(requestParameters, initOverrides);
      return yield response.value();
    });
  }
  /**
   * Brand Viewset
   */
  coreBrandsRetrieveRaw(requestParameters, initOverrides) {
    return __awaiter2(this, void 0, void 0, function* () {
      if (requestParameters.brandUuid === null || requestParameters.brandUuid === void 0) {
        throw new RequiredError("brandUuid", "Required parameter requestParameters.brandUuid was null or undefined when calling coreBrandsRetrieve.");
      }
      const queryParameters = {};
      const headerParameters = {};
      if (this.configuration && this.configuration.accessToken) {
        const token = this.configuration.accessToken;
        const tokenString = yield token("authentik", []);
        if (tokenString) {
          headerParameters["Authorization"] = `Bearer ${tokenString}`;
        }
      }
      const response = yield this.request({
        path: `/core/brands/{brand_uuid}/`.replace(`{${"brand_uuid"}}`, encodeURIComponent(String(requestParameters.brandUuid))),
        method: "GET",
        headers: headerParameters,
        query: queryParameters
      }, initOverrides);
      return new JSONApiResponse(response, (jsonValue) => BrandFromJSON(jsonValue));
    });
  }
  /**
   * Brand Viewset
   */
  coreBrandsRetrieve(requestParameters, initOverrides) {
    return __awaiter2(this, void 0, void 0, function* () {
      const response = yield this.coreBrandsRetrieveRaw(requestParameters, initOverrides);
      return yield response.value();
    });
  }
  /**
   * Brand Viewset
   */
  coreBrandsUpdateRaw(requestParameters, initOverrides) {
    return __awaiter2(this, void 0, void 0, function* () {
      if (requestParameters.brandUuid === null || requestParameters.brandUuid === void 0) {
        throw new RequiredError("brandUuid", "Required parameter requestParameters.brandUuid was null or undefined when calling coreBrandsUpdate.");
      }
      if (requestParameters.brandRequest === null || requestParameters.brandRequest === void 0) {
        throw new RequiredError("brandRequest", "Required parameter requestParameters.brandRequest was null or undefined when calling coreBrandsUpdate.");
      }
      const queryParameters = {};
      const headerParameters = {};
      headerParameters["Content-Type"] = "application/json";
      if (this.configuration && this.configuration.accessToken) {
        const token = this.configuration.accessToken;
        const tokenString = yield token("authentik", []);
        if (tokenString) {
          headerParameters["Authorization"] = `Bearer ${tokenString}`;
        }
      }
      const response = yield this.request({
        path: `/core/brands/{brand_uuid}/`.replace(`{${"brand_uuid"}}`, encodeURIComponent(String(requestParameters.brandUuid))),
        method: "PUT",
        headers: headerParameters,
        query: queryParameters,
        body: BrandRequestToJSON(requestParameters.brandRequest)
      }, initOverrides);
      return new JSONApiResponse(response, (jsonValue) => BrandFromJSON(jsonValue));
    });
  }
  /**
   * Brand Viewset
   */
  coreBrandsUpdate(requestParameters, initOverrides) {
    return __awaiter2(this, void 0, void 0, function* () {
      const response = yield this.coreBrandsUpdateRaw(requestParameters, initOverrides);
      return yield response.value();
    });
  }
  /**
   * Get a list of all objects that use this object
   */
  coreBrandsUsedByListRaw(requestParameters, initOverrides) {
    return __awaiter2(this, void 0, void 0, function* () {
      if (requestParameters.brandUuid === null || requestParameters.brandUuid === void 0) {
        throw new RequiredError("brandUuid", "Required parameter requestParameters.brandUuid was null or undefined when calling coreBrandsUsedByList.");
      }
      const queryParameters = {};
      const headerParameters = {};
      if (this.configuration && this.configuration.accessToken) {
        const token = this.configuration.accessToken;
        const tokenString = yield token("authentik", []);
        if (tokenString) {
          headerParameters["Authorization"] = `Bearer ${tokenString}`;
        }
      }
      const response = yield this.request({
        path: `/core/brands/{brand_uuid}/used_by/`.replace(`{${"brand_uuid"}}`, encodeURIComponent(String(requestParameters.brandUuid))),
        method: "GET",
        headers: headerParameters,
        query: queryParameters
      }, initOverrides);
      return new JSONApiResponse(response, (jsonValue) => jsonValue.map(UsedByFromJSON));
    });
  }
  /**
   * Get a list of all objects that use this object
   */
  coreBrandsUsedByList(requestParameters, initOverrides) {
    return __awaiter2(this, void 0, void 0, function* () {
      const response = yield this.coreBrandsUsedByListRaw(requestParameters, initOverrides);
      return yield response.value();
    });
  }
  /**
   * Add user to group
   */
  coreGroupsAddUserCreateRaw(requestParameters, initOverrides) {
    return __awaiter2(this, void 0, void 0, function* () {
      if (requestParameters.groupUuid === null || requestParameters.groupUuid === void 0) {
        throw new RequiredError("groupUuid", "Required parameter requestParameters.groupUuid was null or undefined when calling coreGroupsAddUserCreate.");
      }
      if (requestParameters.userAccountRequest === null || requestParameters.userAccountRequest === void 0) {
        throw new RequiredError("userAccountRequest", "Required parameter requestParameters.userAccountRequest was null or undefined when calling coreGroupsAddUserCreate.");
      }
      const queryParameters = {};
      const headerParameters = {};
      headerParameters["Content-Type"] = "application/json";
      if (this.configuration && this.configuration.accessToken) {
        const token = this.configuration.accessToken;
        const tokenString = yield token("authentik", []);
        if (tokenString) {
          headerParameters["Authorization"] = `Bearer ${tokenString}`;
        }
      }
      const response = yield this.request({
        path: `/core/groups/{group_uuid}/add_user/`.replace(`{${"group_uuid"}}`, encodeURIComponent(String(requestParameters.groupUuid))),
        method: "POST",
        headers: headerParameters,
        query: queryParameters,
        body: UserAccountRequestToJSON(requestParameters.userAccountRequest)
      }, initOverrides);
      return new VoidApiResponse(response);
    });
  }
  /**
   * Add user to group
   */
  coreGroupsAddUserCreate(requestParameters, initOverrides) {
    return __awaiter2(this, void 0, void 0, function* () {
      yield this.coreGroupsAddUserCreateRaw(requestParameters, initOverrides);
    });
  }
  /**
   * Group Viewset
   */
  coreGroupsCreateRaw(requestParameters, initOverrides) {
    return __awaiter2(this, void 0, void 0, function* () {
      if (requestParameters.groupRequest === null || requestParameters.groupRequest === void 0) {
        throw new RequiredError("groupRequest", "Required parameter requestParameters.groupRequest was null or undefined when calling coreGroupsCreate.");
      }
      const queryParameters = {};
      const headerParameters = {};
      headerParameters["Content-Type"] = "application/json";
      if (this.configuration && this.configuration.accessToken) {
        const token = this.configuration.accessToken;
        const tokenString = yield token("authentik", []);
        if (tokenString) {
          headerParameters["Authorization"] = `Bearer ${tokenString}`;
        }
      }
      const response = yield this.request({
        path: `/core/groups/`,
        method: "POST",
        headers: headerParameters,
        query: queryParameters,
        body: GroupRequestToJSON(requestParameters.groupRequest)
      }, initOverrides);
      return new JSONApiResponse(response, (jsonValue) => GroupFromJSON(jsonValue));
    });
  }
  /**
   * Group Viewset
   */
  coreGroupsCreate(requestParameters, initOverrides) {
    return __awaiter2(this, void 0, void 0, function* () {
      const response = yield this.coreGroupsCreateRaw(requestParameters, initOverrides);
      return yield response.value();
    });
  }
  /**
   * Group Viewset
   */
  coreGroupsDestroyRaw(requestParameters, initOverrides) {
    return __awaiter2(this, void 0, void 0, function* () {
      if (requestParameters.groupUuid === null || requestParameters.groupUuid === void 0) {
        throw new RequiredError("groupUuid", "Required parameter requestParameters.groupUuid was null or undefined when calling coreGroupsDestroy.");
      }
      const queryParameters = {};
      const headerParameters = {};
      if (this.configuration && this.configuration.accessToken) {
        const token = this.configuration.accessToken;
        const tokenString = yield token("authentik", []);
        if (tokenString) {
          headerParameters["Authorization"] = `Bearer ${tokenString}`;
        }
      }
      const response = yield this.request({
        path: `/core/groups/{group_uuid}/`.replace(`{${"group_uuid"}}`, encodeURIComponent(String(requestParameters.groupUuid))),
        method: "DELETE",
        headers: headerParameters,
        query: queryParameters
      }, initOverrides);
      return new VoidApiResponse(response);
    });
  }
  /**
   * Group Viewset
   */
  coreGroupsDestroy(requestParameters, initOverrides) {
    return __awaiter2(this, void 0, void 0, function* () {
      yield this.coreGroupsDestroyRaw(requestParameters, initOverrides);
    });
  }
  /**
   * Group Viewset
   */
  coreGroupsListRaw(requestParameters, initOverrides) {
    return __awaiter2(this, void 0, void 0, function* () {
      const queryParameters = {};
      if (requestParameters.attributes !== void 0) {
        queryParameters["attributes"] = requestParameters.attributes;
      }
      if (requestParameters.includeUsers !== void 0) {
        queryParameters["include_users"] = requestParameters.includeUsers;
      }
      if (requestParameters.isSuperuser !== void 0) {
        queryParameters["is_superuser"] = requestParameters.isSuperuser;
      }
      if (requestParameters.membersByPk) {
        queryParameters["members_by_pk"] = requestParameters.membersByPk;
      }
      if (requestParameters.membersByUsername) {
        queryParameters["members_by_username"] = requestParameters.membersByUsername;
      }
      if (requestParameters.name !== void 0) {
        queryParameters["name"] = requestParameters.name;
      }
      if (requestParameters.ordering !== void 0) {
        queryParameters["ordering"] = requestParameters.ordering;
      }
      if (requestParameters.page !== void 0) {
        queryParameters["page"] = requestParameters.page;
      }
      if (requestParameters.pageSize !== void 0) {
        queryParameters["page_size"] = requestParameters.pageSize;
      }
      if (requestParameters.search !== void 0) {
        queryParameters["search"] = requestParameters.search;
      }
      const headerParameters = {};
      if (this.configuration && this.configuration.accessToken) {
        const token = this.configuration.accessToken;
        const tokenString = yield token("authentik", []);
        if (tokenString) {
          headerParameters["Authorization"] = `Bearer ${tokenString}`;
        }
      }
      const response = yield this.request({
        path: `/core/groups/`,
        method: "GET",
        headers: headerParameters,
        query: queryParameters
      }, initOverrides);
      return new JSONApiResponse(response, (jsonValue) => PaginatedGroupListFromJSON(jsonValue));
    });
  }
  /**
   * Group Viewset
   */
  coreGroupsList(requestParameters = {}, initOverrides) {
    return __awaiter2(this, void 0, void 0, function* () {
      const response = yield this.coreGroupsListRaw(requestParameters, initOverrides);
      return yield response.value();
    });
  }
  /**
   * Group Viewset
   */
  coreGroupsPartialUpdateRaw(requestParameters, initOverrides) {
    return __awaiter2(this, void 0, void 0, function* () {
      if (requestParameters.groupUuid === null || requestParameters.groupUuid === void 0) {
        throw new RequiredError("groupUuid", "Required parameter requestParameters.groupUuid was null or undefined when calling coreGroupsPartialUpdate.");
      }
      const queryParameters = {};
      const headerParameters = {};
      headerParameters["Content-Type"] = "application/json";
      if (this.configuration && this.configuration.accessToken) {
        const token = this.configuration.accessToken;
        const tokenString = yield token("authentik", []);
        if (tokenString) {
          headerParameters["Authorization"] = `Bearer ${tokenString}`;
        }
      }
      const response = yield this.request({
        path: `/core/groups/{group_uuid}/`.replace(`{${"group_uuid"}}`, encodeURIComponent(String(requestParameters.groupUuid))),
        method: "PATCH",
        headers: headerParameters,
        query: queryParameters,
        body: PatchedGroupRequestToJSON(requestParameters.patchedGroupRequest)
      }, initOverrides);
      return new JSONApiResponse(response, (jsonValue) => GroupFromJSON(jsonValue));
    });
  }
  /**
   * Group Viewset
   */
  coreGroupsPartialUpdate(requestParameters, initOverrides) {
    return __awaiter2(this, void 0, void 0, function* () {
      const response = yield this.coreGroupsPartialUpdateRaw(requestParameters, initOverrides);
      return yield response.value();
    });
  }
  /**
   * Add user to group
   */
  coreGroupsRemoveUserCreateRaw(requestParameters, initOverrides) {
    return __awaiter2(this, void 0, void 0, function* () {
      if (requestParameters.groupUuid === null || requestParameters.groupUuid === void 0) {
        throw new RequiredError("groupUuid", "Required parameter requestParameters.groupUuid was null or undefined when calling coreGroupsRemoveUserCreate.");
      }
      if (requestParameters.userAccountRequest === null || requestParameters.userAccountRequest === void 0) {
        throw new RequiredError("userAccountRequest", "Required parameter requestParameters.userAccountRequest was null or undefined when calling coreGroupsRemoveUserCreate.");
      }
      const queryParameters = {};
      const headerParameters = {};
      headerParameters["Content-Type"] = "application/json";
      if (this.configuration && this.configuration.accessToken) {
        const token = this.configuration.accessToken;
        const tokenString = yield token("authentik", []);
        if (tokenString) {
          headerParameters["Authorization"] = `Bearer ${tokenString}`;
        }
      }
      const response = yield this.request({
        path: `/core/groups/{group_uuid}/remove_user/`.replace(`{${"group_uuid"}}`, encodeURIComponent(String(requestParameters.groupUuid))),
        method: "POST",
        headers: headerParameters,
        query: queryParameters,
        body: UserAccountRequestToJSON(requestParameters.userAccountRequest)
      }, initOverrides);
      return new VoidApiResponse(response);
    });
  }
  /**
   * Add user to group
   */
  coreGroupsRemoveUserCreate(requestParameters, initOverrides) {
    return __awaiter2(this, void 0, void 0, function* () {
      yield this.coreGroupsRemoveUserCreateRaw(requestParameters, initOverrides);
    });
  }
  /**
   * Group Viewset
   */
  coreGroupsRetrieveRaw(requestParameters, initOverrides) {
    return __awaiter2(this, void 0, void 0, function* () {
      if (requestParameters.groupUuid === null || requestParameters.groupUuid === void 0) {
        throw new RequiredError("groupUuid", "Required parameter requestParameters.groupUuid was null or undefined when calling coreGroupsRetrieve.");
      }
      const queryParameters = {};
      const headerParameters = {};
      if (this.configuration && this.configuration.accessToken) {
        const token = this.configuration.accessToken;
        const tokenString = yield token("authentik", []);
        if (tokenString) {
          headerParameters["Authorization"] = `Bearer ${tokenString}`;
        }
      }
      const response = yield this.request({
        path: `/core/groups/{group_uuid}/`.replace(`{${"group_uuid"}}`, encodeURIComponent(String(requestParameters.groupUuid))),
        method: "GET",
        headers: headerParameters,
        query: queryParameters
      }, initOverrides);
      return new JSONApiResponse(response, (jsonValue) => GroupFromJSON(jsonValue));
    });
  }
  /**
   * Group Viewset
   */
  coreGroupsRetrieve(requestParameters, initOverrides) {
    return __awaiter2(this, void 0, void 0, function* () {
      const response = yield this.coreGroupsRetrieveRaw(requestParameters, initOverrides);
      return yield response.value();
    });
  }
  /**
   * Group Viewset
   */
  coreGroupsUpdateRaw(requestParameters, initOverrides) {
    return __awaiter2(this, void 0, void 0, function* () {
      if (requestParameters.groupUuid === null || requestParameters.groupUuid === void 0) {
        throw new RequiredError("groupUuid", "Required parameter requestParameters.groupUuid was null or undefined when calling coreGroupsUpdate.");
      }
      if (requestParameters.groupRequest === null || requestParameters.groupRequest === void 0) {
        throw new RequiredError("groupRequest", "Required parameter requestParameters.groupRequest was null or undefined when calling coreGroupsUpdate.");
      }
      const queryParameters = {};
      const headerParameters = {};
      headerParameters["Content-Type"] = "application/json";
      if (this.configuration && this.configuration.accessToken) {
        const token = this.configuration.accessToken;
        const tokenString = yield token("authentik", []);
        if (tokenString) {
          headerParameters["Authorization"] = `Bearer ${tokenString}`;
        }
      }
      const response = yield this.request({
        path: `/core/groups/{group_uuid}/`.replace(`{${"group_uuid"}}`, encodeURIComponent(String(requestParameters.groupUuid))),
        method: "PUT",
        headers: headerParameters,
        query: queryParameters,
        body: GroupRequestToJSON(requestParameters.groupRequest)
      }, initOverrides);
      return new JSONApiResponse(response, (jsonValue) => GroupFromJSON(jsonValue));
    });
  }
  /**
   * Group Viewset
   */
  coreGroupsUpdate(requestParameters, initOverrides) {
    return __awaiter2(this, void 0, void 0, function* () {
      const response = yield this.coreGroupsUpdateRaw(requestParameters, initOverrides);
      return yield response.value();
    });
  }
  /**
   * Get a list of all objects that use this object
   */
  coreGroupsUsedByListRaw(requestParameters, initOverrides) {
    return __awaiter2(this, void 0, void 0, function* () {
      if (requestParameters.groupUuid === null || requestParameters.groupUuid === void 0) {
        throw new RequiredError("groupUuid", "Required parameter requestParameters.groupUuid was null or undefined when calling coreGroupsUsedByList.");
      }
      const queryParameters = {};
      const headerParameters = {};
      if (this.configuration && this.configuration.accessToken) {
        const token = this.configuration.accessToken;
        const tokenString = yield token("authentik", []);
        if (tokenString) {
          headerParameters["Authorization"] = `Bearer ${tokenString}`;
        }
      }
      const response = yield this.request({
        path: `/core/groups/{group_uuid}/used_by/`.replace(`{${"group_uuid"}}`, encodeURIComponent(String(requestParameters.groupUuid))),
        method: "GET",
        headers: headerParameters,
        query: queryParameters
      }, initOverrides);
      return new JSONApiResponse(response, (jsonValue) => jsonValue.map(UsedByFromJSON));
    });
  }
  /**
   * Get a list of all objects that use this object
   */
  coreGroupsUsedByList(requestParameters, initOverrides) {
    return __awaiter2(this, void 0, void 0, function* () {
      const response = yield this.coreGroupsUsedByListRaw(requestParameters, initOverrides);
      return yield response.value();
    });
  }
  /**
   * Token Viewset
   */
  coreTokensCreateRaw(requestParameters, initOverrides) {
    return __awaiter2(this, void 0, void 0, function* () {
      if (requestParameters.tokenRequest === null || requestParameters.tokenRequest === void 0) {
        throw new RequiredError("tokenRequest", "Required parameter requestParameters.tokenRequest was null or undefined when calling coreTokensCreate.");
      }
      const queryParameters = {};
      const headerParameters = {};
      headerParameters["Content-Type"] = "application/json";
      if (this.configuration && this.configuration.accessToken) {
        const token = this.configuration.accessToken;
        const tokenString = yield token("authentik", []);
        if (tokenString) {
          headerParameters["Authorization"] = `Bearer ${tokenString}`;
        }
      }
      const response = yield this.request({
        path: `/core/tokens/`,
        method: "POST",
        headers: headerParameters,
        query: queryParameters,
        body: TokenRequestToJSON(requestParameters.tokenRequest)
      }, initOverrides);
      return new JSONApiResponse(response, (jsonValue) => TokenFromJSON(jsonValue));
    });
  }
  /**
   * Token Viewset
   */
  coreTokensCreate(requestParameters, initOverrides) {
    return __awaiter2(this, void 0, void 0, function* () {
      const response = yield this.coreTokensCreateRaw(requestParameters, initOverrides);
      return yield response.value();
    });
  }
  /**
   * Token Viewset
   */
  coreTokensDestroyRaw(requestParameters, initOverrides) {
    return __awaiter2(this, void 0, void 0, function* () {
      if (requestParameters.identifier === null || requestParameters.identifier === void 0) {
        throw new RequiredError("identifier", "Required parameter requestParameters.identifier was null or undefined when calling coreTokensDestroy.");
      }
      const queryParameters = {};
      const headerParameters = {};
      if (this.configuration && this.configuration.accessToken) {
        const token = this.configuration.accessToken;
        const tokenString = yield token("authentik", []);
        if (tokenString) {
          headerParameters["Authorization"] = `Bearer ${tokenString}`;
        }
      }
      const response = yield this.request({
        path: `/core/tokens/{identifier}/`.replace(`{${"identifier"}}`, encodeURIComponent(String(requestParameters.identifier))),
        method: "DELETE",
        headers: headerParameters,
        query: queryParameters
      }, initOverrides);
      return new VoidApiResponse(response);
    });
  }
  /**
   * Token Viewset
   */
  coreTokensDestroy(requestParameters, initOverrides) {
    return __awaiter2(this, void 0, void 0, function* () {
      yield this.coreTokensDestroyRaw(requestParameters, initOverrides);
    });
  }
  /**
   * Token Viewset
   */
  coreTokensListRaw(requestParameters, initOverrides) {
    return __awaiter2(this, void 0, void 0, function* () {
      const queryParameters = {};
      if (requestParameters.description !== void 0) {
        queryParameters["description"] = requestParameters.description;
      }
      if (requestParameters.expires !== void 0) {
        queryParameters["expires"] = requestParameters.expires.toISOString();
      }
      if (requestParameters.expiring !== void 0) {
        queryParameters["expiring"] = requestParameters.expiring;
      }
      if (requestParameters.identifier !== void 0) {
        queryParameters["identifier"] = requestParameters.identifier;
      }
      if (requestParameters.intent !== void 0) {
        queryParameters["intent"] = requestParameters.intent;
      }
      if (requestParameters.managed !== void 0) {
        queryParameters["managed"] = requestParameters.managed;
      }
      if (requestParameters.ordering !== void 0) {
        queryParameters["ordering"] = requestParameters.ordering;
      }
      if (requestParameters.page !== void 0) {
        queryParameters["page"] = requestParameters.page;
      }
      if (requestParameters.pageSize !== void 0) {
        queryParameters["page_size"] = requestParameters.pageSize;
      }
      if (requestParameters.search !== void 0) {
        queryParameters["search"] = requestParameters.search;
      }
      if (requestParameters.userUsername !== void 0) {
        queryParameters["user__username"] = requestParameters.userUsername;
      }
      const headerParameters = {};
      if (this.configuration && this.configuration.accessToken) {
        const token = this.configuration.accessToken;
        const tokenString = yield token("authentik", []);
        if (tokenString) {
          headerParameters["Authorization"] = `Bearer ${tokenString}`;
        }
      }
      const response = yield this.request({
        path: `/core/tokens/`,
        method: "GET",
        headers: headerParameters,
        query: queryParameters
      }, initOverrides);
      return new JSONApiResponse(response, (jsonValue) => PaginatedTokenListFromJSON(jsonValue));
    });
  }
  /**
   * Token Viewset
   */
  coreTokensList(requestParameters = {}, initOverrides) {
    return __awaiter2(this, void 0, void 0, function* () {
      const response = yield this.coreTokensListRaw(requestParameters, initOverrides);
      return yield response.value();
    });
  }
  /**
   * Token Viewset
   */
  coreTokensPartialUpdateRaw(requestParameters, initOverrides) {
    return __awaiter2(this, void 0, void 0, function* () {
      if (requestParameters.identifier === null || requestParameters.identifier === void 0) {
        throw new RequiredError("identifier", "Required parameter requestParameters.identifier was null or undefined when calling coreTokensPartialUpdate.");
      }
      const queryParameters = {};
      const headerParameters = {};
      headerParameters["Content-Type"] = "application/json";
      if (this.configuration && this.configuration.accessToken) {
        const token = this.configuration.accessToken;
        const tokenString = yield token("authentik", []);
        if (tokenString) {
          headerParameters["Authorization"] = `Bearer ${tokenString}`;
        }
      }
      const response = yield this.request({
        path: `/core/tokens/{identifier}/`.replace(`{${"identifier"}}`, encodeURIComponent(String(requestParameters.identifier))),
        method: "PATCH",
        headers: headerParameters,
        query: queryParameters,
        body: PatchedTokenRequestToJSON(requestParameters.patchedTokenRequest)
      }, initOverrides);
      return new JSONApiResponse(response, (jsonValue) => TokenFromJSON(jsonValue));
    });
  }
  /**
   * Token Viewset
   */
  coreTokensPartialUpdate(requestParameters, initOverrides) {
    return __awaiter2(this, void 0, void 0, function* () {
      const response = yield this.coreTokensPartialUpdateRaw(requestParameters, initOverrides);
      return yield response.value();
    });
  }
  /**
   * Token Viewset
   */
  coreTokensRetrieveRaw(requestParameters, initOverrides) {
    return __awaiter2(this, void 0, void 0, function* () {
      if (requestParameters.identifier === null || requestParameters.identifier === void 0) {
        throw new RequiredError("identifier", "Required parameter requestParameters.identifier was null or undefined when calling coreTokensRetrieve.");
      }
      const queryParameters = {};
      const headerParameters = {};
      if (this.configuration && this.configuration.accessToken) {
        const token = this.configuration.accessToken;
        const tokenString = yield token("authentik", []);
        if (tokenString) {
          headerParameters["Authorization"] = `Bearer ${tokenString}`;
        }
      }
      const response = yield this.request({
        path: `/core/tokens/{identifier}/`.replace(`{${"identifier"}}`, encodeURIComponent(String(requestParameters.identifier))),
        method: "GET",
        headers: headerParameters,
        query: queryParameters
      }, initOverrides);
      return new JSONApiResponse(response, (jsonValue) => TokenFromJSON(jsonValue));
    });
  }
  /**
   * Token Viewset
   */
  coreTokensRetrieve(requestParameters, initOverrides) {
    return __awaiter2(this, void 0, void 0, function* () {
      const response = yield this.coreTokensRetrieveRaw(requestParameters, initOverrides);
      return yield response.value();
    });
  }
  /**
   * Set token key. Action is logged as event. `authentik_core.set_token_key` permission is required.
   */
  coreTokensSetKeyCreateRaw(requestParameters, initOverrides) {
    return __awaiter2(this, void 0, void 0, function* () {
      if (requestParameters.identifier === null || requestParameters.identifier === void 0) {
        throw new RequiredError("identifier", "Required parameter requestParameters.identifier was null or undefined when calling coreTokensSetKeyCreate.");
      }
      if (requestParameters.tokenSetKeyRequest === null || requestParameters.tokenSetKeyRequest === void 0) {
        throw new RequiredError("tokenSetKeyRequest", "Required parameter requestParameters.tokenSetKeyRequest was null or undefined when calling coreTokensSetKeyCreate.");
      }
      const queryParameters = {};
      const headerParameters = {};
      headerParameters["Content-Type"] = "application/json";
      if (this.configuration && this.configuration.accessToken) {
        const token = this.configuration.accessToken;
        const tokenString = yield token("authentik", []);
        if (tokenString) {
          headerParameters["Authorization"] = `Bearer ${tokenString}`;
        }
      }
      const response = yield this.request({
        path: `/core/tokens/{identifier}/set_key/`.replace(`{${"identifier"}}`, encodeURIComponent(String(requestParameters.identifier))),
        method: "POST",
        headers: headerParameters,
        query: queryParameters,
        body: TokenSetKeyRequestToJSON(requestParameters.tokenSetKeyRequest)
      }, initOverrides);
      return new VoidApiResponse(response);
    });
  }
  /**
   * Set token key. Action is logged as event. `authentik_core.set_token_key` permission is required.
   */
  coreTokensSetKeyCreate(requestParameters, initOverrides) {
    return __awaiter2(this, void 0, void 0, function* () {
      yield this.coreTokensSetKeyCreateRaw(requestParameters, initOverrides);
    });
  }
  /**
   * Token Viewset
   */
  coreTokensUpdateRaw(requestParameters, initOverrides) {
    return __awaiter2(this, void 0, void 0, function* () {
      if (requestParameters.identifier === null || requestParameters.identifier === void 0) {
        throw new RequiredError("identifier", "Required parameter requestParameters.identifier was null or undefined when calling coreTokensUpdate.");
      }
      if (requestParameters.tokenRequest === null || requestParameters.tokenRequest === void 0) {
        throw new RequiredError("tokenRequest", "Required parameter requestParameters.tokenRequest was null or undefined when calling coreTokensUpdate.");
      }
      const queryParameters = {};
      const headerParameters = {};
      headerParameters["Content-Type"] = "application/json";
      if (this.configuration && this.configuration.accessToken) {
        const token = this.configuration.accessToken;
        const tokenString = yield token("authentik", []);
        if (tokenString) {
          headerParameters["Authorization"] = `Bearer ${tokenString}`;
        }
      }
      const response = yield this.request({
        path: `/core/tokens/{identifier}/`.replace(`{${"identifier"}}`, encodeURIComponent(String(requestParameters.identifier))),
        method: "PUT",
        headers: headerParameters,
        query: queryParameters,
        body: TokenRequestToJSON(requestParameters.tokenRequest)
      }, initOverrides);
      return new JSONApiResponse(response, (jsonValue) => TokenFromJSON(jsonValue));
    });
  }
  /**
   * Token Viewset
   */
  coreTokensUpdate(requestParameters, initOverrides) {
    return __awaiter2(this, void 0, void 0, function* () {
      const response = yield this.coreTokensUpdateRaw(requestParameters, initOverrides);
      return yield response.value();
    });
  }
  /**
   * Get a list of all objects that use this object
   */
  coreTokensUsedByListRaw(requestParameters, initOverrides) {
    return __awaiter2(this, void 0, void 0, function* () {
      if (requestParameters.identifier === null || requestParameters.identifier === void 0) {
        throw new RequiredError("identifier", "Required parameter requestParameters.identifier was null or undefined when calling coreTokensUsedByList.");
      }
      const queryParameters = {};
      const headerParameters = {};
      if (this.configuration && this.configuration.accessToken) {
        const token = this.configuration.accessToken;
        const tokenString = yield token("authentik", []);
        if (tokenString) {
          headerParameters["Authorization"] = `Bearer ${tokenString}`;
        }
      }
      const response = yield this.request({
        path: `/core/tokens/{identifier}/used_by/`.replace(`{${"identifier"}}`, encodeURIComponent(String(requestParameters.identifier))),
        method: "GET",
        headers: headerParameters,
        query: queryParameters
      }, initOverrides);
      return new JSONApiResponse(response, (jsonValue) => jsonValue.map(UsedByFromJSON));
    });
  }
  /**
   * Get a list of all objects that use this object
   */
  coreTokensUsedByList(requestParameters, initOverrides) {
    return __awaiter2(this, void 0, void 0, function* () {
      const response = yield this.coreTokensUsedByListRaw(requestParameters, initOverrides);
      return yield response.value();
    });
  }
  /**
   * Return token key and log access
   */
  coreTokensViewKeyRetrieveRaw(requestParameters, initOverrides) {
    return __awaiter2(this, void 0, void 0, function* () {
      if (requestParameters.identifier === null || requestParameters.identifier === void 0) {
        throw new RequiredError("identifier", "Required parameter requestParameters.identifier was null or undefined when calling coreTokensViewKeyRetrieve.");
      }
      const queryParameters = {};
      const headerParameters = {};
      if (this.configuration && this.configuration.accessToken) {
        const token = this.configuration.accessToken;
        const tokenString = yield token("authentik", []);
        if (tokenString) {
          headerParameters["Authorization"] = `Bearer ${tokenString}`;
        }
      }
      const response = yield this.request({
        path: `/core/tokens/{identifier}/view_key/`.replace(`{${"identifier"}}`, encodeURIComponent(String(requestParameters.identifier))),
        method: "GET",
        headers: headerParameters,
        query: queryParameters
      }, initOverrides);
      return new JSONApiResponse(response, (jsonValue) => TokenViewFromJSON(jsonValue));
    });
  }
  /**
   * Return token key and log access
   */
  coreTokensViewKeyRetrieve(requestParameters, initOverrides) {
    return __awaiter2(this, void 0, void 0, function* () {
      const response = yield this.coreTokensViewKeyRetrieveRaw(requestParameters, initOverrides);
      return yield response.value();
    });
  }
  /**
   * Convert data into a blueprint, validate it and apply it
   */
  coreTransactionalApplicationsUpdateRaw(requestParameters, initOverrides) {
    return __awaiter2(this, void 0, void 0, function* () {
      if (requestParameters.transactionApplicationRequest === null || requestParameters.transactionApplicationRequest === void 0) {
        throw new RequiredError("transactionApplicationRequest", "Required parameter requestParameters.transactionApplicationRequest was null or undefined when calling coreTransactionalApplicationsUpdate.");
      }
      const queryParameters = {};
      const headerParameters = {};
      headerParameters["Content-Type"] = "application/json";
      if (this.configuration && this.configuration.accessToken) {
        const token = this.configuration.accessToken;
        const tokenString = yield token("authentik", []);
        if (tokenString) {
          headerParameters["Authorization"] = `Bearer ${tokenString}`;
        }
      }
      const response = yield this.request({
        path: `/core/transactional/applications/`,
        method: "PUT",
        headers: headerParameters,
        query: queryParameters,
        body: TransactionApplicationRequestToJSON(requestParameters.transactionApplicationRequest)
      }, initOverrides);
      return new JSONApiResponse(response, (jsonValue) => TransactionApplicationResponseFromJSON(jsonValue));
    });
  }
  /**
   * Convert data into a blueprint, validate it and apply it
   */
  coreTransactionalApplicationsUpdate(requestParameters, initOverrides) {
    return __awaiter2(this, void 0, void 0, function* () {
      const response = yield this.coreTransactionalApplicationsUpdateRaw(requestParameters, initOverrides);
      return yield response.value();
    });
  }
  /**
   * UserConsent Viewset
   */
  coreUserConsentDestroyRaw(requestParameters, initOverrides) {
    return __awaiter2(this, void 0, void 0, function* () {
      if (requestParameters.id === null || requestParameters.id === void 0) {
        throw new RequiredError("id", "Required parameter requestParameters.id was null or undefined when calling coreUserConsentDestroy.");
      }
      const queryParameters = {};
      const headerParameters = {};
      if (this.configuration && this.configuration.accessToken) {
        const token = this.configuration.accessToken;
        const tokenString = yield token("authentik", []);
        if (tokenString) {
          headerParameters["Authorization"] = `Bearer ${tokenString}`;
        }
      }
      const response = yield this.request({
        path: `/core/user_consent/{id}/`.replace(`{${"id"}}`, encodeURIComponent(String(requestParameters.id))),
        method: "DELETE",
        headers: headerParameters,
        query: queryParameters
      }, initOverrides);
      return new VoidApiResponse(response);
    });
  }
  /**
   * UserConsent Viewset
   */
  coreUserConsentDestroy(requestParameters, initOverrides) {
    return __awaiter2(this, void 0, void 0, function* () {
      yield this.coreUserConsentDestroyRaw(requestParameters, initOverrides);
    });
  }
  /**
   * UserConsent Viewset
   */
  coreUserConsentListRaw(requestParameters, initOverrides) {
    return __awaiter2(this, void 0, void 0, function* () {
      const queryParameters = {};
      if (requestParameters.application !== void 0) {
        queryParameters["application"] = requestParameters.application;
      }
      if (requestParameters.ordering !== void 0) {
        queryParameters["ordering"] = requestParameters.ordering;
      }
      if (requestParameters.page !== void 0) {
        queryParameters["page"] = requestParameters.page;
      }
      if (requestParameters.pageSize !== void 0) {
        queryParameters["page_size"] = requestParameters.pageSize;
      }
      if (requestParameters.search !== void 0) {
        queryParameters["search"] = requestParameters.search;
      }
      if (requestParameters.user !== void 0) {
        queryParameters["user"] = requestParameters.user;
      }
      const headerParameters = {};
      if (this.configuration && this.configuration.accessToken) {
        const token = this.configuration.accessToken;
        const tokenString = yield token("authentik", []);
        if (tokenString) {
          headerParameters["Authorization"] = `Bearer ${tokenString}`;
        }
      }
      const response = yield this.request({
        path: `/core/user_consent/`,
        method: "GET",
        headers: headerParameters,
        query: queryParameters
      }, initOverrides);
      return new JSONApiResponse(response, (jsonValue) => PaginatedUserConsentListFromJSON(jsonValue));
    });
  }
  /**
   * UserConsent Viewset
   */
  coreUserConsentList(requestParameters = {}, initOverrides) {
    return __awaiter2(this, void 0, void 0, function* () {
      const response = yield this.coreUserConsentListRaw(requestParameters, initOverrides);
      return yield response.value();
    });
  }
  /**
   * UserConsent Viewset
   */
  coreUserConsentRetrieveRaw(requestParameters, initOverrides) {
    return __awaiter2(this, void 0, void 0, function* () {
      if (requestParameters.id === null || requestParameters.id === void 0) {
        throw new RequiredError("id", "Required parameter requestParameters.id was null or undefined when calling coreUserConsentRetrieve.");
      }
      const queryParameters = {};
      const headerParameters = {};
      if (this.configuration && this.configuration.accessToken) {
        const token = this.configuration.accessToken;
        const tokenString = yield token("authentik", []);
        if (tokenString) {
          headerParameters["Authorization"] = `Bearer ${tokenString}`;
        }
      }
      const response = yield this.request({
        path: `/core/user_consent/{id}/`.replace(`{${"id"}}`, encodeURIComponent(String(requestParameters.id))),
        method: "GET",
        headers: headerParameters,
        query: queryParameters
      }, initOverrides);
      return new JSONApiResponse(response, (jsonValue) => UserConsentFromJSON(jsonValue));
    });
  }
  /**
   * UserConsent Viewset
   */
  coreUserConsentRetrieve(requestParameters, initOverrides) {
    return __awaiter2(this, void 0, void 0, function* () {
      const response = yield this.coreUserConsentRetrieveRaw(requestParameters, initOverrides);
      return yield response.value();
    });
  }
  /**
   * Get a list of all objects that use this object
   */
  coreUserConsentUsedByListRaw(requestParameters, initOverrides) {
    return __awaiter2(this, void 0, void 0, function* () {
      if (requestParameters.id === null || requestParameters.id === void 0) {
        throw new RequiredError("id", "Required parameter requestParameters.id was null or undefined when calling coreUserConsentUsedByList.");
      }
      const queryParameters = {};
      const headerParameters = {};
      if (this.configuration && this.configuration.accessToken) {
        const token = this.configuration.accessToken;
        const tokenString = yield token("authentik", []);
        if (tokenString) {
          headerParameters["Authorization"] = `Bearer ${tokenString}`;
        }
      }
      const response = yield this.request({
        path: `/core/user_consent/{id}/used_by/`.replace(`{${"id"}}`, encodeURIComponent(String(requestParameters.id))),
        method: "GET",
        headers: headerParameters,
        query: queryParameters
      }, initOverrides);
      return new JSONApiResponse(response, (jsonValue) => jsonValue.map(UsedByFromJSON));
    });
  }
  /**
   * Get a list of all objects that use this object
   */
  coreUserConsentUsedByList(requestParameters, initOverrides) {
    return __awaiter2(this, void 0, void 0, function* () {
      const response = yield this.coreUserConsentUsedByListRaw(requestParameters, initOverrides);
      return yield response.value();
    });
  }
  /**
   * User Viewset
   */
  coreUsersCreateRaw(requestParameters, initOverrides) {
    return __awaiter2(this, void 0, void 0, function* () {
      if (requestParameters.userRequest === null || requestParameters.userRequest === void 0) {
        throw new RequiredError("userRequest", "Required parameter requestParameters.userRequest was null or undefined when calling coreUsersCreate.");
      }
      const queryParameters = {};
      const headerParameters = {};
      headerParameters["Content-Type"] = "application/json";
      if (this.configuration && this.configuration.accessToken) {
        const token = this.configuration.accessToken;
        const tokenString = yield token("authentik", []);
        if (tokenString) {
          headerParameters["Authorization"] = `Bearer ${tokenString}`;
        }
      }
      const response = yield this.request({
        path: `/core/users/`,
        method: "POST",
        headers: headerParameters,
        query: queryParameters,
        body: UserRequestToJSON(requestParameters.userRequest)
      }, initOverrides);
      return new JSONApiResponse(response, (jsonValue) => UserFromJSON(jsonValue));
    });
  }
  /**
   * User Viewset
   */
  coreUsersCreate(requestParameters, initOverrides) {
    return __awaiter2(this, void 0, void 0, function* () {
      const response = yield this.coreUsersCreateRaw(requestParameters, initOverrides);
      return yield response.value();
    });
  }
  /**
   * User Viewset
   */
  coreUsersDestroyRaw(requestParameters, initOverrides) {
    return __awaiter2(this, void 0, void 0, function* () {
      if (requestParameters.id === null || requestParameters.id === void 0) {
        throw new RequiredError("id", "Required parameter requestParameters.id was null or undefined when calling coreUsersDestroy.");
      }
      const queryParameters = {};
      const headerParameters = {};
      if (this.configuration && this.configuration.accessToken) {
        const token = this.configuration.accessToken;
        const tokenString = yield token("authentik", []);
        if (tokenString) {
          headerParameters["Authorization"] = `Bearer ${tokenString}`;
        }
      }
      const response = yield this.request({
        path: `/core/users/{id}/`.replace(`{${"id"}}`, encodeURIComponent(String(requestParameters.id))),
        method: "DELETE",
        headers: headerParameters,
        query: queryParameters
      }, initOverrides);
      return new VoidApiResponse(response);
    });
  }
  /**
   * User Viewset
   */
  coreUsersDestroy(requestParameters, initOverrides) {
    return __awaiter2(this, void 0, void 0, function* () {
      yield this.coreUsersDestroyRaw(requestParameters, initOverrides);
    });
  }
  /**
   * Impersonate a user
   */
  coreUsersImpersonateCreateRaw(requestParameters, initOverrides) {
    return __awaiter2(this, void 0, void 0, function* () {
      if (requestParameters.id === null || requestParameters.id === void 0) {
        throw new RequiredError("id", "Required parameter requestParameters.id was null or undefined when calling coreUsersImpersonateCreate.");
      }
      const queryParameters = {};
      const headerParameters = {};
      if (this.configuration && this.configuration.accessToken) {
        const token = this.configuration.accessToken;
        const tokenString = yield token("authentik", []);
        if (tokenString) {
          headerParameters["Authorization"] = `Bearer ${tokenString}`;
        }
      }
      const response = yield this.request({
        path: `/core/users/{id}/impersonate/`.replace(`{${"id"}}`, encodeURIComponent(String(requestParameters.id))),
        method: "POST",
        headers: headerParameters,
        query: queryParameters
      }, initOverrides);
      return new VoidApiResponse(response);
    });
  }
  /**
   * Impersonate a user
   */
  coreUsersImpersonateCreate(requestParameters, initOverrides) {
    return __awaiter2(this, void 0, void 0, function* () {
      yield this.coreUsersImpersonateCreateRaw(requestParameters, initOverrides);
    });
  }
  /**
   * End Impersonation a user
   */
  coreUsersImpersonateEndRetrieveRaw(initOverrides) {
    return __awaiter2(this, void 0, void 0, function* () {
      const queryParameters = {};
      const headerParameters = {};
      if (this.configuration && this.configuration.accessToken) {
        const token = this.configuration.accessToken;
        const tokenString = yield token("authentik", []);
        if (tokenString) {
          headerParameters["Authorization"] = `Bearer ${tokenString}`;
        }
      }
      const response = yield this.request({
        path: `/core/users/impersonate_end/`,
        method: "GET",
        headers: headerParameters,
        query: queryParameters
      }, initOverrides);
      return new VoidApiResponse(response);
    });
  }
  /**
   * End Impersonation a user
   */
  coreUsersImpersonateEndRetrieve(initOverrides) {
    return __awaiter2(this, void 0, void 0, function* () {
      yield this.coreUsersImpersonateEndRetrieveRaw(initOverrides);
    });
  }
  /**
   * User Viewset
   */
  coreUsersListRaw(requestParameters, initOverrides) {
    return __awaiter2(this, void 0, void 0, function* () {
      const queryParameters = {};
      if (requestParameters.attributes !== void 0) {
        queryParameters["attributes"] = requestParameters.attributes;
      }
      if (requestParameters.email !== void 0) {
        queryParameters["email"] = requestParameters.email;
      }
      if (requestParameters.groupsByName) {
        queryParameters["groups_by_name"] = requestParameters.groupsByName;
      }
      if (requestParameters.groupsByPk) {
        queryParameters["groups_by_pk"] = requestParameters.groupsByPk;
      }
      if (requestParameters.includeGroups !== void 0) {
        queryParameters["include_groups"] = requestParameters.includeGroups;
      }
      if (requestParameters.isActive !== void 0) {
        queryParameters["is_active"] = requestParameters.isActive;
      }
      if (requestParameters.isSuperuser !== void 0) {
        queryParameters["is_superuser"] = requestParameters.isSuperuser;
      }
      if (requestParameters.name !== void 0) {
        queryParameters["name"] = requestParameters.name;
      }
      if (requestParameters.ordering !== void 0) {
        queryParameters["ordering"] = requestParameters.ordering;
      }
      if (requestParameters.page !== void 0) {
        queryParameters["page"] = requestParameters.page;
      }
      if (requestParameters.pageSize !== void 0) {
        queryParameters["page_size"] = requestParameters.pageSize;
      }
      if (requestParameters.path !== void 0) {
        queryParameters["path"] = requestParameters.path;
      }
      if (requestParameters.pathStartswith !== void 0) {
        queryParameters["path_startswith"] = requestParameters.pathStartswith;
      }
      if (requestParameters.search !== void 0) {
        queryParameters["search"] = requestParameters.search;
      }
      if (requestParameters.type) {
        queryParameters["type"] = requestParameters.type;
      }
      if (requestParameters.username !== void 0) {
        queryParameters["username"] = requestParameters.username;
      }
      if (requestParameters.uuid !== void 0) {
        queryParameters["uuid"] = requestParameters.uuid;
      }
      const headerParameters = {};
      if (this.configuration && this.configuration.accessToken) {
        const token = this.configuration.accessToken;
        const tokenString = yield token("authentik", []);
        if (tokenString) {
          headerParameters["Authorization"] = `Bearer ${tokenString}`;
        }
      }
      const response = yield this.request({
        path: `/core/users/`,
        method: "GET",
        headers: headerParameters,
        query: queryParameters
      }, initOverrides);
      return new JSONApiResponse(response, (jsonValue) => PaginatedUserListFromJSON(jsonValue));
    });
  }
  /**
   * User Viewset
   */
  coreUsersList(requestParameters = {}, initOverrides) {
    return __awaiter2(this, void 0, void 0, function* () {
      const response = yield this.coreUsersListRaw(requestParameters, initOverrides);
      return yield response.value();
    });
  }
  /**
   * Get information about current user
   */
  coreUsersMeRetrieveRaw(initOverrides) {
    return __awaiter2(this, void 0, void 0, function* () {
      const queryParameters = {};
      const headerParameters = {};
      if (this.configuration && this.configuration.accessToken) {
        const token = this.configuration.accessToken;
        const tokenString = yield token("authentik", []);
        if (tokenString) {
          headerParameters["Authorization"] = `Bearer ${tokenString}`;
        }
      }
      const response = yield this.request({
        path: `/core/users/me/`,
        method: "GET",
        headers: headerParameters,
        query: queryParameters
      }, initOverrides);
      return new JSONApiResponse(response, (jsonValue) => SessionUserFromJSON(jsonValue));
    });
  }
  /**
   * Get information about current user
   */
  coreUsersMeRetrieve(initOverrides) {
    return __awaiter2(this, void 0, void 0, function* () {
      const response = yield this.coreUsersMeRetrieveRaw(initOverrides);
      return yield response.value();
    });
  }
  /**
   * User metrics per 1h
   */
  coreUsersMetricsRetrieveRaw(requestParameters, initOverrides) {
    return __awaiter2(this, void 0, void 0, function* () {
      if (requestParameters.id === null || requestParameters.id === void 0) {
        throw new RequiredError("id", "Required parameter requestParameters.id was null or undefined when calling coreUsersMetricsRetrieve.");
      }
      const queryParameters = {};
      const headerParameters = {};
      if (this.configuration && this.configuration.accessToken) {
        const token = this.configuration.accessToken;
        const tokenString = yield token("authentik", []);
        if (tokenString) {
          headerParameters["Authorization"] = `Bearer ${tokenString}`;
        }
      }
      const response = yield this.request({
        path: `/core/users/{id}/metrics/`.replace(`{${"id"}}`, encodeURIComponent(String(requestParameters.id))),
        method: "GET",
        headers: headerParameters,
        query: queryParameters
      }, initOverrides);
      return new JSONApiResponse(response, (jsonValue) => UserMetricsFromJSON(jsonValue));
    });
  }
  /**
   * User metrics per 1h
   */
  coreUsersMetricsRetrieve(requestParameters, initOverrides) {
    return __awaiter2(this, void 0, void 0, function* () {
      const response = yield this.coreUsersMetricsRetrieveRaw(requestParameters, initOverrides);
      return yield response.value();
    });
  }
  /**
   * User Viewset
   */
  coreUsersPartialUpdateRaw(requestParameters, initOverrides) {
    return __awaiter2(this, void 0, void 0, function* () {
      if (requestParameters.id === null || requestParameters.id === void 0) {
        throw new RequiredError("id", "Required parameter requestParameters.id was null or undefined when calling coreUsersPartialUpdate.");
      }
      const queryParameters = {};
      const headerParameters = {};
      headerParameters["Content-Type"] = "application/json";
      if (this.configuration && this.configuration.accessToken) {
        const token = this.configuration.accessToken;
        const tokenString = yield token("authentik", []);
        if (tokenString) {
          headerParameters["Authorization"] = `Bearer ${tokenString}`;
        }
      }
      const response = yield this.request({
        path: `/core/users/{id}/`.replace(`{${"id"}}`, encodeURIComponent(String(requestParameters.id))),
        method: "PATCH",
        headers: headerParameters,
        query: queryParameters,
        body: PatchedUserRequestToJSON(requestParameters.patchedUserRequest)
      }, initOverrides);
      return new JSONApiResponse(response, (jsonValue) => UserFromJSON(jsonValue));
    });
  }
  /**
   * User Viewset
   */
  coreUsersPartialUpdate(requestParameters, initOverrides) {
    return __awaiter2(this, void 0, void 0, function* () {
      const response = yield this.coreUsersPartialUpdateRaw(requestParameters, initOverrides);
      return yield response.value();
    });
  }
  /**
   * Get all user paths
   */
  coreUsersPathsRetrieveRaw(requestParameters, initOverrides) {
    return __awaiter2(this, void 0, void 0, function* () {
      const queryParameters = {};
      if (requestParameters.search !== void 0) {
        queryParameters["search"] = requestParameters.search;
      }
      const headerParameters = {};
      if (this.configuration && this.configuration.accessToken) {
        const token = this.configuration.accessToken;
        const tokenString = yield token("authentik", []);
        if (tokenString) {
          headerParameters["Authorization"] = `Bearer ${tokenString}`;
        }
      }
      const response = yield this.request({
        path: `/core/users/paths/`,
        method: "GET",
        headers: headerParameters,
        query: queryParameters
      }, initOverrides);
      return new JSONApiResponse(response, (jsonValue) => UserPathFromJSON(jsonValue));
    });
  }
  /**
   * Get all user paths
   */
  coreUsersPathsRetrieve(requestParameters = {}, initOverrides) {
    return __awaiter2(this, void 0, void 0, function* () {
      const response = yield this.coreUsersPathsRetrieveRaw(requestParameters, initOverrides);
      return yield response.value();
    });
  }
  /**
   * Create a temporary link that a user can use to recover their accounts
   */
  coreUsersRecoveryCreateRaw(requestParameters, initOverrides) {
    return __awaiter2(this, void 0, void 0, function* () {
      if (requestParameters.id === null || requestParameters.id === void 0) {
        throw new RequiredError("id", "Required parameter requestParameters.id was null or undefined when calling coreUsersRecoveryCreate.");
      }
      const queryParameters = {};
      const headerParameters = {};
      if (this.configuration && this.configuration.accessToken) {
        const token = this.configuration.accessToken;
        const tokenString = yield token("authentik", []);
        if (tokenString) {
          headerParameters["Authorization"] = `Bearer ${tokenString}`;
        }
      }
      const response = yield this.request({
        path: `/core/users/{id}/recovery/`.replace(`{${"id"}}`, encodeURIComponent(String(requestParameters.id))),
        method: "POST",
        headers: headerParameters,
        query: queryParameters
      }, initOverrides);
      return new JSONApiResponse(response, (jsonValue) => LinkFromJSON(jsonValue));
    });
  }
  /**
   * Create a temporary link that a user can use to recover their accounts
   */
  coreUsersRecoveryCreate(requestParameters, initOverrides) {
    return __awaiter2(this, void 0, void 0, function* () {
      const response = yield this.coreUsersRecoveryCreateRaw(requestParameters, initOverrides);
      return yield response.value();
    });
  }
  /**
   * Create a temporary link that a user can use to recover their accounts
   */
  coreUsersRecoveryEmailCreateRaw(requestParameters, initOverrides) {
    return __awaiter2(this, void 0, void 0, function* () {
      if (requestParameters.emailStage === null || requestParameters.emailStage === void 0) {
        throw new RequiredError("emailStage", "Required parameter requestParameters.emailStage was null or undefined when calling coreUsersRecoveryEmailCreate.");
      }
      if (requestParameters.id === null || requestParameters.id === void 0) {
        throw new RequiredError("id", "Required parameter requestParameters.id was null or undefined when calling coreUsersRecoveryEmailCreate.");
      }
      const queryParameters = {};
      if (requestParameters.emailStage !== void 0) {
        queryParameters["email_stage"] = requestParameters.emailStage;
      }
      const headerParameters = {};
      if (this.configuration && this.configuration.accessToken) {
        const token = this.configuration.accessToken;
        const tokenString = yield token("authentik", []);
        if (tokenString) {
          headerParameters["Authorization"] = `Bearer ${tokenString}`;
        }
      }
      const response = yield this.request({
        path: `/core/users/{id}/recovery_email/`.replace(`{${"id"}}`, encodeURIComponent(String(requestParameters.id))),
        method: "POST",
        headers: headerParameters,
        query: queryParameters
      }, initOverrides);
      return new VoidApiResponse(response);
    });
  }
  /**
   * Create a temporary link that a user can use to recover their accounts
   */
  coreUsersRecoveryEmailCreate(requestParameters, initOverrides) {
    return __awaiter2(this, void 0, void 0, function* () {
      yield this.coreUsersRecoveryEmailCreateRaw(requestParameters, initOverrides);
    });
  }
  /**
   * User Viewset
   */
  coreUsersRetrieveRaw(requestParameters, initOverrides) {
    return __awaiter2(this, void 0, void 0, function* () {
      if (requestParameters.id === null || requestParameters.id === void 0) {
        throw new RequiredError("id", "Required parameter requestParameters.id was null or undefined when calling coreUsersRetrieve.");
      }
      const queryParameters = {};
      const headerParameters = {};
      if (this.configuration && this.configuration.accessToken) {
        const token = this.configuration.accessToken;
        const tokenString = yield token("authentik", []);
        if (tokenString) {
          headerParameters["Authorization"] = `Bearer ${tokenString}`;
        }
      }
      const response = yield this.request({
        path: `/core/users/{id}/`.replace(`{${"id"}}`, encodeURIComponent(String(requestParameters.id))),
        method: "GET",
        headers: headerParameters,
        query: queryParameters
      }, initOverrides);
      return new JSONApiResponse(response, (jsonValue) => UserFromJSON(jsonValue));
    });
  }
  /**
   * User Viewset
   */
  coreUsersRetrieve(requestParameters, initOverrides) {
    return __awaiter2(this, void 0, void 0, function* () {
      const response = yield this.coreUsersRetrieveRaw(requestParameters, initOverrides);
      return yield response.value();
    });
  }
  /**
   * Create a new user account that is marked as a service account
   */
  coreUsersServiceAccountCreateRaw(requestParameters, initOverrides) {
    return __awaiter2(this, void 0, void 0, function* () {
      if (requestParameters.userServiceAccountRequest === null || requestParameters.userServiceAccountRequest === void 0) {
        throw new RequiredError("userServiceAccountRequest", "Required parameter requestParameters.userServiceAccountRequest was null or undefined when calling coreUsersServiceAccountCreate.");
      }
      const queryParameters = {};
      const headerParameters = {};
      headerParameters["Content-Type"] = "application/json";
      if (this.configuration && this.configuration.accessToken) {
        const token = this.configuration.accessToken;
        const tokenString = yield token("authentik", []);
        if (tokenString) {
          headerParameters["Authorization"] = `Bearer ${tokenString}`;
        }
      }
      const response = yield this.request({
        path: `/core/users/service_account/`,
        method: "POST",
        headers: headerParameters,
        query: queryParameters,
        body: UserServiceAccountRequestToJSON(requestParameters.userServiceAccountRequest)
      }, initOverrides);
      return new JSONApiResponse(response, (jsonValue) => UserServiceAccountResponseFromJSON(jsonValue));
    });
  }
  /**
   * Create a new user account that is marked as a service account
   */
  coreUsersServiceAccountCreate(requestParameters, initOverrides) {
    return __awaiter2(this, void 0, void 0, function* () {
      const response = yield this.coreUsersServiceAccountCreateRaw(requestParameters, initOverrides);
      return yield response.value();
    });
  }
  /**
   * Set password for user
   */
  coreUsersSetPasswordCreateRaw(requestParameters, initOverrides) {
    return __awaiter2(this, void 0, void 0, function* () {
      if (requestParameters.id === null || requestParameters.id === void 0) {
        throw new RequiredError("id", "Required parameter requestParameters.id was null or undefined when calling coreUsersSetPasswordCreate.");
      }
      if (requestParameters.userPasswordSetRequest === null || requestParameters.userPasswordSetRequest === void 0) {
        throw new RequiredError("userPasswordSetRequest", "Required parameter requestParameters.userPasswordSetRequest was null or undefined when calling coreUsersSetPasswordCreate.");
      }
      const queryParameters = {};
      const headerParameters = {};
      headerParameters["Content-Type"] = "application/json";
      if (this.configuration && this.configuration.accessToken) {
        const token = this.configuration.accessToken;
        const tokenString = yield token("authentik", []);
        if (tokenString) {
          headerParameters["Authorization"] = `Bearer ${tokenString}`;
        }
      }
      const response = yield this.request({
        path: `/core/users/{id}/set_password/`.replace(`{${"id"}}`, encodeURIComponent(String(requestParameters.id))),
        method: "POST",
        headers: headerParameters,
        query: queryParameters,
        body: UserPasswordSetRequestToJSON(requestParameters.userPasswordSetRequest)
      }, initOverrides);
      return new VoidApiResponse(response);
    });
  }
  /**
   * Set password for user
   */
  coreUsersSetPasswordCreate(requestParameters, initOverrides) {
    return __awaiter2(this, void 0, void 0, function* () {
      yield this.coreUsersSetPasswordCreateRaw(requestParameters, initOverrides);
    });
  }
  /**
   * User Viewset
   */
  coreUsersUpdateRaw(requestParameters, initOverrides) {
    return __awaiter2(this, void 0, void 0, function* () {
      if (requestParameters.id === null || requestParameters.id === void 0) {
        throw new RequiredError("id", "Required parameter requestParameters.id was null or undefined when calling coreUsersUpdate.");
      }
      if (requestParameters.userRequest === null || requestParameters.userRequest === void 0) {
        throw new RequiredError("userRequest", "Required parameter requestParameters.userRequest was null or undefined when calling coreUsersUpdate.");
      }
      const queryParameters = {};
      const headerParameters = {};
      headerParameters["Content-Type"] = "application/json";
      if (this.configuration && this.configuration.accessToken) {
        const token = this.configuration.accessToken;
        const tokenString = yield token("authentik", []);
        if (tokenString) {
          headerParameters["Authorization"] = `Bearer ${tokenString}`;
        }
      }
      const response = yield this.request({
        path: `/core/users/{id}/`.replace(`{${"id"}}`, encodeURIComponent(String(requestParameters.id))),
        method: "PUT",
        headers: headerParameters,
        query: queryParameters,
        body: UserRequestToJSON(requestParameters.userRequest)
      }, initOverrides);
      return new JSONApiResponse(response, (jsonValue) => UserFromJSON(jsonValue));
    });
  }
  /**
   * User Viewset
   */
  coreUsersUpdate(requestParameters, initOverrides) {
    return __awaiter2(this, void 0, void 0, function* () {
      const response = yield this.coreUsersUpdateRaw(requestParameters, initOverrides);
      return yield response.value();
    });
  }
  /**
   * Get a list of all objects that use this object
   */
  coreUsersUsedByListRaw(requestParameters, initOverrides) {
    return __awaiter2(this, void 0, void 0, function* () {
      if (requestParameters.id === null || requestParameters.id === void 0) {
        throw new RequiredError("id", "Required parameter requestParameters.id was null or undefined when calling coreUsersUsedByList.");
      }
      const queryParameters = {};
      const headerParameters = {};
      if (this.configuration && this.configuration.accessToken) {
        const token = this.configuration.accessToken;
        const tokenString = yield token("authentik", []);
        if (tokenString) {
          headerParameters["Authorization"] = `Bearer ${tokenString}`;
        }
      }
      const response = yield this.request({
        path: `/core/users/{id}/used_by/`.replace(`{${"id"}}`, encodeURIComponent(String(requestParameters.id))),
        method: "GET",
        headers: headerParameters,
        query: queryParameters
      }, initOverrides);
      return new JSONApiResponse(response, (jsonValue) => jsonValue.map(UsedByFromJSON));
    });
  }
  /**
   * Get a list of all objects that use this object
   */
  coreUsersUsedByList(requestParameters, initOverrides) {
    return __awaiter2(this, void 0, void 0, function* () {
      const response = yield this.coreUsersUsedByListRaw(requestParameters, initOverrides);
      return yield response.value();
    });
  }
};

// node_modules/@goauthentik/api/dist/esm/apis/EnterpriseApi.js
var __awaiter3 = function(thisArg, _arguments, P2, generator) {
  function adopt(value) {
    return value instanceof P2 ? value : new P2(function(resolve) {
      resolve(value);
    });
  }
  return new (P2 || (P2 = Promise))(function(resolve, reject) {
    function fulfilled(value) {
      try {
        step(generator.next(value));
      } catch (e7) {
        reject(e7);
      }
    }
    function rejected(value) {
      try {
        step(generator["throw"](value));
      } catch (e7) {
        reject(e7);
      }
    }
    function step(result) {
      result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected);
    }
    step((generator = generator.apply(thisArg, _arguments || [])).next());
  });
};
var EnterpriseApi = class extends BaseAPI {
  /**
   * License Viewset
   */
  enterpriseLicenseCreateRaw(requestParameters, initOverrides) {
    return __awaiter3(this, void 0, void 0, function* () {
      if (requestParameters.licenseRequest === null || requestParameters.licenseRequest === void 0) {
        throw new RequiredError("licenseRequest", "Required parameter requestParameters.licenseRequest was null or undefined when calling enterpriseLicenseCreate.");
      }
      const queryParameters = {};
      const headerParameters = {};
      headerParameters["Content-Type"] = "application/json";
      if (this.configuration && this.configuration.accessToken) {
        const token = this.configuration.accessToken;
        const tokenString = yield token("authentik", []);
        if (tokenString) {
          headerParameters["Authorization"] = `Bearer ${tokenString}`;
        }
      }
      const response = yield this.request({
        path: `/enterprise/license/`,
        method: "POST",
        headers: headerParameters,
        query: queryParameters,
        body: LicenseRequestToJSON(requestParameters.licenseRequest)
      }, initOverrides);
      return new JSONApiResponse(response, (jsonValue) => LicenseFromJSON(jsonValue));
    });
  }
  /**
   * License Viewset
   */
  enterpriseLicenseCreate(requestParameters, initOverrides) {
    return __awaiter3(this, void 0, void 0, function* () {
      const response = yield this.enterpriseLicenseCreateRaw(requestParameters, initOverrides);
      return yield response.value();
    });
  }
  /**
   * License Viewset
   */
  enterpriseLicenseDestroyRaw(requestParameters, initOverrides) {
    return __awaiter3(this, void 0, void 0, function* () {
      if (requestParameters.licenseUuid === null || requestParameters.licenseUuid === void 0) {
        throw new RequiredError("licenseUuid", "Required parameter requestParameters.licenseUuid was null or undefined when calling enterpriseLicenseDestroy.");
      }
      const queryParameters = {};
      const headerParameters = {};
      if (this.configuration && this.configuration.accessToken) {
        const token = this.configuration.accessToken;
        const tokenString = yield token("authentik", []);
        if (tokenString) {
          headerParameters["Authorization"] = `Bearer ${tokenString}`;
        }
      }
      const response = yield this.request({
        path: `/enterprise/license/{license_uuid}/`.replace(`{${"license_uuid"}}`, encodeURIComponent(String(requestParameters.licenseUuid))),
        method: "DELETE",
        headers: headerParameters,
        query: queryParameters
      }, initOverrides);
      return new VoidApiResponse(response);
    });
  }
  /**
   * License Viewset
   */
  enterpriseLicenseDestroy(requestParameters, initOverrides) {
    return __awaiter3(this, void 0, void 0, function* () {
      yield this.enterpriseLicenseDestroyRaw(requestParameters, initOverrides);
    });
  }
  /**
   * Forecast how many users will be required in a year
   */
  enterpriseLicenseForecastRetrieveRaw(initOverrides) {
    return __awaiter3(this, void 0, void 0, function* () {
      const queryParameters = {};
      const headerParameters = {};
      if (this.configuration && this.configuration.accessToken) {
        const token = this.configuration.accessToken;
        const tokenString = yield token("authentik", []);
        if (tokenString) {
          headerParameters["Authorization"] = `Bearer ${tokenString}`;
        }
      }
      const response = yield this.request({
        path: `/enterprise/license/forecast/`,
        method: "GET",
        headers: headerParameters,
        query: queryParameters
      }, initOverrides);
      return new JSONApiResponse(response, (jsonValue) => LicenseForecastFromJSON(jsonValue));
    });
  }
  /**
   * Forecast how many users will be required in a year
   */
  enterpriseLicenseForecastRetrieve(initOverrides) {
    return __awaiter3(this, void 0, void 0, function* () {
      const response = yield this.enterpriseLicenseForecastRetrieveRaw(initOverrides);
      return yield response.value();
    });
  }
  /**
   * Get install_id
   */
  enterpriseLicenseGetInstallIdRetrieveRaw(initOverrides) {
    return __awaiter3(this, void 0, void 0, function* () {
      const queryParameters = {};
      const headerParameters = {};
      if (this.configuration && this.configuration.accessToken) {
        const token = this.configuration.accessToken;
        const tokenString = yield token("authentik", []);
        if (tokenString) {
          headerParameters["Authorization"] = `Bearer ${tokenString}`;
        }
      }
      const response = yield this.request({
        path: `/enterprise/license/get_install_id/`,
        method: "GET",
        headers: headerParameters,
        query: queryParameters
      }, initOverrides);
      return new JSONApiResponse(response, (jsonValue) => InstallIDFromJSON(jsonValue));
    });
  }
  /**
   * Get install_id
   */
  enterpriseLicenseGetInstallIdRetrieve(initOverrides) {
    return __awaiter3(this, void 0, void 0, function* () {
      const response = yield this.enterpriseLicenseGetInstallIdRetrieveRaw(initOverrides);
      return yield response.value();
    });
  }
  /**
   * License Viewset
   */
  enterpriseLicenseListRaw(requestParameters, initOverrides) {
    return __awaiter3(this, void 0, void 0, function* () {
      const queryParameters = {};
      if (requestParameters.name !== void 0) {
        queryParameters["name"] = requestParameters.name;
      }
      if (requestParameters.ordering !== void 0) {
        queryParameters["ordering"] = requestParameters.ordering;
      }
      if (requestParameters.page !== void 0) {
        queryParameters["page"] = requestParameters.page;
      }
      if (requestParameters.pageSize !== void 0) {
        queryParameters["page_size"] = requestParameters.pageSize;
      }
      if (requestParameters.search !== void 0) {
        queryParameters["search"] = requestParameters.search;
      }
      const headerParameters = {};
      if (this.configuration && this.configuration.accessToken) {
        const token = this.configuration.accessToken;
        const tokenString = yield token("authentik", []);
        if (tokenString) {
          headerParameters["Authorization"] = `Bearer ${tokenString}`;
        }
      }
      const response = yield this.request({
        path: `/enterprise/license/`,
        method: "GET",
        headers: headerParameters,
        query: queryParameters
      }, initOverrides);
      return new JSONApiResponse(response, (jsonValue) => PaginatedLicenseListFromJSON(jsonValue));
    });
  }
  /**
   * License Viewset
   */
  enterpriseLicenseList(requestParameters = {}, initOverrides) {
    return __awaiter3(this, void 0, void 0, function* () {
      const response = yield this.enterpriseLicenseListRaw(requestParameters, initOverrides);
      return yield response.value();
    });
  }
  /**
   * License Viewset
   */
  enterpriseLicensePartialUpdateRaw(requestParameters, initOverrides) {
    return __awaiter3(this, void 0, void 0, function* () {
      if (requestParameters.licenseUuid === null || requestParameters.licenseUuid === void 0) {
        throw new RequiredError("licenseUuid", "Required parameter requestParameters.licenseUuid was null or undefined when calling enterpriseLicensePartialUpdate.");
      }
      const queryParameters = {};
      const headerParameters = {};
      headerParameters["Content-Type"] = "application/json";
      if (this.configuration && this.configuration.accessToken) {
        const token = this.configuration.accessToken;
        const tokenString = yield token("authentik", []);
        if (tokenString) {
          headerParameters["Authorization"] = `Bearer ${tokenString}`;
        }
      }
      const response = yield this.request({
        path: `/enterprise/license/{license_uuid}/`.replace(`{${"license_uuid"}}`, encodeURIComponent(String(requestParameters.licenseUuid))),
        method: "PATCH",
        headers: headerParameters,
        query: queryParameters,
        body: PatchedLicenseRequestToJSON(requestParameters.patchedLicenseRequest)
      }, initOverrides);
      return new JSONApiResponse(response, (jsonValue) => LicenseFromJSON(jsonValue));
    });
  }
  /**
   * License Viewset
   */
  enterpriseLicensePartialUpdate(requestParameters, initOverrides) {
    return __awaiter3(this, void 0, void 0, function* () {
      const response = yield this.enterpriseLicensePartialUpdateRaw(requestParameters, initOverrides);
      return yield response.value();
    });
  }
  /**
   * License Viewset
   */
  enterpriseLicenseRetrieveRaw(requestParameters, initOverrides) {
    return __awaiter3(this, void 0, void 0, function* () {
      if (requestParameters.licenseUuid === null || requestParameters.licenseUuid === void 0) {
        throw new RequiredError("licenseUuid", "Required parameter requestParameters.licenseUuid was null or undefined when calling enterpriseLicenseRetrieve.");
      }
      const queryParameters = {};
      const headerParameters = {};
      if (this.configuration && this.configuration.accessToken) {
        const token = this.configuration.accessToken;
        const tokenString = yield token("authentik", []);
        if (tokenString) {
          headerParameters["Authorization"] = `Bearer ${tokenString}`;
        }
      }
      const response = yield this.request({
        path: `/enterprise/license/{license_uuid}/`.replace(`{${"license_uuid"}}`, encodeURIComponent(String(requestParameters.licenseUuid))),
        method: "GET",
        headers: headerParameters,
        query: queryParameters
      }, initOverrides);
      return new JSONApiResponse(response, (jsonValue) => LicenseFromJSON(jsonValue));
    });
  }
  /**
   * License Viewset
   */
  enterpriseLicenseRetrieve(requestParameters, initOverrides) {
    return __awaiter3(this, void 0, void 0, function* () {
      const response = yield this.enterpriseLicenseRetrieveRaw(requestParameters, initOverrides);
      return yield response.value();
    });
  }
  /**
   * Get the total license status
   */
  enterpriseLicenseSummaryRetrieveRaw(initOverrides) {
    return __awaiter3(this, void 0, void 0, function* () {
      const queryParameters = {};
      const headerParameters = {};
      if (this.configuration && this.configuration.accessToken) {
        const token = this.configuration.accessToken;
        const tokenString = yield token("authentik", []);
        if (tokenString) {
          headerParameters["Authorization"] = `Bearer ${tokenString}`;
        }
      }
      const response = yield this.request({
        path: `/enterprise/license/summary/`,
        method: "GET",
        headers: headerParameters,
        query: queryParameters
      }, initOverrides);
      return new JSONApiResponse(response, (jsonValue) => LicenseSummaryFromJSON(jsonValue));
    });
  }
  /**
   * Get the total license status
   */
  enterpriseLicenseSummaryRetrieve(initOverrides) {
    return __awaiter3(this, void 0, void 0, function* () {
      const response = yield this.enterpriseLicenseSummaryRetrieveRaw(initOverrides);
      return yield response.value();
    });
  }
  /**
   * License Viewset
   */
  enterpriseLicenseUpdateRaw(requestParameters, initOverrides) {
    return __awaiter3(this, void 0, void 0, function* () {
      if (requestParameters.licenseUuid === null || requestParameters.licenseUuid === void 0) {
        throw new RequiredError("licenseUuid", "Required parameter requestParameters.licenseUuid was null or undefined when calling enterpriseLicenseUpdate.");
      }
      if (requestParameters.licenseRequest === null || requestParameters.licenseRequest === void 0) {
        throw new RequiredError("licenseRequest", "Required parameter requestParameters.licenseRequest was null or undefined when calling enterpriseLicenseUpdate.");
      }
      const queryParameters = {};
      const headerParameters = {};
      headerParameters["Content-Type"] = "application/json";
      if (this.configuration && this.configuration.accessToken) {
        const token = this.configuration.accessToken;
        const tokenString = yield token("authentik", []);
        if (tokenString) {
          headerParameters["Authorization"] = `Bearer ${tokenString}`;
        }
      }
      const response = yield this.request({
        path: `/enterprise/license/{license_uuid}/`.replace(`{${"license_uuid"}}`, encodeURIComponent(String(requestParameters.licenseUuid))),
        method: "PUT",
        headers: headerParameters,
        query: queryParameters,
        body: LicenseRequestToJSON(requestParameters.licenseRequest)
      }, initOverrides);
      return new JSONApiResponse(response, (jsonValue) => LicenseFromJSON(jsonValue));
    });
  }
  /**
   * License Viewset
   */
  enterpriseLicenseUpdate(requestParameters, initOverrides) {
    return __awaiter3(this, void 0, void 0, function* () {
      const response = yield this.enterpriseLicenseUpdateRaw(requestParameters, initOverrides);
      return yield response.value();
    });
  }
  /**
   * Get a list of all objects that use this object
   */
  enterpriseLicenseUsedByListRaw(requestParameters, initOverrides) {
    return __awaiter3(this, void 0, void 0, function* () {
      if (requestParameters.licenseUuid === null || requestParameters.licenseUuid === void 0) {
        throw new RequiredError("licenseUuid", "Required parameter requestParameters.licenseUuid was null or undefined when calling enterpriseLicenseUsedByList.");
      }
      const queryParameters = {};
      const headerParameters = {};
      if (this.configuration && this.configuration.accessToken) {
        const token = this.configuration.accessToken;
        const tokenString = yield token("authentik", []);
        if (tokenString) {
          headerParameters["Authorization"] = `Bearer ${tokenString}`;
        }
      }
      const response = yield this.request({
        path: `/enterprise/license/{license_uuid}/used_by/`.replace(`{${"license_uuid"}}`, encodeURIComponent(String(requestParameters.licenseUuid))),
        method: "GET",
        headers: headerParameters,
        query: queryParameters
      }, initOverrides);
      return new JSONApiResponse(response, (jsonValue) => jsonValue.map(UsedByFromJSON));
    });
  }
  /**
   * Get a list of all objects that use this object
   */
  enterpriseLicenseUsedByList(requestParameters, initOverrides) {
    return __awaiter3(this, void 0, void 0, function* () {
      const response = yield this.enterpriseLicenseUsedByListRaw(requestParameters, initOverrides);
      return yield response.value();
    });
  }
};

// node_modules/@goauthentik/api/dist/esm/apis/RootApi.js
var __awaiter4 = function(thisArg, _arguments, P2, generator) {
  function adopt(value) {
    return value instanceof P2 ? value : new P2(function(resolve) {
      resolve(value);
    });
  }
  return new (P2 || (P2 = Promise))(function(resolve, reject) {
    function fulfilled(value) {
      try {
        step(generator.next(value));
      } catch (e7) {
        reject(e7);
      }
    }
    function rejected(value) {
      try {
        step(generator["throw"](value));
      } catch (e7) {
        reject(e7);
      }
    }
    function step(result) {
      result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected);
    }
    step((generator = generator.apply(thisArg, _arguments || [])).next());
  });
};
var RootApi = class extends BaseAPI {
  /**
   * Retrieve public configuration options
   */
  rootConfigRetrieveRaw(initOverrides) {
    return __awaiter4(this, void 0, void 0, function* () {
      const queryParameters = {};
      const headerParameters = {};
      if (this.configuration && this.configuration.accessToken) {
        const token = this.configuration.accessToken;
        const tokenString = yield token("authentik", []);
        if (tokenString) {
          headerParameters["Authorization"] = `Bearer ${tokenString}`;
        }
      }
      const response = yield this.request({
        path: `/root/config/`,
        method: "GET",
        headers: headerParameters,
        query: queryParameters
      }, initOverrides);
      return new JSONApiResponse(response, (jsonValue) => ConfigFromJSON(jsonValue));
    });
  }
  /**
   * Retrieve public configuration options
   */
  rootConfigRetrieve(initOverrides) {
    return __awaiter4(this, void 0, void 0, function* () {
      const response = yield this.rootConfigRetrieveRaw(initOverrides);
      return yield response.value();
    });
  }
};

// node_modules/@lit/reactive-element/css-tag.js
var t = globalThis;
var e = t.ShadowRoot && (void 0 === t.ShadyCSS || t.ShadyCSS.nativeShadow) && "adoptedStyleSheets" in Document.prototype && "replace" in CSSStyleSheet.prototype;
var s = Symbol();
var o = /* @__PURE__ */ new WeakMap();
var n = class {
  constructor(t5, e7, o5) {
    if (this._$cssResult$ = true, o5 !== s)
      throw Error("CSSResult is not constructable. Use `unsafeCSS` or `css` instead.");
    this.cssText = t5, this.t = e7;
  }
  get styleSheet() {
    let t5 = this.o;
    const s7 = this.t;
    if (e && void 0 === t5) {
      const e7 = void 0 !== s7 && 1 === s7.length;
      e7 && (t5 = o.get(s7)), void 0 === t5 && ((this.o = t5 = new CSSStyleSheet()).replaceSync(this.cssText), e7 && o.set(s7, t5));
    }
    return t5;
  }
  toString() {
    return this.cssText;
  }
};
var r = (t5) => new n("string" == typeof t5 ? t5 : t5 + "", void 0, s);
var i = (t5, ...e7) => {
  const o5 = 1 === t5.length ? t5[0] : e7.reduce((e8, s7, o6) => e8 + ((t6) => {
    if (true === t6._$cssResult$)
      return t6.cssText;
    if ("number" == typeof t6)
      return t6;
    throw Error("Value passed to 'css' function must be a 'css' function result: " + t6 + ". Use 'unsafeCSS' to pass non-literal values, but take care to ensure page security.");
  })(s7) + t5[o6 + 1], t5[0]);
  return new n(o5, t5, s);
};
var S = (s7, o5) => {
  if (e)
    s7.adoptedStyleSheets = o5.map((t5) => t5 instanceof CSSStyleSheet ? t5 : t5.styleSheet);
  else
    for (const e7 of o5) {
      const o6 = document.createElement("style"), n6 = t.litNonce;
      void 0 !== n6 && o6.setAttribute("nonce", n6), o6.textContent = e7.cssText, s7.appendChild(o6);
    }
};
var c = e ? (t5) => t5 : (t5) => t5 instanceof CSSStyleSheet ? ((t6) => {
  let e7 = "";
  for (const s7 of t6.cssRules)
    e7 += s7.cssText;
  return r(e7);
})(t5) : t5;

// node_modules/@lit/reactive-element/reactive-element.js
var { is: i2, defineProperty: e2, getOwnPropertyDescriptor: r2, getOwnPropertyNames: h, getOwnPropertySymbols: o2, getPrototypeOf: n2 } = Object;
var a = globalThis;
var c2 = a.trustedTypes;
var l = c2 ? c2.emptyScript : "";
var p = a.reactiveElementPolyfillSupport;
var d = (t5, s7) => t5;
var u = { toAttribute(t5, s7) {
  switch (s7) {
    case Boolean:
      t5 = t5 ? l : null;
      break;
    case Object:
    case Array:
      t5 = null == t5 ? t5 : JSON.stringify(t5);
  }
  return t5;
}, fromAttribute(t5, s7) {
  let i5 = t5;
  switch (s7) {
    case Boolean:
      i5 = null !== t5;
      break;
    case Number:
      i5 = null === t5 ? null : Number(t5);
      break;
    case Object:
    case Array:
      try {
        i5 = JSON.parse(t5);
      } catch (t6) {
        i5 = null;
      }
  }
  return i5;
} };
var f = (t5, s7) => !i2(t5, s7);
var y = { attribute: true, type: String, converter: u, reflect: false, hasChanged: f };
Symbol.metadata ??= Symbol("metadata"), a.litPropertyMetadata ??= /* @__PURE__ */ new WeakMap();
var b = class extends HTMLElement {
  static addInitializer(t5) {
    this._$Ei(), (this.l ??= []).push(t5);
  }
  static get observedAttributes() {
    return this.finalize(), this._$Eh && [...this._$Eh.keys()];
  }
  static createProperty(t5, s7 = y) {
    if (s7.state && (s7.attribute = false), this._$Ei(), this.elementProperties.set(t5, s7), !s7.noAccessor) {
      const i5 = Symbol(), r7 = this.getPropertyDescriptor(t5, i5, s7);
      void 0 !== r7 && e2(this.prototype, t5, r7);
    }
  }
  static getPropertyDescriptor(t5, s7, i5) {
    const { get: e7, set: h3 } = r2(this.prototype, t5) ?? { get() {
      return this[s7];
    }, set(t6) {
      this[s7] = t6;
    } };
    return { get() {
      return e7?.call(this);
    }, set(s8) {
      const r7 = e7?.call(this);
      h3.call(this, s8), this.requestUpdate(t5, r7, i5);
    }, configurable: true, enumerable: true };
  }
  static getPropertyOptions(t5) {
    return this.elementProperties.get(t5) ?? y;
  }
  static _$Ei() {
    if (this.hasOwnProperty(d("elementProperties")))
      return;
    const t5 = n2(this);
    t5.finalize(), void 0 !== t5.l && (this.l = [...t5.l]), this.elementProperties = new Map(t5.elementProperties);
  }
  static finalize() {
    if (this.hasOwnProperty(d("finalized")))
      return;
    if (this.finalized = true, this._$Ei(), this.hasOwnProperty(d("properties"))) {
      const t6 = this.properties, s7 = [...h(t6), ...o2(t6)];
      for (const i5 of s7)
        this.createProperty(i5, t6[i5]);
    }
    const t5 = this[Symbol.metadata];
    if (null !== t5) {
      const s7 = litPropertyMetadata.get(t5);
      if (void 0 !== s7)
        for (const [t6, i5] of s7)
          this.elementProperties.set(t6, i5);
    }
    this._$Eh = /* @__PURE__ */ new Map();
    for (const [t6, s7] of this.elementProperties) {
      const i5 = this._$Eu(t6, s7);
      void 0 !== i5 && this._$Eh.set(i5, t6);
    }
    this.elementStyles = this.finalizeStyles(this.styles);
  }
  static finalizeStyles(s7) {
    const i5 = [];
    if (Array.isArray(s7)) {
      const e7 = new Set(s7.flat(1 / 0).reverse());
      for (const s8 of e7)
        i5.unshift(c(s8));
    } else
      void 0 !== s7 && i5.push(c(s7));
    return i5;
  }
  static _$Eu(t5, s7) {
    const i5 = s7.attribute;
    return false === i5 ? void 0 : "string" == typeof i5 ? i5 : "string" == typeof t5 ? t5.toLowerCase() : void 0;
  }
  constructor() {
    super(), this._$Ep = void 0, this.isUpdatePending = false, this.hasUpdated = false, this._$Em = null, this._$Ev();
  }
  _$Ev() {
    this._$ES = new Promise((t5) => this.enableUpdating = t5), this._$AL = /* @__PURE__ */ new Map(), this._$E_(), this.requestUpdate(), this.constructor.l?.forEach((t5) => t5(this));
  }
  addController(t5) {
    (this._$EO ??= /* @__PURE__ */ new Set()).add(t5), void 0 !== this.renderRoot && this.isConnected && t5.hostConnected?.();
  }
  removeController(t5) {
    this._$EO?.delete(t5);
  }
  _$E_() {
    const t5 = /* @__PURE__ */ new Map(), s7 = this.constructor.elementProperties;
    for (const i5 of s7.keys())
      this.hasOwnProperty(i5) && (t5.set(i5, this[i5]), delete this[i5]);
    t5.size > 0 && (this._$Ep = t5);
  }
  createRenderRoot() {
    const t5 = this.shadowRoot ?? this.attachShadow(this.constructor.shadowRootOptions);
    return S(t5, this.constructor.elementStyles), t5;
  }
  connectedCallback() {
    this.renderRoot ??= this.createRenderRoot(), this.enableUpdating(true), this._$EO?.forEach((t5) => t5.hostConnected?.());
  }
  enableUpdating(t5) {
  }
  disconnectedCallback() {
    this._$EO?.forEach((t5) => t5.hostDisconnected?.());
  }
  attributeChangedCallback(t5, s7, i5) {
    this._$AK(t5, i5);
  }
  _$EC(t5, s7) {
    const i5 = this.constructor.elementProperties.get(t5), e7 = this.constructor._$Eu(t5, i5);
    if (void 0 !== e7 && true === i5.reflect) {
      const r7 = (void 0 !== i5.converter?.toAttribute ? i5.converter : u).toAttribute(s7, i5.type);
      this._$Em = t5, null == r7 ? this.removeAttribute(e7) : this.setAttribute(e7, r7), this._$Em = null;
    }
  }
  _$AK(t5, s7) {
    const i5 = this.constructor, e7 = i5._$Eh.get(t5);
    if (void 0 !== e7 && this._$Em !== e7) {
      const t6 = i5.getPropertyOptions(e7), r7 = "function" == typeof t6.converter ? { fromAttribute: t6.converter } : void 0 !== t6.converter?.fromAttribute ? t6.converter : u;
      this._$Em = e7, this[e7] = r7.fromAttribute(s7, t6.type), this._$Em = null;
    }
  }
  requestUpdate(t5, s7, i5) {
    if (void 0 !== t5) {
      if (i5 ??= this.constructor.getPropertyOptions(t5), !(i5.hasChanged ?? f)(this[t5], s7))
        return;
      this.P(t5, s7, i5);
    }
    false === this.isUpdatePending && (this._$ES = this._$ET());
  }
  P(t5, s7, i5) {
    this._$AL.has(t5) || this._$AL.set(t5, s7), true === i5.reflect && this._$Em !== t5 && (this._$Ej ??= /* @__PURE__ */ new Set()).add(t5);
  }
  async _$ET() {
    this.isUpdatePending = true;
    try {
      await this._$ES;
    } catch (t6) {
      Promise.reject(t6);
    }
    const t5 = this.scheduleUpdate();
    return null != t5 && await t5, !this.isUpdatePending;
  }
  scheduleUpdate() {
    return this.performUpdate();
  }
  performUpdate() {
    if (!this.isUpdatePending)
      return;
    if (!this.hasUpdated) {
      if (this.renderRoot ??= this.createRenderRoot(), this._$Ep) {
        for (const [t7, s8] of this._$Ep)
          this[t7] = s8;
        this._$Ep = void 0;
      }
      const t6 = this.constructor.elementProperties;
      if (t6.size > 0)
        for (const [s8, i5] of t6)
          true !== i5.wrapped || this._$AL.has(s8) || void 0 === this[s8] || this.P(s8, this[s8], i5);
    }
    let t5 = false;
    const s7 = this._$AL;
    try {
      t5 = this.shouldUpdate(s7), t5 ? (this.willUpdate(s7), this._$EO?.forEach((t6) => t6.hostUpdate?.()), this.update(s7)) : this._$EU();
    } catch (s8) {
      throw t5 = false, this._$EU(), s8;
    }
    t5 && this._$AE(s7);
  }
  willUpdate(t5) {
  }
  _$AE(t5) {
    this._$EO?.forEach((t6) => t6.hostUpdated?.()), this.hasUpdated || (this.hasUpdated = true, this.firstUpdated(t5)), this.updated(t5);
  }
  _$EU() {
    this._$AL = /* @__PURE__ */ new Map(), this.isUpdatePending = false;
  }
  get updateComplete() {
    return this.getUpdateComplete();
  }
  getUpdateComplete() {
    return this._$ES;
  }
  shouldUpdate(t5) {
    return true;
  }
  update(t5) {
    this._$Ej &&= this._$Ej.forEach((t6) => this._$EC(t6, this[t6])), this._$EU();
  }
  updated(t5) {
  }
  firstUpdated(t5) {
  }
};
b.elementStyles = [], b.shadowRootOptions = { mode: "open" }, b[d("elementProperties")] = /* @__PURE__ */ new Map(), b[d("finalized")] = /* @__PURE__ */ new Map(), p?.({ ReactiveElement: b }), (a.reactiveElementVersions ??= []).push("2.0.4");

// node_modules/lit/node_modules/lit-html/lit-html.js
var t2 = globalThis;
var i3 = t2.trustedTypes;
var s2 = i3 ? i3.createPolicy("lit-html", { createHTML: (t5) => t5 }) : void 0;
var e3 = "$lit$";
var h2 = `lit$${(Math.random() + "").slice(9)}$`;
var o3 = "?" + h2;
var n3 = `<${o3}>`;
var r3 = document;
var l2 = () => r3.createComment("");
var c3 = (t5) => null === t5 || "object" != typeof t5 && "function" != typeof t5;
var a2 = Array.isArray;
var u2 = (t5) => a2(t5) || "function" == typeof t5?.[Symbol.iterator];
var d2 = "[ 	\n\f\r]";
var f2 = /<(?:(!--|\/[^a-zA-Z])|(\/?[a-zA-Z][^>\s]*)|(\/?$))/g;
var v = /-->/g;
var _ = />/g;
var m = RegExp(`>|${d2}(?:([^\\s"'>=/]+)(${d2}*=${d2}*(?:[^ 	
\f\r"'\`<>=]|("|')|))|$)`, "g");
var p2 = /'/g;
var g = /"/g;
var $ = /^(?:script|style|textarea|title)$/i;
var y2 = (t5) => (i5, ...s7) => ({ _$litType$: t5, strings: i5, values: s7 });
var x = y2(1);
var b2 = y2(2);
var w = Symbol.for("lit-noChange");
var T = Symbol.for("lit-nothing");
var A = /* @__PURE__ */ new WeakMap();
var E = r3.createTreeWalker(r3, 129);
function C(t5, i5) {
  if (!Array.isArray(t5) || !t5.hasOwnProperty("raw"))
    throw Error("invalid template strings array");
  return void 0 !== s2 ? s2.createHTML(i5) : i5;
}
var P = (t5, i5) => {
  const s7 = t5.length - 1, o5 = [];
  let r7, l3 = 2 === i5 ? "<svg>" : "", c5 = f2;
  for (let i6 = 0; i6 < s7; i6++) {
    const s8 = t5[i6];
    let a3, u3, d3 = -1, y3 = 0;
    for (; y3 < s8.length && (c5.lastIndex = y3, u3 = c5.exec(s8), null !== u3); )
      y3 = c5.lastIndex, c5 === f2 ? "!--" === u3[1] ? c5 = v : void 0 !== u3[1] ? c5 = _ : void 0 !== u3[2] ? ($.test(u3[2]) && (r7 = RegExp("</" + u3[2], "g")), c5 = m) : void 0 !== u3[3] && (c5 = m) : c5 === m ? ">" === u3[0] ? (c5 = r7 ?? f2, d3 = -1) : void 0 === u3[1] ? d3 = -2 : (d3 = c5.lastIndex - u3[2].length, a3 = u3[1], c5 = void 0 === u3[3] ? m : '"' === u3[3] ? g : p2) : c5 === g || c5 === p2 ? c5 = m : c5 === v || c5 === _ ? c5 = f2 : (c5 = m, r7 = void 0);
    const x2 = c5 === m && t5[i6 + 1].startsWith("/>") ? " " : "";
    l3 += c5 === f2 ? s8 + n3 : d3 >= 0 ? (o5.push(a3), s8.slice(0, d3) + e3 + s8.slice(d3) + h2 + x2) : s8 + h2 + (-2 === d3 ? i6 : x2);
  }
  return [C(t5, l3 + (t5[s7] || "<?>") + (2 === i5 ? "</svg>" : "")), o5];
};
var V = class _V {
  constructor({ strings: t5, _$litType$: s7 }, n6) {
    let r7;
    this.parts = [];
    let c5 = 0, a3 = 0;
    const u3 = t5.length - 1, d3 = this.parts, [f3, v2] = P(t5, s7);
    if (this.el = _V.createElement(f3, n6), E.currentNode = this.el.content, 2 === s7) {
      const t6 = this.el.content.firstChild;
      t6.replaceWith(...t6.childNodes);
    }
    for (; null !== (r7 = E.nextNode()) && d3.length < u3; ) {
      if (1 === r7.nodeType) {
        if (r7.hasAttributes())
          for (const t6 of r7.getAttributeNames())
            if (t6.endsWith(e3)) {
              const i5 = v2[a3++], s8 = r7.getAttribute(t6).split(h2), e7 = /([.?@])?(.*)/.exec(i5);
              d3.push({ type: 1, index: c5, name: e7[2], strings: s8, ctor: "." === e7[1] ? k : "?" === e7[1] ? H : "@" === e7[1] ? I : R }), r7.removeAttribute(t6);
            } else
              t6.startsWith(h2) && (d3.push({ type: 6, index: c5 }), r7.removeAttribute(t6));
        if ($.test(r7.tagName)) {
          const t6 = r7.textContent.split(h2), s8 = t6.length - 1;
          if (s8 > 0) {
            r7.textContent = i3 ? i3.emptyScript : "";
            for (let i5 = 0; i5 < s8; i5++)
              r7.append(t6[i5], l2()), E.nextNode(), d3.push({ type: 2, index: ++c5 });
            r7.append(t6[s8], l2());
          }
        }
      } else if (8 === r7.nodeType)
        if (r7.data === o3)
          d3.push({ type: 2, index: c5 });
        else {
          let t6 = -1;
          for (; -1 !== (t6 = r7.data.indexOf(h2, t6 + 1)); )
            d3.push({ type: 7, index: c5 }), t6 += h2.length - 1;
        }
      c5++;
    }
  }
  static createElement(t5, i5) {
    const s7 = r3.createElement("template");
    return s7.innerHTML = t5, s7;
  }
};
function N(t5, i5, s7 = t5, e7) {
  if (i5 === w)
    return i5;
  let h3 = void 0 !== e7 ? s7._$Co?.[e7] : s7._$Cl;
  const o5 = c3(i5) ? void 0 : i5._$litDirective$;
  return h3?.constructor !== o5 && (h3?._$AO?.(false), void 0 === o5 ? h3 = void 0 : (h3 = new o5(t5), h3._$AT(t5, s7, e7)), void 0 !== e7 ? (s7._$Co ??= [])[e7] = h3 : s7._$Cl = h3), void 0 !== h3 && (i5 = N(t5, h3._$AS(t5, i5.values), h3, e7)), i5;
}
var S2 = class {
  constructor(t5, i5) {
    this._$AV = [], this._$AN = void 0, this._$AD = t5, this._$AM = i5;
  }
  get parentNode() {
    return this._$AM.parentNode;
  }
  get _$AU() {
    return this._$AM._$AU;
  }
  u(t5) {
    const { el: { content: i5 }, parts: s7 } = this._$AD, e7 = (t5?.creationScope ?? r3).importNode(i5, true);
    E.currentNode = e7;
    let h3 = E.nextNode(), o5 = 0, n6 = 0, l3 = s7[0];
    for (; void 0 !== l3; ) {
      if (o5 === l3.index) {
        let i6;
        2 === l3.type ? i6 = new M(h3, h3.nextSibling, this, t5) : 1 === l3.type ? i6 = new l3.ctor(h3, l3.name, l3.strings, this, t5) : 6 === l3.type && (i6 = new L(h3, this, t5)), this._$AV.push(i6), l3 = s7[++n6];
      }
      o5 !== l3?.index && (h3 = E.nextNode(), o5++);
    }
    return E.currentNode = r3, e7;
  }
  p(t5) {
    let i5 = 0;
    for (const s7 of this._$AV)
      void 0 !== s7 && (void 0 !== s7.strings ? (s7._$AI(t5, s7, i5), i5 += s7.strings.length - 2) : s7._$AI(t5[i5])), i5++;
  }
};
var M = class _M {
  get _$AU() {
    return this._$AM?._$AU ?? this._$Cv;
  }
  constructor(t5, i5, s7, e7) {
    this.type = 2, this._$AH = T, this._$AN = void 0, this._$AA = t5, this._$AB = i5, this._$AM = s7, this.options = e7, this._$Cv = e7?.isConnected ?? true;
  }
  get parentNode() {
    let t5 = this._$AA.parentNode;
    const i5 = this._$AM;
    return void 0 !== i5 && 11 === t5?.nodeType && (t5 = i5.parentNode), t5;
  }
  get startNode() {
    return this._$AA;
  }
  get endNode() {
    return this._$AB;
  }
  _$AI(t5, i5 = this) {
    t5 = N(this, t5, i5), c3(t5) ? t5 === T || null == t5 || "" === t5 ? (this._$AH !== T && this._$AR(), this._$AH = T) : t5 !== this._$AH && t5 !== w && this._(t5) : void 0 !== t5._$litType$ ? this.$(t5) : void 0 !== t5.nodeType ? this.T(t5) : u2(t5) ? this.k(t5) : this._(t5);
  }
  S(t5) {
    return this._$AA.parentNode.insertBefore(t5, this._$AB);
  }
  T(t5) {
    this._$AH !== t5 && (this._$AR(), this._$AH = this.S(t5));
  }
  _(t5) {
    this._$AH !== T && c3(this._$AH) ? this._$AA.nextSibling.data = t5 : this.T(r3.createTextNode(t5)), this._$AH = t5;
  }
  $(t5) {
    const { values: i5, _$litType$: s7 } = t5, e7 = "number" == typeof s7 ? this._$AC(t5) : (void 0 === s7.el && (s7.el = V.createElement(C(s7.h, s7.h[0]), this.options)), s7);
    if (this._$AH?._$AD === e7)
      this._$AH.p(i5);
    else {
      const t6 = new S2(e7, this), s8 = t6.u(this.options);
      t6.p(i5), this.T(s8), this._$AH = t6;
    }
  }
  _$AC(t5) {
    let i5 = A.get(t5.strings);
    return void 0 === i5 && A.set(t5.strings, i5 = new V(t5)), i5;
  }
  k(t5) {
    a2(this._$AH) || (this._$AH = [], this._$AR());
    const i5 = this._$AH;
    let s7, e7 = 0;
    for (const h3 of t5)
      e7 === i5.length ? i5.push(s7 = new _M(this.S(l2()), this.S(l2()), this, this.options)) : s7 = i5[e7], s7._$AI(h3), e7++;
    e7 < i5.length && (this._$AR(s7 && s7._$AB.nextSibling, e7), i5.length = e7);
  }
  _$AR(t5 = this._$AA.nextSibling, i5) {
    for (this._$AP?.(false, true, i5); t5 && t5 !== this._$AB; ) {
      const i6 = t5.nextSibling;
      t5.remove(), t5 = i6;
    }
  }
  setConnected(t5) {
    void 0 === this._$AM && (this._$Cv = t5, this._$AP?.(t5));
  }
};
var R = class {
  get tagName() {
    return this.element.tagName;
  }
  get _$AU() {
    return this._$AM._$AU;
  }
  constructor(t5, i5, s7, e7, h3) {
    this.type = 1, this._$AH = T, this._$AN = void 0, this.element = t5, this.name = i5, this._$AM = e7, this.options = h3, s7.length > 2 || "" !== s7[0] || "" !== s7[1] ? (this._$AH = Array(s7.length - 1).fill(new String()), this.strings = s7) : this._$AH = T;
  }
  _$AI(t5, i5 = this, s7, e7) {
    const h3 = this.strings;
    let o5 = false;
    if (void 0 === h3)
      t5 = N(this, t5, i5, 0), o5 = !c3(t5) || t5 !== this._$AH && t5 !== w, o5 && (this._$AH = t5);
    else {
      const e8 = t5;
      let n6, r7;
      for (t5 = h3[0], n6 = 0; n6 < h3.length - 1; n6++)
        r7 = N(this, e8[s7 + n6], i5, n6), r7 === w && (r7 = this._$AH[n6]), o5 ||= !c3(r7) || r7 !== this._$AH[n6], r7 === T ? t5 = T : t5 !== T && (t5 += (r7 ?? "") + h3[n6 + 1]), this._$AH[n6] = r7;
    }
    o5 && !e7 && this.j(t5);
  }
  j(t5) {
    t5 === T ? this.element.removeAttribute(this.name) : this.element.setAttribute(this.name, t5 ?? "");
  }
};
var k = class extends R {
  constructor() {
    super(...arguments), this.type = 3;
  }
  j(t5) {
    this.element[this.name] = t5 === T ? void 0 : t5;
  }
};
var H = class extends R {
  constructor() {
    super(...arguments), this.type = 4;
  }
  j(t5) {
    this.element.toggleAttribute(this.name, !!t5 && t5 !== T);
  }
};
var I = class extends R {
  constructor(t5, i5, s7, e7, h3) {
    super(t5, i5, s7, e7, h3), this.type = 5;
  }
  _$AI(t5, i5 = this) {
    if ((t5 = N(this, t5, i5, 0) ?? T) === w)
      return;
    const s7 = this._$AH, e7 = t5 === T && s7 !== T || t5.capture !== s7.capture || t5.once !== s7.once || t5.passive !== s7.passive, h3 = t5 !== T && (s7 === T || e7);
    e7 && this.element.removeEventListener(this.name, this, s7), h3 && this.element.addEventListener(this.name, this, t5), this._$AH = t5;
  }
  handleEvent(t5) {
    "function" == typeof this._$AH ? this._$AH.call(this.options?.host ?? this.element, t5) : this._$AH.handleEvent(t5);
  }
};
var L = class {
  constructor(t5, i5, s7) {
    this.element = t5, this.type = 6, this._$AN = void 0, this._$AM = i5, this.options = s7;
  }
  get _$AU() {
    return this._$AM._$AU;
  }
  _$AI(t5) {
    N(this, t5);
  }
};
var Z = t2.litHtmlPolyfillSupport;
Z?.(V, M), (t2.litHtmlVersions ??= []).push("3.1.2");
var j = (t5, i5, s7) => {
  const e7 = s7?.renderBefore ?? i5;
  let h3 = e7._$litPart$;
  if (void 0 === h3) {
    const t6 = s7?.renderBefore ?? null;
    e7._$litPart$ = h3 = new M(i5.insertBefore(l2(), t6), t6, void 0, s7 ?? {});
  }
  return h3._$AI(t5), h3;
};

// node_modules/lit/node_modules/lit-element/lit-element.js
var s3 = class extends b {
  constructor() {
    super(...arguments), this.renderOptions = { host: this }, this._$Do = void 0;
  }
  createRenderRoot() {
    const t5 = super.createRenderRoot();
    return this.renderOptions.renderBefore ??= t5.firstChild, t5;
  }
  update(t5) {
    const i5 = this.render();
    this.hasUpdated || (this.renderOptions.isConnected = this.isConnected), super.update(t5), this._$Do = j(i5, this.renderRoot, this.renderOptions);
  }
  connectedCallback() {
    super.connectedCallback(), this._$Do?.setConnected(true);
  }
  disconnectedCallback() {
    super.disconnectedCallback(), this._$Do?.setConnected(false);
  }
  render() {
    return w;
  }
};
s3._$litElement$ = true, s3["finalized", "finalized"] = true, globalThis.litElementHydrateSupport?.({ LitElement: s3 });
var r4 = globalThis.litElementPolyfillSupport;
r4?.({ LitElement: s3 });
(globalThis.litElementVersions ??= []).push("4.0.4");

// src/common/utils.ts
function getCookie(name) {
  let cookieValue = "";
  if (document.cookie && document.cookie !== "") {
    const cookies = document.cookie.split(";");
    for (let i5 = 0; i5 < cookies.length; i5++) {
      const cookie = cookies[i5].trim();
      if (cookie.substring(0, name.length + 1) === name + "=") {
        cookieValue = decodeURIComponent(cookie.substring(name.length + 1));
        break;
      }
    }
  }
  return cookieValue;
}
var ascii_lowercase = "abcdefghijklmnopqrstuvwxyz";
var ascii_uppercase = "ABCDEFGHIJKLMNOPQRSTUVWXYZ";
var ascii_letters = ascii_lowercase + ascii_uppercase;
var digits = "0123456789";
var hexdigits = digits + "abcdefABCDEF";
var isCSSResult = (v2) => v2 instanceof n && v2.styleSheet !== void 0;
var _adaptCSS = (sheet) => typeof sheet === "string" ? i([sheet], []).styleSheet : isCSSResult(sheet) ? sheet.styleSheet : sheet;
function adaptCSS(sheet) {
  return Array.isArray(sheet) ? sheet.map(_adaptCSS) : _adaptCSS(sheet);
}
var _timeUnits = /* @__PURE__ */ new Map([
  ["year", 24 * 60 * 60 * 1e3 * 365],
  ["month", 24 * 60 * 60 * 1e3 * 365 / 12],
  ["day", 24 * 60 * 60 * 1e3],
  ["hour", 60 * 60 * 1e3],
  ["minute", 60 * 1e3],
  ["second", 1e3]
]);

// src/common/api/middleware.ts
var CSRFHeaderName = "X-authentik-CSRF";
var LoggingMiddleware = class {
  constructor(brand) {
    this.brand = brand;
  }
  post(context) {
    let msg2 = `authentik/api[${this.brand.matchedDomain}]: `;
    msg2 += `%c${context.response.status}%c ${context.init.method} ${context.url}`;
    let style = "";
    if (context.response.status >= 400) {
      style = "color: red; font-weight: bold;";
    }
    console.debug(msg2, style, "");
    return Promise.resolve(context.response);
  }
};
var CSRFMiddleware = class {
  pre(context) {
    context.init.headers[CSRFHeaderName] = getCookie("authentik_csrf");
    return Promise.resolve(context);
  }
};
var EventMiddleware = class {
  post(context) {
    const request = {
      method: (context.init.method || "GET").toUpperCase(),
      path: context.url,
      status: context.response.status
    };
    window.dispatchEvent(
      new CustomEvent(EVENT_REQUEST_POST, {
        bubbles: true,
        composed: true,
        detail: request
      })
    );
    return Promise.resolve(context.response);
  }
};

// src/common/global.ts
function globalAK() {
  const ak = window.authentik;
  if (ak && !ak._converted) {
    ak._converted = true;
    ak.brand = CurrentBrandFromJSON(ak.brand);
    ak.config = ConfigFromJSON(ak.config);
  }
  if (!ak) {
    return {
      config: ConfigFromJSON({
        capabilities: []
      }),
      brand: CurrentBrandFromJSON({
        ui_footer_links: []
      }),
      versionFamily: "",
      versionSubdomain: "",
      build: ""
    };
  }
  return ak;
}

// src/common/api/config.ts
var globalConfigPromise = Promise.resolve(globalAK().config);
var globalBrandPromise = Promise.resolve(globalAK().brand);
function getMetaContent(key) {
  const metaEl = document.querySelector(`meta[name=${key}]`);
  if (!metaEl)
    return "";
  return metaEl.content;
}
var DEFAULT_CONFIG = new Configuration({
  basePath: window.location.origin + "/api/v3",
  headers: {
    "sentry-trace": getMetaContent("sentry-trace")
  },
  middleware: [
    new CSRFMiddleware(),
    new EventMiddleware(),
    new LoggingMiddleware(globalAK().brand)
  ]
});
console.debug(`authentik(early): version ${VERSION}, apiBase ${DEFAULT_CONFIG.basePath}`);

// src/common/users.ts
var globalMePromise;
function me() {
  if (!globalMePromise) {
    globalMePromise = new CoreApi(DEFAULT_CONFIG).coreUsersMeRetrieve().then((user) => {
      if (!user.user.settings || !("locale" in user.user.settings)) {
        return user;
      }
      const locale = user.user.settings.locale;
      if (locale && locale !== "") {
        console.debug(
          `authentik/locale: Activating user's configured locale '${locale}'`
        );
        window.dispatchEvent(
          new CustomEvent(EVENT_LOCALE_REQUEST, {
            composed: true,
            bubbles: true,
            detail: { locale }
          })
        );
      }
      return user;
    }).catch((ex) => {
      const defaultUser = {
        user: {
          pk: -1,
          isSuperuser: false,
          isActive: true,
          groups: [],
          avatar: "",
          uid: "",
          username: "",
          name: "",
          settings: {},
          systemPermissions: []
        }
      };
      if (ex.response?.status === 401 || ex.response?.status === 403) {
        const relativeUrl = window.location.toString().substring(window.location.origin.length);
        window.location.assign(
          `/flows/-/default/authentication/?next=${encodeURIComponent(relativeUrl)}`
        );
      }
      return defaultUser;
    });
  }
  return globalMePromise;
}

// src/common/sentry.ts
function currentInterface() {
  const pathMatches = window.location.pathname.match(/.+if\/(\w+)\//);
  let currentInterface2 = "unknown";
  if (pathMatches && pathMatches.length >= 2) {
    currentInterface2 = pathMatches[1];
  }
  return currentInterface2.toLowerCase();
}

// src/common/ui/config.ts
var DefaultUIConfig = class {
  constructor() {
    this.enabledFeatures = {
      apiDrawer: true,
      notificationDrawer: true,
      settings: true,
      applicationEdit: true,
      search: true
    };
    this.layout = {
      type: "row" /* row */
    };
    this.navbar = {
      userDisplay: "username" /* username */
    };
    this.theme = {
      base: UiThemeEnum.Automatic,
      background: "",
      cardBackground: ""
    };
    this.pagination = {
      perPage: 20
    };
    this.locale = "";
    this.defaults = {
      userPath: "users"
    };
    if (currentInterface() === "user") {
      this.enabledFeatures.apiDrawer = false;
    }
  }
};
var globalUiConfig;
function getConfigForUser(user) {
  const settings = user.settings;
  let config2 = new DefaultUIConfig();
  if (!settings) {
    return config2;
  }
  config2 = Object.assign(new DefaultUIConfig(), settings);
  return config2;
}
function uiConfig() {
  if (!globalUiConfig) {
    globalUiConfig = me().then((user) => {
      return getConfigForUser(user.user);
    });
  }
  return globalUiConfig;
}

// src/elements/decorators/bound.ts
function bound(target, key, descriptor) {
  if (typeof descriptor?.value !== "function") {
    throw new Error("Only methods can be @bound.");
  }
  return {
    configurable: true,
    get() {
      const method = descriptor.value.bind(this);
      Object.defineProperty(this, key, { value: method, configurable: true, writable: true });
      return method;
    }
  };
}

// src/elements/controllers/ModalOrchestrationController.ts
var modalIsLive = (modal) => modal.isConnected && modal.checkVisibility();
var ModalOrchestrationController = class {
  constructor(host) {
    this.knownModals = [];
    this.host = host;
    host.addController(this);
  }
  hostConnected() {
    window.addEventListener("keyup", this.handleKeyup);
    window.addEventListener("ak-modal-show", this.addModal);
    window.addEventListener("ak-modal-hide", this.closeModal);
  }
  hostDisconnected() {
    window.removeEventListener("keyup", this.handleKeyup);
    window.removeEventListener("ak-modal-show", this.addModal);
    window.removeEventListener("ak-modal-hide", this.closeModal);
  }
  addModal(e7) {
    this.knownModals = [...this.knownModals, e7.modal];
  }
  scheduleCleanup(modal) {
    setTimeout(() => {
      this.knownModals = this.knownModals.filter((m2) => modalIsLive(m2) && modal !== m2);
    }, 0);
  }
  closeModal(e7) {
    const modal = e7.modal;
    if (!modalIsLive(modal)) {
      return;
    }
    if (modal.closeModal() !== false) {
      this.scheduleCleanup(modal);
    }
  }
  removeTopmostModal() {
    let checking = true;
    while (checking) {
      const modal = this.knownModals.pop();
      if (!modal) {
        break;
      }
      if (!modalIsLive(modal)) {
        continue;
      }
      if (modal.closeModal() !== false) {
        this.scheduleCleanup(modal);
      }
      checking = false;
      break;
    }
  }
  handleKeyup(e7) {
    if (e7.key === "Escape" || e7.key === "Esc") {
      this.removeTopmostModal();
    }
  }
};
__decorateClass([
  bound
], ModalOrchestrationController.prototype, "addModal", 1);
__decorateClass([
  bound
], ModalOrchestrationController.prototype, "closeModal", 1);
__decorateClass([
  bound
], ModalOrchestrationController.prototype, "handleKeyup", 1);

// src/elements/utils/ensureCSSStyleSheet.ts
var supportsAdoptingStyleSheets = window.ShadowRoot && (window.ShadyCSS === void 0 || window.ShadyCSS.nativeShadow) && "adoptedStyleSheets" in Document.prototype && "replace" in CSSStyleSheet.prototype;
function stringToStylesheet(css2) {
  if (supportsAdoptingStyleSheets) {
    const sheet2 = r(css2).styleSheet;
    if (sheet2 === void 0) {
      throw new Error(
        `CSS processing error: undefined stylesheet from string.  Source: ${css2}`
      );
    }
    return sheet2;
  }
  const sheet = new CSSStyleSheet();
  sheet.replaceSync(css2);
  return sheet;
}
function cssResultToStylesheet(css2) {
  const sheet = css2.styleSheet;
  return sheet ? sheet : stringToStylesheet(css2.toString());
}
var ensureCSSStyleSheet = (css2) => css2 instanceof n ? cssResultToStylesheet(css2) : typeof css2 === "string" ? stringToStylesheet(css2) : css2;

// node_modules/@lit/reactive-element/decorators/custom-element.js
var t3 = (t5) => (e7, o5) => {
  void 0 !== o5 ? o5.addInitializer(() => {
    customElements.define(t5, e7);
  }) : customElements.define(t5, e7);
};

// node_modules/@lit/reactive-element/decorators/property.js
var o4 = { attribute: true, type: String, converter: u, reflect: false, hasChanged: f };
var r5 = (t5 = o4, e7, r7) => {
  const { kind: n6, metadata: i5 } = r7;
  let s7 = globalThis.litPropertyMetadata.get(i5);
  if (void 0 === s7 && globalThis.litPropertyMetadata.set(i5, s7 = /* @__PURE__ */ new Map()), s7.set(r7.name, t5), "accessor" === n6) {
    const { name: o5 } = r7;
    return { set(r8) {
      const n7 = e7.get.call(this);
      e7.set.call(this, r8), this.requestUpdate(o5, n7, t5);
    }, init(e8) {
      return void 0 !== e8 && this.P(o5, void 0, t5), e8;
    } };
  }
  if ("setter" === n6) {
    const { name: o5 } = r7;
    return function(r8) {
      const n7 = this[o5];
      e7.call(this, r8), this.requestUpdate(o5, n7, t5);
    };
  }
  throw Error("Unsupported decorator location: " + n6);
};
function n4(t5) {
  return (e7, o5) => "object" == typeof o5 ? r5(t5, e7, o5) : ((t6, e8, o6) => {
    const r7 = e8.hasOwnProperty(o6);
    return e8.constructor.createProperty(o6, r7 ? { ...t6, wrapped: true } : t6), r7 ? Object.getOwnPropertyDescriptor(e8, o6) : void 0;
  })(t5, e7, o5);
}

// node_modules/@lit/reactive-element/decorators/state.js
function r6(r7) {
  return n4({ ...r7, state: true, attribute: false });
}

// node_modules/@patternfly/patternfly/patternfly-base.css
var patternfly_base_default = '.pf-t-light {\n  --pf-global--Color--100: var(--pf-global--Color--dark-100);\n  --pf-global--Color--200: var(--pf-global--Color--dark-200);\n  --pf-global--BorderColor--100: var(--pf-global--BorderColor--dark-100);\n  --pf-global--primary-color--100: var(--pf-global--primary-color--dark-100);\n  --pf-global--link--Color: var(--pf-global--link--Color--dark);\n  --pf-global--link--Color--hover: var(--pf-global--link--Color--dark--hover);\n  --pf-global--BackgroundColor--100: var(--pf-global--BackgroundColor--light-100);\n}\n\n.pf-t-dark {\n  --pf-global--Color--100: var(--pf-global--Color--light-100);\n  --pf-global--Color--200: var(--pf-global--Color--light-200);\n  --pf-global--BorderColor--100: var(--pf-global--BorderColor--light-100);\n  --pf-global--primary-color--100: var(--pf-global--primary-color--light-100);\n  --pf-global--link--Color: var(--pf-global--link--Color--light);\n  --pf-global--link--Color--hover: var(--pf-global--link--Color--light);\n  --pf-global--BackgroundColor--100: var(--pf-global--BackgroundColor--dark-100);\n}\n.pf-t-dark .pf-c-card {\n  --pf-c-card--BackgroundColor: var(--pf-global--BackgroundColor--dark-transparent-200);\n}\n.pf-t-dark .pf-c-button {\n  --pf-c-button--m-primary--Color: var(--pf-global--primary-color--dark-100);\n  --pf-c-button--m-primary--hover--Color: var(--pf-global--primary-color--dark-100);\n  --pf-c-button--m-primary--focus--Color: var(--pf-global--primary-color--dark-100);\n  --pf-c-button--m-primary--active--Color: var(--pf-global--primary-color--dark-100);\n  --pf-c-button--m-primary--BackgroundColor: var(--pf-global--BackgroundColor--light-100);\n  --pf-c-button--m-primary--hover--BackgroundColor: var(--pf-global--BackgroundColor--light-300);\n  --pf-c-button--m-primary--focus--BackgroundColor: var(--pf-global--BackgroundColor--light-300);\n  --pf-c-button--m-primary--active--BackgroundColor: var(--pf-global--BackgroundColor--light-300);\n  --pf-c-button--m-secondary--Color: var(--pf-global--Color--light-100);\n  --pf-c-button--m-secondary--hover--Color: var(--pf-global--Color--light-100);\n  --pf-c-button--m-secondary--focus--Color: var(--pf-global--Color--light-100);\n  --pf-c-button--m-secondary--active--Color: var(--pf-global--Color--light-100);\n  --pf-c-button--m-secondary--BorderColor: var(--pf-global--Color--light-100);\n  --pf-c-button--m-secondary--hover--BorderColor: var(--pf-global--Color--light-100);\n  --pf-c-button--m-secondary--focus--BorderColor: var(--pf-global--Color--light-100);\n  --pf-c-button--m-secondary--active--BorderColor: var(--pf-global--Color--light-100);\n}\n\n:root {\n  --pf-global--palette--black-100: #fafafa;\n  --pf-global--palette--black-150: #f5f5f5;\n  --pf-global--palette--black-200: #f0f0f0;\n  --pf-global--palette--black-300: #d2d2d2;\n  --pf-global--palette--black-400: #b8bbbe;\n  --pf-global--palette--black-500: #8a8d90;\n  --pf-global--palette--black-600: #6a6e73;\n  --pf-global--palette--black-700: #4f5255;\n  --pf-global--palette--black-800: #3c3f42;\n  --pf-global--palette--black-850: #212427;\n  --pf-global--palette--black-900: #151515;\n  --pf-global--palette--black-1000: #030303;\n  --pf-global--palette--blue-50: #e7f1fa;\n  --pf-global--palette--blue-100: #bee1f4;\n  --pf-global--palette--blue-200: #73bcf7;\n  --pf-global--palette--blue-300: #2b9af3;\n  --pf-global--palette--blue-400: #06c;\n  --pf-global--palette--blue-500: #004080;\n  --pf-global--palette--blue-600: #002952;\n  --pf-global--palette--blue-700: #001223;\n  --pf-global--palette--cyan-50: #f2f9f9;\n  --pf-global--palette--cyan-100: #a2d9d9;\n  --pf-global--palette--cyan-200: #73c5c5;\n  --pf-global--palette--cyan-300: #009596;\n  --pf-global--palette--cyan-400: #005f60;\n  --pf-global--palette--cyan-500: #003737;\n  --pf-global--palette--cyan-600: #002323;\n  --pf-global--palette--cyan-700: #000f0f;\n  --pf-global--palette--gold-50: #fdf7e7;\n  --pf-global--palette--gold-100: #f9e0a2;\n  --pf-global--palette--gold-200: #f6d173;\n  --pf-global--palette--gold-300: #f4c145;\n  --pf-global--palette--gold-400: #f0ab00;\n  --pf-global--palette--gold-500: #c58c00;\n  --pf-global--palette--gold-600: #795600;\n  --pf-global--palette--gold-700: #3d2c00;\n  --pf-global--palette--green-50: #f3faf2;\n  --pf-global--palette--green-100: #bde5b8;\n  --pf-global--palette--green-200: #95d58e;\n  --pf-global--palette--green-300: #6ec664;\n  --pf-global--palette--green-400: #5ba352;\n  --pf-global--palette--green-500: #3e8635;\n  --pf-global--palette--green-600: #1e4f18;\n  --pf-global--palette--green-700: #0f280d;\n  --pf-global--palette--light-blue-100: #beedf9;\n  --pf-global--palette--light-blue-200: #7cdbf3;\n  --pf-global--palette--light-blue-300: #35caed;\n  --pf-global--palette--light-blue-400: #00b9e4;\n  --pf-global--palette--light-blue-500: #008bad;\n  --pf-global--palette--light-blue-600: #005c73;\n  --pf-global--palette--light-blue-700: #002d39;\n  --pf-global--palette--light-green-100: #e4f5bc;\n  --pf-global--palette--light-green-200: #c8eb79;\n  --pf-global--palette--light-green-300: #ace12e;\n  --pf-global--palette--light-green-400: #92d400;\n  --pf-global--palette--light-green-500: #6ca100;\n  --pf-global--palette--light-green-600: #486b00;\n  --pf-global--palette--light-green-700: #253600;\n  --pf-global--palette--orange-50: #fff6ec;\n  --pf-global--palette--orange-100: #f4b678;\n  --pf-global--palette--orange-200: #ef9234;\n  --pf-global--palette--orange-300: #ec7a08;\n  --pf-global--palette--orange-400: #c46100;\n  --pf-global--palette--orange-500: #8f4700;\n  --pf-global--palette--orange-600: #773d00;\n  --pf-global--palette--orange-700: #3b1f00;\n  --pf-global--palette--purple-50: #f2f0fc;\n  --pf-global--palette--purple-100: #cbc1ff;\n  --pf-global--palette--purple-200: #b2a3ff;\n  --pf-global--palette--purple-300: #a18fff;\n  --pf-global--palette--purple-400: #8476d1;\n  --pf-global--palette--purple-500: #6753ac;\n  --pf-global--palette--purple-600: #40199a;\n  --pf-global--palette--purple-700: #1f0066;\n  --pf-global--palette--red-50: #faeae8;\n  --pf-global--palette--red-100: #c9190b;\n  --pf-global--palette--red-200: #a30000;\n  --pf-global--palette--red-300: #7d1007;\n  --pf-global--palette--red-400: #470000;\n  --pf-global--palette--red-500: #2c0000;\n  --pf-global--palette--white: #fff;\n  --pf-global--BackgroundColor--100: #fff;\n  --pf-global--BackgroundColor--150: #fafafa;\n  --pf-global--BackgroundColor--200: #f0f0f0;\n  --pf-global--BackgroundColor--light-100: #fff;\n  --pf-global--BackgroundColor--light-200: #fafafa;\n  --pf-global--BackgroundColor--light-300: #f0f0f0;\n  --pf-global--BackgroundColor--dark-100: #151515;\n  --pf-global--BackgroundColor--dark-200: #3c3f42;\n  --pf-global--BackgroundColor--dark-300: #212427;\n  --pf-global--BackgroundColor--dark-400: #4f5255;\n  --pf-global--BackgroundColor--dark-transparent-100: rgba(3, 3, 3, 0.62);\n  --pf-global--BackgroundColor--dark-transparent-200: rgba(3, 3, 3, 0.32);\n  --pf-global--Color--100: #151515;\n  --pf-global--Color--200: #6a6e73;\n  --pf-global--Color--300: #3c3f42;\n  --pf-global--Color--400: #8a8d90;\n  --pf-global--Color--light-100: #fff;\n  --pf-global--Color--light-200: #f0f0f0;\n  --pf-global--Color--light-300: #d2d2d2;\n  --pf-global--Color--dark-100: #151515;\n  --pf-global--Color--dark-200: #6a6e73;\n  --pf-global--active-color--100: #06c;\n  --pf-global--active-color--200: #bee1f4;\n  --pf-global--active-color--300: #2b9af3;\n  --pf-global--active-color--400: #73bcf7;\n  --pf-global--disabled-color--100: #6a6e73;\n  --pf-global--disabled-color--200: #d2d2d2;\n  --pf-global--disabled-color--300: #f0f0f0;\n  --pf-global--primary-color--100: #06c;\n  --pf-global--primary-color--200: #004080;\n  --pf-global--primary-color--light-100: #73bcf7;\n  --pf-global--primary-color--dark-100: #06c;\n  --pf-global--secondary-color--100: #6a6e73;\n  --pf-global--default-color--100: #73c5c5;\n  --pf-global--default-color--200: #009596;\n  --pf-global--default-color--300: #003737;\n  --pf-global--success-color--100: #3e8635;\n  --pf-global--success-color--200: #1e4f18;\n  --pf-global--info-color--100: #2b9af3;\n  --pf-global--info-color--200: #002952;\n  --pf-global--warning-color--100: #f0ab00;\n  --pf-global--warning-color--200: #795600;\n  --pf-global--danger-color--100: #c9190b;\n  --pf-global--danger-color--200: #a30000;\n  --pf-global--danger-color--300: #470000;\n  --pf-global--BoxShadow--sm: 0 0.0625rem 0.125rem 0 rgba(3, 3, 3, 0.12), 0 0 0.125rem 0 rgba(3, 3, 3, 0.06);\n  --pf-global--BoxShadow--sm-top: 0 -0.125rem 0.25rem -0.0625rem rgba(3, 3, 3, 0.16);\n  --pf-global--BoxShadow--sm-right: 0.125rem 0 0.25rem -0.0625rem rgba(3, 3, 3, 0.16);\n  --pf-global--BoxShadow--sm-bottom: 0 0.125rem 0.25rem -0.0625rem rgba(3, 3, 3, 0.16);\n  --pf-global--BoxShadow--sm-left: -0.125rem 0 0.25rem -0.0625rem rgba(3, 3, 3, 0.16);\n  --pf-global--BoxShadow--md: 0 0.25rem 0.5rem 0rem rgba(3, 3, 3, 0.12), 0 0 0.25rem 0 rgba(3, 3, 3, 0.06);\n  --pf-global--BoxShadow--md-top: 0 -0.5rem 0.5rem -0.375rem rgba(3, 3, 3, 0.18);\n  --pf-global--BoxShadow--md-right: 0.5rem 0 0.5rem -0.375rem rgba(3, 3, 3, 0.18);\n  --pf-global--BoxShadow--md-bottom: 0 0.5rem 0.5rem -0.375rem rgba(3, 3, 3, 0.18);\n  --pf-global--BoxShadow--md-left: -0.5rem 0 0.5rem -0.375rem rgba(3, 3, 3, 0.18);\n  --pf-global--BoxShadow--lg: 0 0.5rem 1rem 0 rgba(3, 3, 3, 0.16), 0 0 0.375rem 0 rgba(3, 3, 3, 0.08);\n  --pf-global--BoxShadow--lg-top: 0 -0.75rem 0.75rem -0.5rem rgba(3, 3, 3, 0.18);\n  --pf-global--BoxShadow--lg-right: 0.75rem 0 0.75rem -0.5rem rgba(3, 3, 3, 0.18);\n  --pf-global--BoxShadow--lg-bottom: 0 0.75rem 0.75rem -0.5rem rgba(3, 3, 3, 0.18);\n  --pf-global--BoxShadow--lg-left: -0.75rem 0 0.75rem -0.5rem rgba(3, 3, 3, 0.18);\n  --pf-global--BoxShadow--xl: 0 1rem 2rem 0 rgba(3, 3, 3, 0.16), 0 0 0.5rem 0 rgba(3, 3, 3, 0.1);\n  --pf-global--BoxShadow--xl-top: 0 -1rem 1rem -0.5rem rgba(3, 3, 3, 0.2);\n  --pf-global--BoxShadow--xl-right: 1rem 0 1rem -0.5rem rgba(3, 3, 3, 0.2);\n  --pf-global--BoxShadow--xl-bottom: 0 1rem 1rem -0.5rem rgba(3, 3, 3, 0.2);\n  --pf-global--BoxShadow--xl-left: -1rem 0 1rem -0.5rem rgba(3, 3, 3, 0.2);\n  --pf-global--BoxShadow--inset: inset 0 0 0.625rem 0 rgba(3, 3, 3, 0.25);\n  --pf-global--font-path: "./assets/fonts";\n  --pf-global--fonticon-path: "./assets/pficon";\n  --pf-global--spacer--xs: 0.25rem;\n  --pf-global--spacer--sm: 0.5rem;\n  --pf-global--spacer--md: 1rem;\n  --pf-global--spacer--lg: 1.5rem;\n  --pf-global--spacer--xl: 2rem;\n  --pf-global--spacer--2xl: 3rem;\n  --pf-global--spacer--3xl: 4rem;\n  --pf-global--spacer--4xl: 5rem;\n  --pf-global--spacer--form-element: 0.375rem;\n  --pf-global--gutter: 1rem;\n  --pf-global--gutter--md: 1.5rem;\n  --pf-global--ZIndex--xs: 100;\n  --pf-global--ZIndex--sm: 200;\n  --pf-global--ZIndex--md: 300;\n  --pf-global--ZIndex--lg: 400;\n  --pf-global--ZIndex--xl: 500;\n  --pf-global--ZIndex--2xl: 600;\n  --pf-global--breakpoint--xs: 0;\n  --pf-global--breakpoint--sm: 576px;\n  --pf-global--breakpoint--md: 768px;\n  --pf-global--breakpoint--lg: 992px;\n  --pf-global--breakpoint--xl: 1200px;\n  --pf-global--breakpoint--2xl: 1450px;\n  --pf-global--height-breakpoint--sm: 0;\n  --pf-global--height-breakpoint--md: 40rem;\n  --pf-global--height-breakpoint--lg: 48rem;\n  --pf-global--height-breakpoint--xl: 60rem;\n  --pf-global--height-breakpoint--2xl: 80rem;\n  --pf-global--link--Color: #06c;\n  --pf-global--link--Color--hover: #004080;\n  --pf-global--link--Color--light: #2b9af3;\n  --pf-global--link--Color--light--hover: #73bcf7;\n  --pf-global--link--Color--dark: #06c;\n  --pf-global--link--Color--dark--hover: #004080;\n  --pf-global--link--Color--visited: #40199a;\n  --pf-global--link--TextDecoration: none;\n  --pf-global--link--TextDecoration--hover: underline;\n  --pf-global--BorderWidth--sm: 1px;\n  --pf-global--BorderWidth--md: 2px;\n  --pf-global--BorderWidth--lg: 3px;\n  --pf-global--BorderWidth--xl: 4px;\n  --pf-global--BorderColor--100: #d2d2d2;\n  --pf-global--BorderColor--200: #8a8d90;\n  --pf-global--BorderColor--300: #f0f0f0;\n  --pf-global--BorderColor--dark-100: #d2d2d2;\n  --pf-global--BorderColor--light-100: #b8bbbe;\n  --pf-global--BorderRadius--sm: 3px;\n  --pf-global--BorderRadius--lg: 30em;\n  --pf-global--icon--Color--light: #6a6e73;\n  --pf-global--icon--Color--dark: #151515;\n  --pf-global--icon--FontSize--sm: 0.625rem;\n  --pf-global--icon--FontSize--md: 1.125rem;\n  --pf-global--icon--FontSize--lg: 1.5rem;\n  --pf-global--icon--FontSize--xl: 3.375rem;\n  --pf-global--FontFamily--sans-serif: "RedHatText", "Overpass", overpass, helvetica, arial, sans-serif;\n  --pf-global--FontFamily--heading--sans-serif: "RedHatDisplay", "Overpass", overpass, helvetica, arial, sans-serif;\n  --pf-global--FontFamily--monospace: "Liberation Mono", consolas, "SFMono-Regular", menlo, monaco, "Courier New", monospace;\n  --pf-global--FontFamily--redhat-updated--sans-serif: "RedHatTextUpdated", "Overpass", overpass, helvetica, arial, sans-serif;\n  --pf-global--FontFamily--redhat-updated--heading--sans-serif: "RedHatDisplayUpdated", "Overpass", overpass, helvetica, arial, sans-serif;\n  --pf-global--FontFamily--redhat--monospace: "RedHatMono", "Liberation Mono", consolas, "SFMono-Regular", menlo, monaco, "Courier New", monospace;\n  --pf-global--FontFamily--redhatVF--sans-serif: "RedHatTextVF", "RedHatText", "Overpass", overpass, helvetica, arial, sans-serif;\n  --pf-global--FontFamily--redhatVF--heading--sans-serif: "RedHatDisplayVF", "RedHatDisplay", "Overpass", overpass, helvetica, arial, sans-serif;\n  --pf-global--FontFamily--redhatVF--monospace: "RedHatMonoVF", "RedHatMono", "Liberation Mono", consolas, "SFMono-Regular", menlo, monaco, "Courier New", monospace;\n  --pf-global--FontFamily--overpass--sans-serif: "overpass", overpass, "open sans", -apple-system, blinkmacsystemfont, "Segoe UI", roboto, "Helvetica Neue", arial, sans-serif, "Apple Color Emoji", "Segoe UI Emoji", "Segoe UI Symbol";\n  --pf-global--FontFamily--overpass--monospace: "overpass-mono", overpass-mono, "SFMono-Regular", menlo, monaco, consolas, "Liberation Mono", "Courier New", monospace;\n  --pf-global--FontSize--4xl: 2.25rem;\n  --pf-global--FontSize--3xl: 1.75rem;\n  --pf-global--FontSize--2xl: 1.5rem;\n  --pf-global--FontSize--xl: 1.25rem;\n  --pf-global--FontSize--lg: 1.125rem;\n  --pf-global--FontSize--md: 1rem;\n  --pf-global--FontSize--sm: 0.875rem;\n  --pf-global--FontSize--xs: 0.75rem;\n  --pf-global--FontWeight--light: 300;\n  --pf-global--FontWeight--normal: 400;\n  --pf-global--FontWeight--semi-bold: 700;\n  --pf-global--FontWeight--overpass--semi-bold: 500;\n  --pf-global--FontWeight--bold: 700;\n  --pf-global--FontWeight--overpass--bold: 600;\n  --pf-global--LineHeight--sm: 1.3;\n  --pf-global--LineHeight--md: 1.5;\n  --pf-global--ListStyle: disc outside;\n  --pf-global--Transition: all 250ms cubic-bezier(0.42, 0, 0.58, 1);\n  --pf-global--TimingFunction: cubic-bezier(0.645, 0.045, 0.355, 1);\n  --pf-global--TransitionDuration: 250ms;\n  --pf-global--arrow--width: 0.9375rem;\n  --pf-global--arrow--width-lg: 1.5625rem;\n  --pf-global--target-size--MinWidth: 44px;\n  --pf-global--target-size--MinHeight: 44px;\n}\n\n.pf-m-overpass-font {\n  --pf-global--FontFamily--sans-serif: var(--pf-global--FontFamily--overpass--sans-serif);\n  --pf-global--FontFamily--heading--sans-serif: var(--pf-global--FontFamily--sans-serif);\n  --pf-global--FontFamily--monospace: var(--pf-global--FontFamily--overpass--monospace);\n  --pf-global--FontWeight--semi-bold: var(--pf-global--FontWeight--overpass--semi-bold);\n  --pf-global--FontWeight--bold: var(--pf-global--FontWeight--overpass--bold);\n}\n\n.pf-m-redhat-updated-font {\n  --pf-global--FontFamily--sans-serif: var(--pf-global--FontFamily--redhat-updated--sans-serif);\n  --pf-global--FontFamily--heading--sans-serif: var(--pf-global--FontFamily--redhat-updated--heading--sans-serif);\n}\n\n.pf-m-redhatmono-font {\n  --pf-global--FontFamily--monospace: var(--pf-global--FontFamily--redhat--monospace);\n}\n\n.pf-m-redhatVF-font {\n  --pf-global--FontFamily--sans-serif: var(--pf-global--FontFamily--redhatVF--sans-serif);\n  --pf-global--FontFamily--heading--sans-serif: var(--pf-global--FontFamily--redhatVF--heading--sans-serif);\n  --pf-global--FontFamily--monospace: var(--pf-global--FontFamily--redhatVF--monospace);\n}\n\n:root:where(.pf-theme-dark) {\n  --pf-global--palette--black-50: #e0e0e0;\n  --pf-global--palette--black-100: #c6c7c8;\n  --pf-global--palette--black-200: #aaabac;\n  --pf-global--palette--black-300: #868789;\n  --pf-global--palette--black-400: #57585a;\n  --pf-global--palette--black-500: #444548;\n  --pf-global--palette--black-600: #36373a;\n  --pf-global--palette--black-700: #26292d;\n  --pf-global--palette--black-800: #1b1d21;\n  --pf-global--palette--black-900: #0f1214;\n  --pf-global--palette--red-9999: #fe5142;\n  --pf-global--palette--red-8888: #ff7468;\n  --pf-global--palette--blue-300: #1fa7f8;\n  --pf-global--BackgroundColor--100: #1b1d21;\n  --pf-global--BackgroundColor--150: #212427;\n  --pf-global--BackgroundColor--200: #0f1214;\n  --pf-global--BackgroundColor--300: #26292d;\n  --pf-global--BackgroundColor--400: #36373a;\n  --pf-global--BorderColor--100: #444548;\n  --pf-global--BorderColor--200: #444548;\n  --pf-global--BorderColor--300: #57585a;\n  --pf-global--BorderColor--400: #aaabac;\n  --pf-global--Color--100: #e0e0e0;\n  --pf-global--Color--200: #aaabac;\n  --pf-global--active-color--100: #1fa7f8;\n  --pf-global--primary-color--100: #1fa7f8;\n  --pf-global--primary-color--300: #06c;\n  --pf-global--success-color--100: #5ba352;\n  --pf-global--warning-color--100: #f0ab00;\n  --pf-global--warning-color--200: #f4c145;\n  --pf-global--danger-color--100: #fe5142;\n  --pf-global--danger-color--200: #ff7468;\n  --pf-global--link--Color: #1fa7f8;\n  --pf-global--link--Color--hover: #73bcf7;\n  --pf-global--link--Color--visited: #a18fff;\n  --pf-global--disabled-color--100: #57585a;\n  --pf-global--disabled-color--200: #444548;\n  --pf-global--disabled-color--300: #aaabac;\n  --pf-global--icon--Color--light: #aaabac;\n  --pf-global--icon--Color--dark: #aaabac;\n  --pf-global--Color--dark-100: #e0e0e0;\n  --pf-global--Color--dark-200: #aaabac;\n  --pf-global--Color--light-100: #e0e0e0;\n  --pf-global--Color--light-200: #aaabac;\n  --pf-global--Color--light-300: #3c3f42;\n  --pf-global--BorderColor--dark-100: #444548;\n  --pf-global--BorderColor--light-100: #444548;\n  --pf-global--primary-color--light-100: #1fa7f8;\n  --pf-global--primary-color--dark-100: #1fa7f8;\n  --pf-global--link--Color--light: #1fa7f8;\n  --pf-global--link--Color--light--hover: #73bcf7;\n  --pf-global--link--Color--dark: #1fa7f8;\n  --pf-global--link--Color--dark--hover: #73bcf7;\n  --pf-global--BackgroundColor--light-100: #1b1d21;\n  --pf-global--BackgroundColor--light-200: #0f1214;\n  --pf-global--BackgroundColor--light-300: #26292d;\n  --pf-global--BackgroundColor--dark-100: #1b1d21;\n  --pf-global--BackgroundColor--dark-200: #0f1214;\n  --pf-global--BackgroundColor--dark-300: #26292d;\n  --pf-global--BackgroundColor--dark-400: #36373a;\n  --pf-global--BoxShadow--sm: 0 0.0625rem 0.125rem 0 rgba(3, 3, 3, 0.48), 0 0 0.125rem 0 rgba(3, 3, 3, 0.24);\n  --pf-global--BoxShadow--sm-top: 0 -0.125rem 0.25rem -0.0625rem rgba(3, 3, 3, 0.64);\n  --pf-global--BoxShadow--sm-right: 0.125rem 0 0.25rem -0.0625rem rgba(3, 3, 3, 0.64);\n  --pf-global--BoxShadow--sm-bottom: 0 0.125rem 0.25rem -0.0625rem rgba(3, 3, 3, 0.64);\n  --pf-global--BoxShadow--sm-left: -0.125rem 0 0.25rem -0.0625rem rgba(3, 3, 3, 0.64);\n  --pf-global--BoxShadow--md: 0 0.25rem 0.5rem 0rem rgba(3, 3, 3, 0.48), 0 0 0.25rem 0 rgba(3, 3, 3, 0.24);\n  --pf-global--BoxShadow--md-top: 0 -0.5rem 0.5rem -0.375rem rgba(3, 3, 3, 0.72);\n  --pf-global--BoxShadow--md-right: 0.5rem 0 0.5rem -0.375rem rgba(3, 3, 3, 0.72);\n  --pf-global--BoxShadow--md-bottom: 0 0.5rem 0.5rem -0.375rem rgba(3, 3, 3, 0.72);\n  --pf-global--BoxShadow--md-left: -0.5rem 0 0.5rem -0.375rem rgba(3, 3, 3, 0.72);\n  --pf-global--BoxShadow--lg: 0 0.5rem 1rem 0 rgba(3, 3, 3, 0.64), 0 0 0.375rem 0 rgba(3, 3, 3, 0.32);\n  --pf-global--BoxShadow--lg-top: 0 -0.75rem 0.75rem -0.5rem rgba(3, 3, 3, 0.72);\n  --pf-global--BoxShadow--lg-right: 0.75rem 0 0.75rem -0.5rem rgba(3, 3, 3, 0.72);\n  --pf-global--BoxShadow--lg-bottom: 0 0.75rem 0.75rem -0.5rem rgba(3, 3, 3, 0.72);\n  --pf-global--BoxShadow--lg-left: -0.75rem 0 0.75rem -0.5rem rgba(3, 3, 3, 0.72);\n  --pf-global--BoxShadow--xl: 0 1rem 2rem 0 rgba(3, 3, 3, 0.64), 0 0 0.5rem 0 rgba(3, 3, 3, 0.4);\n  --pf-global--BoxShadow--xl-top: 0 -1rem 1rem -0.5rem rgba(3, 3, 3, 0.8);\n  --pf-global--BoxShadow--xl-right: 1rem 0 1rem -0.5rem rgba(3, 3, 3, 0.8);\n  --pf-global--BoxShadow--xl-bottom: 0 1rem 1rem -0.5rem rgba(3, 3, 3, 0.8);\n  --pf-global--BoxShadow--xl-left: -1rem 0 1rem -0.5rem rgba(3, 3, 3, 0.8);\n  --pf-global--BoxShadow--inset: inset 0 0 0.625rem 0 #030303;\n}\n\n@font-face {\n  font-family: "RedHatDisplay";\n  src: url("./assets/fonts/RedHatDisplay/RedHatDisplay-Regular.woff2") format("woff2"), url("./assets/fonts/RedHatDisplay/RedHatDisplay-Regular.woff") format("woff");\n  font-style: normal;\n  font-weight: 300;\n  text-rendering: optimizelegibility;\n}\n@font-face {\n  font-family: "RedHatDisplay";\n  src: url("./assets/fonts/RedHatDisplay/RedHatDisplay-Medium.woff2") format("woff2"), url("./assets/fonts/RedHatDisplay/RedHatDisplay-Medium.woff") format("woff");\n  font-style: normal;\n  font-weight: 400;\n  text-rendering: optimizelegibility;\n}\n@font-face {\n  font-family: "RedHatDisplay";\n  src: url("./assets/fonts/RedHatDisplay/RedHatDisplay-Bold.woff2") format("woff2"), url("./assets/fonts/RedHatDisplay/RedHatDisplay-Bold.woff") format("woff");\n  font-style: normal;\n  font-weight: 700;\n  text-rendering: optimizelegibility;\n}\n@font-face {\n  font-family: "RedHatText";\n  src: url("./assets/fonts/RedHatText/RedHatText-Regular.woff2") format("woff2"), url("./assets/fonts/RedHatText/RedHatText-Regular.woff") format("woff");\n  font-style: normal;\n  font-weight: 400;\n  text-rendering: optimizelegibility;\n}\n@font-face {\n  font-family: "RedHatText";\n  src: url("./assets/fonts/RedHatText/RedHatText-Medium.woff2") format("woff2"), url("./assets/fonts/RedHatText/RedHatText-Medium.woff") format("woff");\n  font-style: normal;\n  font-weight: 700;\n  text-rendering: optimizelegibility;\n}\n@font-face {\n  font-family: "RedHatDisplayUpdated";\n  src: url("./assets/fonts/RedHatFont-updated/RedHatDisplay/RedHatDisplay-updated-Regular.woff2") format("woff2");\n  font-style: normal;\n  font-weight: 300;\n  text-rendering: optimizelegibility;\n}\n@font-face {\n  font-family: "RedHatDisplayUpdated";\n  src: url("./assets/fonts/RedHatFont-updated/RedHatDisplay/RedHatDisplay-updated-Medium.woff2") format("woff2");\n  font-style: normal;\n  font-weight: 400;\n  text-rendering: optimizelegibility;\n}\n@font-face {\n  font-family: "RedHatDisplayUpdated";\n  src: url("./assets/fonts/RedHatFont-updated/RedHatDisplay/RedHatDisplay-updated-Bold.woff2") format("woff2");\n  font-style: normal;\n  font-weight: 700;\n  text-rendering: optimizelegibility;\n}\n@font-face {\n  font-family: "RedHatTextUpdated";\n  src: url("./assets/fonts/RedHatFont-updated/RedHatText/RedHatText-updated-Regular.woff2") format("woff2");\n  font-style: normal;\n  font-weight: 400;\n  text-rendering: optimizelegibility;\n}\n@font-face {\n  font-family: "RedHatTextUpdated";\n  src: url("./assets/fonts/RedHatFont-updated/RedHatText/RedHatText-updated-Medium.woff2") format("woff2");\n  font-style: normal;\n  font-weight: 700;\n  text-rendering: optimizelegibility;\n}\n@font-face {\n  font-family: "RedHatMono";\n  src: url("./assets/fonts/RedHatFont-updated/RedHatMono/RedHatMono-updated-Regular.woff2") format("woff2");\n  font-style: normal;\n  font-weight: 400;\n  font-display: fallback;\n}\n@font-face {\n  font-family: "RedHatDisplayVF";\n  src: url("./assets/fonts/RedHatFont-updated/modified/RedHatDisplayVFModified-updated.woff2") format("woff2-variations");\n  font-style: normal;\n  font-weight: 300 900;\n  font-display: fallback;\n}\n@font-face {\n  font-family: "RedHatDisplayVF";\n  src: url("./assets/fonts/RedHatFont-updated/modified/RedHatDisplayVF-updated-ItalicModified.woff2") format("woff2-variations");\n  font-style: italic;\n  font-weight: 300 900;\n  font-display: fallback;\n}\n@font-face {\n  font-family: "RedHatTextVF";\n  src: url("./assets/fonts/RedHatFont-updated/modified/RedHatTextVFModified-updated.woff2") format("woff2-variations");\n  font-style: normal;\n  font-weight: 400 500;\n  font-display: fallback;\n}\n@font-face {\n  font-family: "RedHatTextVF";\n  src: url("./assets/fonts/RedHatFont-updated/modified/RedHatTextVF-updated-ItalicModified.woff2") format("woff2-variations");\n  font-style: italic;\n  font-weight: 400 500;\n  font-display: fallback;\n}\n@font-face {\n  font-family: "RedHatMonoVF";\n  src: url("./assets/fonts/RedHatFont-updated/RedHatMono/RedHatMonoVF-updated.woff2") format("woff2-variations");\n  font-style: normal;\n  font-weight: 300 700;\n  font-display: fallback;\n}\n@font-face {\n  font-family: "RedHatMonoVF";\n  src: url("./assets/fonts/RedHatFont-updated/RedHatMono/RedHatMonoVF-updated-Italic.woff2") format("woff2-variations");\n  font-style: italic;\n  font-weight: 300 700;\n  font-display: fallback;\n}\n@font-face {\n  font-family: "overpass";\n  font-style: normal;\n  font-weight: 200;\n  src: url("./assets/fonts/overpass-webfont/overpass-thin.woff2") format("woff2"), url("./assets/fonts/overpass-webfont/overpass-thin.woff") format("woff");\n}\n@font-face {\n  font-family: "overpass";\n  font-style: italic;\n  font-weight: 200;\n  src: url("./assets/fonts/overpass-webfont/overpass-thin-italic.woff2") format("woff2"), url("./assets/fonts/overpass-webfont/overpass-thin-italic.woff") format("woff");\n}\n@font-face {\n  font-family: "overpass";\n  font-style: normal;\n  font-weight: 300;\n  src: url("./assets/fonts/overpass-webfont/overpass-extralight.woff2") format("woff2"), url("./assets/fonts/overpass-webfont/overpass-extralight.woff") format("woff");\n}\n@font-face {\n  font-family: "overpass";\n  font-style: italic;\n  font-weight: 300;\n  src: url("./assets/fonts/overpass-webfont/overpass-extralight-italic.woff2") format("woff2"), url("./assets/fonts/overpass-webfont/overpass-extralight-italic.woff") format("woff");\n}\n@font-face {\n  font-family: "overpass";\n  font-style: normal;\n  font-weight: 400;\n  src: url("./assets/fonts/overpass-webfont/overpass-light.woff2") format("woff2"), url("./assets/fonts/overpass-webfont/overpass-light.woff") format("woff");\n}\n@font-face {\n  font-family: "overpass";\n  font-style: italic;\n  font-weight: 400;\n  src: url("./assets/fonts/overpass-webfont/overpass-light-italic.woff2") format("woff2"), url("./assets/fonts/overpass-webfont/overpass-light-italic.woff") format("woff");\n}\n@font-face {\n  font-family: "overpass";\n  font-style: normal;\n  font-weight: 500;\n  src: url("./assets/fonts/overpass-webfont/overpass-regular.woff2") format("woff2"), url("./assets/fonts/overpass-webfont/overpass-regular.woff") format("woff");\n}\n@font-face {\n  font-family: "overpass";\n  font-style: italic;\n  font-weight: 500;\n  src: url("./assets/fonts/overpass-webfont/overpass-italic.woff2") format("woff2"), url("./assets/fonts/overpass-webfont/overpass-italic.woff") format("woff");\n}\n@font-face {\n  font-family: "overpass";\n  font-style: normal;\n  font-weight: 600;\n  src: url("./assets/fonts/overpass-webfont/overpass-semibold.woff2") format("woff2"), url("./assets/fonts/overpass-webfont/overpass-semibold.woff") format("woff");\n}\n@font-face {\n  font-family: "overpass";\n  font-style: italic;\n  font-weight: 600;\n  src: url("./assets/fonts/overpass-webfont/overpass-semibold-italic.woff2") format("woff2"), url("./assets/fonts/overpass-webfont/overpass-semibold-italic.woff") format("woff");\n}\n@font-face {\n  font-family: "overpass";\n  font-style: normal;\n  font-weight: 700;\n  src: url("./assets/fonts/overpass-webfont/overpass-bold.woff2") format("woff2"), url("./assets/fonts/overpass-webfont/overpass-bold.woff") format("woff");\n}\n@font-face {\n  font-family: "overpass";\n  font-style: italic;\n  font-weight: 700;\n  src: url("./assets/fonts/overpass-webfont/overpass-bold-italic.woff2") format("woff2"), url("./assets/fonts/overpass-webfont/overpass-bold-italic.woff") format("woff");\n}\n@font-face {\n  font-family: "overpass";\n  font-style: normal;\n  font-weight: 800;\n  src: url("./assets/fonts/overpass-webfont/overpass-extrabold.woff2") format("woff2"), url("./assets/fonts/overpass-webfont/overpass-extrabold.woff") format("woff");\n}\n@font-face {\n  font-family: "overpass";\n  font-style: italic;\n  font-weight: 800;\n  src: url("./assets/fonts/overpass-webfont/overpass-extrabold-italic.woff2") format("woff2"), url("./assets/fonts/overpass-webfont/overpass-extrabold-italic.woff") format("woff");\n}\n@font-face {\n  font-family: "overpass";\n  font-style: normal;\n  font-weight: 900;\n  src: url("./assets/fonts/overpass-webfont/overpass-heavy.woff2") format("woff2"), url("./assets/fonts/overpass-webfont/overpass-heavy.woff") format("woff");\n}\n@font-face {\n  font-family: "overpass";\n  font-style: italic;\n  font-weight: 900;\n  src: url("./assets/fonts/overpass-webfont/overpass-heavy-italic.woff2") format("woff2"), url("./assets/fonts/overpass-webfont/overpass-heavy-italic.woff") format("woff");\n}\n@font-face {\n  font-family: "overpass-mono";\n  font-style: normal;\n  font-weight: 300;\n  src: url("./assets/fonts/overpass-mono-webfont/overpass-mono-light.woff2") format("woff2"), url("./assets/fonts/overpass-mono-webfont/overpass-mono-light.woff") format("woff");\n}\n@font-face {\n  font-family: "overpass-mono";\n  font-style: normal;\n  font-weight: 400;\n  src: url("./assets/fonts/overpass-mono-webfont/overpass-mono-regular.woff2") format("woff2"), url("./assets/fonts/overpass-mono-webfont/overpass-mono-regular.woff") format("woff");\n}\n@font-face {\n  font-family: "overpass-mono";\n  font-style: normal;\n  font-weight: 500;\n  src: url("./assets/fonts/overpass-mono-webfont/overpass-mono-semibold.woff2") format("woff2"), url("./assets/fonts/overpass-mono-webfont/overpass-mono-semibold.woff") format("woff");\n}\n@font-face {\n  font-family: "overpass-mono";\n  font-style: normal;\n  font-weight: 600;\n  src: url("./assets/fonts/overpass-mono-webfont/overpass-mono-bold.woff2") format("woff2"), url("./assets/fonts/overpass-mono-webfont/overpass-mono-bold.woff") format("woff");\n}\n[class*=pf-c-], [class*=pf-c-]::before, [class*=pf-c-]::after {\n  padding: 0;\n  margin: 0;\n  background-color: transparent;\n}\n\nhtml {\n  font-size: var(--pf-global--root--FontSize, unset) !important;\n}\n\n.pf-screen-reader {\n  position: fixed;\n  top: 0;\n  left: 0;\n  overflow: hidden;\n  clip: rect(0, 0, 0, 0);\n  white-space: nowrap;\n  border: 0;\n}\n.pf-screen-reader.pf-m-full-size {\n  width: 100%;\n  height: 100%;\n}\n.pf-screen-reader.pf-m-absolute {\n  position: absolute;\n}\n\n.pf-m-tabular-nums {\n  font-variant-numeric: tabular-nums;\n}\n\nhtml,\nbody,\np,\nol,\nul,\nli,\ndl,\ndt,\ndd,\nblockquote,\nfigure,\nfieldset,\nlegend,\ntextarea,\npre,\niframe,\nhr,\nh1,\nh2,\nh3,\nh4,\nh5,\nh6 {\n  padding: 0;\n  margin: 0;\n}\n\nhtml,\nbody {\n  height: 100%;\n}\n\nh1,\nh2,\nh3,\nh4,\nh5,\nh6 {\n  font-size: 100%;\n  font-weight: var(--pf-global--FontWeight--normal);\n}\n\nul {\n  list-style: none;\n}\n\nbutton,\ninput,\noptgroup,\nselect,\ntextarea {\n  margin: 0;\n  font-family: inherit;\n  font-size: 100%;\n  line-height: var(--pf-global--LineHeight--md);\n  color: var(--pf-global--Color--100);\n}\n\nimg,\nembed,\niframe,\nobject,\naudio,\nvideo {\n  max-width: 100%;\n  height: auto;\n}\n\niframe {\n  border: 0;\n}\n\ntable {\n  border-spacing: 0;\n  border-collapse: collapse;\n}\n\ntd,\nth {\n  padding: 0;\n  text-align: left;\n}\n\ncode,\npre {\n  font-family: var(--pf-global--FontFamily--monospace);\n}\n\n*,\n*::before,\n*::after {\n  box-sizing: border-box;\n}\n\nhtml {\n  font-family: sans-serif;\n  line-height: 1.15;\n}\n\nbody {\n  font-family: var(--pf-global--FontFamily--sans-serif);\n  font-size: var(--pf-global--FontSize--md);\n  font-weight: var(--pf-global--FontWeight--normal);\n  line-height: var(--pf-global--LineHeight--md);\n  text-align: left;\n  background-color: var(--pf-global--BackgroundColor--100);\n}\n\na {\n  font-weight: var(--pf-global--link--FontWeight);\n  color: var(--pf-global--link--Color);\n  text-decoration: var(--pf-global--link--TextDecoration);\n}\na:hover {\n  --pf-global--link--Color: var(--pf-global--link--Color--hover);\n  --pf-global--link--TextDecoration: var(--pf-global--link--TextDecoration--hover);\n}\n\nbutton,\na {\n  cursor: pointer;\n}\n\n.pf-m-overpass-font a {\n  font-weight: var(--pf-global--FontWeight--semi-bold);\n}\n\n:root:where(.pf-theme-dark) {\n  color-scheme: dark;\n}\n\n.pf-t-dark.pf-m-transparent {\n  background-color: transparent;\n}\n.pf-t-dark.pf-m-transparent-100 {\n  background-color: rgba(3, 3, 3, 0.42);\n}\n.pf-t-dark.pf-m-transparent-200 {\n  background-color: rgba(3, 3, 3, 0.6);\n}\n.pf-t-dark.pf-m-opaque-100 {\n  background-color: #1b1d21;\n}\n.pf-t-dark.pf-m-opaque-200 {\n  background-color: #0f1214;\n}\n\n.pf-t-light.pf-m-transparent {\n  background-color: transparent;\n}\n.pf-t-light.pf-m-opaque-100 {\n  background-color: #fff;\n}\n.pf-t-light.pf-m-opaque-200 {\n  background-color: #c6c7c8;\n}\n.pf-t-light.pf-m-opaque-300 {\n  background-color: #aaabac;\n}\n\n* .fa,\n* .fas,\n* .far,\n* .fal,\n* .fab {\n  -moz-osx-font-smoothing: grayscale;\n  -webkit-font-smoothing: antialiased;\n  display: inline-block;\n  font-style: normal;\n  font-variant: normal;\n  text-rendering: auto;\n  line-height: 1;\n}\n* .fa-lg {\n  font-size: 1.3333333333em;\n  line-height: 0.75em;\n  vertical-align: -0.0667em;\n}\n* .fa-xs {\n  font-size: 0.75em;\n}\n* .fa-sm {\n  font-size: 0.875em;\n}\n* .fa-1x {\n  font-size: 1em;\n}\n* .fa-2x {\n  font-size: 2em;\n}\n* .fa-3x {\n  font-size: 3em;\n}\n* .fa-4x {\n  font-size: 4em;\n}\n* .fa-5x {\n  font-size: 5em;\n}\n* .fa-6x {\n  font-size: 6em;\n}\n* .fa-7x {\n  font-size: 7em;\n}\n* .fa-8x {\n  font-size: 8em;\n}\n* .fa-9x {\n  font-size: 9em;\n}\n* .fa-10x {\n  font-size: 10em;\n}\n* .fa-fw {\n  text-align: center;\n  width: 1.25em;\n}\n* .fa-ul {\n  list-style-type: none;\n  margin-left: 2.5em;\n  padding-left: 0;\n}\n* .fa-ul > li {\n  position: relative;\n}\n* .fa-li {\n  left: -2em;\n  position: absolute;\n  text-align: center;\n  width: 2em;\n  line-height: inherit;\n}\n* .fa-border {\n  border: solid 0.08em #eee;\n  border-radius: 0.1em;\n  padding: 0.2em 0.25em 0.15em;\n}\n* .fa-pull-left {\n  float: left;\n}\n* .fa-pull-right {\n  float: right;\n}\n* .fa.fa-pull-left,\n* .fas.fa-pull-left,\n* .far.fa-pull-left,\n* .fal.fa-pull-left,\n* .fab.fa-pull-left {\n  margin-right: 0.3em;\n}\n* .fa.fa-pull-right,\n* .fas.fa-pull-right,\n* .far.fa-pull-right,\n* .fal.fa-pull-right,\n* .fab.fa-pull-right {\n  margin-left: 0.3em;\n}\n* .fa-spin {\n  animation: fa-spin 2s infinite linear;\n}\n* .fa-pulse {\n  animation: fa-spin 1s infinite steps(8);\n}\n@keyframes fa-spin {\n  0% {\n    transform: rotate(0deg);\n  }\n  100% {\n    transform: rotate(360deg);\n  }\n}\n* .fa-rotate-90 {\n  -ms-filter: "progid:DXImageTransform.Microsoft.BasicImage(rotation=1)";\n  transform: rotate(90deg);\n}\n* .fa-rotate-180 {\n  -ms-filter: "progid:DXImageTransform.Microsoft.BasicImage(rotation=2)";\n  transform: rotate(180deg);\n}\n* .fa-rotate-270 {\n  -ms-filter: "progid:DXImageTransform.Microsoft.BasicImage(rotation=3)";\n  transform: rotate(270deg);\n}\n* .fa-flip-horizontal {\n  -ms-filter: "progid:DXImageTransform.Microsoft.BasicImage(rotation=0, mirror=1)";\n  transform: scale(-1, 1);\n}\n* .fa-flip-vertical {\n  -ms-filter: "progid:DXImageTransform.Microsoft.BasicImage(rotation=2, mirror=1)";\n  transform: scale(1, -1);\n}\n* .fa-flip-horizontal.fa-flip-vertical {\n  -ms-filter: "progid:DXImageTransform.Microsoft.BasicImage(rotation=2, mirror=1)";\n  transform: scale(-1, -1);\n}\n* :root .fa-rotate-90,\n* :root .fa-rotate-180,\n* :root .fa-rotate-270,\n* :root .fa-flip-horizontal,\n* :root .fa-flip-vertical {\n  filter: none;\n}\n* .fa-stack {\n  display: inline-block;\n  height: 2em;\n  line-height: 2em;\n  position: relative;\n  vertical-align: middle;\n  width: 2.5em;\n}\n* .fa-stack-1x,\n* .fa-stack-2x {\n  left: 0;\n  position: absolute;\n  text-align: center;\n  width: 100%;\n}\n* .fa-stack-1x {\n  line-height: inherit;\n}\n* .fa-stack-2x {\n  font-size: 2em;\n}\n* .fa-inverse {\n  color: #fff;\n}\n* .fa-500px:before {\n  content: "\\f26e";\n}\n* .fa-accessible-icon:before {\n  content: "\\f368";\n}\n* .fa-accusoft:before {\n  content: "\\f369";\n}\n* .fa-acquisitions-incorporated:before {\n  content: "\\f6af";\n}\n* .fa-ad:before {\n  content: "\\f641";\n}\n* .fa-address-book:before {\n  content: "\\f2b9";\n}\n* .fa-address-card:before {\n  content: "\\f2bb";\n}\n* .fa-adjust:before {\n  content: "\\f042";\n}\n* .fa-adn:before {\n  content: "\\f170";\n}\n* .fa-adobe:before {\n  content: "\\f778";\n}\n* .fa-adversal:before {\n  content: "\\f36a";\n}\n* .fa-affiliatetheme:before {\n  content: "\\f36b";\n}\n* .fa-air-freshener:before {\n  content: "\\f5d0";\n}\n* .fa-algolia:before {\n  content: "\\f36c";\n}\n* .fa-align-center:before {\n  content: "\\f037";\n}\n* .fa-align-justify:before {\n  content: "\\f039";\n}\n* .fa-align-left:before {\n  content: "\\f036";\n}\n* .fa-align-right:before {\n  content: "\\f038";\n}\n* .fa-alipay:before {\n  content: "\\f642";\n}\n* .fa-allergies:before {\n  content: "\\f461";\n}\n* .fa-amazon:before {\n  content: "\\f270";\n}\n* .fa-amazon-pay:before {\n  content: "\\f42c";\n}\n* .fa-ambulance:before {\n  content: "\\f0f9";\n}\n* .fa-american-sign-language-interpreting:before {\n  content: "\\f2a3";\n}\n* .fa-amilia:before {\n  content: "\\f36d";\n}\n* .fa-anchor:before {\n  content: "\\f13d";\n}\n* .fa-android:before {\n  content: "\\f17b";\n}\n* .fa-angellist:before {\n  content: "\\f209";\n}\n* .fa-angle-double-down:before {\n  content: "\\f103";\n}\n* .fa-angle-double-left:before {\n  content: "\\f100";\n}\n* .fa-angle-double-right:before {\n  content: "\\f101";\n}\n* .fa-angle-double-up:before {\n  content: "\\f102";\n}\n* .fa-angle-down:before {\n  content: "\\f107";\n}\n* .fa-angle-left:before {\n  content: "\\f104";\n}\n* .fa-angle-right:before {\n  content: "\\f105";\n}\n* .fa-angle-up:before {\n  content: "\\f106";\n}\n* .fa-angry:before {\n  content: "\\f556";\n}\n* .fa-angrycreative:before {\n  content: "\\f36e";\n}\n* .fa-angular:before {\n  content: "\\f420";\n}\n* .fa-ankh:before {\n  content: "\\f644";\n}\n* .fa-app-store:before {\n  content: "\\f36f";\n}\n* .fa-app-store-ios:before {\n  content: "\\f370";\n}\n* .fa-apper:before {\n  content: "\\f371";\n}\n* .fa-apple:before {\n  content: "\\f179";\n}\n* .fa-apple-alt:before {\n  content: "\\f5d1";\n}\n* .fa-apple-pay:before {\n  content: "\\f415";\n}\n* .fa-archive:before {\n  content: "\\f187";\n}\n* .fa-archway:before {\n  content: "\\f557";\n}\n* .fa-arrow-alt-circle-down:before {\n  content: "\\f358";\n}\n* .fa-arrow-alt-circle-left:before {\n  content: "\\f359";\n}\n* .fa-arrow-alt-circle-right:before {\n  content: "\\f35a";\n}\n* .fa-arrow-alt-circle-up:before {\n  content: "\\f35b";\n}\n* .fa-arrow-circle-down:before {\n  content: "\\f0ab";\n}\n* .fa-arrow-circle-left:before {\n  content: "\\f0a8";\n}\n* .fa-arrow-circle-right:before {\n  content: "\\f0a9";\n}\n* .fa-arrow-circle-up:before {\n  content: "\\f0aa";\n}\n* .fa-arrow-down:before {\n  content: "\\f063";\n}\n* .fa-arrow-left:before {\n  content: "\\f060";\n}\n* .fa-arrow-right:before {\n  content: "\\f061";\n}\n* .fa-arrow-up:before {\n  content: "\\f062";\n}\n* .fa-arrows-alt:before {\n  content: "\\f0b2";\n}\n* .fa-arrows-alt-h:before {\n  content: "\\f337";\n}\n* .fa-arrows-alt-v:before {\n  content: "\\f338";\n}\n* .fa-artstation:before {\n  content: "\\f77a";\n}\n* .fa-assistive-listening-systems:before {\n  content: "\\f2a2";\n}\n* .fa-asterisk:before {\n  content: "\\f069";\n}\n* .fa-asymmetrik:before {\n  content: "\\f372";\n}\n* .fa-at:before {\n  content: "\\f1fa";\n}\n* .fa-atlas:before {\n  content: "\\f558";\n}\n* .fa-atlassian:before {\n  content: "\\f77b";\n}\n* .fa-atom:before {\n  content: "\\f5d2";\n}\n* .fa-audible:before {\n  content: "\\f373";\n}\n* .fa-audio-description:before {\n  content: "\\f29e";\n}\n* .fa-autoprefixer:before {\n  content: "\\f41c";\n}\n* .fa-avianex:before {\n  content: "\\f374";\n}\n* .fa-aviato:before {\n  content: "\\f421";\n}\n* .fa-award:before {\n  content: "\\f559";\n}\n* .fa-aws:before {\n  content: "\\f375";\n}\n* .fa-baby:before {\n  content: "\\f77c";\n}\n* .fa-baby-carriage:before {\n  content: "\\f77d";\n}\n* .fa-backspace:before {\n  content: "\\f55a";\n}\n* .fa-backward:before {\n  content: "\\f04a";\n}\n* .fa-balance-scale:before {\n  content: "\\f24e";\n}\n* .fa-ban:before {\n  content: "\\f05e";\n}\n* .fa-band-aid:before {\n  content: "\\f462";\n}\n* .fa-bandcamp:before {\n  content: "\\f2d5";\n}\n* .fa-barcode:before {\n  content: "\\f02a";\n}\n* .fa-bars:before {\n  content: "\\f0c9";\n}\n* .fa-baseball-ball:before {\n  content: "\\f433";\n}\n* .fa-basketball-ball:before {\n  content: "\\f434";\n}\n* .fa-bath:before {\n  content: "\\f2cd";\n}\n* .fa-battery-empty:before {\n  content: "\\f244";\n}\n* .fa-battery-full:before {\n  content: "\\f240";\n}\n* .fa-battery-half:before {\n  content: "\\f242";\n}\n* .fa-battery-quarter:before {\n  content: "\\f243";\n}\n* .fa-battery-three-quarters:before {\n  content: "\\f241";\n}\n* .fa-bed:before {\n  content: "\\f236";\n}\n* .fa-beer:before {\n  content: "\\f0fc";\n}\n* .fa-behance:before {\n  content: "\\f1b4";\n}\n* .fa-behance-square:before {\n  content: "\\f1b5";\n}\n* .fa-bell:before {\n  content: "\\f0f3";\n}\n* .fa-bell-slash:before {\n  content: "\\f1f6";\n}\n* .fa-bezier-curve:before {\n  content: "\\f55b";\n}\n* .fa-bible:before {\n  content: "\\f647";\n}\n* .fa-bicycle:before {\n  content: "\\f206";\n}\n* .fa-bimobject:before {\n  content: "\\f378";\n}\n* .fa-binoculars:before {\n  content: "\\f1e5";\n}\n* .fa-biohazard:before {\n  content: "\\f780";\n}\n* .fa-birthday-cake:before {\n  content: "\\f1fd";\n}\n* .fa-bitbucket:before {\n  content: "\\f171";\n}\n* .fa-bitcoin:before {\n  content: "\\f379";\n}\n* .fa-bity:before {\n  content: "\\f37a";\n}\n* .fa-black-tie:before {\n  content: "\\f27e";\n}\n* .fa-blackberry:before {\n  content: "\\f37b";\n}\n* .fa-blender:before {\n  content: "\\f517";\n}\n* .fa-blender-phone:before {\n  content: "\\f6b6";\n}\n* .fa-blind:before {\n  content: "\\f29d";\n}\n* .fa-blog:before {\n  content: "\\f781";\n}\n* .fa-blogger:before {\n  content: "\\f37c";\n}\n* .fa-blogger-b:before {\n  content: "\\f37d";\n}\n* .fa-bluetooth:before {\n  content: "\\f293";\n}\n* .fa-bluetooth-b:before {\n  content: "\\f294";\n}\n* .fa-bold:before {\n  content: "\\f032";\n}\n* .fa-bolt:before {\n  content: "\\f0e7";\n}\n* .fa-bomb:before {\n  content: "\\f1e2";\n}\n* .fa-bone:before {\n  content: "\\f5d7";\n}\n* .fa-bong:before {\n  content: "\\f55c";\n}\n* .fa-book:before {\n  content: "\\f02d";\n}\n* .fa-book-dead:before {\n  content: "\\f6b7";\n}\n* .fa-book-open:before {\n  content: "\\f518";\n}\n* .fa-book-reader:before {\n  content: "\\f5da";\n}\n* .fa-bookmark:before {\n  content: "\\f02e";\n}\n* .fa-bowling-ball:before {\n  content: "\\f436";\n}\n* .fa-box:before {\n  content: "\\f466";\n}\n* .fa-box-open:before {\n  content: "\\f49e";\n}\n* .fa-boxes:before {\n  content: "\\f468";\n}\n* .fa-braille:before {\n  content: "\\f2a1";\n}\n* .fa-brain:before {\n  content: "\\f5dc";\n}\n* .fa-briefcase:before {\n  content: "\\f0b1";\n}\n* .fa-briefcase-medical:before {\n  content: "\\f469";\n}\n* .fa-broadcast-tower:before {\n  content: "\\f519";\n}\n* .fa-broom:before {\n  content: "\\f51a";\n}\n* .fa-brush:before {\n  content: "\\f55d";\n}\n* .fa-btc:before {\n  content: "\\f15a";\n}\n* .fa-bug:before {\n  content: "\\f188";\n}\n* .fa-building:before {\n  content: "\\f1ad";\n}\n* .fa-bullhorn:before {\n  content: "\\f0a1";\n}\n* .fa-bullseye:before {\n  content: "\\f140";\n}\n* .fa-burn:before {\n  content: "\\f46a";\n}\n* .fa-buromobelexperte:before {\n  content: "\\f37f";\n}\n* .fa-bus:before {\n  content: "\\f207";\n}\n* .fa-bus-alt:before {\n  content: "\\f55e";\n}\n* .fa-business-time:before {\n  content: "\\f64a";\n}\n* .fa-buysellads:before {\n  content: "\\f20d";\n}\n* .fa-calculator:before {\n  content: "\\f1ec";\n}\n* .fa-calendar:before {\n  content: "\\f133";\n}\n* .fa-calendar-alt:before {\n  content: "\\f073";\n}\n* .fa-calendar-check:before {\n  content: "\\f274";\n}\n* .fa-calendar-day:before {\n  content: "\\f783";\n}\n* .fa-calendar-minus:before {\n  content: "\\f272";\n}\n* .fa-calendar-plus:before {\n  content: "\\f271";\n}\n* .fa-calendar-times:before {\n  content: "\\f273";\n}\n* .fa-calendar-week:before {\n  content: "\\f784";\n}\n* .fa-camera:before {\n  content: "\\f030";\n}\n* .fa-camera-retro:before {\n  content: "\\f083";\n}\n* .fa-campground:before {\n  content: "\\f6bb";\n}\n* .fa-canadian-maple-leaf:before {\n  content: "\\f785";\n}\n* .fa-candy-cane:before {\n  content: "\\f786";\n}\n* .fa-cannabis:before {\n  content: "\\f55f";\n}\n* .fa-capsules:before {\n  content: "\\f46b";\n}\n* .fa-car:before {\n  content: "\\f1b9";\n}\n* .fa-car-alt:before {\n  content: "\\f5de";\n}\n* .fa-car-battery:before {\n  content: "\\f5df";\n}\n* .fa-car-crash:before {\n  content: "\\f5e1";\n}\n* .fa-car-side:before {\n  content: "\\f5e4";\n}\n* .fa-caret-down:before {\n  content: "\\f0d7";\n}\n* .fa-caret-left:before {\n  content: "\\f0d9";\n}\n* .fa-caret-right:before {\n  content: "\\f0da";\n}\n* .fa-caret-square-down:before {\n  content: "\\f150";\n}\n* .fa-caret-square-left:before {\n  content: "\\f191";\n}\n* .fa-caret-square-right:before {\n  content: "\\f152";\n}\n* .fa-caret-square-up:before {\n  content: "\\f151";\n}\n* .fa-caret-up:before {\n  content: "\\f0d8";\n}\n* .fa-carrot:before {\n  content: "\\f787";\n}\n* .fa-cart-arrow-down:before {\n  content: "\\f218";\n}\n* .fa-cart-plus:before {\n  content: "\\f217";\n}\n* .fa-cash-register:before {\n  content: "\\f788";\n}\n* .fa-cat:before {\n  content: "\\f6be";\n}\n* .fa-cc-amazon-pay:before {\n  content: "\\f42d";\n}\n* .fa-cc-amex:before {\n  content: "\\f1f3";\n}\n* .fa-cc-apple-pay:before {\n  content: "\\f416";\n}\n* .fa-cc-diners-club:before {\n  content: "\\f24c";\n}\n* .fa-cc-discover:before {\n  content: "\\f1f2";\n}\n* .fa-cc-jcb:before {\n  content: "\\f24b";\n}\n* .fa-cc-mastercard:before {\n  content: "\\f1f1";\n}\n* .fa-cc-paypal:before {\n  content: "\\f1f4";\n}\n* .fa-cc-stripe:before {\n  content: "\\f1f5";\n}\n* .fa-cc-visa:before {\n  content: "\\f1f0";\n}\n* .fa-centercode:before {\n  content: "\\f380";\n}\n* .fa-centos:before {\n  content: "\\f789";\n}\n* .fa-certificate:before {\n  content: "\\f0a3";\n}\n* .fa-chair:before {\n  content: "\\f6c0";\n}\n* .fa-chalkboard:before {\n  content: "\\f51b";\n}\n* .fa-chalkboard-teacher:before {\n  content: "\\f51c";\n}\n* .fa-charging-station:before {\n  content: "\\f5e7";\n}\n* .fa-chart-area:before {\n  content: "\\f1fe";\n}\n* .fa-chart-bar:before {\n  content: "\\f080";\n}\n* .fa-chart-line:before {\n  content: "\\f201";\n}\n* .fa-chart-pie:before {\n  content: "\\f200";\n}\n* .fa-check:before {\n  content: "\\f00c";\n}\n* .fa-check-circle:before {\n  content: "\\f058";\n}\n* .fa-check-double:before {\n  content: "\\f560";\n}\n* .fa-check-square:before {\n  content: "\\f14a";\n}\n* .fa-chess:before {\n  content: "\\f439";\n}\n* .fa-chess-bishop:before {\n  content: "\\f43a";\n}\n* .fa-chess-board:before {\n  content: "\\f43c";\n}\n* .fa-chess-king:before {\n  content: "\\f43f";\n}\n* .fa-chess-knight:before {\n  content: "\\f441";\n}\n* .fa-chess-pawn:before {\n  content: "\\f443";\n}\n* .fa-chess-queen:before {\n  content: "\\f445";\n}\n* .fa-chess-rook:before {\n  content: "\\f447";\n}\n* .fa-chevron-circle-down:before {\n  content: "\\f13a";\n}\n* .fa-chevron-circle-left:before {\n  content: "\\f137";\n}\n* .fa-chevron-circle-right:before {\n  content: "\\f138";\n}\n* .fa-chevron-circle-up:before {\n  content: "\\f139";\n}\n* .fa-chevron-down:before {\n  content: "\\f078";\n}\n* .fa-chevron-left:before {\n  content: "\\f053";\n}\n* .fa-chevron-right:before {\n  content: "\\f054";\n}\n* .fa-chevron-up:before {\n  content: "\\f077";\n}\n* .fa-child:before {\n  content: "\\f1ae";\n}\n* .fa-chrome:before {\n  content: "\\f268";\n}\n* .fa-church:before {\n  content: "\\f51d";\n}\n* .fa-circle:before {\n  content: "\\f111";\n}\n* .fa-circle-notch:before {\n  content: "\\f1ce";\n}\n* .fa-city:before {\n  content: "\\f64f";\n}\n* .fa-clipboard:before {\n  content: "\\f328";\n}\n* .fa-clipboard-check:before {\n  content: "\\f46c";\n}\n* .fa-clipboard-list:before {\n  content: "\\f46d";\n}\n* .fa-clock:before {\n  content: "\\f017";\n}\n* .fa-clone:before {\n  content: "\\f24d";\n}\n* .fa-closed-captioning:before {\n  content: "\\f20a";\n}\n* .fa-cloud:before {\n  content: "\\f0c2";\n}\n* .fa-cloud-download-alt:before {\n  content: "\\f381";\n}\n* .fa-cloud-meatball:before {\n  content: "\\f73b";\n}\n* .fa-cloud-moon:before {\n  content: "\\f6c3";\n}\n* .fa-cloud-moon-rain:before {\n  content: "\\f73c";\n}\n* .fa-cloud-rain:before {\n  content: "\\f73d";\n}\n* .fa-cloud-showers-heavy:before {\n  content: "\\f740";\n}\n* .fa-cloud-sun:before {\n  content: "\\f6c4";\n}\n* .fa-cloud-sun-rain:before {\n  content: "\\f743";\n}\n* .fa-cloud-upload-alt:before {\n  content: "\\f382";\n}\n* .fa-cloudscale:before {\n  content: "\\f383";\n}\n* .fa-cloudsmith:before {\n  content: "\\f384";\n}\n* .fa-cloudversify:before {\n  content: "\\f385";\n}\n* .fa-cocktail:before {\n  content: "\\f561";\n}\n* .fa-code:before {\n  content: "\\f121";\n}\n* .fa-code-branch:before {\n  content: "\\f126";\n}\n* .fa-codepen:before {\n  content: "\\f1cb";\n}\n* .fa-codiepie:before {\n  content: "\\f284";\n}\n* .fa-coffee:before {\n  content: "\\f0f4";\n}\n* .fa-cog:before {\n  content: "\\f013";\n}\n* .fa-cogs:before {\n  content: "\\f085";\n}\n* .fa-coins:before {\n  content: "\\f51e";\n}\n* .fa-columns:before {\n  content: "\\f0db";\n}\n* .fa-comment:before {\n  content: "\\f075";\n}\n* .fa-comment-alt:before {\n  content: "\\f27a";\n}\n* .fa-comment-dollar:before {\n  content: "\\f651";\n}\n* .fa-comment-dots:before {\n  content: "\\f4ad";\n}\n* .fa-comment-slash:before {\n  content: "\\f4b3";\n}\n* .fa-comments:before {\n  content: "\\f086";\n}\n* .fa-comments-dollar:before {\n  content: "\\f653";\n}\n* .fa-compact-disc:before {\n  content: "\\f51f";\n}\n* .fa-compass:before {\n  content: "\\f14e";\n}\n* .fa-compress:before {\n  content: "\\f066";\n}\n* .fa-compress-arrows-alt:before {\n  content: "\\f78c";\n}\n* .fa-concierge-bell:before {\n  content: "\\f562";\n}\n* .fa-confluence:before {\n  content: "\\f78d";\n}\n* .fa-connectdevelop:before {\n  content: "\\f20e";\n}\n* .fa-contao:before {\n  content: "\\f26d";\n}\n* .fa-cookie:before {\n  content: "\\f563";\n}\n* .fa-cookie-bite:before {\n  content: "\\f564";\n}\n* .fa-copy:before {\n  content: "\\f0c5";\n}\n* .fa-copyright:before {\n  content: "\\f1f9";\n}\n* .fa-couch:before {\n  content: "\\f4b8";\n}\n* .fa-cpanel:before {\n  content: "\\f388";\n}\n* .fa-creative-commons:before {\n  content: "\\f25e";\n}\n* .fa-creative-commons-by:before {\n  content: "\\f4e7";\n}\n* .fa-creative-commons-nc:before {\n  content: "\\f4e8";\n}\n* .fa-creative-commons-nc-eu:before {\n  content: "\\f4e9";\n}\n* .fa-creative-commons-nc-jp:before {\n  content: "\\f4ea";\n}\n* .fa-creative-commons-nd:before {\n  content: "\\f4eb";\n}\n* .fa-creative-commons-pd:before {\n  content: "\\f4ec";\n}\n* .fa-creative-commons-pd-alt:before {\n  content: "\\f4ed";\n}\n* .fa-creative-commons-remix:before {\n  content: "\\f4ee";\n}\n* .fa-creative-commons-sa:before {\n  content: "\\f4ef";\n}\n* .fa-creative-commons-sampling:before {\n  content: "\\f4f0";\n}\n* .fa-creative-commons-sampling-plus:before {\n  content: "\\f4f1";\n}\n* .fa-creative-commons-share:before {\n  content: "\\f4f2";\n}\n* .fa-creative-commons-zero:before {\n  content: "\\f4f3";\n}\n* .fa-credit-card:before {\n  content: "\\f09d";\n}\n* .fa-critical-role:before {\n  content: "\\f6c9";\n}\n* .fa-crop:before {\n  content: "\\f125";\n}\n* .fa-crop-alt:before {\n  content: "\\f565";\n}\n* .fa-cross:before {\n  content: "\\f654";\n}\n* .fa-crosshairs:before {\n  content: "\\f05b";\n}\n* .fa-crow:before {\n  content: "\\f520";\n}\n* .fa-crown:before {\n  content: "\\f521";\n}\n* .fa-css3:before {\n  content: "\\f13c";\n}\n* .fa-css3-alt:before {\n  content: "\\f38b";\n}\n* .fa-cube:before {\n  content: "\\f1b2";\n}\n* .fa-cubes:before {\n  content: "\\f1b3";\n}\n* .fa-cut:before {\n  content: "\\f0c4";\n}\n* .fa-cuttlefish:before {\n  content: "\\f38c";\n}\n* .fa-d-and-d:before {\n  content: "\\f38d";\n}\n* .fa-d-and-d-beyond:before {\n  content: "\\f6ca";\n}\n* .fa-dashcube:before {\n  content: "\\f210";\n}\n* .fa-database:before {\n  content: "\\f1c0";\n}\n* .fa-deaf:before {\n  content: "\\f2a4";\n}\n* .fa-delicious:before {\n  content: "\\f1a5";\n}\n* .fa-democrat:before {\n  content: "\\f747";\n}\n* .fa-deploydog:before {\n  content: "\\f38e";\n}\n* .fa-deskpro:before {\n  content: "\\f38f";\n}\n* .fa-desktop:before {\n  content: "\\f108";\n}\n* .fa-dev:before {\n  content: "\\f6cc";\n}\n* .fa-deviantart:before {\n  content: "\\f1bd";\n}\n* .fa-dharmachakra:before {\n  content: "\\f655";\n}\n* .fa-dhl:before {\n  content: "\\f790";\n}\n* .fa-diagnoses:before {\n  content: "\\f470";\n}\n* .fa-diaspora:before {\n  content: "\\f791";\n}\n* .fa-dice:before {\n  content: "\\f522";\n}\n* .fa-dice-d20:before {\n  content: "\\f6cf";\n}\n* .fa-dice-d6:before {\n  content: "\\f6d1";\n}\n* .fa-dice-five:before {\n  content: "\\f523";\n}\n* .fa-dice-four:before {\n  content: "\\f524";\n}\n* .fa-dice-one:before {\n  content: "\\f525";\n}\n* .fa-dice-six:before {\n  content: "\\f526";\n}\n* .fa-dice-three:before {\n  content: "\\f527";\n}\n* .fa-dice-two:before {\n  content: "\\f528";\n}\n* .fa-digg:before {\n  content: "\\f1a6";\n}\n* .fa-digital-ocean:before {\n  content: "\\f391";\n}\n* .fa-digital-tachograph:before {\n  content: "\\f566";\n}\n* .fa-directions:before {\n  content: "\\f5eb";\n}\n* .fa-discord:before {\n  content: "\\f392";\n}\n* .fa-discourse:before {\n  content: "\\f393";\n}\n* .fa-divide:before {\n  content: "\\f529";\n}\n* .fa-dizzy:before {\n  content: "\\f567";\n}\n* .fa-dna:before {\n  content: "\\f471";\n}\n* .fa-dochub:before {\n  content: "\\f394";\n}\n* .fa-docker:before {\n  content: "\\f395";\n}\n* .fa-dog:before {\n  content: "\\f6d3";\n}\n* .fa-dollar-sign:before {\n  content: "\\f155";\n}\n* .fa-dolly:before {\n  content: "\\f472";\n}\n* .fa-dolly-flatbed:before {\n  content: "\\f474";\n}\n* .fa-donate:before {\n  content: "\\f4b9";\n}\n* .fa-door-closed:before {\n  content: "\\f52a";\n}\n* .fa-door-open:before {\n  content: "\\f52b";\n}\n* .fa-dot-circle:before {\n  content: "\\f192";\n}\n* .fa-dove:before {\n  content: "\\f4ba";\n}\n* .fa-download:before {\n  content: "\\f019";\n}\n* .fa-draft2digital:before {\n  content: "\\f396";\n}\n* .fa-drafting-compass:before {\n  content: "\\f568";\n}\n* .fa-dragon:before {\n  content: "\\f6d5";\n}\n* .fa-draw-polygon:before {\n  content: "\\f5ee";\n}\n* .fa-dribbble:before {\n  content: "\\f17d";\n}\n* .fa-dribbble-square:before {\n  content: "\\f397";\n}\n* .fa-dropbox:before {\n  content: "\\f16b";\n}\n* .fa-drum:before {\n  content: "\\f569";\n}\n* .fa-drum-steelpan:before {\n  content: "\\f56a";\n}\n* .fa-drumstick-bite:before {\n  content: "\\f6d7";\n}\n* .fa-drupal:before {\n  content: "\\f1a9";\n}\n* .fa-dumbbell:before {\n  content: "\\f44b";\n}\n* .fa-dumpster:before {\n  content: "\\f793";\n}\n* .fa-dumpster-fire:before {\n  content: "\\f794";\n}\n* .fa-dungeon:before {\n  content: "\\f6d9";\n}\n* .fa-dyalog:before {\n  content: "\\f399";\n}\n* .fa-earlybirds:before {\n  content: "\\f39a";\n}\n* .fa-ebay:before {\n  content: "\\f4f4";\n}\n* .fa-edge:before {\n  content: "\\f282";\n}\n* .fa-edit:before {\n  content: "\\f044";\n}\n* .fa-eject:before {\n  content: "\\f052";\n}\n* .fa-elementor:before {\n  content: "\\f430";\n}\n* .fa-ellipsis-h:before {\n  content: "\\f141";\n}\n* .fa-ellipsis-v:before {\n  content: "\\f142";\n}\n* .fa-ello:before {\n  content: "\\f5f1";\n}\n* .fa-ember:before {\n  content: "\\f423";\n}\n* .fa-empire:before {\n  content: "\\f1d1";\n}\n* .fa-envelope:before {\n  content: "\\f0e0";\n}\n* .fa-envelope-open:before {\n  content: "\\f2b6";\n}\n* .fa-envelope-open-text:before {\n  content: "\\f658";\n}\n* .fa-envelope-square:before {\n  content: "\\f199";\n}\n* .fa-envira:before {\n  content: "\\f299";\n}\n* .fa-equals:before {\n  content: "\\f52c";\n}\n* .fa-eraser:before {\n  content: "\\f12d";\n}\n* .fa-erlang:before {\n  content: "\\f39d";\n}\n* .fa-ethereum:before {\n  content: "\\f42e";\n}\n* .fa-ethernet:before {\n  content: "\\f796";\n}\n* .fa-etsy:before {\n  content: "\\f2d7";\n}\n* .fa-euro-sign:before {\n  content: "\\f153";\n}\n* .fa-exchange-alt:before {\n  content: "\\f362";\n}\n* .fa-exclamation:before {\n  content: "\\f12a";\n}\n* .fa-exclamation-circle:before {\n  content: "\\f06a";\n}\n* .fa-exclamation-triangle:before {\n  content: "\\f071";\n}\n* .fa-expand:before {\n  content: "\\f065";\n}\n* .fa-expand-arrows-alt:before {\n  content: "\\f31e";\n}\n* .fa-expeditedssl:before {\n  content: "\\f23e";\n}\n* .fa-external-link-alt:before {\n  content: "\\f35d";\n}\n* .fa-external-link-square-alt:before {\n  content: "\\f360";\n}\n* .fa-eye:before {\n  content: "\\f06e";\n}\n* .fa-eye-dropper:before {\n  content: "\\f1fb";\n}\n* .fa-eye-slash:before {\n  content: "\\f070";\n}\n* .fa-facebook:before {\n  content: "\\f09a";\n}\n* .fa-facebook-f:before {\n  content: "\\f39e";\n}\n* .fa-facebook-messenger:before {\n  content: "\\f39f";\n}\n* .fa-facebook-square:before {\n  content: "\\f082";\n}\n* .fa-fantasy-flight-games:before {\n  content: "\\f6dc";\n}\n* .fa-fast-backward:before {\n  content: "\\f049";\n}\n* .fa-fast-forward:before {\n  content: "\\f050";\n}\n* .fa-fax:before {\n  content: "\\f1ac";\n}\n* .fa-feather:before {\n  content: "\\f52d";\n}\n* .fa-feather-alt:before {\n  content: "\\f56b";\n}\n* .fa-fedex:before {\n  content: "\\f797";\n}\n* .fa-fedora:before {\n  content: "\\f798";\n}\n* .fa-female:before {\n  content: "\\f182";\n}\n* .fa-fighter-jet:before {\n  content: "\\f0fb";\n}\n* .fa-figma:before {\n  content: "\\f799";\n}\n* .fa-file:before {\n  content: "\\f15b";\n}\n* .fa-file-alt:before {\n  content: "\\f15c";\n}\n* .fa-file-archive:before {\n  content: "\\f1c6";\n}\n* .fa-file-audio:before {\n  content: "\\f1c7";\n}\n* .fa-file-code:before {\n  content: "\\f1c9";\n}\n* .fa-file-contract:before {\n  content: "\\f56c";\n}\n* .fa-file-csv:before {\n  content: "\\f6dd";\n}\n* .fa-file-download:before {\n  content: "\\f56d";\n}\n* .fa-file-excel:before {\n  content: "\\f1c3";\n}\n* .fa-file-export:before {\n  content: "\\f56e";\n}\n* .fa-file-image:before {\n  content: "\\f1c5";\n}\n* .fa-file-import:before {\n  content: "\\f56f";\n}\n* .fa-file-invoice:before {\n  content: "\\f570";\n}\n* .fa-file-invoice-dollar:before {\n  content: "\\f571";\n}\n* .fa-file-medical:before {\n  content: "\\f477";\n}\n* .fa-file-medical-alt:before {\n  content: "\\f478";\n}\n* .fa-file-pdf:before {\n  content: "\\f1c1";\n}\n* .fa-file-powerpoint:before {\n  content: "\\f1c4";\n}\n* .fa-file-prescription:before {\n  content: "\\f572";\n}\n* .fa-file-signature:before {\n  content: "\\f573";\n}\n* .fa-file-upload:before {\n  content: "\\f574";\n}\n* .fa-file-video:before {\n  content: "\\f1c8";\n}\n* .fa-file-word:before {\n  content: "\\f1c2";\n}\n* .fa-fill:before {\n  content: "\\f575";\n}\n* .fa-fill-drip:before {\n  content: "\\f576";\n}\n* .fa-film:before {\n  content: "\\f008";\n}\n* .fa-filter:before {\n  content: "\\f0b0";\n}\n* .fa-fingerprint:before {\n  content: "\\f577";\n}\n* .fa-fire:before {\n  content: "\\f06d";\n}\n* .fa-fire-alt:before {\n  content: "\\f7e4";\n}\n* .fa-fire-extinguisher:before {\n  content: "\\f134";\n}\n* .fa-firefox:before {\n  content: "\\f269";\n}\n* .fa-first-aid:before {\n  content: "\\f479";\n}\n* .fa-first-order:before {\n  content: "\\f2b0";\n}\n* .fa-first-order-alt:before {\n  content: "\\f50a";\n}\n* .fa-firstdraft:before {\n  content: "\\f3a1";\n}\n* .fa-fish:before {\n  content: "\\f578";\n}\n* .fa-fist-raised:before {\n  content: "\\f6de";\n}\n* .fa-flag:before {\n  content: "\\f024";\n}\n* .fa-flag-checkered:before {\n  content: "\\f11e";\n}\n* .fa-flag-usa:before {\n  content: "\\f74d";\n}\n* .fa-flask:before {\n  content: "\\f0c3";\n}\n* .fa-flickr:before {\n  content: "\\f16e";\n}\n* .fa-flipboard:before {\n  content: "\\f44d";\n}\n* .fa-flushed:before {\n  content: "\\f579";\n}\n* .fa-fly:before {\n  content: "\\f417";\n}\n* .fa-folder:before {\n  content: "\\f07b";\n}\n* .fa-folder-minus:before {\n  content: "\\f65d";\n}\n* .fa-folder-open:before {\n  content: "\\f07c";\n}\n* .fa-folder-plus:before {\n  content: "\\f65e";\n}\n* .fa-font:before {\n  content: "\\f031";\n}\n* .fa-font-awesome:before {\n  content: "\\f2b4";\n}\n* .fa-font-awesome-alt:before {\n  content: "\\f35c";\n}\n* .fa-font-awesome-flag:before {\n  content: "\\f425";\n}\n* .fa-font-awesome-logo-full:before {\n  content: "\\f4e6";\n}\n* .fa-fonticons:before {\n  content: "\\f280";\n}\n* .fa-fonticons-fi:before {\n  content: "\\f3a2";\n}\n* .fa-football-ball:before {\n  content: "\\f44e";\n}\n* .fa-fort-awesome:before {\n  content: "\\f286";\n}\n* .fa-fort-awesome-alt:before {\n  content: "\\f3a3";\n}\n* .fa-forumbee:before {\n  content: "\\f211";\n}\n* .fa-forward:before {\n  content: "\\f04e";\n}\n* .fa-foursquare:before {\n  content: "\\f180";\n}\n* .fa-free-code-camp:before {\n  content: "\\f2c5";\n}\n* .fa-freebsd:before {\n  content: "\\f3a4";\n}\n* .fa-frog:before {\n  content: "\\f52e";\n}\n* .fa-frown:before {\n  content: "\\f119";\n}\n* .fa-frown-open:before {\n  content: "\\f57a";\n}\n* .fa-fulcrum:before {\n  content: "\\f50b";\n}\n* .fa-funnel-dollar:before {\n  content: "\\f662";\n}\n* .fa-futbol:before {\n  content: "\\f1e3";\n}\n* .fa-galactic-republic:before {\n  content: "\\f50c";\n}\n* .fa-galactic-senate:before {\n  content: "\\f50d";\n}\n* .fa-gamepad:before {\n  content: "\\f11b";\n}\n* .fa-gas-pump:before {\n  content: "\\f52f";\n}\n* .fa-gavel:before {\n  content: "\\f0e3";\n}\n* .fa-gem:before {\n  content: "\\f3a5";\n}\n* .fa-genderless:before {\n  content: "\\f22d";\n}\n* .fa-get-pocket:before {\n  content: "\\f265";\n}\n* .fa-gg:before {\n  content: "\\f260";\n}\n* .fa-gg-circle:before {\n  content: "\\f261";\n}\n* .fa-ghost:before {\n  content: "\\f6e2";\n}\n* .fa-gift:before {\n  content: "\\f06b";\n}\n* .fa-gifts:before {\n  content: "\\f79c";\n}\n* .fa-git:before {\n  content: "\\f1d3";\n}\n* .fa-git-square:before {\n  content: "\\f1d2";\n}\n* .fa-github:before {\n  content: "\\f09b";\n}\n* .fa-github-alt:before {\n  content: "\\f113";\n}\n* .fa-github-square:before {\n  content: "\\f092";\n}\n* .fa-gitkraken:before {\n  content: "\\f3a6";\n}\n* .fa-gitlab:before {\n  content: "\\f296";\n}\n* .fa-gitter:before {\n  content: "\\f426";\n}\n* .fa-glass-cheers:before {\n  content: "\\f79f";\n}\n* .fa-glass-martini:before {\n  content: "\\f000";\n}\n* .fa-glass-martini-alt:before {\n  content: "\\f57b";\n}\n* .fa-glass-whiskey:before {\n  content: "\\f7a0";\n}\n* .fa-glasses:before {\n  content: "\\f530";\n}\n* .fa-glide:before {\n  content: "\\f2a5";\n}\n* .fa-glide-g:before {\n  content: "\\f2a6";\n}\n* .fa-globe:before {\n  content: "\\f0ac";\n}\n* .fa-globe-africa:before {\n  content: "\\f57c";\n}\n* .fa-globe-americas:before {\n  content: "\\f57d";\n}\n* .fa-globe-asia:before {\n  content: "\\f57e";\n}\n* .fa-globe-europe:before {\n  content: "\\f7a2";\n}\n* .fa-gofore:before {\n  content: "\\f3a7";\n}\n* .fa-golf-ball:before {\n  content: "\\f450";\n}\n* .fa-goodreads:before {\n  content: "\\f3a8";\n}\n* .fa-goodreads-g:before {\n  content: "\\f3a9";\n}\n* .fa-google:before {\n  content: "\\f1a0";\n}\n* .fa-google-drive:before {\n  content: "\\f3aa";\n}\n* .fa-google-play:before {\n  content: "\\f3ab";\n}\n* .fa-google-plus:before {\n  content: "\\f2b3";\n}\n* .fa-google-plus-g:before {\n  content: "\\f0d5";\n}\n* .fa-google-plus-square:before {\n  content: "\\f0d4";\n}\n* .fa-google-wallet:before {\n  content: "\\f1ee";\n}\n* .fa-gopuram:before {\n  content: "\\f664";\n}\n* .fa-graduation-cap:before {\n  content: "\\f19d";\n}\n* .fa-gratipay:before {\n  content: "\\f184";\n}\n* .fa-grav:before {\n  content: "\\f2d6";\n}\n* .fa-greater-than:before {\n  content: "\\f531";\n}\n* .fa-greater-than-equal:before {\n  content: "\\f532";\n}\n* .fa-grimace:before {\n  content: "\\f57f";\n}\n* .fa-grin:before {\n  content: "\\f580";\n}\n* .fa-grin-alt:before {\n  content: "\\f581";\n}\n* .fa-grin-beam:before {\n  content: "\\f582";\n}\n* .fa-grin-beam-sweat:before {\n  content: "\\f583";\n}\n* .fa-grin-hearts:before {\n  content: "\\f584";\n}\n* .fa-grin-squint:before {\n  content: "\\f585";\n}\n* .fa-grin-squint-tears:before {\n  content: "\\f586";\n}\n* .fa-grin-stars:before {\n  content: "\\f587";\n}\n* .fa-grin-tears:before {\n  content: "\\f588";\n}\n* .fa-grin-tongue:before {\n  content: "\\f589";\n}\n* .fa-grin-tongue-squint:before {\n  content: "\\f58a";\n}\n* .fa-grin-tongue-wink:before {\n  content: "\\f58b";\n}\n* .fa-grin-wink:before {\n  content: "\\f58c";\n}\n* .fa-grip-horizontal:before {\n  content: "\\f58d";\n}\n* .fa-grip-lines:before {\n  content: "\\f7a4";\n}\n* .fa-grip-lines-vertical:before {\n  content: "\\f7a5";\n}\n* .fa-grip-vertical:before {\n  content: "\\f58e";\n}\n* .fa-gripfire:before {\n  content: "\\f3ac";\n}\n* .fa-grunt:before {\n  content: "\\f3ad";\n}\n* .fa-guitar:before {\n  content: "\\f7a6";\n}\n* .fa-gulp:before {\n  content: "\\f3ae";\n}\n* .fa-h-square:before {\n  content: "\\f0fd";\n}\n* .fa-hacker-news:before {\n  content: "\\f1d4";\n}\n* .fa-hacker-news-square:before {\n  content: "\\f3af";\n}\n* .fa-hackerrank:before {\n  content: "\\f5f7";\n}\n* .fa-hammer:before {\n  content: "\\f6e3";\n}\n* .fa-hamsa:before {\n  content: "\\f665";\n}\n* .fa-hand-holding:before {\n  content: "\\f4bd";\n}\n* .fa-hand-holding-heart:before {\n  content: "\\f4be";\n}\n* .fa-hand-holding-usd:before {\n  content: "\\f4c0";\n}\n* .fa-hand-lizard:before {\n  content: "\\f258";\n}\n* .fa-hand-paper:before {\n  content: "\\f256";\n}\n* .fa-hand-peace:before {\n  content: "\\f25b";\n}\n* .fa-hand-point-down:before {\n  content: "\\f0a7";\n}\n* .fa-hand-point-left:before {\n  content: "\\f0a5";\n}\n* .fa-hand-point-right:before {\n  content: "\\f0a4";\n}\n* .fa-hand-point-up:before {\n  content: "\\f0a6";\n}\n* .fa-hand-pointer:before {\n  content: "\\f25a";\n}\n* .fa-hand-rock:before {\n  content: "\\f255";\n}\n* .fa-hand-scissors:before {\n  content: "\\f257";\n}\n* .fa-hand-spock:before {\n  content: "\\f259";\n}\n* .fa-hands:before {\n  content: "\\f4c2";\n}\n* .fa-hands-helping:before {\n  content: "\\f4c4";\n}\n* .fa-handshake:before {\n  content: "\\f2b5";\n}\n* .fa-hanukiah:before {\n  content: "\\f6e6";\n}\n* .fa-hashtag:before {\n  content: "\\f292";\n}\n* .fa-hat-wizard:before {\n  content: "\\f6e8";\n}\n* .fa-haykal:before {\n  content: "\\f666";\n}\n* .fa-hdd:before {\n  content: "\\f0a0";\n}\n* .fa-heading:before {\n  content: "\\f1dc";\n}\n* .fa-headphones:before {\n  content: "\\f025";\n}\n* .fa-headphones-alt:before {\n  content: "\\f58f";\n}\n* .fa-headset:before {\n  content: "\\f590";\n}\n* .fa-heart:before {\n  content: "\\f004";\n}\n* .fa-heart-broken:before {\n  content: "\\f7a9";\n}\n* .fa-heartbeat:before {\n  content: "\\f21e";\n}\n* .fa-helicopter:before {\n  content: "\\f533";\n}\n* .fa-highlighter:before {\n  content: "\\f591";\n}\n* .fa-hiking:before {\n  content: "\\f6ec";\n}\n* .fa-hippo:before {\n  content: "\\f6ed";\n}\n* .fa-hips:before {\n  content: "\\f452";\n}\n* .fa-hire-a-helper:before {\n  content: "\\f3b0";\n}\n* .fa-history:before {\n  content: "\\f1da";\n}\n* .fa-hockey-puck:before {\n  content: "\\f453";\n}\n* .fa-holly-berry:before {\n  content: "\\f7aa";\n}\n* .fa-home:before {\n  content: "\\f015";\n}\n* .fa-hooli:before {\n  content: "\\f427";\n}\n* .fa-hornbill:before {\n  content: "\\f592";\n}\n* .fa-horse:before {\n  content: "\\f6f0";\n}\n* .fa-horse-head:before {\n  content: "\\f7ab";\n}\n* .fa-hospital:before {\n  content: "\\f0f8";\n}\n* .fa-hospital-alt:before {\n  content: "\\f47d";\n}\n* .fa-hospital-symbol:before {\n  content: "\\f47e";\n}\n* .fa-hot-tub:before {\n  content: "\\f593";\n}\n* .fa-hotel:before {\n  content: "\\f594";\n}\n* .fa-hotjar:before {\n  content: "\\f3b1";\n}\n* .fa-hourglass:before {\n  content: "\\f254";\n}\n* .fa-hourglass-end:before {\n  content: "\\f253";\n}\n* .fa-hourglass-half:before {\n  content: "\\f252";\n}\n* .fa-hourglass-start:before {\n  content: "\\f251";\n}\n* .fa-house-damage:before {\n  content: "\\f6f1";\n}\n* .fa-houzz:before {\n  content: "\\f27c";\n}\n* .fa-hryvnia:before {\n  content: "\\f6f2";\n}\n* .fa-html5:before {\n  content: "\\f13b";\n}\n* .fa-hubspot:before {\n  content: "\\f3b2";\n}\n* .fa-i-cursor:before {\n  content: "\\f246";\n}\n* .fa-icicles:before {\n  content: "\\f7ad";\n}\n* .fa-id-badge:before {\n  content: "\\f2c1";\n}\n* .fa-id-card:before {\n  content: "\\f2c2";\n}\n* .fa-id-card-alt:before {\n  content: "\\f47f";\n}\n* .fa-igloo:before {\n  content: "\\f7ae";\n}\n* .fa-image:before {\n  content: "\\f03e";\n}\n* .fa-images:before {\n  content: "\\f302";\n}\n* .fa-imdb:before {\n  content: "\\f2d8";\n}\n* .fa-inbox:before {\n  content: "\\f01c";\n}\n* .fa-indent:before {\n  content: "\\f03c";\n}\n* .fa-industry:before {\n  content: "\\f275";\n}\n* .fa-infinity:before {\n  content: "\\f534";\n}\n* .fa-info:before {\n  content: "\\f129";\n}\n* .fa-info-circle:before {\n  content: "\\f05a";\n}\n* .fa-instagram:before {\n  content: "\\f16d";\n}\n* .fa-intercom:before {\n  content: "\\f7af";\n}\n* .fa-internet-explorer:before {\n  content: "\\f26b";\n}\n* .fa-invision:before {\n  content: "\\f7b0";\n}\n* .fa-ioxhost:before {\n  content: "\\f208";\n}\n* .fa-italic:before {\n  content: "\\f033";\n}\n* .fa-itunes:before {\n  content: "\\f3b4";\n}\n* .fa-itunes-note:before {\n  content: "\\f3b5";\n}\n* .fa-java:before {\n  content: "\\f4e4";\n}\n* .fa-jedi:before {\n  content: "\\f669";\n}\n* .fa-jedi-order:before {\n  content: "\\f50e";\n}\n* .fa-jenkins:before {\n  content: "\\f3b6";\n}\n* .fa-jira:before {\n  content: "\\f7b1";\n}\n* .fa-joget:before {\n  content: "\\f3b7";\n}\n* .fa-joint:before {\n  content: "\\f595";\n}\n* .fa-joomla:before {\n  content: "\\f1aa";\n}\n* .fa-journal-whills:before {\n  content: "\\f66a";\n}\n* .fa-js:before {\n  content: "\\f3b8";\n}\n* .fa-js-square:before {\n  content: "\\f3b9";\n}\n* .fa-jsfiddle:before {\n  content: "\\f1cc";\n}\n* .fa-kaaba:before {\n  content: "\\f66b";\n}\n* .fa-kaggle:before {\n  content: "\\f5fa";\n}\n* .fa-key:before {\n  content: "\\f084";\n}\n* .fa-keybase:before {\n  content: "\\f4f5";\n}\n* .fa-keyboard:before {\n  content: "\\f11c";\n}\n* .fa-keycdn:before {\n  content: "\\f3ba";\n}\n* .fa-khanda:before {\n  content: "\\f66d";\n}\n* .fa-kickstarter:before {\n  content: "\\f3bb";\n}\n* .fa-kickstarter-k:before {\n  content: "\\f3bc";\n}\n* .fa-kiss:before {\n  content: "\\f596";\n}\n* .fa-kiss-beam:before {\n  content: "\\f597";\n}\n* .fa-kiss-wink-heart:before {\n  content: "\\f598";\n}\n* .fa-kiwi-bird:before {\n  content: "\\f535";\n}\n* .fa-korvue:before {\n  content: "\\f42f";\n}\n* .fa-landmark:before {\n  content: "\\f66f";\n}\n* .fa-language:before {\n  content: "\\f1ab";\n}\n* .fa-laptop:before {\n  content: "\\f109";\n}\n* .fa-laptop-code:before {\n  content: "\\f5fc";\n}\n* .fa-laravel:before {\n  content: "\\f3bd";\n}\n* .fa-lastfm:before {\n  content: "\\f202";\n}\n* .fa-lastfm-square:before {\n  content: "\\f203";\n}\n* .fa-laugh:before {\n  content: "\\f599";\n}\n* .fa-laugh-beam:before {\n  content: "\\f59a";\n}\n* .fa-laugh-squint:before {\n  content: "\\f59b";\n}\n* .fa-laugh-wink:before {\n  content: "\\f59c";\n}\n* .fa-layer-group:before {\n  content: "\\f5fd";\n}\n* .fa-leaf:before {\n  content: "\\f06c";\n}\n* .fa-leanpub:before {\n  content: "\\f212";\n}\n* .fa-lemon:before {\n  content: "\\f094";\n}\n* .fa-less:before {\n  content: "\\f41d";\n}\n* .fa-less-than:before {\n  content: "\\f536";\n}\n* .fa-less-than-equal:before {\n  content: "\\f537";\n}\n* .fa-level-down-alt:before {\n  content: "\\f3be";\n}\n* .fa-level-up-alt:before {\n  content: "\\f3bf";\n}\n* .fa-life-ring:before {\n  content: "\\f1cd";\n}\n* .fa-lightbulb:before {\n  content: "\\f0eb";\n}\n* .fa-line:before {\n  content: "\\f3c0";\n}\n* .fa-link:before {\n  content: "\\f0c1";\n}\n* .fa-linkedin:before {\n  content: "\\f08c";\n}\n* .fa-linkedin-in:before {\n  content: "\\f0e1";\n}\n* .fa-linode:before {\n  content: "\\f2b8";\n}\n* .fa-linux:before {\n  content: "\\f17c";\n}\n* .fa-lira-sign:before {\n  content: "\\f195";\n}\n* .fa-list:before {\n  content: "\\f03a";\n}\n* .fa-list-alt:before {\n  content: "\\f022";\n}\n* .fa-list-ol:before {\n  content: "\\f0cb";\n}\n* .fa-list-ul:before {\n  content: "\\f0ca";\n}\n* .fa-location-arrow:before {\n  content: "\\f124";\n}\n* .fa-lock:before {\n  content: "\\f023";\n}\n* .fa-lock-open:before {\n  content: "\\f3c1";\n}\n* .fa-long-arrow-alt-down:before {\n  content: "\\f309";\n}\n* .fa-long-arrow-alt-left:before {\n  content: "\\f30a";\n}\n* .fa-long-arrow-alt-right:before {\n  content: "\\f30b";\n}\n* .fa-long-arrow-alt-up:before {\n  content: "\\f30c";\n}\n* .fa-low-vision:before {\n  content: "\\f2a8";\n}\n* .fa-luggage-cart:before {\n  content: "\\f59d";\n}\n* .fa-lyft:before {\n  content: "\\f3c3";\n}\n* .fa-magento:before {\n  content: "\\f3c4";\n}\n* .fa-magic:before {\n  content: "\\f0d0";\n}\n* .fa-magnet:before {\n  content: "\\f076";\n}\n* .fa-mail-bulk:before {\n  content: "\\f674";\n}\n* .fa-mailchimp:before {\n  content: "\\f59e";\n}\n* .fa-male:before {\n  content: "\\f183";\n}\n* .fa-mandalorian:before {\n  content: "\\f50f";\n}\n* .fa-map:before {\n  content: "\\f279";\n}\n* .fa-map-marked:before {\n  content: "\\f59f";\n}\n* .fa-map-marked-alt:before {\n  content: "\\f5a0";\n}\n* .fa-map-marker:before {\n  content: "\\f041";\n}\n* .fa-map-marker-alt:before {\n  content: "\\f3c5";\n}\n* .fa-map-pin:before {\n  content: "\\f276";\n}\n* .fa-map-signs:before {\n  content: "\\f277";\n}\n* .fa-markdown:before {\n  content: "\\f60f";\n}\n* .fa-marker:before {\n  content: "\\f5a1";\n}\n* .fa-mars:before {\n  content: "\\f222";\n}\n* .fa-mars-double:before {\n  content: "\\f227";\n}\n* .fa-mars-stroke:before {\n  content: "\\f229";\n}\n* .fa-mars-stroke-h:before {\n  content: "\\f22b";\n}\n* .fa-mars-stroke-v:before {\n  content: "\\f22a";\n}\n* .fa-mask:before {\n  content: "\\f6fa";\n}\n* .fa-mastodon:before {\n  content: "\\f4f6";\n}\n* .fa-maxcdn:before {\n  content: "\\f136";\n}\n* .fa-medal:before {\n  content: "\\f5a2";\n}\n* .fa-medapps:before {\n  content: "\\f3c6";\n}\n* .fa-medium:before {\n  content: "\\f23a";\n}\n* .fa-medium-m:before {\n  content: "\\f3c7";\n}\n* .fa-medkit:before {\n  content: "\\f0fa";\n}\n* .fa-medrt:before {\n  content: "\\f3c8";\n}\n* .fa-meetup:before {\n  content: "\\f2e0";\n}\n* .fa-megaport:before {\n  content: "\\f5a3";\n}\n* .fa-meh:before {\n  content: "\\f11a";\n}\n* .fa-meh-blank:before {\n  content: "\\f5a4";\n}\n* .fa-meh-rolling-eyes:before {\n  content: "\\f5a5";\n}\n* .fa-memory:before {\n  content: "\\f538";\n}\n* .fa-mendeley:before {\n  content: "\\f7b3";\n}\n* .fa-menorah:before {\n  content: "\\f676";\n}\n* .fa-mercury:before {\n  content: "\\f223";\n}\n* .fa-meteor:before {\n  content: "\\f753";\n}\n* .fa-microchip:before {\n  content: "\\f2db";\n}\n* .fa-microphone:before {\n  content: "\\f130";\n}\n* .fa-microphone-alt:before {\n  content: "\\f3c9";\n}\n* .fa-microphone-alt-slash:before {\n  content: "\\f539";\n}\n* .fa-microphone-slash:before {\n  content: "\\f131";\n}\n* .fa-microscope:before {\n  content: "\\f610";\n}\n* .fa-microsoft:before {\n  content: "\\f3ca";\n}\n* .fa-minus:before {\n  content: "\\f068";\n}\n* .fa-minus-circle:before {\n  content: "\\f056";\n}\n* .fa-minus-square:before {\n  content: "\\f146";\n}\n* .fa-mitten:before {\n  content: "\\f7b5";\n}\n* .fa-mix:before {\n  content: "\\f3cb";\n}\n* .fa-mixcloud:before {\n  content: "\\f289";\n}\n* .fa-mizuni:before {\n  content: "\\f3cc";\n}\n* .fa-mobile:before {\n  content: "\\f10b";\n}\n* .fa-mobile-alt:before {\n  content: "\\f3cd";\n}\n* .fa-modx:before {\n  content: "\\f285";\n}\n* .fa-monero:before {\n  content: "\\f3d0";\n}\n* .fa-money-bill:before {\n  content: "\\f0d6";\n}\n* .fa-money-bill-alt:before {\n  content: "\\f3d1";\n}\n* .fa-money-bill-wave:before {\n  content: "\\f53a";\n}\n* .fa-money-bill-wave-alt:before {\n  content: "\\f53b";\n}\n* .fa-money-check:before {\n  content: "\\f53c";\n}\n* .fa-money-check-alt:before {\n  content: "\\f53d";\n}\n* .fa-monument:before {\n  content: "\\f5a6";\n}\n* .fa-moon:before {\n  content: "\\f186";\n}\n* .fa-mortar-pestle:before {\n  content: "\\f5a7";\n}\n* .fa-mosque:before {\n  content: "\\f678";\n}\n* .fa-motorcycle:before {\n  content: "\\f21c";\n}\n* .fa-mountain:before {\n  content: "\\f6fc";\n}\n* .fa-mouse-pointer:before {\n  content: "\\f245";\n}\n* .fa-mug-hot:before {\n  content: "\\f7b6";\n}\n* .fa-music:before {\n  content: "\\f001";\n}\n* .fa-napster:before {\n  content: "\\f3d2";\n}\n* .fa-neos:before {\n  content: "\\f612";\n}\n* .fa-network-wired:before {\n  content: "\\f6ff";\n}\n* .fa-neuter:before {\n  content: "\\f22c";\n}\n* .fa-newspaper:before {\n  content: "\\f1ea";\n}\n* .fa-nimblr:before {\n  content: "\\f5a8";\n}\n* .fa-nintendo-switch:before {\n  content: "\\f418";\n}\n* .fa-node:before {\n  content: "\\f419";\n}\n* .fa-node-js:before {\n  content: "\\f3d3";\n}\n* .fa-not-equal:before {\n  content: "\\f53e";\n}\n* .fa-notes-medical:before {\n  content: "\\f481";\n}\n* .fa-npm:before {\n  content: "\\f3d4";\n}\n* .fa-ns8:before {\n  content: "\\f3d5";\n}\n* .fa-nutritionix:before {\n  content: "\\f3d6";\n}\n* .fa-object-group:before {\n  content: "\\f247";\n}\n* .fa-object-ungroup:before {\n  content: "\\f248";\n}\n* .fa-odnoklassniki:before {\n  content: "\\f263";\n}\n* .fa-odnoklassniki-square:before {\n  content: "\\f264";\n}\n* .fa-oil-can:before {\n  content: "\\f613";\n}\n* .fa-old-republic:before {\n  content: "\\f510";\n}\n* .fa-om:before {\n  content: "\\f679";\n}\n* .fa-opencart:before {\n  content: "\\f23d";\n}\n* .fa-openid:before {\n  content: "\\f19b";\n}\n* .fa-opera:before {\n  content: "\\f26a";\n}\n* .fa-optin-monster:before {\n  content: "\\f23c";\n}\n* .fa-osi:before {\n  content: "\\f41a";\n}\n* .fa-otter:before {\n  content: "\\f700";\n}\n* .fa-outdent:before {\n  content: "\\f03b";\n}\n* .fa-page4:before {\n  content: "\\f3d7";\n}\n* .fa-pagelines:before {\n  content: "\\f18c";\n}\n* .fa-paint-brush:before {\n  content: "\\f1fc";\n}\n* .fa-paint-roller:before {\n  content: "\\f5aa";\n}\n* .fa-palette:before {\n  content: "\\f53f";\n}\n* .fa-palfed:before {\n  content: "\\f3d8";\n}\n* .fa-pallet:before {\n  content: "\\f482";\n}\n* .fa-paper-plane:before {\n  content: "\\f1d8";\n}\n* .fa-paperclip:before {\n  content: "\\f0c6";\n}\n* .fa-parachute-box:before {\n  content: "\\f4cd";\n}\n* .fa-paragraph:before {\n  content: "\\f1dd";\n}\n* .fa-parking:before {\n  content: "\\f540";\n}\n* .fa-passport:before {\n  content: "\\f5ab";\n}\n* .fa-pastafarianism:before {\n  content: "\\f67b";\n}\n* .fa-paste:before {\n  content: "\\f0ea";\n}\n* .fa-patreon:before {\n  content: "\\f3d9";\n}\n* .fa-pause:before {\n  content: "\\f04c";\n}\n* .fa-pause-circle:before {\n  content: "\\f28b";\n}\n* .fa-paw:before {\n  content: "\\f1b0";\n}\n* .fa-paypal:before {\n  content: "\\f1ed";\n}\n* .fa-peace:before {\n  content: "\\f67c";\n}\n* .fa-pen:before {\n  content: "\\f304";\n}\n* .fa-pen-alt:before {\n  content: "\\f305";\n}\n* .fa-pen-fancy:before {\n  content: "\\f5ac";\n}\n* .fa-pen-nib:before {\n  content: "\\f5ad";\n}\n* .fa-pen-square:before {\n  content: "\\f14b";\n}\n* .fa-pencil-alt:before {\n  content: "\\f303";\n}\n* .fa-pencil-ruler:before {\n  content: "\\f5ae";\n}\n* .fa-penny-arcade:before {\n  content: "\\f704";\n}\n* .fa-people-carry:before {\n  content: "\\f4ce";\n}\n* .fa-percent:before {\n  content: "\\f295";\n}\n* .fa-percentage:before {\n  content: "\\f541";\n}\n* .fa-periscope:before {\n  content: "\\f3da";\n}\n* .fa-person-booth:before {\n  content: "\\f756";\n}\n* .fa-phabricator:before {\n  content: "\\f3db";\n}\n* .fa-phoenix-framework:before {\n  content: "\\f3dc";\n}\n* .fa-phoenix-squadron:before {\n  content: "\\f511";\n}\n* .fa-phone:before {\n  content: "\\f095";\n}\n* .fa-phone-slash:before {\n  content: "\\f3dd";\n}\n* .fa-phone-square:before {\n  content: "\\f098";\n}\n* .fa-phone-volume:before {\n  content: "\\f2a0";\n}\n* .fa-php:before {\n  content: "\\f457";\n}\n* .fa-pied-piper:before {\n  content: "\\f2ae";\n}\n* .fa-pied-piper-alt:before {\n  content: "\\f1a8";\n}\n* .fa-pied-piper-hat:before {\n  content: "\\f4e5";\n}\n* .fa-pied-piper-pp:before {\n  content: "\\f1a7";\n}\n* .fa-piggy-bank:before {\n  content: "\\f4d3";\n}\n* .fa-pills:before {\n  content: "\\f484";\n}\n* .fa-pinterest:before {\n  content: "\\f0d2";\n}\n* .fa-pinterest-p:before {\n  content: "\\f231";\n}\n* .fa-pinterest-square:before {\n  content: "\\f0d3";\n}\n* .fa-place-of-worship:before {\n  content: "\\f67f";\n}\n* .fa-plane:before {\n  content: "\\f072";\n}\n* .fa-plane-arrival:before {\n  content: "\\f5af";\n}\n* .fa-plane-departure:before {\n  content: "\\f5b0";\n}\n* .fa-play:before {\n  content: "\\f04b";\n}\n* .fa-play-circle:before {\n  content: "\\f144";\n}\n* .fa-playstation:before {\n  content: "\\f3df";\n}\n* .fa-plug:before {\n  content: "\\f1e6";\n}\n* .fa-plus:before {\n  content: "\\f067";\n}\n* .fa-plus-circle:before {\n  content: "\\f055";\n}\n* .fa-plus-square:before {\n  content: "\\f0fe";\n}\n* .fa-podcast:before {\n  content: "\\f2ce";\n}\n* .fa-poll:before {\n  content: "\\f681";\n}\n* .fa-poll-h:before {\n  content: "\\f682";\n}\n* .fa-poo:before {\n  content: "\\f2fe";\n}\n* .fa-poo-storm:before {\n  content: "\\f75a";\n}\n* .fa-poop:before {\n  content: "\\f619";\n}\n* .fa-portrait:before {\n  content: "\\f3e0";\n}\n* .fa-pound-sign:before {\n  content: "\\f154";\n}\n* .fa-power-off:before {\n  content: "\\f011";\n}\n* .fa-pray:before {\n  content: "\\f683";\n}\n* .fa-praying-hands:before {\n  content: "\\f684";\n}\n* .fa-prescription:before {\n  content: "\\f5b1";\n}\n* .fa-prescription-bottle:before {\n  content: "\\f485";\n}\n* .fa-prescription-bottle-alt:before {\n  content: "\\f486";\n}\n* .fa-print:before {\n  content: "\\f02f";\n}\n* .fa-procedures:before {\n  content: "\\f487";\n}\n* .fa-product-hunt:before {\n  content: "\\f288";\n}\n* .fa-project-diagram:before {\n  content: "\\f542";\n}\n* .fa-pushed:before {\n  content: "\\f3e1";\n}\n* .fa-puzzle-piece:before {\n  content: "\\f12e";\n}\n* .fa-python:before {\n  content: "\\f3e2";\n}\n* .fa-qq:before {\n  content: "\\f1d6";\n}\n* .fa-qrcode:before {\n  content: "\\f029";\n}\n* .fa-question:before {\n  content: "\\f128";\n}\n* .fa-question-circle:before {\n  content: "\\f059";\n}\n* .fa-quidditch:before {\n  content: "\\f458";\n}\n* .fa-quinscape:before {\n  content: "\\f459";\n}\n* .fa-quora:before {\n  content: "\\f2c4";\n}\n* .fa-quote-left:before {\n  content: "\\f10d";\n}\n* .fa-quote-right:before {\n  content: "\\f10e";\n}\n* .fa-quran:before {\n  content: "\\f687";\n}\n* .fa-r-project:before {\n  content: "\\f4f7";\n}\n* .fa-radiation:before {\n  content: "\\f7b9";\n}\n* .fa-radiation-alt:before {\n  content: "\\f7ba";\n}\n* .fa-rainbow:before {\n  content: "\\f75b";\n}\n* .fa-random:before {\n  content: "\\f074";\n}\n* .fa-raspberry-pi:before {\n  content: "\\f7bb";\n}\n* .fa-ravelry:before {\n  content: "\\f2d9";\n}\n* .fa-react:before {\n  content: "\\f41b";\n}\n* .fa-reacteurope:before {\n  content: "\\f75d";\n}\n* .fa-readme:before {\n  content: "\\f4d5";\n}\n* .fa-rebel:before {\n  content: "\\f1d0";\n}\n* .fa-receipt:before {\n  content: "\\f543";\n}\n* .fa-recycle:before {\n  content: "\\f1b8";\n}\n* .fa-red-river:before {\n  content: "\\f3e3";\n}\n* .fa-reddit:before {\n  content: "\\f1a1";\n}\n* .fa-reddit-alien:before {\n  content: "\\f281";\n}\n* .fa-reddit-square:before {\n  content: "\\f1a2";\n}\n* .fa-redhat:before {\n  content: "\\f7bc";\n}\n* .fa-redo:before {\n  content: "\\f01e";\n}\n* .fa-redo-alt:before {\n  content: "\\f2f9";\n}\n* .fa-registered:before {\n  content: "\\f25d";\n}\n* .fa-renren:before {\n  content: "\\f18b";\n}\n* .fa-reply:before {\n  content: "\\f3e5";\n}\n* .fa-reply-all:before {\n  content: "\\f122";\n}\n* .fa-replyd:before {\n  content: "\\f3e6";\n}\n* .fa-republican:before {\n  content: "\\f75e";\n}\n* .fa-researchgate:before {\n  content: "\\f4f8";\n}\n* .fa-resolving:before {\n  content: "\\f3e7";\n}\n* .fa-restroom:before {\n  content: "\\f7bd";\n}\n* .fa-retweet:before {\n  content: "\\f079";\n}\n* .fa-rev:before {\n  content: "\\f5b2";\n}\n* .fa-ribbon:before {\n  content: "\\f4d6";\n}\n* .fa-ring:before {\n  content: "\\f70b";\n}\n* .fa-road:before {\n  content: "\\f018";\n}\n* .fa-robot:before {\n  content: "\\f544";\n}\n* .fa-rocket:before {\n  content: "\\f135";\n}\n* .fa-rocketchat:before {\n  content: "\\f3e8";\n}\n* .fa-rockrms:before {\n  content: "\\f3e9";\n}\n* .fa-route:before {\n  content: "\\f4d7";\n}\n* .fa-rss:before {\n  content: "\\f09e";\n}\n* .fa-rss-square:before {\n  content: "\\f143";\n}\n* .fa-ruble-sign:before {\n  content: "\\f158";\n}\n* .fa-ruler:before {\n  content: "\\f545";\n}\n* .fa-ruler-combined:before {\n  content: "\\f546";\n}\n* .fa-ruler-horizontal:before {\n  content: "\\f547";\n}\n* .fa-ruler-vertical:before {\n  content: "\\f548";\n}\n* .fa-running:before {\n  content: "\\f70c";\n}\n* .fa-rupee-sign:before {\n  content: "\\f156";\n}\n* .fa-sad-cry:before {\n  content: "\\f5b3";\n}\n* .fa-sad-tear:before {\n  content: "\\f5b4";\n}\n* .fa-safari:before {\n  content: "\\f267";\n}\n* .fa-sass:before {\n  content: "\\f41e";\n}\n* .fa-satellite:before {\n  content: "\\f7bf";\n}\n* .fa-satellite-dish:before {\n  content: "\\f7c0";\n}\n* .fa-save:before {\n  content: "\\f0c7";\n}\n* .fa-schlix:before {\n  content: "\\f3ea";\n}\n* .fa-school:before {\n  content: "\\f549";\n}\n* .fa-screwdriver:before {\n  content: "\\f54a";\n}\n* .fa-scribd:before {\n  content: "\\f28a";\n}\n* .fa-scroll:before {\n  content: "\\f70e";\n}\n* .fa-sd-card:before {\n  content: "\\f7c2";\n}\n* .fa-search:before {\n  content: "\\f002";\n}\n* .fa-search-dollar:before {\n  content: "\\f688";\n}\n* .fa-search-location:before {\n  content: "\\f689";\n}\n* .fa-search-minus:before {\n  content: "\\f010";\n}\n* .fa-search-plus:before {\n  content: "\\f00e";\n}\n* .fa-searchengin:before {\n  content: "\\f3eb";\n}\n* .fa-seedling:before {\n  content: "\\f4d8";\n}\n* .fa-sellcast:before {\n  content: "\\f2da";\n}\n* .fa-sellsy:before {\n  content: "\\f213";\n}\n* .fa-server:before {\n  content: "\\f233";\n}\n* .fa-servicestack:before {\n  content: "\\f3ec";\n}\n* .fa-shapes:before {\n  content: "\\f61f";\n}\n* .fa-share:before {\n  content: "\\f064";\n}\n* .fa-share-alt:before {\n  content: "\\f1e0";\n}\n* .fa-share-alt-square:before {\n  content: "\\f1e1";\n}\n* .fa-share-square:before {\n  content: "\\f14d";\n}\n* .fa-shekel-sign:before {\n  content: "\\f20b";\n}\n* .fa-shield-alt:before {\n  content: "\\f3ed";\n}\n* .fa-ship:before {\n  content: "\\f21a";\n}\n* .fa-shipping-fast:before {\n  content: "\\f48b";\n}\n* .fa-shirtsinbulk:before {\n  content: "\\f214";\n}\n* .fa-shoe-prints:before {\n  content: "\\f54b";\n}\n* .fa-shopping-bag:before {\n  content: "\\f290";\n}\n* .fa-shopping-basket:before {\n  content: "\\f291";\n}\n* .fa-shopping-cart:before {\n  content: "\\f07a";\n}\n* .fa-shopware:before {\n  content: "\\f5b5";\n}\n* .fa-shower:before {\n  content: "\\f2cc";\n}\n* .fa-shuttle-van:before {\n  content: "\\f5b6";\n}\n* .fa-sign:before {\n  content: "\\f4d9";\n}\n* .fa-sign-in-alt:before {\n  content: "\\f2f6";\n}\n* .fa-sign-language:before {\n  content: "\\f2a7";\n}\n* .fa-sign-out-alt:before {\n  content: "\\f2f5";\n}\n* .fa-signal:before {\n  content: "\\f012";\n}\n* .fa-signature:before {\n  content: "\\f5b7";\n}\n* .fa-sim-card:before {\n  content: "\\f7c4";\n}\n* .fa-simplybuilt:before {\n  content: "\\f215";\n}\n* .fa-sistrix:before {\n  content: "\\f3ee";\n}\n* .fa-sitemap:before {\n  content: "\\f0e8";\n}\n* .fa-sith:before {\n  content: "\\f512";\n}\n* .fa-skating:before {\n  content: "\\f7c5";\n}\n* .fa-sketch:before {\n  content: "\\f7c6";\n}\n* .fa-skiing:before {\n  content: "\\f7c9";\n}\n* .fa-skiing-nordic:before {\n  content: "\\f7ca";\n}\n* .fa-skull:before {\n  content: "\\f54c";\n}\n* .fa-skull-crossbones:before {\n  content: "\\f714";\n}\n* .fa-skyatlas:before {\n  content: "\\f216";\n}\n* .fa-skype:before {\n  content: "\\f17e";\n}\n* .fa-slack:before {\n  content: "\\f198";\n}\n* .fa-slack-hash:before {\n  content: "\\f3ef";\n}\n* .fa-slash:before {\n  content: "\\f715";\n}\n* .fa-sleigh:before {\n  content: "\\f7cc";\n}\n* .fa-sliders-h:before {\n  content: "\\f1de";\n}\n* .fa-slideshare:before {\n  content: "\\f1e7";\n}\n* .fa-smile:before {\n  content: "\\f118";\n}\n* .fa-smile-beam:before {\n  content: "\\f5b8";\n}\n* .fa-smile-wink:before {\n  content: "\\f4da";\n}\n* .fa-smog:before {\n  content: "\\f75f";\n}\n* .fa-smoking:before {\n  content: "\\f48d";\n}\n* .fa-smoking-ban:before {\n  content: "\\f54d";\n}\n* .fa-sms:before {\n  content: "\\f7cd";\n}\n* .fa-snapchat:before {\n  content: "\\f2ab";\n}\n* .fa-snapchat-ghost:before {\n  content: "\\f2ac";\n}\n* .fa-snapchat-square:before {\n  content: "\\f2ad";\n}\n* .fa-snowboarding:before {\n  content: "\\f7ce";\n}\n* .fa-snowflake:before {\n  content: "\\f2dc";\n}\n* .fa-snowman:before {\n  content: "\\f7d0";\n}\n* .fa-snowplow:before {\n  content: "\\f7d2";\n}\n* .fa-socks:before {\n  content: "\\f696";\n}\n* .fa-solar-panel:before {\n  content: "\\f5ba";\n}\n* .fa-sort:before {\n  content: "\\f0dc";\n}\n* .fa-sort-alpha-down:before {\n  content: "\\f15d";\n}\n* .fa-sort-alpha-up:before {\n  content: "\\f15e";\n}\n* .fa-sort-amount-down:before {\n  content: "\\f160";\n}\n* .fa-sort-amount-up:before {\n  content: "\\f161";\n}\n* .fa-sort-down:before {\n  content: "\\f0dd";\n}\n* .fa-sort-numeric-down:before {\n  content: "\\f162";\n}\n* .fa-sort-numeric-up:before {\n  content: "\\f163";\n}\n* .fa-sort-up:before {\n  content: "\\f0de";\n}\n* .fa-soundcloud:before {\n  content: "\\f1be";\n}\n* .fa-sourcetree:before {\n  content: "\\f7d3";\n}\n* .fa-spa:before {\n  content: "\\f5bb";\n}\n* .fa-space-shuttle:before {\n  content: "\\f197";\n}\n* .fa-speakap:before {\n  content: "\\f3f3";\n}\n* .fa-spider:before {\n  content: "\\f717";\n}\n* .fa-spinner:before {\n  content: "\\f110";\n}\n* .fa-splotch:before {\n  content: "\\f5bc";\n}\n* .fa-spotify:before {\n  content: "\\f1bc";\n}\n* .fa-spray-can:before {\n  content: "\\f5bd";\n}\n* .fa-square:before {\n  content: "\\f0c8";\n}\n* .fa-square-full:before {\n  content: "\\f45c";\n}\n* .fa-square-root-alt:before {\n  content: "\\f698";\n}\n* .fa-squarespace:before {\n  content: "\\f5be";\n}\n* .fa-stack-exchange:before {\n  content: "\\f18d";\n}\n* .fa-stack-overflow:before {\n  content: "\\f16c";\n}\n* .fa-stamp:before {\n  content: "\\f5bf";\n}\n* .fa-star:before {\n  content: "\\f005";\n}\n* .fa-star-and-crescent:before {\n  content: "\\f699";\n}\n* .fa-star-half:before {\n  content: "\\f089";\n}\n* .fa-star-half-alt:before {\n  content: "\\f5c0";\n}\n* .fa-star-of-david:before {\n  content: "\\f69a";\n}\n* .fa-star-of-life:before {\n  content: "\\f621";\n}\n* .fa-staylinked:before {\n  content: "\\f3f5";\n}\n* .fa-steam:before {\n  content: "\\f1b6";\n}\n* .fa-steam-square:before {\n  content: "\\f1b7";\n}\n* .fa-steam-symbol:before {\n  content: "\\f3f6";\n}\n* .fa-step-backward:before {\n  content: "\\f048";\n}\n* .fa-step-forward:before {\n  content: "\\f051";\n}\n* .fa-stethoscope:before {\n  content: "\\f0f1";\n}\n* .fa-sticker-mule:before {\n  content: "\\f3f7";\n}\n* .fa-sticky-note:before {\n  content: "\\f249";\n}\n* .fa-stop:before {\n  content: "\\f04d";\n}\n* .fa-stop-circle:before {\n  content: "\\f28d";\n}\n* .fa-stopwatch:before {\n  content: "\\f2f2";\n}\n* .fa-store:before {\n  content: "\\f54e";\n}\n* .fa-store-alt:before {\n  content: "\\f54f";\n}\n* .fa-strava:before {\n  content: "\\f428";\n}\n* .fa-stream:before {\n  content: "\\f550";\n}\n* .fa-street-view:before {\n  content: "\\f21d";\n}\n* .fa-strikethrough:before {\n  content: "\\f0cc";\n}\n* .fa-stripe:before {\n  content: "\\f429";\n}\n* .fa-stripe-s:before {\n  content: "\\f42a";\n}\n* .fa-stroopwafel:before {\n  content: "\\f551";\n}\n* .fa-studiovinari:before {\n  content: "\\f3f8";\n}\n* .fa-stumbleupon:before {\n  content: "\\f1a4";\n}\n* .fa-stumbleupon-circle:before {\n  content: "\\f1a3";\n}\n* .fa-subscript:before {\n  content: "\\f12c";\n}\n* .fa-subway:before {\n  content: "\\f239";\n}\n* .fa-suitcase:before {\n  content: "\\f0f2";\n}\n* .fa-suitcase-rolling:before {\n  content: "\\f5c1";\n}\n* .fa-sun:before {\n  content: "\\f185";\n}\n* .fa-superpowers:before {\n  content: "\\f2dd";\n}\n* .fa-superscript:before {\n  content: "\\f12b";\n}\n* .fa-supple:before {\n  content: "\\f3f9";\n}\n* .fa-surprise:before {\n  content: "\\f5c2";\n}\n* .fa-suse:before {\n  content: "\\f7d6";\n}\n* .fa-swatchbook:before {\n  content: "\\f5c3";\n}\n* .fa-swimmer:before {\n  content: "\\f5c4";\n}\n* .fa-swimming-pool:before {\n  content: "\\f5c5";\n}\n* .fa-synagogue:before {\n  content: "\\f69b";\n}\n* .fa-sync:before {\n  content: "\\f021";\n}\n* .fa-sync-alt:before {\n  content: "\\f2f1";\n}\n* .fa-syringe:before {\n  content: "\\f48e";\n}\n* .fa-table:before {\n  content: "\\f0ce";\n}\n* .fa-table-tennis:before {\n  content: "\\f45d";\n}\n* .fa-tablet:before {\n  content: "\\f10a";\n}\n* .fa-tablet-alt:before {\n  content: "\\f3fa";\n}\n* .fa-tablets:before {\n  content: "\\f490";\n}\n* .fa-tachometer-alt:before {\n  content: "\\f3fd";\n}\n* .fa-tag:before {\n  content: "\\f02b";\n}\n* .fa-tags:before {\n  content: "\\f02c";\n}\n* .fa-tape:before {\n  content: "\\f4db";\n}\n* .fa-tasks:before {\n  content: "\\f0ae";\n}\n* .fa-taxi:before {\n  content: "\\f1ba";\n}\n* .fa-teamspeak:before {\n  content: "\\f4f9";\n}\n* .fa-teeth:before {\n  content: "\\f62e";\n}\n* .fa-teeth-open:before {\n  content: "\\f62f";\n}\n* .fa-telegram:before {\n  content: "\\f2c6";\n}\n* .fa-telegram-plane:before {\n  content: "\\f3fe";\n}\n* .fa-temperature-high:before {\n  content: "\\f769";\n}\n* .fa-temperature-low:before {\n  content: "\\f76b";\n}\n* .fa-tencent-weibo:before {\n  content: "\\f1d5";\n}\n* .fa-tenge:before {\n  content: "\\f7d7";\n}\n* .fa-terminal:before {\n  content: "\\f120";\n}\n* .fa-text-height:before {\n  content: "\\f034";\n}\n* .fa-text-width:before {\n  content: "\\f035";\n}\n* .fa-th:before {\n  content: "\\f00a";\n}\n* .fa-th-large:before {\n  content: "\\f009";\n}\n* .fa-th-list:before {\n  content: "\\f00b";\n}\n* .fa-the-red-yeti:before {\n  content: "\\f69d";\n}\n* .fa-theater-masks:before {\n  content: "\\f630";\n}\n* .fa-themeco:before {\n  content: "\\f5c6";\n}\n* .fa-themeisle:before {\n  content: "\\f2b2";\n}\n* .fa-thermometer:before {\n  content: "\\f491";\n}\n* .fa-thermometer-empty:before {\n  content: "\\f2cb";\n}\n* .fa-thermometer-full:before {\n  content: "\\f2c7";\n}\n* .fa-thermometer-half:before {\n  content: "\\f2c9";\n}\n* .fa-thermometer-quarter:before {\n  content: "\\f2ca";\n}\n* .fa-thermometer-three-quarters:before {\n  content: "\\f2c8";\n}\n* .fa-think-peaks:before {\n  content: "\\f731";\n}\n* .fa-thumbs-down:before {\n  content: "\\f165";\n}\n* .fa-thumbs-up:before {\n  content: "\\f164";\n}\n* .fa-thumbtack:before {\n  content: "\\f08d";\n}\n* .fa-ticket-alt:before {\n  content: "\\f3ff";\n}\n* .fa-times:before {\n  content: "\\f00d";\n}\n* .fa-times-circle:before {\n  content: "\\f057";\n}\n* .fa-tint:before {\n  content: "\\f043";\n}\n* .fa-tint-slash:before {\n  content: "\\f5c7";\n}\n* .fa-tired:before {\n  content: "\\f5c8";\n}\n* .fa-toggle-off:before {\n  content: "\\f204";\n}\n* .fa-toggle-on:before {\n  content: "\\f205";\n}\n* .fa-toilet:before {\n  content: "\\f7d8";\n}\n* .fa-toilet-paper:before {\n  content: "\\f71e";\n}\n* .fa-toolbox:before {\n  content: "\\f552";\n}\n* .fa-tools:before {\n  content: "\\f7d9";\n}\n* .fa-tooth:before {\n  content: "\\f5c9";\n}\n* .fa-torah:before {\n  content: "\\f6a0";\n}\n* .fa-torii-gate:before {\n  content: "\\f6a1";\n}\n* .fa-tractor:before {\n  content: "\\f722";\n}\n* .fa-trade-federation:before {\n  content: "\\f513";\n}\n* .fa-trademark:before {\n  content: "\\f25c";\n}\n* .fa-traffic-light:before {\n  content: "\\f637";\n}\n* .fa-train:before {\n  content: "\\f238";\n}\n* .fa-tram:before {\n  content: "\\f7da";\n}\n* .fa-transgender:before {\n  content: "\\f224";\n}\n* .fa-transgender-alt:before {\n  content: "\\f225";\n}\n* .fa-trash:before {\n  content: "\\f1f8";\n}\n* .fa-trash-alt:before {\n  content: "\\f2ed";\n}\n* .fa-tree:before {\n  content: "\\f1bb";\n}\n* .fa-trello:before {\n  content: "\\f181";\n}\n* .fa-tripadvisor:before {\n  content: "\\f262";\n}\n* .fa-trophy:before {\n  content: "\\f091";\n}\n* .fa-truck:before {\n  content: "\\f0d1";\n}\n* .fa-truck-loading:before {\n  content: "\\f4de";\n}\n* .fa-truck-monster:before {\n  content: "\\f63b";\n}\n* .fa-truck-moving:before {\n  content: "\\f4df";\n}\n* .fa-truck-pickup:before {\n  content: "\\f63c";\n}\n* .fa-tshirt:before {\n  content: "\\f553";\n}\n* .fa-tty:before {\n  content: "\\f1e4";\n}\n* .fa-tumblr:before {\n  content: "\\f173";\n}\n* .fa-tumblr-square:before {\n  content: "\\f174";\n}\n* .fa-tv:before {\n  content: "\\f26c";\n}\n* .fa-twitch:before {\n  content: "\\f1e8";\n}\n* .fa-twitter:before {\n  content: "\\f099";\n}\n* .fa-twitter-square:before {\n  content: "\\f081";\n}\n* .fa-typo3:before {\n  content: "\\f42b";\n}\n* .fa-uber:before {\n  content: "\\f402";\n}\n* .fa-ubuntu:before {\n  content: "\\f7df";\n}\n* .fa-uikit:before {\n  content: "\\f403";\n}\n* .fa-umbrella:before {\n  content: "\\f0e9";\n}\n* .fa-umbrella-beach:before {\n  content: "\\f5ca";\n}\n* .fa-underline:before {\n  content: "\\f0cd";\n}\n* .fa-undo:before {\n  content: "\\f0e2";\n}\n* .fa-undo-alt:before {\n  content: "\\f2ea";\n}\n* .fa-uniregistry:before {\n  content: "\\f404";\n}\n* .fa-universal-access:before {\n  content: "\\f29a";\n}\n* .fa-university:before {\n  content: "\\f19c";\n}\n* .fa-unlink:before {\n  content: "\\f127";\n}\n* .fa-unlock:before {\n  content: "\\f09c";\n}\n* .fa-unlock-alt:before {\n  content: "\\f13e";\n}\n* .fa-untappd:before {\n  content: "\\f405";\n}\n* .fa-upload:before {\n  content: "\\f093";\n}\n* .fa-ups:before {\n  content: "\\f7e0";\n}\n* .fa-usb:before {\n  content: "\\f287";\n}\n* .fa-user:before {\n  content: "\\f007";\n}\n* .fa-user-alt:before {\n  content: "\\f406";\n}\n* .fa-user-alt-slash:before {\n  content: "\\f4fa";\n}\n* .fa-user-astronaut:before {\n  content: "\\f4fb";\n}\n* .fa-user-check:before {\n  content: "\\f4fc";\n}\n* .fa-user-circle:before {\n  content: "\\f2bd";\n}\n* .fa-user-clock:before {\n  content: "\\f4fd";\n}\n* .fa-user-cog:before {\n  content: "\\f4fe";\n}\n* .fa-user-edit:before {\n  content: "\\f4ff";\n}\n* .fa-user-friends:before {\n  content: "\\f500";\n}\n* .fa-user-graduate:before {\n  content: "\\f501";\n}\n* .fa-user-injured:before {\n  content: "\\f728";\n}\n* .fa-user-lock:before {\n  content: "\\f502";\n}\n* .fa-user-md:before {\n  content: "\\f0f0";\n}\n* .fa-user-minus:before {\n  content: "\\f503";\n}\n* .fa-user-ninja:before {\n  content: "\\f504";\n}\n* .fa-user-plus:before {\n  content: "\\f234";\n}\n* .fa-user-secret:before {\n  content: "\\f21b";\n}\n* .fa-user-shield:before {\n  content: "\\f505";\n}\n* .fa-user-slash:before {\n  content: "\\f506";\n}\n* .fa-user-tag:before {\n  content: "\\f507";\n}\n* .fa-user-tie:before {\n  content: "\\f508";\n}\n* .fa-user-times:before {\n  content: "\\f235";\n}\n* .fa-users:before {\n  content: "\\f0c0";\n}\n* .fa-users-cog:before {\n  content: "\\f509";\n}\n* .fa-usps:before {\n  content: "\\f7e1";\n}\n* .fa-ussunnah:before {\n  content: "\\f407";\n}\n* .fa-utensil-spoon:before {\n  content: "\\f2e5";\n}\n* .fa-utensils:before {\n  content: "\\f2e7";\n}\n* .fa-vaadin:before {\n  content: "\\f408";\n}\n* .fa-vector-square:before {\n  content: "\\f5cb";\n}\n* .fa-venus:before {\n  content: "\\f221";\n}\n* .fa-venus-double:before {\n  content: "\\f226";\n}\n* .fa-venus-mars:before {\n  content: "\\f228";\n}\n* .fa-viacoin:before {\n  content: "\\f237";\n}\n* .fa-viadeo:before {\n  content: "\\f2a9";\n}\n* .fa-viadeo-square:before {\n  content: "\\f2aa";\n}\n* .fa-vial:before {\n  content: "\\f492";\n}\n* .fa-vials:before {\n  content: "\\f493";\n}\n* .fa-viber:before {\n  content: "\\f409";\n}\n* .fa-video:before {\n  content: "\\f03d";\n}\n* .fa-video-slash:before {\n  content: "\\f4e2";\n}\n* .fa-vihara:before {\n  content: "\\f6a7";\n}\n* .fa-vimeo:before {\n  content: "\\f40a";\n}\n* .fa-vimeo-square:before {\n  content: "\\f194";\n}\n* .fa-vimeo-v:before {\n  content: "\\f27d";\n}\n* .fa-vine:before {\n  content: "\\f1ca";\n}\n* .fa-vk:before {\n  content: "\\f189";\n}\n* .fa-vnv:before {\n  content: "\\f40b";\n}\n* .fa-volleyball-ball:before {\n  content: "\\f45f";\n}\n* .fa-volume-down:before {\n  content: "\\f027";\n}\n* .fa-volume-mute:before {\n  content: "\\f6a9";\n}\n* .fa-volume-off:before {\n  content: "\\f026";\n}\n* .fa-volume-up:before {\n  content: "\\f028";\n}\n* .fa-vote-yea:before {\n  content: "\\f772";\n}\n* .fa-vr-cardboard:before {\n  content: "\\f729";\n}\n* .fa-vuejs:before {\n  content: "\\f41f";\n}\n* .fa-walking:before {\n  content: "\\f554";\n}\n* .fa-wallet:before {\n  content: "\\f555";\n}\n* .fa-warehouse:before {\n  content: "\\f494";\n}\n* .fa-water:before {\n  content: "\\f773";\n}\n* .fa-weebly:before {\n  content: "\\f5cc";\n}\n* .fa-weibo:before {\n  content: "\\f18a";\n}\n* .fa-weight:before {\n  content: "\\f496";\n}\n* .fa-weight-hanging:before {\n  content: "\\f5cd";\n}\n* .fa-weixin:before {\n  content: "\\f1d7";\n}\n* .fa-whatsapp:before {\n  content: "\\f232";\n}\n* .fa-whatsapp-square:before {\n  content: "\\f40c";\n}\n* .fa-wheelchair:before {\n  content: "\\f193";\n}\n* .fa-whmcs:before {\n  content: "\\f40d";\n}\n* .fa-wifi:before {\n  content: "\\f1eb";\n}\n* .fa-wikipedia-w:before {\n  content: "\\f266";\n}\n* .fa-wind:before {\n  content: "\\f72e";\n}\n* .fa-window-close:before {\n  content: "\\f410";\n}\n* .fa-window-maximize:before {\n  content: "\\f2d0";\n}\n* .fa-window-minimize:before {\n  content: "\\f2d1";\n}\n* .fa-window-restore:before {\n  content: "\\f2d2";\n}\n* .fa-windows:before {\n  content: "\\f17a";\n}\n* .fa-wine-bottle:before {\n  content: "\\f72f";\n}\n* .fa-wine-glass:before {\n  content: "\\f4e3";\n}\n* .fa-wine-glass-alt:before {\n  content: "\\f5ce";\n}\n* .fa-wix:before {\n  content: "\\f5cf";\n}\n* .fa-wizards-of-the-coast:before {\n  content: "\\f730";\n}\n* .fa-wolf-pack-battalion:before {\n  content: "\\f514";\n}\n* .fa-won-sign:before {\n  content: "\\f159";\n}\n* .fa-wordpress:before {\n  content: "\\f19a";\n}\n* .fa-wordpress-simple:before {\n  content: "\\f411";\n}\n* .fa-wpbeginner:before {\n  content: "\\f297";\n}\n* .fa-wpexplorer:before {\n  content: "\\f2de";\n}\n* .fa-wpforms:before {\n  content: "\\f298";\n}\n* .fa-wpressr:before {\n  content: "\\f3e4";\n}\n* .fa-wrench:before {\n  content: "\\f0ad";\n}\n* .fa-x-ray:before {\n  content: "\\f497";\n}\n* .fa-xbox:before {\n  content: "\\f412";\n}\n* .fa-xing:before {\n  content: "\\f168";\n}\n* .fa-xing-square:before {\n  content: "\\f169";\n}\n* .fa-y-combinator:before {\n  content: "\\f23b";\n}\n* .fa-yahoo:before {\n  content: "\\f19e";\n}\n* .fa-yandex:before {\n  content: "\\f413";\n}\n* .fa-yandex-international:before {\n  content: "\\f414";\n}\n* .fa-yarn:before {\n  content: "\\f7e3";\n}\n* .fa-yelp:before {\n  content: "\\f1e9";\n}\n* .fa-yen-sign:before {\n  content: "\\f157";\n}\n* .fa-yin-yang:before {\n  content: "\\f6ad";\n}\n* .fa-yoast:before {\n  content: "\\f2b1";\n}\n* .fa-youtube:before {\n  content: "\\f167";\n}\n* .fa-youtube-square:before {\n  content: "\\f431";\n}\n* .fa-zhihu:before {\n  content: "\\f63f";\n}\n* .sr-only {\n  border: 0;\n  clip: rect(0, 0, 0, 0);\n  height: 1px;\n  margin: -1px;\n  overflow: hidden;\n  padding: 0;\n  position: absolute;\n  width: 1px;\n}\n* .sr-only-focusable:active, * .sr-only-focusable:focus {\n  clip: auto;\n  height: auto;\n  margin: 0;\n  overflow: visible;\n  position: static;\n  width: auto;\n}\n\n@font-face {\n  font-family: "Font Awesome 5 Free";\n  font-style: normal;\n  font-weight: 900;\n  src: url("./assets/fonts/webfonts/fa-solid-900.woff2") format("woff2"), url("./assets/fonts/webfonts/fa-solid-900.woff") format("woff");\n}\n.fa,\n.fas {\n  font-family: "Font Awesome 5 Free";\n  font-weight: 900;\n}\n\n@font-face {\n  font-family: "pficon";\n  src: url("./assets/pficon/pficon.woff2") format("woff2"), url("./assets/pficon/pficon.woff") format("woff");\n}\n.pf-icon-zone:before, .pf-icon-warning-triangle:before, .pf-icon-volume:before, .pf-icon-virtual-machine:before, .pf-icon-users:before, .pf-icon-user:before, .pf-icon-unplugged:before, .pf-icon-unlocked:before, .pf-icon-unknown:before, .pf-icon-trend-up:before, .pf-icon-trend-down:before, .pf-icon-topology:before, .pf-icon-thumb-tack:before, .pf-icon-tenant:before, .pf-icon-task:before, .pf-icon-storage-domain:before, .pf-icon-spinner2:before, .pf-icon-spinner:before, .pf-icon-services:before, .pf-icon-service:before, .pf-icon-service-catalog:before, .pf-icon-server:before, .pf-icon-server-group:before, .pf-icon-security:before, .pf-icon-screen:before, .pf-icon-save:before, .pf-icon-running:before, .pf-icon-resources-full:before, .pf-icon-resources-empty:before, .pf-icon-resources-almost-full:before, .pf-icon-resources-almost-empty:before, .pf-icon-resource-pool:before, .pf-icon-repository:before, .pf-icon-replicator:before, .pf-icon-remove2:before, .pf-icon-registry:before, .pf-icon-regions:before, .pf-icon-rebooting:before, .pf-icon-rebalance:before, .pf-icon-project:before, .pf-icon-process-automation:before, .pf-icon-private:before, .pf-icon-print:before, .pf-icon-port:before, .pf-icon-plugged:before, .pf-icon-pficon-vcenter:before, .pf-icon-pficon-template:before, .pf-icon-pficon-sort-common-desc:before, .pf-icon-pficon-sort-common-asc:before, .pf-icon-pficon-satellite:before, .pf-icon-pficon-network-range:before, .pf-icon-pficon-history:before, .pf-icon-pficon-dragdrop:before, .pf-icon-pending:before, .pf-icon-paused:before, .pf-icon-panel-open:before, .pf-icon-panel-close:before, .pf-icon-package:before, .pf-icon-os-image:before, .pf-icon-orders:before, .pf-icon-optimize:before, .pf-icon-openstack:before, .pf-icon-openshift:before, .pf-icon-open-drawer-right:before, .pf-icon-on:before, .pf-icon-on-running:before, .pf-icon-ok:before, .pf-icon-off:before, .pf-icon-not-started:before, .pf-icon-new-process:before, .pf-icon-network:before, .pf-icon-namespaces:before, .pf-icon-monitoring:before, .pf-icon-module:before, .pf-icon-migration:before, .pf-icon-middleware:before, .pf-icon-messages:before, .pf-icon-memory:before, .pf-icon-maintenance:before, .pf-icon-locked:before, .pf-icon-key:before, .pf-icon-integration:before, .pf-icon-infrastructure:before, .pf-icon-info:before, .pf-icon-in-progress:before, .pf-icon-import:before, .pf-icon-home:before, .pf-icon-history:before, .pf-icon-help:before, .pf-icon-globe-route:before, .pf-icon-folder-open:before, .pf-icon-folder-close:before, .pf-icon-flavor:before, .pf-icon-filter:before, .pf-icon-export:before, .pf-icon-error-circle-o:before, .pf-icon-equalizer:before, .pf-icon-enterprise:before, .pf-icon-enhancement:before, .pf-icon-edit:before, .pf-icon-domain:before, .pf-icon-disconnected:before, .pf-icon-degraded:before, .pf-icon-data-source:before, .pf-icon-data-sink:before, .pf-icon-data-processor:before, .pf-icon-critical-risk:before, .pf-icon-cpu:before, .pf-icon-container-node:before, .pf-icon-connected:before, .pf-icon-cluster:before, .pf-icon-cloud-tenant:before, .pf-icon-cloud-security:before, .pf-icon-close:before, .pf-icon-chat:before, .pf-icon-catalog:before, .pf-icon-bundle:before, .pf-icon-builder-image:before, .pf-icon-build:before, .pf-icon-blueprint:before, .pf-icon-bell:before, .pf-icon-automation:before, .pf-icon-attention-bell:before, .pf-icon-asleep:before, .pf-icon-arrow:before, .pf-icon-applications:before, .pf-icon-ansible-tower:before, .pf-icon-add-circle-o:before {\n  font-family: "pficon";\n  -webkit-font-smoothing: antialiased;\n  -moz-osx-font-smoothing: grayscale;\n  font-style: normal;\n  font-variant: normal;\n  font-weight: normal;\n  text-decoration: none;\n  text-transform: none;\n}\n\n.pf-icon-add-circle-o:before {\n  content: "\\e61b";\n}\n\n.pf-icon-ansible-tower:before {\n  content: "\\e950";\n}\n\n.pf-icon-applications:before {\n  content: "\\e936";\n}\n\n.pf-icon-arrow:before {\n  content: "\\e929";\n}\n\n.pf-icon-asleep:before {\n  content: "\\e92e";\n}\n\n.pf-icon-attention-bell:before {\n  content: "\\e951";\n}\n\n.pf-icon-automation:before {\n  content: "\\e937";\n}\n\n.pf-icon-bell:before {\n  content: "\\e952";\n}\n\n.pf-icon-blueprint:before {\n  content: "\\e915";\n}\n\n.pf-icon-build:before {\n  content: "\\e902";\n}\n\n.pf-icon-builder-image:before {\n  content: "\\e800";\n}\n\n.pf-icon-bundle:before {\n  content: "\\e918";\n}\n\n.pf-icon-catalog:before {\n  content: "\\e953";\n}\n\n.pf-icon-chat:before {\n  content: "\\e954";\n}\n\n.pf-icon-close:before {\n  content: "\\e60b";\n}\n\n.pf-icon-cloud-security:before {\n  content: "\\e903";\n}\n\n.pf-icon-cloud-tenant:before {\n  content: "\\e904";\n}\n\n.pf-icon-cluster:before {\n  content: "\\e620";\n}\n\n.pf-icon-connected:before {\n  content: "\\e938";\n}\n\n.pf-icon-container-node:before {\n  content: "\\e621";\n}\n\n.pf-icon-cpu:before {\n  content: "\\e927";\n}\n\n.pf-icon-critical-risk:before {\n  content: "\\e976";\n}\n\n.pf-icon-data-processor:before {\n  content: "\\e97b";\n}\n\n.pf-icon-data-sink:before {\n  content: "\\e978";\n}\n\n.pf-icon-data-source:before {\n  content: "\\e979";\n}\n\n.pf-icon-degraded:before {\n  content: "\\e91b";\n}\n\n.pf-icon-disconnected:before {\n  content: "\\e955";\n}\n\n.pf-icon-domain:before {\n  content: "\\e919";\n}\n\n.pf-icon-edit:before {\n  content: "\\e60a";\n}\n\n.pf-icon-enhancement:before {\n  content: "\\e93a";\n}\n\n.pf-icon-enterprise:before {\n  content: "\\e906";\n}\n\n.pf-icon-equalizer:before {\n  content: "\\e956";\n}\n\n.pf-icon-error-circle-o:before {\n  content: "\\e926";\n}\n\n.pf-icon-export:before {\n  content: "\\e616";\n}\n\n.pf-icon-filter:before {\n  content: "\\e943";\n}\n\n.pf-icon-flavor:before {\n  content: "\\e957";\n}\n\n.pf-icon-folder-close:before {\n  content: "\\e607";\n}\n\n.pf-icon-folder-open:before {\n  content: "\\e606";\n}\n\n.pf-icon-globe-route:before {\n  content: "\\e958";\n}\n\n.pf-icon-help:before {\n  content: "\\e605";\n}\n\n.pf-icon-history:before {\n  content: "\\e617";\n}\n\n.pf-icon-home:before {\n  content: "\\e618";\n}\n\n.pf-icon-import:before {\n  content: "\\e615";\n}\n\n.pf-icon-in-progress:before {\n  content: "\\e933";\n}\n\n.pf-icon-info:before {\n  content: "\\e92b";\n}\n\n.pf-icon-infrastructure:before {\n  content: "\\e93d";\n}\n\n.pf-icon-integration:before {\n  content: "\\e948";\n}\n\n.pf-icon-key:before {\n  content: "\\e924";\n}\n\n.pf-icon-locked:before {\n  content: "\\e923";\n}\n\n.pf-icon-maintenance:before {\n  content: "\\e932";\n}\n\n.pf-icon-memory:before {\n  content: "\\e908";\n}\n\n.pf-icon-messages:before {\n  content: "\\e603";\n}\n\n.pf-icon-middleware:before {\n  content: "\\e917";\n}\n\n.pf-icon-migration:before {\n  content: "\\e931";\n}\n\n.pf-icon-module:before {\n  content: "\\e959";\n}\n\n.pf-icon-monitoring:before {\n  content: "\\e95a";\n}\n\n.pf-icon-namespaces:before {\n  content: "\\e95b";\n}\n\n.pf-icon-network:before {\n  content: "\\e909";\n}\n\n.pf-icon-new-process:before {\n  content: "\\e95c";\n}\n\n.pf-icon-not-started:before {\n  content: "\\e95d";\n}\n\n.pf-icon-off:before {\n  content: "\\e92d";\n}\n\n.pf-icon-ok:before {\n  content: "\\e602";\n}\n\n.pf-icon-on-running:before {\n  content: "\\e925";\n}\n\n.pf-icon-on:before {\n  content: "\\e92c";\n}\n\n.pf-icon-open-drawer-right:before {\n  content: "\\e977";\n}\n\n.pf-icon-openshift:before {\n  content: "\\e95e";\n}\n\n.pf-icon-openstack:before {\n  content: "\\e95f";\n}\n\n.pf-icon-optimize:before {\n  content: "\\e93e";\n}\n\n.pf-icon-orders:before {\n  content: "\\e93f";\n}\n\n.pf-icon-os-image:before {\n  content: "\\e960";\n}\n\n.pf-icon-package:before {\n  content: "\\e961";\n}\n\n.pf-icon-panel-close:before {\n  content: "\\e962";\n}\n\n.pf-icon-panel-open:before {\n  content: "\\e963";\n}\n\n.pf-icon-paused:before {\n  content: "\\e92f";\n}\n\n.pf-icon-pending:before {\n  content: "\\e964";\n}\n\n.pf-icon-pficon-dragdrop:before {\n  content: "\\e965";\n}\n\n.pf-icon-pficon-history:before {\n  content: "\\e966";\n}\n\n.pf-icon-pficon-network-range:before {\n  content: "\\e967";\n}\n\n.pf-icon-pficon-satellite:before {\n  content: "\\e968";\n}\n\n.pf-icon-pficon-sort-common-asc:before {\n  content: "\\e94e";\n}\n\n.pf-icon-pficon-sort-common-desc:before {\n  content: "\\e94f";\n}\n\n.pf-icon-pficon-template:before {\n  content: "\\e94c";\n}\n\n.pf-icon-pficon-vcenter:before {\n  content: "\\e969";\n}\n\n.pf-icon-plugged:before {\n  content: "\\e96a";\n}\n\n.pf-icon-port:before {\n  content: "\\e96b";\n}\n\n.pf-icon-print:before {\n  content: "\\e612";\n}\n\n.pf-icon-private:before {\n  content: "\\e914";\n}\n\n.pf-icon-process-automation:before {\n  content: "\\e949";\n}\n\n.pf-icon-project:before {\n  content: "\\e96c";\n}\n\n.pf-icon-rebalance:before {\n  content: "\\e91c";\n}\n\n.pf-icon-rebooting:before {\n  content: "\\e96d";\n}\n\n.pf-icon-regions:before {\n  content: "\\e90a";\n}\n\n.pf-icon-registry:before {\n  content: "\\e623";\n}\n\n.pf-icon-remove2:before {\n  content: "\\e96e";\n}\n\n.pf-icon-replicator:before {\n  content: "\\e624";\n}\n\n.pf-icon-repository:before {\n  content: "\\e90b";\n}\n\n.pf-icon-resource-pool:before {\n  content: "\\e90c";\n}\n\n.pf-icon-resources-almost-empty:before {\n  content: "\\e91d";\n}\n\n.pf-icon-resources-almost-full:before {\n  content: "\\e912";\n}\n\n.pf-icon-resources-empty:before {\n  content: "\\e96f";\n}\n\n.pf-icon-resources-full:before {\n  content: "\\e913";\n}\n\n.pf-icon-running:before {\n  content: "\\e970";\n}\n\n.pf-icon-save:before {\n  content: "\\e601";\n}\n\n.pf-icon-screen:before {\n  content: "\\e971";\n}\n\n.pf-icon-security:before {\n  content: "\\e946";\n}\n\n.pf-icon-server-group:before {\n  content: "\\e91a";\n}\n\n.pf-icon-server:before {\n  content: "\\e90d";\n}\n\n.pf-icon-service-catalog:before {\n  content: "\\e972";\n}\n\n.pf-icon-service:before {\n  content: "\\e61e";\n}\n\n.pf-icon-services:before {\n  content: "\\e947";\n}\n\n.pf-icon-spinner:before {\n  content: "\\e973";\n}\n\n.pf-icon-spinner2:before {\n  content: "\\e613";\n}\n\n.pf-icon-storage-domain:before {\n  content: "\\e90e";\n}\n\n.pf-icon-task:before {\n  content: "\\e974";\n}\n\n.pf-icon-tenant:before {\n  content: "\\e916";\n}\n\n.pf-icon-thumb-tack:before {\n  content: "\\e920";\n}\n\n.pf-icon-topology:before {\n  content: "\\e608";\n}\n\n.pf-icon-trend-down:before {\n  content: "\\e900";\n}\n\n.pf-icon-trend-up:before {\n  content: "\\e901";\n}\n\n.pf-icon-unknown:before {\n  content: "\\e935";\n}\n\n.pf-icon-unlocked:before {\n  content: "\\e922";\n}\n\n.pf-icon-unplugged:before {\n  content: "\\e942";\n}\n\n.pf-icon-user:before {\n  content: "\\e91e";\n}\n\n.pf-icon-users:before {\n  content: "\\e91f";\n}\n\n.pf-icon-virtual-machine:before {\n  content: "\\e90f";\n}\n\n.pf-icon-volume:before {\n  content: "\\e910";\n}\n\n.pf-icon-warning-triangle:before {\n  content: "\\e975";\n}\n\n.pf-icon-zone:before {\n  content: "\\e911";\n}';

// node_modules/@lit/localize/internal/str-tag.js
var _str = (strings, ...values) => ({
  strTag: true,
  strings,
  values
});
var str = _str;
var isStrTagged = (val) => typeof val !== "string" && "strTag" in val;
var joinStringsAndValues = (strings, values, valueOrder) => {
  let concat = strings[0];
  for (let i5 = 1; i5 < strings.length; i5++) {
    concat += values[valueOrder ? valueOrder[i5 - 1] : i5 - 1];
    concat += strings[i5];
  }
  return concat;
};

// node_modules/@lit/localize/internal/default-msg.js
var defaultMsg = (template) => isStrTagged(template) ? joinStringsAndValues(template.strings, template.values) : template;

// node_modules/@lit/localize/internal/locale-status-event.js
var LOCALE_STATUS_EVENT = "lit-localize-status";

// node_modules/@lit/localize/internal/localized-controller.js
var LocalizeController = class {
  constructor(host) {
    this.__litLocalizeEventHandler = (event) => {
      if (event.detail.status === "ready") {
        this.host.requestUpdate();
      }
    };
    this.host = host;
  }
  hostConnected() {
    window.addEventListener(LOCALE_STATUS_EVENT, this.__litLocalizeEventHandler);
  }
  hostDisconnected() {
    window.removeEventListener(LOCALE_STATUS_EVENT, this.__litLocalizeEventHandler);
  }
};
var _updateWhenLocaleChanges = (host) => host.addController(new LocalizeController(host));
var updateWhenLocaleChanges = _updateWhenLocaleChanges;

// node_modules/@lit/localize/internal/localized-decorator.js
var localized = () => (clazz, _context) => {
  clazz.addInitializer(updateWhenLocaleChanges);
  return clazz;
};

// node_modules/@lit/localize/internal/deferred.js
var Deferred = class {
  constructor() {
    this.settled = false;
    this.promise = new Promise((resolve, reject) => {
      this._resolve = resolve;
      this._reject = reject;
    });
  }
  resolve(value) {
    this.settled = true;
    this._resolve(value);
  }
  reject(error) {
    this.settled = true;
    this._reject(error);
  }
};

// node_modules/@lit/localize/internal/fnv1a64.js
var hl = [];
for (let i5 = 0; i5 < 256; i5++) {
  hl[i5] = (i5 >> 4 & 15).toString(16) + (i5 & 15).toString(16);
}

// node_modules/@lit/localize/init/runtime.js
var loading = new Deferred();
loading.resolve();

// node_modules/@lit/localize/lit-localize.js
var msg = defaultMsg;

// src/common/styles/authentik.css
var authentik_default = ":root {\n    --ak-accent: #fd4b2d;\n\n    --ak-dark-foreground: #fafafa;\n    --ak-dark-foreground-darker: #bebebe;\n    --ak-dark-foreground-link: #5a5cb9;\n    --ak-dark-background: #18191a;\n    --ak-dark-background-darker: #000000;\n    --ak-dark-background-light: #1c1e21;\n    --ak-dark-background-light-ish: #212427;\n    --ak-dark-background-lighter: #2b2e33;\n\n    /* PatternFly likes to override global variables for some reason */\n    --ak-global--Color--100: var(--pf-global--Color--100);\n\n    /* Minimum width after which the sidebar becomes automatic */\n    --ak-sidebar--minimum-auto-width: 80rem;\n}\n\n::-webkit-scrollbar {\n    width: 5px;\n    height: 5px;\n    background-color: transparent;\n}\n::-webkit-scrollbar-thumb {\n    background-color: var(--ak-accent);\n}\n::-webkit-scrollbar-track {\n    background-color: transparent;\n}\n::-webkit-scrollbar-corner {\n    background-color: transparent;\n}\n\nhtml {\n    --pf-c-nav__link--PaddingTop: 0.5rem;\n    --pf-c-nav__link--PaddingRight: 0.5rem;\n    --pf-c-nav__link--PaddingBottom: 0.5rem;\n    --pf-c-nav__link--PaddingLeft: 0.5rem;\n}\n\nhtml > form > input {\n    position: absolute;\n    top: -2000px;\n    left: -2000px;\n}\n\n.pf-icon {\n    display: inline-block;\n    font-style: normal;\n    font-variant: normal;\n    text-rendering: auto;\n    line-height: 1;\n    vertical-align: middle;\n}\n\n.pf-c-page__header {\n    z-index: 0;\n    background-color: var(--ak-dark-background-light);\n    box-shadow: var(--pf-global--BoxShadow--lg-bottom);\n}\n\n/*****************************\n* Login adjustments\n*****************************/\n/* Ensure card is displayed on small screens */\n.pf-c-login__main {\n    display: block;\n    position: relative;\n    width: 100%;\n}\n.ak-login-container {\n    height: calc(100vh - var(--pf-global--spacer--lg) - var(--pf-global--spacer--lg));\n    width: 35rem;\n    display: flex;\n    flex-direction: column;\n    justify-content: space-evenly;\n}\n.pf-c-login__header {\n    flex-grow: 1;\n}\n.pf-c-login__footer {\n    flex-grow: 2;\n    display: flex;\n    justify-content: end;\n    flex-direction: column;\n}\n.pf-c-login__footer ul.pf-c-list.pf-m-inline {\n    justify-content: center;\n    padding: 2rem 0;\n}\n/*****************************\n* End Login adjustments\n*****************************/\n\n.pf-c-content h1 {\n    display: flex;\n    align-items: flex-start;\n}\n.pf-c-content h1 i {\n    font-style: normal;\n}\n.pf-c-content h1 :first-child {\n    margin-right: var(--pf-global--spacer--sm);\n}\n\n/* ensure background on non-flow pages match */\n.pf-c-background-image::before {\n    background-image: var(--ak-flow-background);\n    background-position: center;\n}\n\n.pf-m-success {\n    color: var(--pf-global--success-color--100) !important;\n}\n.pf-m-warning {\n    color: var(--pf-global--warning-color--100);\n}\n.pf-m-danger {\n    color: var(--pf-global--danger-color--100);\n}\n\n.pf-c-description-list__description .pf-c-button {\n    margin-right: 6px;\n    margin-bottom: 6px;\n}\n\n/* Flow-card adjustments for static pages */\n.pf-c-brand {\n    padding-top: calc(\n        var(--pf-c-login__main-footer-links--PaddingTop) +\n            var(--pf-c-login__main-footer-links--PaddingBottom) +\n            var(--pf-c-login__main-body--PaddingBottom)\n    );\n    max-height: 9rem;\n}\n\n.ak-brand {\n    display: flex;\n    justify-content: center;\n    width: 100%;\n}\n.ak-brand img {\n    padding: 0 2rem;\n    max-height: inherit;\n}\n\n@media (min-height: 60rem) {\n    .pf-c-login.stacked .pf-c-login__main {\n        margin-top: 13rem;\n    }\n}\n\n.pf-c-data-list {\n    padding-inline-start: 0;\n}\n";

// src/common/styles/theme-dark.css
var theme_dark_default = ':root {\n    --pf-global--Color--100: var(--ak-dark-foreground) !important;\n    --ak-global--Color--100: var(--ak-dark-foreground) !important;\n    --pf-c-page__main-section--m-light--BackgroundColor: var(--ak-dark-background-darker);\n    --pf-global--link--Color: var(--ak-dark-foreground-link) !important;\n}\nbody {\n    background-color: var(--ak-dark-background) !important;\n}\n.pf-c-radio {\n    --pf-c-radio__label--Color: var(--ak-dark-foreground);\n}\n/* Global page background colour */\n.pf-c-page {\n    --pf-c-page--BackgroundColor: var(--ak-dark-background);\n}\n.pf-c-drawer__content {\n    --pf-c-drawer__content--BackgroundColor: var(--ak-dark-background);\n}\n.pf-c-title {\n    color: var(--ak-dark-foreground);\n}\n.pf-u-mb-xl {\n    color: var(--ak-dark-foreground);\n}\n/* Header sections */\n.pf-c-page__main-section {\n    --pf-c-page__main-section--BackgroundColor: var(--ak-dark-background);\n}\n.sidebar-trigger,\n.notification-trigger {\n    background-color: transparent !important;\n}\n.pf-c-page__main-section.pf-m-light {\n    background-color: transparent;\n}\n.pf-c-content {\n    color: var(--ak-dark-foreground);\n}\n/* Card */\n.pf-c-card {\n    --pf-c-card--BackgroundColor: var(--ak-dark-background-light);\n    color: var(--ak-dark-foreground);\n}\n.pf-c-card__title,\n.pf-c-card__body {\n    color: var(--ak-dark-foreground);\n}\n.pf-c-toolbar {\n    --pf-c-toolbar--BackgroundColor: var(--ak-dark-background-light);\n}\n.pf-c-pagination.pf-m-bottom {\n    background-color: var(--ak-dark-background-light);\n}\n/* table */\n.pf-c-table {\n    --pf-c-table--BackgroundColor: var(--ak-dark-background-light);\n    --pf-c-table--BorderColor: var(--ak-dark-background-lighter);\n    --pf-c-table--cell--Color: var(--ak-dark-foreground);\n    --pf-c-table--tr--m-hoverable--hover--BackgroundColor: var(--ak-dark-background-light-ish);\n    --pf-c-table--tr--m-hoverable--active--BackgroundColor: var(--ak-dark-background-lighter);\n}\n.pf-c-table__text {\n    color: var(--ak-dark-foreground);\n}\n.pf-c-table__sort:not(.pf-m-selected) .pf-c-table__button .pf-c-table__text {\n    color: var(--ak-dark-foreground) !important;\n}\n.pf-c-table__sort-indicator i {\n    color: var(--ak-dark-foreground) !important;\n}\n.pf-c-table__expandable-row.pf-m-expanded {\n    --pf-c-table__expandable-row--m-expanded--BorderBottomColor: var(--ak-dark-background-lighter);\n}\n/* tabs */\n.pf-c-tabs {\n    background-color: transparent;\n}\n.pf-c-tabs.pf-m-box.pf-m-vertical .pf-c-tabs__list::before {\n    border-color: transparent;\n}\n.pf-c-tabs.pf-m-box .pf-c-tabs__item.pf-m-current:first-child .pf-c-tabs__link::before {\n    border-color: transparent;\n}\n.pf-c-tabs__link::before {\n    border-color: transparent;\n}\n.pf-c-tabs__item.pf-m-current {\n    --pf-c-tabs__link--after--BorderColor: var(--ak-accent);\n}\n.pf-c-tabs__link {\n    --pf-c-tabs__link--Color: var(--ak-dark-foreground);\n}\n.pf-c-tabs.pf-m-vertical .pf-c-tabs__link {\n    background-color: transparent;\n}\n/* table, on mobile */\n@media screen and (max-width: 1200px) {\n    .pf-m-grid-xl.pf-c-table tbody:first-of-type {\n        border-top-color: var(--ak-dark-background);\n    }\n    .pf-m-grid-xl.pf-c-table tr:not(.pf-c-table__expandable-row) {\n        border-bottom-color: var(--ak-dark-background);\n    }\n}\n/* class for pagination text */\n.pf-c-options-menu__toggle {\n    color: var(--ak-dark-foreground);\n}\n/* table icon used for expanding rows */\n.pf-c-table__toggle-icon {\n    color: var(--ak-dark-foreground);\n}\n/* expandable elements */\n.pf-c-expandable-section__toggle-text {\n    color: var(--ak-dark-foreground);\n}\n.pf-c-expandable-section__toggle-icon {\n    color: var(--ak-dark-foreground);\n}\n.pf-c-expandable-section.pf-m-display-lg {\n    background-color: var(--ak-dark-background-light-ish);\n}\n/* header for form group */\n.pf-c-form__field-group-header-title-text {\n    color: var(--ak-dark-foreground);\n}\n.pf-c-form__field-group {\n    border-bottom: 0;\n}\n/* inputs */\noptgroup,\noption {\n    color: var(--ak-dark-foreground);\n}\nselect[multiple] optgroup:checked,\nselect[multiple] option:checked {\n    color: var(--ak-dark-background);\n}\n.pf-c-input-group {\n    --pf-c-input-group--BackgroundColor: transparent;\n}\n.pf-c-form-control {\n    --pf-c-form-control--BorderTopColor: transparent !important;\n    --pf-c-form-control--BorderRightColor: transparent !important;\n    --pf-c-form-control--BorderLeftColor: transparent !important;\n    --pf-global--BackgroundColor--100: var(--ak-dark-background-light) !important;\n    --pf-c-form-control--BackgroundColor: var(--ak-dark-background-light);\n    --pf-c-form-control--Color: var(--ak-dark-foreground) !important;\n}\n.pf-c-form-control:disabled {\n    background-color: var(--ak-dark-background-light);\n}\n.pf-c-form-control[readonly] {\n    background-color: var(--ak-dark-background-light);\n}\n.pf-c-switch__input:checked ~ .pf-c-switch__label {\n    --pf-c-switch__input--checked__label--Color: var(--ak-dark-foreground);\n}\ninput[type="datetime-local"]::-webkit-calendar-picker-indicator,\ninput[type="date"]::-webkit-calendar-picker-indicator {\n    filter: invert(1);\n}\n/* select toggle */\n.pf-c-select__toggle::before {\n    --pf-c-select__toggle--before--BorderTopColor: var(--ak-dark-background-lighter);\n    --pf-c-select__toggle--before--BorderRightColor: var(--ak-dark-background-lighter);\n    --pf-c-select__toggle--before--BorderLeftColor: var(--ak-dark-background-lighter);\n}\n.pf-c-select__toggle.pf-m-typeahead {\n    --pf-c-select__toggle--BackgroundColor: var(--ak-dark-background-light);\n}\n.pf-c-select__menu {\n    --pf-c-select__menu--BackgroundColor: var(--ak-dark-background-light-ish);\n    color: var(--ak-dark-foreground);\n}\n.pf-c-select__menu-item {\n    color: var(--ak-dark-foreground);\n}\n.pf-c-select__menu-wrapper:hover,\n.pf-c-select__menu-item:hover {\n    --pf-c-select__menu-item--hover--BackgroundColor: var(--ak-dark-background-lighter);\n}\n.pf-c-select__menu-wrapper:focus-within,\n.pf-c-select__menu-wrapper.pf-m-focus,\n.pf-c-select__menu-item:focus,\n.pf-c-select__menu-item.pf-m-focus {\n    --pf-c-select__menu-item--focus--BackgroundColor: var(--ak-dark-background-light-ish);\n}\n.pf-c-button:disabled {\n    color: var(--ak-dark-background-lighter);\n}\n.pf-c-button.pf-m-plain:hover {\n    color: var(--ak-dark-foreground);\n}\n.pf-c-button.pf-m-control {\n    --pf-c-button--after--BorderColor: var(--ak-dark-background-lighter)\n        var(--ak-dark-background-lighter) var(--pf-c-button--m-control--after--BorderBottomColor)\n        var(--ak-dark-background-lighter);\n    background-color: var(--ak-dark-background-light);\n    color: var(--ak-dark-foreground);\n}\n.pf-m-tertiary,\n.pf-c-button.pf-m-tertiary {\n    --pf-c-button--after--BorderColor: var(--ak-dark-foreground-darker);\n    color: var(--ak-dark-foreground-darker);\n}\n.pf-m-tertiary:hover,\n.pf-c-button.pf-m-tertiary:hover {\n    --pf-c-button--after--BorderColor: var(--ak-dark-background-lighter);\n}\n.pf-c-form__label-text {\n    color: var(--ak-dark-foreground);\n}\n.pf-c-check__label {\n    color: var(--ak-dark-foreground);\n}\n.pf-c-dropdown__toggle::before {\n    border-color: transparent;\n}\n.pf-c-dropdown__menu {\n    --pf-c-dropdown__menu--BackgroundColor: var(--ak-dark-background);\n}\n.pf-c-dropdown__menu-item {\n    --pf-c-dropdown__menu-item--BackgroundColor: var(--ak-dark-background);\n    --pf-c-dropdown__menu-item--Color: var(--ak-dark-foreground);\n}\n.pf-c-dropdown__menu-item:hover,\n.pf-c-dropdown__menu-item:focus {\n    --pf-c-dropdown__menu-item--BackgroundColor: var(--ak-dark-background-light-ish);\n    --pf-c-dropdown__menu-item--Color: var(--ak-dark-foreground);\n}\n.pf-c-toggle-group__button {\n    color: var(--ak-dark-foreground) !important;\n}\n.pf-c-toggle-group__button:not(.pf-m-selected) {\n    background-color: var(--ak-dark-background-light) !important;\n}\n.pf-c-toggle-group__button.pf-m-selected {\n    color: var(--ak-dark-foreground) !important;\n    background-color: var(--pf-global--primary-color--100) !important;\n}\n/* inputs help text */\n.pf-c-form__helper-text:not(.pf-m-error) {\n    color: var(--ak-dark-foreground);\n}\n/* modal */\n.pf-c-modal-box,\n.pf-c-modal-box__header,\n.pf-c-modal-box__footer,\n.pf-c-modal-box__body {\n    background-color: var(--ak-dark-background);\n}\n/* sidebar */\n.pf-c-nav {\n    background-color: var(--ak-dark-background-light);\n}\n/* flows */\n.pf-c-login__main {\n    --pf-c-login__main--BackgroundColor: var(--ak-dark-background);\n}\n.pf-c-login__main-body,\n.pf-c-login__main-header,\n.pf-c-login__main-header-desc {\n    color: var(--ak-dark-foreground);\n}\n.pf-c-login__main-footer-links-item img,\n.pf-c-login__main-footer-links-item .fas {\n    filter: invert(1);\n}\n.pf-c-login__main-footer-band {\n    --pf-c-login__main-footer-band--BackgroundColor: var(--ak-dark-background-lighter);\n    color: var(--ak-dark-foreground);\n}\n.form-control-static {\n    color: var(--ak-dark-foreground);\n}\n/* notifications */\n.pf-c-drawer__panel {\n    background-color: var(--ak-dark-background);\n}\n.pf-c-notification-drawer {\n    --pf-c-notification-drawer--BackgroundColor: var(--ak-dark-background);\n}\n.pf-c-notification-drawer__header {\n    background-color: var(--ak-dark-background-lighter);\n    color: var(--ak-dark-foreground);\n}\n.pf-c-notification-drawer__list-item {\n    background-color: var(--ak-dark-background-light-ish);\n    color: var(--ak-dark-foreground);\n    --pf-c-notification-drawer__list-item--BorderBottomColor: var(\n        --ak-dark-background-lighter\n    ) !important;\n}\n/* data list */\n.pf-c-data-list {\n    padding-inline-start: 0;\n    border-top-color: var(--ak-dark-background-lighter);\n}\n.pf-c-data-list__item {\n    --pf-c-data-list__item--BackgroundColor: transparent;\n    --pf-c-data-list__item--BorderBottomColor: var(--ak-dark-background-lighter);\n    color: var(--ak-dark-foreground);\n}\n/* wizards */\n.pf-c-wizard__nav {\n    --pf-c-wizard__nav--BackgroundColor: var(--ak-dark-background-lighter);\n    --pf-c-wizard__nav--lg--BorderRightColor: transparent;\n}\n.pf-c-wizard__main {\n    background-color: var(--ak-dark-background-light-ish);\n}\n.pf-c-wizard__footer {\n    --pf-c-wizard__footer--BackgroundColor: var(--ak-dark-background-light-ish);\n}\n.pf-c-wizard__toggle-num,\n.pf-c-wizard__nav-link::before {\n    --pf-c-wizard__nav-link--before--BackgroundColor: transparent;\n}\n/* tree view */\n.pf-c-tree-view__node {\n    --pf-c-tree-view__node--Color: var(--ak-dark-foreground);\n}\n.pf-c-tree-view__node-toggle {\n    --pf-c-tree-view__node-toggle--Color: var(--ak-dark-foreground);\n}\n.pf-c-tree-view__node:focus {\n    --pf-c-tree-view__node--focus--BackgroundColor: var(--ak-dark-background-light-ish);\n}\n.pf-c-tree-view__content:hover,\n.pf-c-tree-view__content:focus-within {\n    --pf-c-tree-view__node--hover--BackgroundColor: var(--ak-dark-background-light-ish);\n}\n/* stepper */\n.pf-c-progress-stepper__step-title {\n    --pf-c-progress-stepper__step-title--Color: var(--ak-dark-foreground);\n}\n';

// src/elements/Base.ts
var rootInterface = () => document.body.querySelector("[data-ak-interface-root]") ?? void 0;
var css;
function fetchCustomCSS() {
  if (!css) {
    css = Promise.all(
      Array.of(...document.head.querySelectorAll("link[data-inject]")).map(
        (link) => {
          return fetch(link.href).then((res) => {
            return res.text();
          }).finally(() => {
            return "";
          });
        }
      )
    );
  }
  return css;
}
var QUERY_MEDIA_COLOR_LIGHT = "(prefers-color-scheme: light)";
var AKElement = class extends s3 {
  get activeTheme() {
    return this._activeTheme;
  }
  constructor() {
    super();
  }
  setInitialStyles(root) {
    const styleRoot = "ShadyDOM" in window ? document : root;
    styleRoot.adoptedStyleSheets = adaptCSS([
      ...styleRoot.adoptedStyleSheets,
      ensureCSSStyleSheet(authentik_default)
    ]);
    this._initTheme(styleRoot);
    this._initCustomCSS(styleRoot);
  }
  createRenderRoot() {
    this.fixElementStyles();
    const root = super.createRenderRoot();
    this.setInitialStyles(root);
    return root;
  }
  async getTheme() {
    return rootInterface()?.getTheme() || UiThemeEnum.Automatic;
  }
  fixElementStyles() {
    this.constructor.elementStyles = this.constructor.elementStyles.map(ensureCSSStyleSheet);
  }
  async _initTheme(root) {
    this._activateTheme(
      root,
      window.matchMedia(QUERY_MEDIA_COLOR_LIGHT).matches ? UiThemeEnum.Light : UiThemeEnum.Dark
    );
    this._applyTheme(root, await this.getTheme());
  }
  async _initCustomCSS(root) {
    const sheets = await fetchCustomCSS();
    sheets.map((css2) => {
      if (css2 === "") {
        return;
      }
      new CSSStyleSheet().replace(css2).then((sheet) => {
        root.adoptedStyleSheets = [...root.adoptedStyleSheets, sheet];
      });
    });
  }
  _applyTheme(root, theme) {
    if (!theme) {
      theme = UiThemeEnum.Automatic;
    }
    if (theme === UiThemeEnum.Automatic) {
      if (!this._mediaMatcher) {
        this._mediaMatcher = window.matchMedia(QUERY_MEDIA_COLOR_LIGHT);
        this._mediaMatcherHandler = (ev) => {
          const theme2 = ev?.matches || this._mediaMatcher?.matches ? UiThemeEnum.Light : UiThemeEnum.Dark;
          this._activateTheme(root, theme2);
        };
        this._mediaMatcher.addEventListener("change", this._mediaMatcherHandler);
      }
      return;
    } else if (this._mediaMatcher && this._mediaMatcherHandler) {
      this._mediaMatcher.removeEventListener("change", this._mediaMatcherHandler);
      this._mediaMatcher = void 0;
    }
    this._activateTheme(root, theme);
  }
  static themeToStylesheet(theme) {
    if (theme === UiThemeEnum.Dark) {
      return theme_dark_default;
    }
    return void 0;
  }
  _activateTheme(root, theme) {
    if (theme === this._activeTheme) {
      return;
    }
    this.dispatchEvent(
      new CustomEvent(EVENT_THEME_CHANGE, {
        bubbles: true,
        composed: true,
        detail: theme
      })
    );
    this.setAttribute("theme", theme);
    const stylesheet = AKElement.themeToStylesheet(theme);
    const oldStylesheet = AKElement.themeToStylesheet(this._activeTheme);
    if (stylesheet) {
      root.adoptedStyleSheets = [...root.adoptedStyleSheets, ensureCSSStyleSheet(stylesheet)];
    }
    if (oldStylesheet) {
      root.adoptedStyleSheets = root.adoptedStyleSheets.filter((v2) => v2 !== oldStylesheet);
    }
    this._activeTheme = theme;
    this.requestUpdate();
  }
};
AKElement = __decorateClass([
  localized()
], AKElement);

// node_modules/@lit/context/lib/context-request-event.js
var s4 = class extends Event {
  constructor(s7, t5, e7) {
    super("context-request", { bubbles: true, composed: true }), this.context = s7, this.callback = t5, this.subscribe = e7 ?? false;
  }
};

// node_modules/@lit/context/lib/create-context.js
function n5(n6) {
  return n6;
}

// node_modules/@lit/context/lib/value-notifier.js
var s5 = class {
  get value() {
    return this.o;
  }
  set value(s7) {
    this.setValue(s7);
  }
  setValue(s7, t5 = false) {
    const i5 = t5 || !Object.is(s7, this.o);
    this.o = s7, i5 && this.updateObservers();
  }
  constructor(s7) {
    this.subscriptions = /* @__PURE__ */ new Map(), this.updateObservers = () => {
      for (const [s8, { disposer: t5 }] of this.subscriptions)
        s8(this.o, t5);
    }, void 0 !== s7 && (this.value = s7);
  }
  addCallback(s7, t5, i5) {
    if (!i5)
      return void s7(this.value);
    this.subscriptions.has(s7) || this.subscriptions.set(s7, { disposer: () => {
      this.subscriptions.delete(s7);
    }, consumerHost: t5 });
    const { disposer: h3 } = this.subscriptions.get(s7);
    s7(this.value, h3);
  }
  clearCallbacks() {
    this.subscriptions.clear();
  }
};

// node_modules/@lit/context/lib/controllers/context-provider.js
var e5 = class extends Event {
  constructor(t5) {
    super("context-provider", { bubbles: true, composed: true }), this.context = t5;
  }
};
var i4 = class extends s5 {
  constructor(s7, e7, i5) {
    super(void 0 !== e7.context ? e7.initialValue : i5), this.onContextRequest = (t5) => {
      const s8 = t5.composedPath()[0];
      t5.context === this.context && s8 !== this.host && (t5.stopPropagation(), this.addCallback(t5.callback, s8, t5.subscribe));
    }, this.onProviderRequest = (s8) => {
      const e8 = s8.composedPath()[0];
      if (s8.context !== this.context || e8 === this.host)
        return;
      const i6 = /* @__PURE__ */ new Set();
      for (const [s9, { consumerHost: e9 }] of this.subscriptions)
        i6.has(s9) || (i6.add(s9), e9.dispatchEvent(new s4(this.context, s9, true)));
      s8.stopPropagation();
    }, this.host = s7, void 0 !== e7.context ? this.context = e7.context : this.context = e7, this.attachListeners(), this.host.addController?.(this);
  }
  attachListeners() {
    this.host.addEventListener("context-request", this.onContextRequest), this.host.addEventListener("context-provider", this.onProviderRequest);
  }
  hostConnected() {
    this.host.dispatchEvent(new e5(this.context));
  }
};

// src/elements/AuthentikContexts.ts
var authentikConfigContext = n5(Symbol("authentik-config-context"));
var authentikUserContext = n5(Symbol("authentik-user-context"));
var authentikEnterpriseContext = n5(
  Symbol("authentik-enterprise-context")
);
var authentikBrandContext = n5(Symbol("authentik-brand-context"));

// src/elements/Interface/BrandContextController.ts
var BrandContextController = class {
  constructor(host) {
    this.host = host;
    this.context = new i4(this.host, {
      context: authentikBrandContext,
      initialValue: void 0
    });
    this.fetch = this.fetch.bind(this);
    this.fetch();
  }
  fetch() {
    new CoreApi(DEFAULT_CONFIG).coreBrandsCurrentRetrieve().then((brand) => {
      this.context.setValue(brand);
      this.host.brand = brand;
    });
  }
  hostConnected() {
    window.addEventListener(EVENT_REFRESH, this.fetch);
  }
  hostDisconnected() {
    window.removeEventListener(EVENT_REFRESH, this.fetch);
  }
  hostUpdate() {
    if (this.host.brand !== this.context.value) {
      this.context.setValue(this.host.brand);
    }
  }
};

// src/elements/Interface/ConfigContextController.ts
var ConfigContextController = class {
  constructor(host) {
    this.host = host;
    this.context = new i4(this.host, {
      context: authentikConfigContext,
      initialValue: void 0
    });
    this.context.setValue(globalAK().config);
    this.host.config = globalAK().config;
    this.fetch = this.fetch.bind(this);
    this.fetch();
  }
  fetch() {
    new RootApi(DEFAULT_CONFIG).rootConfigRetrieve().then((config2) => {
      this.context.setValue(config2);
      this.host.config = config2;
    });
  }
  hostConnected() {
    window.addEventListener(EVENT_REFRESH, this.fetch);
  }
  hostDisconnected() {
    window.removeEventListener(EVENT_REFRESH, this.fetch);
  }
  hostUpdate() {
    if (this.host.config !== this.context.value) {
      this.context.setValue(this.host.config);
    }
  }
};

// src/elements/Interface/EnterpriseContextController.ts
var EnterpriseContextController = class {
  constructor(host) {
    this.host = host;
    this.context = new i4(this.host, {
      context: authentikEnterpriseContext,
      initialValue: void 0
    });
    this.fetch = this.fetch.bind(this);
    this.fetch();
  }
  fetch() {
    new EnterpriseApi(DEFAULT_CONFIG).enterpriseLicenseSummaryRetrieve().then((enterprise) => {
      this.context.setValue(enterprise);
      this.host.licenseSummary = enterprise;
    });
  }
  hostConnected() {
    window.addEventListener(EVENT_REFRESH_ENTERPRISE, this.fetch);
  }
  hostDisconnected() {
    window.removeEventListener(EVENT_REFRESH_ENTERPRISE, this.fetch);
  }
  hostUpdate() {
    if (this.host.licenseSummary !== this.context.value) {
      this.context.setValue(this.host.licenseSummary);
    }
  }
};

// src/elements/Interface/Interface.ts
var brandContext = Symbol("brandContext");
var configContext = Symbol("configContext");
var modalController = Symbol("modalController");
var Interface = class extends AKElement {
  static {
    brandContext, configContext, modalController;
  }
  constructor() {
    super();
    document.adoptedStyleSheets = [...document.adoptedStyleSheets, ensureCSSStyleSheet(patternfly_base_default)];
    this[brandContext] = new BrandContextController(this);
    this[configContext] = new ConfigContextController(this);
    this[modalController] = new ModalOrchestrationController(this);
    this.dataset.akInterfaceRoot = "true";
  }
  _activateTheme(root, theme) {
    super._activateTheme(root, theme);
    super._activateTheme(document, theme);
  }
  async getTheme() {
    if (!this.uiConfig) {
      this.uiConfig = await uiConfig();
    }
    return this.uiConfig.theme?.base || UiThemeEnum.Automatic;
  }
};
__decorateClass([
  r6()
], Interface.prototype, "uiConfig", 2);
__decorateClass([
  r6()
], Interface.prototype, "config", 2);
__decorateClass([
  r6()
], Interface.prototype, "brand", 2);
var enterpriseContext = Symbol("enterpriseContext");
var EnterpriseAwareInterface = class extends Interface {
  static {
    enterpriseContext;
  }
  constructor() {
    super();
    this[enterpriseContext] = new EnterpriseContextController(this);
  }
};
__decorateClass([
  r6()
], EnterpriseAwareInterface.prototype, "licenseSummary", 2);

// node_modules/@patternfly/patternfly/components/Spinner/spinner.css
var spinner_default = '.pf-c-spinner {\n  --pf-c-spinner--diameter: var(--pf-global--icon--FontSize--xl);\n  --pf-c-spinner--Width: var(--pf-c-spinner--diameter);\n  --pf-c-spinner--Height: var(--pf-c-spinner--diameter);\n  --pf-c-spinner--Color: var(--pf-global--primary-color--100);\n  --pf-c-spinner--m-sm--diameter: var(--pf-global--icon--FontSize--sm);\n  --pf-c-spinner--m-md--diameter: var(--pf-global--icon--FontSize--md);\n  --pf-c-spinner--m-lg--diameter: var(--pf-global--icon--FontSize--lg);\n  --pf-c-spinner--m-xl--diameter: var(--pf-global--icon--FontSize--xl);\n  --pf-c-spinner--m-inline--diameter: 1em;\n  width: var(--pf-c-spinner--Width);\n  height: var(--pf-c-spinner--Height);\n  overflow: hidden;\n}\n.pf-c-spinner.pf-m-inline {\n  --pf-c-spinner--diameter: var(--pf-c-spinner--m-inline--diameter);\n}\n.pf-c-spinner.pf-m-sm {\n  --pf-c-spinner--diameter: var(--pf-c-spinner--m-sm--diameter);\n}\n.pf-c-spinner.pf-m-md {\n  --pf-c-spinner--diameter: var(--pf-c-spinner--m-md--diameter);\n}\n.pf-c-spinner.pf-m-lg {\n  --pf-c-spinner--diameter: var(--pf-c-spinner--m-lg--diameter);\n}\n.pf-c-spinner.pf-m-xl {\n  --pf-c-spinner--diameter: var(--pf-c-spinner--m-xl--diameter);\n}\n\nspan.pf-c-spinner {\n  --pf-c-spinner--AnimationDuration: 1.5s;\n  --pf-c-spinner--AnimationTimingFunction: cubic-bezier(.77, .005, .315, 1);\n  --pf-c-spinner--stroke-width-multiplier: .1;\n  --pf-c-spinner--stroke-width: calc(var(--pf-c-spinner--diameter) * var(--pf-c-spinner--stroke-width-multiplier));\n  --pf-c-spinner__clipper--Width: var(--pf-c-spinner--diameter);\n  --pf-c-spinner__clipper--Height: var(--pf-c-spinner--diameter);\n  --pf-c-spinner__clipper--after--BoxShadowColor: var(--pf-c-spinner--Color);\n  --pf-c-spinner__clipper--after--Width: var(--pf-c-spinner--diameter);\n  --pf-c-spinner__clipper--after--Height: var(--pf-c-spinner--diameter);\n  --pf-c-spinner__clipper--after--BoxShadowSpreadRadius: var(--pf-c-spinner--stroke-width);\n  --pf-c-spinner__lead-ball--after--BackgroundColor: var(--pf-c-spinner--Color);\n  --pf-c-spinner__ball--after--Width: var(--pf-c-spinner--stroke-width);\n  --pf-c-spinner__ball--after--Height: var(--pf-c-spinner--stroke-width);\n  --pf-c-spinner__tail-ball--after--BackgroundColor: var(--pf-c-spinner--Color);\n  position: relative;\n  display: inline-block;\n  text-align: left;\n  animation: pf-animation-spinner-parent calc(var(--pf-c-spinner--AnimationDuration) * 2) var(--pf-c-spinner--AnimationTimingFunction) infinite;\n}\n\n@keyframes pf-animation-spinner-parent {\n  0% {\n    transform: rotate(0deg);\n  }\n  50% {\n    transform: rotate(540deg);\n  }\n  100% {\n    transform: rotate(1080deg);\n  }\n}\n.pf-c-spinner__clipper {\n  position: absolute;\n  width: var(--pf-c-spinner__clipper--Width);\n  height: var(--pf-c-spinner__clipper--Height);\n  clip-path: inset(0 0 50% 50%);\n  animation: pf-animation-spinner__clipper var(--pf-c-spinner--AnimationDuration) linear infinite;\n}\n\n@keyframes pf-animation-spinner__clipper {\n  0% {\n    transform: rotate(90deg);\n  }\n  100% {\n    transform: rotate(360deg);\n  }\n}\n.pf-c-spinner__clipper::after {\n  position: absolute;\n  width: var(--pf-c-spinner__clipper--after--Width);\n  height: var(--pf-c-spinner__clipper--after--Height);\n  clip-path: inset(0 0 0 50%);\n  content: "";\n  border-radius: 50%;\n  box-shadow: inset 0 0 0 var(--pf-c-spinner__clipper--after--BoxShadowSpreadRadius) var(--pf-c-spinner__clipper--after--BoxShadowColor);\n  animation: pf-animation-spinner__clipper-after var(--pf-c-spinner--AnimationDuration) linear infinite;\n}\n\n@keyframes pf-animation-spinner__clipper-after {\n  0% {\n    transform: rotate(-180deg);\n  }\n  100% {\n    transform: rotate(90deg);\n  }\n}\n.pf-c-spinner__lead-ball {\n  position: absolute;\n  top: 0;\n  left: 0;\n  width: 100%;\n  height: 100%;\n  animation: pf-animation-spinner__lead-ball var(--pf-c-spinner--AnimationDuration) linear infinite;\n}\n.pf-c-spinner__lead-ball::after {\n  position: absolute;\n  top: calc(50% - var(--pf-c-spinner__ball--after--Height) / 2);\n  right: 0;\n  width: var(--pf-c-spinner__ball--after--Width);\n  height: var(--pf-c-spinner__ball--after--Height);\n  content: "";\n  background-color: var(--pf-c-spinner__lead-ball--after--BackgroundColor);\n  border-radius: 50%;\n  transform-origin: top right;\n}\n\n@keyframes pf-animation-spinner__lead-ball {\n  0% {\n    transform: rotate(0deg);\n  }\n  33% {\n    transform: rotate(180deg);\n  }\n  100% {\n    transform: rotate(360deg);\n  }\n}\n.pf-c-spinner__tail-ball {\n  position: absolute;\n  top: 0;\n  left: 0;\n  width: 100%;\n  height: 100%;\n  animation: pf-animation-spinner__tail-ball var(--pf-c-spinner--AnimationDuration) linear infinite;\n}\n.pf-c-spinner__tail-ball::after {\n  position: absolute;\n  top: calc(50% - var(--pf-c-spinner__ball--after--Height) / 2);\n  right: 0;\n  width: var(--pf-c-spinner__ball--after--Width);\n  height: var(--pf-c-spinner__ball--after--Height);\n  content: "";\n  background-color: var(--pf-c-spinner__tail-ball--after--BackgroundColor);\n  border-radius: 50%;\n  transform-origin: top right;\n}\n\n@keyframes pf-animation-spinner__tail-ball {\n  0% {\n    transform: rotate(0deg);\n  }\n  66% {\n    transform: rotate(180deg);\n  }\n  100% {\n    transform: rotate(360deg);\n  }\n}\nsvg.pf-c-spinner {\n  --pf-c-spinner--diameter: var(--pf-global--icon--FontSize--xl);\n  --pf-c-spinner--AnimationDuration: 1.4s;\n  --pf-c-spinner--AnimationTimingFunction: linear;\n  --pf-c-spinner--stroke-width: 10;\n  --pf-c-spinner__path--Stroke: var(--pf-c-spinner--Color);\n  --pf-c-spinner__path--StrokeWidth: var(--pf-c-spinner--stroke-width);\n  --pf-c-spinner__path--AnimationTimingFunction: ease-in-out;\n  --pf-c-spinner--m-sm--diameter: var(--pf-global--icon--FontSize--sm);\n  --pf-c-spinner--m-md--diameter: var(--pf-global--icon--FontSize--md);\n  --pf-c-spinner--m-lg--diameter: var(--pf-global--icon--FontSize--lg);\n  --pf-c-spinner--m-xl--diameter: var(--pf-global--icon--FontSize--xl);\n  animation: pf-c-spinner-animation-rotate calc(var(--pf-c-spinner--AnimationDuration) * 2) var(--pf-c-spinner--AnimationTimingFunction) infinite;\n}\nsvg.pf-c-spinner.pf-m-sm {\n  --pf-c-spinner--diameter: var(--pf-c-spinner--m-sm--diameter);\n}\nsvg.pf-c-spinner.pf-m-md {\n  --pf-c-spinner--diameter: var(--pf-c-spinner--m-md--diameter);\n}\nsvg.pf-c-spinner.pf-m-lg {\n  --pf-c-spinner--diameter: var(--pf-c-spinner--m-lg--diameter);\n}\nsvg.pf-c-spinner.pf-m-xl {\n  --pf-c-spinner--diameter: var(--pf-c-spinner--m-xl--diameter);\n}\n\n.pf-c-spinner__path {\n  width: 100%;\n  height: 100%;\n  transform-origin: 50% 50%;\n  animation: pf-c-spinner-animation-dash var(--pf-c-spinner--AnimationDuration) var(--pf-c-spinner__path--AnimationTimingFunction) infinite;\n  stroke: var(--pf-c-spinner--Color);\n  stroke-linecap: round;\n  stroke-dasharray: 283;\n  stroke-dashoffset: 280;\n  stroke-width: var(--pf-c-spinner--stroke-width);\n}\n\n@keyframes pf-c-spinner-animation-rotate {\n  0% {\n    transform: rotate(0deg);\n  }\n  100% {\n    transform: rotate(360deg);\n  }\n}\n@keyframes pf-c-spinner-animation-dash {\n  0% {\n    stroke-dashoffset: 280;\n    transform: rotate(0);\n  }\n  15% {\n    stroke-width: calc(var(--pf-c-spinner__path--StrokeWidth) - 4);\n  }\n  40% {\n    stroke-dashoffset: 150;\n    stroke-dasharray: 220;\n  }\n  100% {\n    stroke-dashoffset: 280;\n    transform: rotate(720deg);\n  }\n}';

// src/elements/Spinner.ts
var Spinner = class extends AKElement {
  constructor() {
    super(...arguments);
    this.size = "pf-m-md" /* Medium */;
  }
  static get styles() {
    return [spinner_default];
  }
  render() {
    return x`<span
            class="pf-c-spinner ${this.size.toString()}"
            role="progressbar"
            aria-valuetext="${msg("Loading...")}"
        >
            <span class="pf-c-spinner__clipper"></span>
            <span class="pf-c-spinner__lead-ball"></span>
            <span class="pf-c-spinner__tail-ball"></span>
        </span>`;
  }
};
__decorateClass([
  n4()
], Spinner.prototype, "size", 2);
Spinner = __decorateClass([
  t3("ak-spinner")
], Spinner);

// node_modules/@patternfly/patternfly/components/EmptyState/empty-state.css
var empty_state_default = ".pf-c-empty-state {\n  --pf-c-empty-state--PaddingTop: var(--pf-global--spacer--xl);\n  --pf-c-empty-state--PaddingRight: var(--pf-global--spacer--xl);\n  --pf-c-empty-state--PaddingBottom: var(--pf-global--spacer--xl);\n  --pf-c-empty-state--PaddingLeft: var(--pf-global--spacer--xl);\n  --pf-c-empty-state__content--MaxWidth: none;\n  --pf-c-empty-state__icon--MarginBottom: var(--pf-global--spacer--lg);\n  --pf-c-empty-state__icon--FontSize: var(--pf-global--icon--FontSize--xl);\n  --pf-c-empty-state__icon--Color: var(--pf-global--icon--Color--light);\n  --pf-c-empty-state__content--c-title--m-lg--FontSize: var(--pf-global--FontSize--xl);\n  --pf-c-empty-state__body--MarginTop: var(--pf-global--spacer--md);\n  --pf-c-empty-state__body--Color: var(--pf-global--Color--200);\n  --pf-c-empty-state__primary--MarginTop: var(--pf-global--spacer--xl);\n  --pf-c-empty-state__primary--secondary--MarginTop: var(--pf-global--spacer--sm);\n  --pf-c-empty-state__secondary--MarginTop: var(--pf-global--spacer--xl);\n  --pf-c-empty-state__secondary--MarginBottom: calc(var(--pf-global--spacer--xs) * -1);\n  --pf-c-empty-state__secondary--child--MarginRight: calc(var(--pf-global--spacer--xs) / 2);\n  --pf-c-empty-state__secondary--child--MarginBottom: var(--pf-global--spacer--xs);\n  --pf-c-empty-state__secondary--child--MarginLeft: calc(var(--pf-global--spacer--xs) / 2);\n  --pf-c-empty-state--m-xs__content--MaxWidth: 21.875rem;\n  --pf-c-empty-state--m-xs__body--FontSize: var(--pf-global--FontSize--sm);\n  --pf-c-empty-state--m-xs--button--FontSize: var(--pf-global--FontSize--sm);\n  --pf-c-empty-state--m-xs--PaddingTop: var(--pf-global--spacer--md);\n  --pf-c-empty-state--m-xs--PaddingRight: var(--pf-global--spacer--md);\n  --pf-c-empty-state--m-xs--PaddingBottom: var(--pf-global--spacer--md);\n  --pf-c-empty-state--m-xs--PaddingLeft: var(--pf-global--spacer--md);\n  --pf-c-empty-state--m-xs__icon--MarginBottom: var(--pf-global--spacer--md);\n  --pf-c-empty-state--m-xs__body--MarginTop: var(--pf-global--spacer--md);\n  --pf-c-empty-state--m-xs__primary--MarginTop: var(--pf-global--spacer--md);\n  --pf-c-empty-state--m-xs__secondary--MarginTop: var(--pf-global--spacer--md);\n  --pf-c-empty-state--m-sm__content--MaxWidth: 25rem;\n  --pf-c-empty-state--m-lg__content--MaxWidth: 37.5rem;\n  --pf-c-empty-state--m-xl__body--FontSize: var(--pf-global--FontSize--xl);\n  --pf-c-empty-state--m-xl__body--MarginTop: var(--pf-global--spacer--lg);\n  --pf-c-empty-state--m-xl__icon--MarginBottom: var(--pf-global--spacer--xl);\n  --pf-c-empty-state--m-xl__icon--FontSize: 6.25rem;\n  --pf-c-empty-state--m-xl--c-button__secondary--MarginTop: var(--pf-global--spacer--md);\n  display: flex;\n  align-items: center;\n  justify-content: center;\n  padding: var(--pf-c-empty-state--PaddingTop) var(--pf-c-empty-state--PaddingRight) var(--pf-c-empty-state--PaddingBottom) var(--pf-c-empty-state--PaddingLeft);\n  text-align: center;\n}\n.pf-c-empty-state.pf-m-xs {\n  --pf-c-empty-state--PaddingTop: var(--pf-c-empty-state--m-xs--PaddingTop);\n  --pf-c-empty-state--PaddingRight: var(--pf-c-empty-state--m-xs--PaddingRight);\n  --pf-c-empty-state--PaddingBottom: var(--pf-c-empty-state--m-xs--PaddingBottom);\n  --pf-c-empty-state--PaddingLeft: var(--pf-c-empty-state--m-xs--PaddingLeft);\n  --pf-c-empty-state__content--MaxWidth: var(--pf-c-empty-state--m-xs__content--MaxWidth);\n  --pf-c-empty-state__icon--MarginBottom: var(--pf-c-empty-state--m-xs__icon--MarginBottom);\n  --pf-c-empty-state__body--MarginTop: var(--pf-c-empty-state--m-xs__body--MarginTop);\n  --pf-c-empty-state__primary--MarginTop: var(--pf-c-empty-state--m-xs__primary--MarginTop);\n  --pf-c-empty-state__secondary--MarginTop: var(--pf-c-empty-state--m-xs__secondary--MarginTop);\n}\n.pf-c-empty-state.pf-m-xs .pf-c-empty-state__body {\n  font-size: var(--pf-c-empty-state--m-xs__body--FontSize);\n}\n.pf-c-empty-state.pf-m-xs .pf-c-button {\n  --pf-c-button--FontSize: var(--pf-c-empty-state--m-xs--button--FontSize);\n}\n.pf-c-empty-state.pf-m-sm {\n  --pf-c-empty-state__content--MaxWidth: var(--pf-c-empty-state--m-sm__content--MaxWidth);\n}\n.pf-c-empty-state.pf-m-lg {\n  --pf-c-empty-state__content--MaxWidth: var(--pf-c-empty-state--m-lg__content--MaxWidth);\n}\n.pf-c-empty-state.pf-m-xl {\n  --pf-c-empty-state__body--MarginTop: var(--pf-c-empty-state--m-xl__body--MarginTop);\n  --pf-c-empty-state__icon--MarginBottom: var(--pf-c-empty-state--m-xl__icon--MarginBottom);\n  --pf-c-empty-state__icon--FontSize: var(--pf-c-empty-state--m-xl__icon--FontSize);\n  --pf-c-empty-state--c-button__secondary--MarginTop: var(--pf-c-empty-state--m-xl--c-button__secondary--MarginTop);\n}\n.pf-c-empty-state.pf-m-xl .pf-c-empty-state__body {\n  font-size: var(--pf-c-empty-state--m-xl__body--FontSize);\n}\n.pf-c-empty-state.pf-m-full-height {\n  height: 100%;\n}\n\n.pf-c-empty-state__content {\n  max-width: var(--pf-c-empty-state__content--MaxWidth);\n}\n.pf-c-empty-state__content > .pf-c-title.pf-m-lg {\n  font-size: var(--pf-c-empty-state__content--c-title--m-lg--FontSize);\n}\n\n.pf-c-empty-state__icon {\n  margin-bottom: var(--pf-c-empty-state__icon--MarginBottom);\n  font-size: var(--pf-c-empty-state__icon--FontSize);\n  color: var(--pf-c-empty-state__icon--Color);\n}\n\n.pf-c-empty-state__body {\n  margin-top: var(--pf-c-empty-state__body--MarginTop);\n  color: var(--pf-c-empty-state__body--Color);\n}\n\n.pf-c-empty-state__content > .pf-c-button.pf-m-primary,\n.pf-c-empty-state__primary {\n  margin-top: var(--pf-c-empty-state__primary--MarginTop);\n}\n.pf-c-empty-state__content > .pf-c-button.pf-m-primary + .pf-c-empty-state__secondary,\n.pf-c-empty-state__primary + .pf-c-empty-state__secondary {\n  margin-top: var(--pf-c-empty-state__primary--secondary--MarginTop);\n}\n\n.pf-c-empty-state__secondary {\n  display: flex;\n  flex-wrap: wrap;\n  justify-content: center;\n  margin-top: var(--pf-c-empty-state__secondary--MarginTop);\n  margin-bottom: var(--pf-c-empty-state__secondary--MarginBottom);\n}\n.pf-c-empty-state__secondary > * {\n  margin-right: var(--pf-c-empty-state__secondary--child--MarginRight);\n  margin-bottom: var(--pf-c-empty-state__secondary--child--MarginBottom);\n  margin-left: var(--pf-c-empty-state__secondary--child--MarginLeft);\n}\n\n.pf-m-overpass-font .pf-c-empty-state .pf-c-empty-state__content > .pf-c-title.pf-m-lg {\n  font-size: var(--pf-global--FontSize--lg);\n}";

// node_modules/@patternfly/patternfly/components/Title/title.css
var title_default = ".pf-c-title {\n  --pf-c-title--FontFamily: var(--pf-global--FontFamily--heading--sans-serif);\n  --pf-c-title--m-4xl--LineHeight: var(--pf-global--LineHeight--sm);\n  --pf-c-title--m-4xl--FontSize: var(--pf-global--FontSize--4xl);\n  --pf-c-title--m-4xl--FontWeight: var(--pf-global--FontWeight--normal);\n  --pf-c-title--m-3xl--LineHeight: var(--pf-global--LineHeight--sm);\n  --pf-c-title--m-3xl--FontSize: var(--pf-global--FontSize--3xl);\n  --pf-c-title--m-3xl--FontWeight: var(--pf-global--FontWeight--normal);\n  --pf-c-title--m-2xl--LineHeight: var(--pf-global--LineHeight--sm);\n  --pf-c-title--m-2xl--FontSize: var(--pf-global--FontSize--2xl);\n  --pf-c-title--m-2xl--FontWeight: var(--pf-global--FontWeight--normal);\n  --pf-c-title--m-xl--LineHeight: var(--pf-global--LineHeight--md);\n  --pf-c-title--m-xl--FontSize: var(--pf-global--FontSize--xl);\n  --pf-c-title--m-xl--FontWeight: var(--pf-global--FontWeight--normal);\n  --pf-c-title--m-lg--LineHeight: var(--pf-global--LineHeight--md);\n  --pf-c-title--m-lg--FontSize: var(--pf-global--FontSize--lg);\n  --pf-c-title--m-lg--FontWeight: var(--pf-global--FontWeight--normal);\n  --pf-c-title--m-md--LineHeight: var(--pf-global--LineHeight--md);\n  --pf-c-title--m-md--FontSize: var(--pf-global--FontSize--md);\n  --pf-c-title--m-md--FontWeight: var(--pf-global--FontWeight--normal);\n  font-family: var(--pf-c-title--FontFamily);\n  word-break: break-word;\n}\n.pf-c-title.pf-m-4xl {\n  font-size: var(--pf-c-title--m-4xl--FontSize);\n  font-weight: var(--pf-c-title--m-4xl--FontWeight);\n  line-height: var(--pf-c-title--m-4xl--LineHeight);\n}\n.pf-c-title.pf-m-3xl {\n  font-size: var(--pf-c-title--m-3xl--FontSize);\n  font-weight: var(--pf-c-title--m-3xl--FontWeight);\n  line-height: var(--pf-c-title--m-3xl--LineHeight);\n}\n.pf-c-title.pf-m-2xl {\n  font-size: var(--pf-c-title--m-2xl--FontSize);\n  font-weight: var(--pf-c-title--m-2xl--FontWeight);\n  line-height: var(--pf-c-title--m-2xl--LineHeight);\n}\n.pf-c-title.pf-m-xl {\n  font-size: var(--pf-c-title--m-xl--FontSize);\n  font-weight: var(--pf-c-title--m-xl--FontWeight);\n  line-height: var(--pf-c-title--m-xl--LineHeight);\n}\n.pf-c-title.pf-m-lg {\n  font-size: var(--pf-c-title--m-lg--FontSize);\n  font-weight: var(--pf-c-title--m-lg--FontWeight);\n  line-height: var(--pf-c-title--m-lg--LineHeight);\n}\n.pf-c-title.pf-m-md {\n  font-size: var(--pf-c-title--m-md--FontSize);\n  font-weight: var(--pf-c-title--m-md--FontWeight);\n  line-height: var(--pf-c-title--m-md--LineHeight);\n}\n\n.pf-m-overpass-font .pf-c-title {\n  --pf-c-title--m-md--FontWeight: var(--pf-global--FontWeight--semi-bold);\n  --pf-c-title--m-lg--FontWeight: var(--pf-global--FontWeight--semi-bold);\n}";

// src/elements/EmptyState.ts
var EmptyState = class extends AKElement {
  constructor() {
    super(...arguments);
    this.icon = "";
    this.loading = false;
    this.fullHeight = false;
    this.header = "";
  }
  static get styles() {
    return [
      patternfly_base_default,
      empty_state_default,
      title_default,
      i`
                i.pf-c-empty-state__icon {
                    height: var(--pf-global--icon--FontSize--2xl);
                    line-height: var(--pf-global--icon--FontSize--2xl);
                }
            `
    ];
  }
  render() {
    return x`<div class="pf-c-empty-state ${this.fullHeight && "pf-m-full-height"}">
            <div class="pf-c-empty-state__content">
                ${this.loading ? x`<div class="pf-c-empty-state__icon">
                          <ak-spinner size=${"pf-m-xl" /* XLarge */}></ak-spinner>
                      </div>` : x`<i
                          class="pf-icon fa ${this.icon || "fa-question-circle"} pf-c-empty-state__icon"
                          aria-hidden="true"
                      ></i>`}
                <h1 class="pf-c-title pf-m-lg">${this.header}</h1>
                <div class="pf-c-empty-state__body">
                    <slot name="body"></slot>
                </div>
                <div class="pf-c-empty-state__primary">
                    <slot name="primary"></slot>
                </div>
            </div>
        </div>`;
  }
};
__decorateClass([
  n4({ type: String })
], EmptyState.prototype, "icon", 2);
__decorateClass([
  n4({ type: Boolean })
], EmptyState.prototype, "loading", 2);
__decorateClass([
  n4({ type: Boolean })
], EmptyState.prototype, "fullHeight", 2);
__decorateClass([
  n4()
], EmptyState.prototype, "header", 2);
EmptyState = __decorateClass([
  t3("ak-empty-state")
], EmptyState);

// src/elements/LoadingOverlay.ts
var LoadingOverlay = class extends AKElement {
  constructor() {
    super(...arguments);
    this.topMost = false;
  }
  static get styles() {
    return [
      patternfly_base_default,
      i`
                :host {
                    display: flex;
                    height: 100%;
                    width: 100%;
                    justify-content: center;
                    align-items: center;
                    position: absolute;
                    background-color: var(--pf-global--BackgroundColor--dark-transparent-200);
                    z-index: 1;
                }
                :host([topMost]) {
                    z-index: 999;
                }
            `
    ];
  }
  render() {
    return x`<ak-empty-state ?loading="${true}">
            <slot name="body" slot="body"></slot>
        </ak-empty-state>`;
  }
};
__decorateClass([
  n4({ type: Boolean })
], LoadingOverlay.prototype, "topMost", 2);
LoadingOverlay = __decorateClass([
  t3("ak-loading-overlay")
], LoadingOverlay);

// node_modules/guacamole-common-js/dist/esm/guacamole-common.js
var Guacamole = Guacamole || {};
Guacamole.ArrayBufferReader = function(stream) {
  var guac_reader = this;
  stream.onblob = function(data) {
    var binary = window.atob(data);
    var arrayBuffer = new ArrayBuffer(binary.length);
    var bufferView = new Uint8Array(arrayBuffer);
    for (var i5 = 0; i5 < binary.length; i5++)
      bufferView[i5] = binary.charCodeAt(i5);
    if (guac_reader.ondata)
      guac_reader.ondata(arrayBuffer);
  };
  stream.onend = function() {
    if (guac_reader.onend)
      guac_reader.onend();
  };
  this.ondata = null;
  this.onend = null;
};
var Guacamole = Guacamole || {};
Guacamole.ArrayBufferWriter = function(stream) {
  var guac_writer = this;
  stream.onack = function(status) {
    if (guac_writer.onack)
      guac_writer.onack(status);
  };
  function __send_blob(bytes) {
    var binary = "";
    for (var i5 = 0; i5 < bytes.byteLength; i5++)
      binary += String.fromCharCode(bytes[i5]);
    stream.sendBlob(window.btoa(binary));
  }
  this.blobLength = Guacamole.ArrayBufferWriter.DEFAULT_BLOB_LENGTH;
  this.sendData = function(data) {
    var bytes = new Uint8Array(data);
    if (bytes.length <= guac_writer.blobLength)
      __send_blob(bytes);
    else {
      for (var offset = 0; offset < bytes.length; offset += guac_writer.blobLength)
        __send_blob(bytes.subarray(offset, offset + guac_writer.blobLength));
    }
  };
  this.sendEnd = function() {
    stream.sendEnd();
  };
  this.onack = null;
};
Guacamole.ArrayBufferWriter.DEFAULT_BLOB_LENGTH = 6048;
var Guacamole = Guacamole || {};
Guacamole.AudioContextFactory = {
  /**
   * A singleton instance of a Web Audio API AudioContext object, or null if
   * no instance has yes been created. This property may be manually set if
   * you wish to supply your own AudioContext instance, but care must be
   * taken to do so as early as possible. Assignments to this property will
   * not retroactively affect the value returned by previous calls to
   * getAudioContext().
   *
   * @type {AudioContext}
   */
  "singleton": null,
  /**
   * Returns a singleton instance of a Web Audio API AudioContext object.
   *
   * @return {AudioContext}
   *     A singleton instance of a Web Audio API AudioContext object, or null
   *     if the Web Audio API is not supported.
   */
  "getAudioContext": function getAudioContext() {
    var AudioContext = window.AudioContext || window.webkitAudioContext;
    if (AudioContext) {
      try {
        if (!Guacamole.AudioContextFactory.singleton)
          Guacamole.AudioContextFactory.singleton = new AudioContext();
        return Guacamole.AudioContextFactory.singleton;
      } catch (e7) {
      }
    }
    return null;
  }
};
var Guacamole = Guacamole || {};
Guacamole.AudioPlayer = function AudioPlayer() {
  this.sync = function sync() {
  };
};
Guacamole.AudioPlayer.isSupportedType = function isSupportedType(mimetype) {
  return Guacamole.RawAudioPlayer.isSupportedType(mimetype);
};
Guacamole.AudioPlayer.getSupportedTypes = function getSupportedTypes() {
  return Guacamole.RawAudioPlayer.getSupportedTypes();
};
Guacamole.AudioPlayer.getInstance = function getInstance(stream, mimetype) {
  if (Guacamole.RawAudioPlayer.isSupportedType(mimetype))
    return new Guacamole.RawAudioPlayer(stream, mimetype);
  return null;
};
Guacamole.RawAudioPlayer = function RawAudioPlayer(stream, mimetype) {
  var format = Guacamole.RawAudioFormat.parse(mimetype);
  var context = Guacamole.AudioContextFactory.getAudioContext();
  var nextPacketTime = context.currentTime;
  var reader = new Guacamole.ArrayBufferReader(stream);
  var MIN_SPLIT_SIZE = 0.02;
  var maxLatency = 0.3;
  var SampleArray = format.bytesPerSample === 1 ? window.Int8Array : window.Int16Array;
  var maxSampleValue = format.bytesPerSample === 1 ? 128 : 32768;
  var packetQueue = [];
  var joinAudioPackets = function joinAudioPackets2(packets) {
    if (packets.length <= 1)
      return packets[0];
    var totalLength = 0;
    packets.forEach(function addPacketLengths(packet) {
      totalLength += packet.length;
    });
    var offset = 0;
    var joined = new SampleArray(totalLength);
    packets.forEach(function appendPacket(packet) {
      joined.set(packet, offset);
      offset += packet.length;
    });
    return joined;
  };
  var splitAudioPacket = function splitAudioPacket2(data) {
    var minValue = Number.MAX_VALUE;
    var optimalSplitLength = data.length;
    var samples = Math.floor(data.length / format.channels);
    var minSplitSamples = Math.floor(format.rate * MIN_SPLIT_SIZE);
    var start = Math.max(
      format.channels * minSplitSamples,
      format.channels * (samples - minSplitSamples)
    );
    for (var offset = start; offset < data.length; offset += format.channels) {
      var totalValue = 0;
      for (var channel = 0; channel < format.channels; channel++) {
        totalValue += Math.abs(data[offset + channel]);
      }
      if (totalValue <= minValue) {
        optimalSplitLength = offset + format.channels;
        minValue = totalValue;
      }
    }
    if (optimalSplitLength === data.length)
      return [data];
    return [
      new SampleArray(data.buffer.slice(0, optimalSplitLength * format.bytesPerSample)),
      new SampleArray(data.buffer.slice(optimalSplitLength * format.bytesPerSample))
    ];
  };
  var pushAudioPacket = function pushAudioPacket2(data) {
    packetQueue.push(new SampleArray(data));
  };
  var shiftAudioPacket = function shiftAudioPacket2() {
    var data = joinAudioPackets(packetQueue);
    if (!data)
      return null;
    packetQueue = splitAudioPacket(data);
    data = packetQueue.shift();
    return data;
  };
  var toAudioBuffer = function toAudioBuffer2(data) {
    var samples = data.length / format.channels;
    var packetTime = context.currentTime;
    if (nextPacketTime < packetTime)
      nextPacketTime = packetTime;
    var audioBuffer = context.createBuffer(format.channels, samples, format.rate);
    for (var channel = 0; channel < format.channels; channel++) {
      var audioData = audioBuffer.getChannelData(channel);
      var offset = channel;
      for (var i5 = 0; i5 < samples; i5++) {
        audioData[i5] = data[offset] / maxSampleValue;
        offset += format.channels;
      }
    }
    return audioBuffer;
  };
  reader.ondata = function playReceivedAudio(data) {
    pushAudioPacket(new SampleArray(data));
    var packet = shiftAudioPacket();
    if (!packet)
      return;
    var packetTime = context.currentTime;
    if (nextPacketTime < packetTime)
      nextPacketTime = packetTime;
    var source = context.createBufferSource();
    source.connect(context.destination);
    if (!source.start)
      source.start = source.noteOn;
    source.buffer = toAudioBuffer(packet);
    source.start(nextPacketTime);
    nextPacketTime += packet.length / format.channels / format.rate;
  };
  this.sync = function sync() {
    var now = context.currentTime;
    nextPacketTime = Math.min(nextPacketTime, now + maxLatency);
  };
};
Guacamole.RawAudioPlayer.prototype = new Guacamole.AudioPlayer();
Guacamole.RawAudioPlayer.isSupportedType = function isSupportedType2(mimetype) {
  if (!Guacamole.AudioContextFactory.getAudioContext())
    return false;
  return Guacamole.RawAudioFormat.parse(mimetype) !== null;
};
Guacamole.RawAudioPlayer.getSupportedTypes = function getSupportedTypes2() {
  if (!Guacamole.AudioContextFactory.getAudioContext())
    return [];
  return [
    "audio/L8",
    "audio/L16"
  ];
};
var Guacamole = Guacamole || {};
Guacamole.AudioRecorder = function AudioRecorder() {
  this.onclose = null;
  this.onerror = null;
};
Guacamole.AudioRecorder.isSupportedType = function isSupportedType3(mimetype) {
  return Guacamole.RawAudioRecorder.isSupportedType(mimetype);
};
Guacamole.AudioRecorder.getSupportedTypes = function getSupportedTypes3() {
  return Guacamole.RawAudioRecorder.getSupportedTypes();
};
Guacamole.AudioRecorder.getInstance = function getInstance2(stream, mimetype) {
  if (Guacamole.RawAudioRecorder.isSupportedType(mimetype))
    return new Guacamole.RawAudioRecorder(stream, mimetype);
  return null;
};
Guacamole.RawAudioRecorder = function RawAudioRecorder(stream, mimetype) {
  var recorder = this;
  var BUFFER_SIZE = 2048;
  var LANCZOS_WINDOW_SIZE = 3;
  var format = Guacamole.RawAudioFormat.parse(mimetype);
  var context = Guacamole.AudioContextFactory.getAudioContext();
  if (!navigator.mediaDevices)
    navigator.mediaDevices = {};
  if (!navigator.mediaDevices.getUserMedia)
    navigator.mediaDevices.getUserMedia = (navigator.getUserMedia || navigator.webkitGetUserMedia || navigator.mozGetUserMedia || navigator.msGetUserMedia).bind(navigator);
  var writer = new Guacamole.ArrayBufferWriter(stream);
  var SampleArray = format.bytesPerSample === 1 ? window.Int8Array : window.Int16Array;
  var maxSampleValue = format.bytesPerSample === 1 ? 128 : 32768;
  var readSamples = 0;
  var writtenSamples = 0;
  var mediaStream = null;
  var source = null;
  var processor = null;
  var sinc = function sinc2(x2) {
    if (x2 === 0)
      return 1;
    var piX = Math.PI * x2;
    return Math.sin(piX) / piX;
  };
  var lanczos = function lanczos2(x2, a3) {
    if (-a3 < x2 && x2 < a3)
      return sinc(x2) * sinc(x2 / a3);
    return 0;
  };
  var interpolateSample = function getValueAt(audioData, t5) {
    var index = (audioData.length - 1) * t5;
    var start = Math.floor(index) - LANCZOS_WINDOW_SIZE + 1;
    var end = Math.floor(index) + LANCZOS_WINDOW_SIZE;
    var sum = 0;
    for (var i5 = start; i5 <= end; i5++) {
      sum += (audioData[i5] || 0) * lanczos(index - i5, LANCZOS_WINDOW_SIZE);
    }
    return sum;
  };
  var toSampleArray = function toSampleArray2(audioBuffer) {
    var inSamples = audioBuffer.length;
    readSamples += inSamples;
    var expectedWrittenSamples = Math.round(readSamples * format.rate / audioBuffer.sampleRate);
    var outSamples = expectedWrittenSamples - writtenSamples;
    writtenSamples += outSamples;
    var data = new SampleArray(outSamples * format.channels);
    for (var channel = 0; channel < format.channels; channel++) {
      var audioData = audioBuffer.getChannelData(channel);
      var offset = channel;
      for (var i5 = 0; i5 < outSamples; i5++) {
        data[offset] = interpolateSample(audioData, i5 / (outSamples - 1)) * maxSampleValue;
        offset += format.channels;
      }
    }
    return data;
  };
  var streamReceived = function streamReceived2(stream2) {
    processor = context.createScriptProcessor(BUFFER_SIZE, format.channels, format.channels);
    processor.connect(context.destination);
    processor.onaudioprocess = function processAudio(e7) {
      writer.sendData(toSampleArray(e7.inputBuffer).buffer);
    };
    source = context.createMediaStreamSource(stream2);
    source.connect(processor);
    if (context.state === "suspended")
      context.resume();
    mediaStream = stream2;
  };
  var streamDenied = function streamDenied2() {
    writer.sendEnd();
    if (recorder.onerror)
      recorder.onerror();
  };
  var beginAudioCapture = function beginAudioCapture2() {
    var promise = navigator.mediaDevices.getUserMedia({
      "audio": true
    }, streamReceived, streamDenied);
    if (promise && promise.then)
      promise.then(streamReceived, streamDenied);
  };
  var stopAudioCapture = function stopAudioCapture2() {
    if (source)
      source.disconnect();
    if (processor)
      processor.disconnect();
    if (mediaStream) {
      var tracks = mediaStream.getTracks();
      for (var i5 = 0; i5 < tracks.length; i5++)
        tracks[i5].stop();
    }
    processor = null;
    source = null;
    mediaStream = null;
    writer.sendEnd();
  };
  writer.onack = function audioStreamAcknowledged(status) {
    if (status.code === Guacamole.Status.Code.SUCCESS && !mediaStream)
      beginAudioCapture();
    else {
      stopAudioCapture();
      writer.onack = null;
      if (status.code === Guacamole.Status.Code.RESOURCE_CLOSED) {
        if (recorder.onclose)
          recorder.onclose();
      } else {
        if (recorder.onerror)
          recorder.onerror();
      }
    }
  };
};
Guacamole.RawAudioRecorder.prototype = new Guacamole.AudioRecorder();
Guacamole.RawAudioRecorder.isSupportedType = function isSupportedType4(mimetype) {
  if (!Guacamole.AudioContextFactory.getAudioContext())
    return false;
  return Guacamole.RawAudioFormat.parse(mimetype) !== null;
};
Guacamole.RawAudioRecorder.getSupportedTypes = function getSupportedTypes4() {
  if (!Guacamole.AudioContextFactory.getAudioContext())
    return [];
  return [
    "audio/L8",
    "audio/L16"
  ];
};
var Guacamole = Guacamole || {};
Guacamole.BlobReader = function(stream, mimetype) {
  var guac_reader = this;
  var length = 0;
  var blob_builder;
  if (window.BlobBuilder)
    blob_builder = new BlobBuilder();
  else if (window.WebKitBlobBuilder)
    blob_builder = new WebKitBlobBuilder();
  else if (window.MozBlobBuilder)
    blob_builder = new MozBlobBuilder();
  else
    blob_builder = new function() {
      var blobs = [];
      this.append = function(data) {
        blobs.push(new Blob([data], { "type": mimetype }));
      };
      this.getBlob = function() {
        return new Blob(blobs, { "type": mimetype });
      };
    }();
  stream.onblob = function(data) {
    var binary = window.atob(data);
    var arrayBuffer = new ArrayBuffer(binary.length);
    var bufferView = new Uint8Array(arrayBuffer);
    for (var i5 = 0; i5 < binary.length; i5++)
      bufferView[i5] = binary.charCodeAt(i5);
    blob_builder.append(arrayBuffer);
    length += arrayBuffer.byteLength;
    if (guac_reader.onprogress)
      guac_reader.onprogress(arrayBuffer.byteLength);
    stream.sendAck("OK", 0);
  };
  stream.onend = function() {
    if (guac_reader.onend)
      guac_reader.onend();
  };
  this.getLength = function() {
    return length;
  };
  this.getBlob = function() {
    return blob_builder.getBlob();
  };
  this.onprogress = null;
  this.onend = null;
};
var Guacamole = Guacamole || {};
Guacamole.BlobWriter = function BlobWriter(stream) {
  var guacWriter = this;
  var arrayBufferWriter = new Guacamole.ArrayBufferWriter(stream);
  arrayBufferWriter.onack = function(status) {
    if (guacWriter.onack)
      guacWriter.onack(status);
  };
  var slice = function slice2(blob, start, end) {
    var sliceImplementation = (blob.slice || blob.webkitSlice || blob.mozSlice).bind(blob);
    var length = end - start;
    if (length !== end) {
      var sliceResult = sliceImplementation(start, length);
      if (sliceResult.size === length)
        return sliceResult;
    }
    return sliceImplementation(start, end);
  };
  this.sendBlob = function sendBlob(blob) {
    var offset = 0;
    var reader = new FileReader();
    var readNextChunk = function readNextChunk2() {
      if (offset >= blob.size) {
        if (guacWriter.oncomplete)
          guacWriter.oncomplete(blob);
        return;
      }
      var chunk = slice(blob, offset, offset + arrayBufferWriter.blobLength);
      offset += arrayBufferWriter.blobLength;
      reader.readAsArrayBuffer(chunk);
    };
    reader.onload = function chunkLoadComplete() {
      arrayBufferWriter.sendData(reader.result);
      arrayBufferWriter.onack = function sendMoreChunks(status) {
        if (guacWriter.onack)
          guacWriter.onack(status);
        if (status.isError())
          return;
        if (guacWriter.onprogress)
          guacWriter.onprogress(blob, offset - arrayBufferWriter.blobLength);
        readNextChunk();
      };
    };
    reader.onerror = function chunkLoadFailed() {
      if (guacWriter.onerror)
        guacWriter.onerror(blob, offset, reader.error);
    };
    readNextChunk();
  };
  this.sendEnd = function sendEnd() {
    arrayBufferWriter.sendEnd();
  };
  this.onack = null;
  this.onerror = null;
  this.onprogress = null;
  this.oncomplete = null;
};
var Guacamole = Guacamole || {};
Guacamole.Client = function(tunnel) {
  var guac_client = this;
  var currentState = Guacamole.Client.State.IDLE;
  var currentTimestamp = 0;
  var KEEP_ALIVE_FREQUENCY = 5e3;
  var keepAliveTimeout = null;
  var lastSentKeepAlive = 0;
  var lineCap = {
    0: "butt",
    1: "round",
    2: "square"
  };
  var lineJoin = {
    0: "bevel",
    1: "miter",
    2: "round"
  };
  var display = new Guacamole.Display();
  var layers = {};
  var audioPlayers = {};
  var videoPlayers = {};
  var parsers = [];
  var streams = [];
  var objects = [];
  var stream_indices = new Guacamole.IntegerPool();
  var output_streams = [];
  function setState(state) {
    if (state != currentState) {
      currentState = state;
      if (guac_client.onstatechange)
        guac_client.onstatechange(currentState);
    }
  }
  function isConnected() {
    return currentState == Guacamole.Client.State.CONNECTED || currentState == Guacamole.Client.State.WAITING;
  }
  this.exportState = function exportState(callback) {
    var state = {
      "currentState": currentState,
      "currentTimestamp": currentTimestamp,
      "layers": {}
    };
    var layersSnapshot = {};
    for (var key in layers) {
      layersSnapshot[key] = layers[key];
    }
    display.flush(function populateLayers() {
      for (var key2 in layersSnapshot) {
        var index = parseInt(key2);
        var layer = layersSnapshot[key2];
        var canvas = layer.toCanvas();
        var exportLayer = {
          "width": layer.width,
          "height": layer.height
        };
        if (layer.width && layer.height)
          exportLayer.url = canvas.toDataURL("image/png");
        if (index > 0) {
          exportLayer.x = layer.x;
          exportLayer.y = layer.y;
          exportLayer.z = layer.z;
          exportLayer.alpha = layer.alpha;
          exportLayer.matrix = layer.matrix;
          exportLayer.parent = getLayerIndex(layer.parent);
        }
        state.layers[key2] = exportLayer;
      }
      callback(state);
    });
  };
  this.importState = function importState(state, callback) {
    var key;
    var index;
    currentState = state.currentState;
    currentTimestamp = state.currentTimestamp;
    display.cancel();
    for (key in layers) {
      index = parseInt(key);
      if (index > 0)
        layers[key].dispose();
    }
    layers = {};
    for (key in state.layers) {
      index = parseInt(key);
      var importLayer = state.layers[key];
      var layer = getLayer(index);
      display.resize(layer, importLayer.width, importLayer.height);
      if (importLayer.url) {
        display.setChannelMask(layer, Guacamole.Layer.SRC);
        display.draw(layer, 0, 0, importLayer.url);
      }
      if (index > 0 && importLayer.parent >= 0) {
        var parent = getLayer(importLayer.parent);
        display.move(layer, parent, importLayer.x, importLayer.y, importLayer.z);
        display.shade(layer, importLayer.alpha);
        var matrix = importLayer.matrix;
        display.distort(
          layer,
          matrix[0],
          matrix[1],
          matrix[2],
          matrix[3],
          matrix[4],
          matrix[5]
        );
      }
    }
    display.flush(callback);
  };
  this.getDisplay = function() {
    return display;
  };
  this.sendSize = function(width, height) {
    if (!isConnected())
      return;
    tunnel.sendMessage("size", width, height);
  };
  this.sendKeyEvent = function(pressed, keysym) {
    if (!isConnected())
      return;
    tunnel.sendMessage("key", keysym, pressed);
  };
  this.sendMouseState = function sendMouseState(mouseState, applyDisplayScale) {
    if (!isConnected())
      return;
    var x2 = mouseState.x;
    var y3 = mouseState.y;
    if (applyDisplayScale) {
      x2 /= display.getScale();
      y3 /= display.getScale();
    }
    display.moveCursor(
      Math.floor(x2),
      Math.floor(y3)
    );
    var buttonMask = 0;
    if (mouseState.left)
      buttonMask |= 1;
    if (mouseState.middle)
      buttonMask |= 2;
    if (mouseState.right)
      buttonMask |= 4;
    if (mouseState.up)
      buttonMask |= 8;
    if (mouseState.down)
      buttonMask |= 16;
    tunnel.sendMessage("mouse", Math.floor(x2), Math.floor(y3), buttonMask);
  };
  this.sendTouchState = function sendTouchState(touchState, applyDisplayScale) {
    if (!isConnected())
      return;
    var x2 = touchState.x;
    var y3 = touchState.y;
    if (applyDisplayScale) {
      x2 /= display.getScale();
      y3 /= display.getScale();
    }
    tunnel.sendMessage(
      "touch",
      touchState.id,
      Math.floor(x2),
      Math.floor(y3),
      Math.floor(touchState.radiusX),
      Math.floor(touchState.radiusY),
      touchState.angle,
      touchState.force
    );
  };
  this.createOutputStream = function createOutputStream() {
    var index = stream_indices.next();
    var stream = output_streams[index] = new Guacamole.OutputStream(guac_client, index);
    return stream;
  };
  this.createAudioStream = function(mimetype) {
    var stream = guac_client.createOutputStream();
    tunnel.sendMessage("audio", stream.index, mimetype);
    return stream;
  };
  this.createFileStream = function(mimetype, filename) {
    var stream = guac_client.createOutputStream();
    tunnel.sendMessage("file", stream.index, mimetype, filename);
    return stream;
  };
  this.createPipeStream = function(mimetype, name) {
    var stream = guac_client.createOutputStream();
    tunnel.sendMessage("pipe", stream.index, mimetype, name);
    return stream;
  };
  this.createClipboardStream = function(mimetype) {
    var stream = guac_client.createOutputStream();
    tunnel.sendMessage("clipboard", stream.index, mimetype);
    return stream;
  };
  this.createArgumentValueStream = function createArgumentValueStream(mimetype, name) {
    var stream = guac_client.createOutputStream();
    tunnel.sendMessage("argv", stream.index, mimetype, name);
    return stream;
  };
  this.createObjectOutputStream = function createObjectOutputStream(index, mimetype, name) {
    var stream = guac_client.createOutputStream();
    tunnel.sendMessage("put", index, stream.index, mimetype, name);
    return stream;
  };
  this.requestObjectInputStream = function requestObjectInputStream(index, name) {
    if (!isConnected())
      return;
    tunnel.sendMessage("get", index, name);
  };
  this.sendAck = function(index, message, code) {
    if (!isConnected())
      return;
    tunnel.sendMessage("ack", index, message, code);
  };
  this.sendBlob = function(index, data) {
    if (!isConnected())
      return;
    tunnel.sendMessage("blob", index, data);
  };
  this.endStream = function(index) {
    if (!isConnected())
      return;
    tunnel.sendMessage("end", index);
    if (output_streams[index]) {
      stream_indices.free(index);
      delete output_streams[index];
    }
  };
  this.onstatechange = null;
  this.onname = null;
  this.onerror = null;
  this.onmsg = null;
  this.onjoin = null;
  this.onleave = null;
  this.onaudio = null;
  this.onvideo = null;
  this.onmultitouch = null;
  this.onargv = null;
  this.onclipboard = null;
  this.onfile = null;
  this.onfilesystem = null;
  this.onpipe = null;
  this.onrequired = null;
  this.onsync = null;
  var getLayer = function getLayer2(index) {
    var layer = layers[index];
    if (!layer) {
      if (index === 0)
        layer = display.getDefaultLayer();
      else if (index > 0)
        layer = display.createLayer();
      else
        layer = display.createBuffer();
      layers[index] = layer;
    }
    return layer;
  };
  var getLayerIndex = function getLayerIndex2(layer) {
    if (!layer)
      return null;
    for (var key in layers) {
      if (layer === layers[key])
        return parseInt(key);
    }
    return null;
  };
  function getParser(index) {
    var parser = parsers[index];
    if (parser == null) {
      parser = parsers[index] = new Guacamole.Parser();
      parser.oninstruction = tunnel.oninstruction;
    }
    return parser;
  }
  var layerPropertyHandlers = {
    "miter-limit": function(layer, value) {
      display.setMiterLimit(layer, parseFloat(value));
    },
    "multi-touch": function layerSupportsMultiTouch(layer, value) {
      if (guac_client.onmultitouch && layer instanceof Guacamole.Display.VisibleLayer)
        guac_client.onmultitouch(layer, parseInt(value));
    }
  };
  var instructionHandlers = {
    "ack": function(parameters) {
      var stream_index = parseInt(parameters[0]);
      var reason = parameters[1];
      var code = parseInt(parameters[2]);
      var stream = output_streams[stream_index];
      if (stream) {
        if (stream.onack)
          stream.onack(new Guacamole.Status(code, reason));
        if (code >= 256 && output_streams[stream_index] === stream) {
          stream_indices.free(stream_index);
          delete output_streams[stream_index];
        }
      }
    },
    "arc": function(parameters) {
      var layer = getLayer(parseInt(parameters[0]));
      var x2 = parseInt(parameters[1]);
      var y3 = parseInt(parameters[2]);
      var radius = parseInt(parameters[3]);
      var startAngle = parseFloat(parameters[4]);
      var endAngle = parseFloat(parameters[5]);
      var negative = parseInt(parameters[6]);
      display.arc(layer, x2, y3, radius, startAngle, endAngle, negative != 0);
    },
    "argv": function(parameters) {
      var stream_index = parseInt(parameters[0]);
      var mimetype = parameters[1];
      var name = parameters[2];
      if (guac_client.onargv) {
        var stream = streams[stream_index] = new Guacamole.InputStream(guac_client, stream_index);
        guac_client.onargv(stream, mimetype, name);
      } else
        guac_client.sendAck(stream_index, "Receiving argument values unsupported", 256);
    },
    "audio": function(parameters) {
      var stream_index = parseInt(parameters[0]);
      var mimetype = parameters[1];
      var stream = streams[stream_index] = new Guacamole.InputStream(guac_client, stream_index);
      var audioPlayer = null;
      if (guac_client.onaudio)
        audioPlayer = guac_client.onaudio(stream, mimetype);
      if (!audioPlayer)
        audioPlayer = Guacamole.AudioPlayer.getInstance(stream, mimetype);
      if (audioPlayer) {
        audioPlayers[stream_index] = audioPlayer;
        guac_client.sendAck(stream_index, "OK", 0);
      } else
        guac_client.sendAck(stream_index, "BAD TYPE", 783);
    },
    "blob": function(parameters) {
      var stream_index = parseInt(parameters[0]);
      var data = parameters[1];
      var stream = streams[stream_index];
      if (stream && stream.onblob)
        stream.onblob(data);
    },
    "body": function handleBody(parameters) {
      var objectIndex = parseInt(parameters[0]);
      var object = objects[objectIndex];
      var streamIndex = parseInt(parameters[1]);
      var mimetype = parameters[2];
      var name = parameters[3];
      if (object && object.onbody) {
        var stream = streams[streamIndex] = new Guacamole.InputStream(guac_client, streamIndex);
        object.onbody(stream, mimetype, name);
      } else
        guac_client.sendAck(streamIndex, "Receipt of body unsupported", 256);
    },
    "cfill": function(parameters) {
      var channelMask = parseInt(parameters[0]);
      var layer = getLayer(parseInt(parameters[1]));
      var r7 = parseInt(parameters[2]);
      var g2 = parseInt(parameters[3]);
      var b3 = parseInt(parameters[4]);
      var a3 = parseInt(parameters[5]);
      display.setChannelMask(layer, channelMask);
      display.fillColor(layer, r7, g2, b3, a3);
    },
    "clip": function(parameters) {
      var layer = getLayer(parseInt(parameters[0]));
      display.clip(layer);
    },
    "clipboard": function(parameters) {
      var stream_index = parseInt(parameters[0]);
      var mimetype = parameters[1];
      if (guac_client.onclipboard) {
        var stream = streams[stream_index] = new Guacamole.InputStream(guac_client, stream_index);
        guac_client.onclipboard(stream, mimetype);
      } else
        guac_client.sendAck(stream_index, "Clipboard unsupported", 256);
    },
    "close": function(parameters) {
      var layer = getLayer(parseInt(parameters[0]));
      display.close(layer);
    },
    "copy": function(parameters) {
      var srcL = getLayer(parseInt(parameters[0]));
      var srcX = parseInt(parameters[1]);
      var srcY = parseInt(parameters[2]);
      var srcWidth = parseInt(parameters[3]);
      var srcHeight = parseInt(parameters[4]);
      var channelMask = parseInt(parameters[5]);
      var dstL = getLayer(parseInt(parameters[6]));
      var dstX = parseInt(parameters[7]);
      var dstY = parseInt(parameters[8]);
      display.setChannelMask(dstL, channelMask);
      display.copy(
        srcL,
        srcX,
        srcY,
        srcWidth,
        srcHeight,
        dstL,
        dstX,
        dstY
      );
    },
    "cstroke": function(parameters) {
      var channelMask = parseInt(parameters[0]);
      var layer = getLayer(parseInt(parameters[1]));
      var cap = lineCap[parseInt(parameters[2])];
      var join = lineJoin[parseInt(parameters[3])];
      var thickness = parseInt(parameters[4]);
      var r7 = parseInt(parameters[5]);
      var g2 = parseInt(parameters[6]);
      var b3 = parseInt(parameters[7]);
      var a3 = parseInt(parameters[8]);
      display.setChannelMask(layer, channelMask);
      display.strokeColor(layer, cap, join, thickness, r7, g2, b3, a3);
    },
    "cursor": function(parameters) {
      var cursorHotspotX = parseInt(parameters[0]);
      var cursorHotspotY = parseInt(parameters[1]);
      var srcL = getLayer(parseInt(parameters[2]));
      var srcX = parseInt(parameters[3]);
      var srcY = parseInt(parameters[4]);
      var srcWidth = parseInt(parameters[5]);
      var srcHeight = parseInt(parameters[6]);
      display.setCursor(
        cursorHotspotX,
        cursorHotspotY,
        srcL,
        srcX,
        srcY,
        srcWidth,
        srcHeight
      );
    },
    "curve": function(parameters) {
      var layer = getLayer(parseInt(parameters[0]));
      var cp1x = parseInt(parameters[1]);
      var cp1y = parseInt(parameters[2]);
      var cp2x = parseInt(parameters[3]);
      var cp2y = parseInt(parameters[4]);
      var x2 = parseInt(parameters[5]);
      var y3 = parseInt(parameters[6]);
      display.curveTo(layer, cp1x, cp1y, cp2x, cp2y, x2, y3);
    },
    "disconnect": function handleDisconnect(parameters) {
      guac_client.disconnect();
    },
    "dispose": function(parameters) {
      var layer_index = parseInt(parameters[0]);
      if (layer_index > 0) {
        var layer = getLayer(layer_index);
        display.dispose(layer);
        delete layers[layer_index];
      } else if (layer_index < 0)
        delete layers[layer_index];
    },
    "distort": function(parameters) {
      var layer_index = parseInt(parameters[0]);
      var a3 = parseFloat(parameters[1]);
      var b3 = parseFloat(parameters[2]);
      var c5 = parseFloat(parameters[3]);
      var d3 = parseFloat(parameters[4]);
      var e7 = parseFloat(parameters[5]);
      var f3 = parseFloat(parameters[6]);
      if (layer_index >= 0) {
        var layer = getLayer(layer_index);
        display.distort(layer, a3, b3, c5, d3, e7, f3);
      }
    },
    "error": function(parameters) {
      var reason = parameters[0];
      var code = parseInt(parameters[1]);
      if (guac_client.onerror)
        guac_client.onerror(new Guacamole.Status(code, reason));
      guac_client.disconnect();
    },
    "end": function(parameters) {
      var stream_index = parseInt(parameters[0]);
      var stream = streams[stream_index];
      if (stream) {
        if (stream.onend)
          stream.onend();
        delete streams[stream_index];
      }
    },
    "file": function(parameters) {
      var stream_index = parseInt(parameters[0]);
      var mimetype = parameters[1];
      var filename = parameters[2];
      if (guac_client.onfile) {
        var stream = streams[stream_index] = new Guacamole.InputStream(guac_client, stream_index);
        guac_client.onfile(stream, mimetype, filename);
      } else
        guac_client.sendAck(stream_index, "File transfer unsupported", 256);
    },
    "filesystem": function handleFilesystem(parameters) {
      var objectIndex = parseInt(parameters[0]);
      var name = parameters[1];
      if (guac_client.onfilesystem) {
        var object = objects[objectIndex] = new Guacamole.Object(guac_client, objectIndex);
        guac_client.onfilesystem(object, name);
      }
    },
    "identity": function(parameters) {
      var layer = getLayer(parseInt(parameters[0]));
      display.setTransform(layer, 1, 0, 0, 1, 0, 0);
    },
    "img": function(parameters) {
      var stream_index = parseInt(parameters[0]);
      var channelMask = parseInt(parameters[1]);
      var layer = getLayer(parseInt(parameters[2]));
      var mimetype = parameters[3];
      var x2 = parseInt(parameters[4]);
      var y3 = parseInt(parameters[5]);
      var stream = streams[stream_index] = new Guacamole.InputStream(guac_client, stream_index);
      display.setChannelMask(layer, channelMask);
      display.drawStream(layer, x2, y3, stream, mimetype);
    },
    "jpeg": function(parameters) {
      var channelMask = parseInt(parameters[0]);
      var layer = getLayer(parseInt(parameters[1]));
      var x2 = parseInt(parameters[2]);
      var y3 = parseInt(parameters[3]);
      var data = parameters[4];
      display.setChannelMask(layer, channelMask);
      display.draw(layer, x2, y3, "data:image/jpeg;base64," + data);
    },
    "lfill": function(parameters) {
      var channelMask = parseInt(parameters[0]);
      var layer = getLayer(parseInt(parameters[1]));
      var srcLayer = getLayer(parseInt(parameters[2]));
      display.setChannelMask(layer, channelMask);
      display.fillLayer(layer, srcLayer);
    },
    "line": function(parameters) {
      var layer = getLayer(parseInt(parameters[0]));
      var x2 = parseInt(parameters[1]);
      var y3 = parseInt(parameters[2]);
      display.lineTo(layer, x2, y3);
    },
    "lstroke": function(parameters) {
      var channelMask = parseInt(parameters[0]);
      var layer = getLayer(parseInt(parameters[1]));
      var srcLayer = getLayer(parseInt(parameters[2]));
      display.setChannelMask(layer, channelMask);
      display.strokeLayer(layer, srcLayer);
    },
    "mouse": function handleMouse(parameters) {
      var x2 = parseInt(parameters[0]);
      var y3 = parseInt(parameters[1]);
      display.showCursor(true);
      display.moveCursor(x2, y3);
    },
    "move": function(parameters) {
      var layer_index = parseInt(parameters[0]);
      var parent_index = parseInt(parameters[1]);
      var x2 = parseInt(parameters[2]);
      var y3 = parseInt(parameters[3]);
      var z = parseInt(parameters[4]);
      if (layer_index > 0 && parent_index >= 0) {
        var layer = getLayer(layer_index);
        var parent = getLayer(parent_index);
        display.move(layer, parent, x2, y3, z);
      }
    },
    "msg": function(parameters) {
      var userID;
      var username;
      var allowDefault = true;
      var msgid = parseInt(parameters[0]);
      if (guac_client.onmsg) {
        allowDefault = guac_client.onmsg(msgid, parameters.slice(1));
        if (allowDefault === void 0)
          allowDefault = true;
      }
      if (allowDefault) {
        switch (msgid) {
          case Guacamole.Client.Message.USER_JOINED:
            userID = parameters[1];
            username = parameters[2];
            if (guac_client.onjoin)
              guac_client.onjoin(userID, username);
            break;
          case Guacamole.Client.Message.USER_LEFT:
            userID = parameters[1];
            username = parameters[2];
            if (guac_client.onleave)
              guac_client.onleave(userID, username);
            break;
        }
      }
    },
    "name": function(parameters) {
      if (guac_client.onname)
        guac_client.onname(parameters[0]);
    },
    "nest": function(parameters) {
      var parser = getParser(parseInt(parameters[0]));
      parser.receive(parameters[1]);
    },
    "pipe": function(parameters) {
      var stream_index = parseInt(parameters[0]);
      var mimetype = parameters[1];
      var name = parameters[2];
      if (guac_client.onpipe) {
        var stream = streams[stream_index] = new Guacamole.InputStream(guac_client, stream_index);
        guac_client.onpipe(stream, mimetype, name);
      } else
        guac_client.sendAck(stream_index, "Named pipes unsupported", 256);
    },
    "png": function(parameters) {
      var channelMask = parseInt(parameters[0]);
      var layer = getLayer(parseInt(parameters[1]));
      var x2 = parseInt(parameters[2]);
      var y3 = parseInt(parameters[3]);
      var data = parameters[4];
      display.setChannelMask(layer, channelMask);
      display.draw(layer, x2, y3, "data:image/png;base64," + data);
    },
    "pop": function(parameters) {
      var layer = getLayer(parseInt(parameters[0]));
      display.pop(layer);
    },
    "push": function(parameters) {
      var layer = getLayer(parseInt(parameters[0]));
      display.push(layer);
    },
    "rect": function(parameters) {
      var layer = getLayer(parseInt(parameters[0]));
      var x2 = parseInt(parameters[1]);
      var y3 = parseInt(parameters[2]);
      var w2 = parseInt(parameters[3]);
      var h3 = parseInt(parameters[4]);
      display.rect(layer, x2, y3, w2, h3);
    },
    "required": function required(parameters) {
      if (guac_client.onrequired)
        guac_client.onrequired(parameters);
    },
    "reset": function(parameters) {
      var layer = getLayer(parseInt(parameters[0]));
      display.reset(layer);
    },
    "set": function(parameters) {
      var layer = getLayer(parseInt(parameters[0]));
      var name = parameters[1];
      var value = parameters[2];
      var handler = layerPropertyHandlers[name];
      if (handler)
        handler(layer, value);
    },
    "shade": function(parameters) {
      var layer_index = parseInt(parameters[0]);
      var a3 = parseInt(parameters[1]);
      if (layer_index >= 0) {
        var layer = getLayer(layer_index);
        display.shade(layer, a3);
      }
    },
    "size": function(parameters) {
      var layer_index = parseInt(parameters[0]);
      var layer = getLayer(layer_index);
      var width = parseInt(parameters[1]);
      var height = parseInt(parameters[2]);
      display.resize(layer, width, height);
    },
    "start": function(parameters) {
      var layer = getLayer(parseInt(parameters[0]));
      var x2 = parseInt(parameters[1]);
      var y3 = parseInt(parameters[2]);
      display.moveTo(layer, x2, y3);
    },
    "sync": function(parameters) {
      var timestamp = parseInt(parameters[0]);
      var frames = parameters[1] ? parseInt(parameters[1]) : 0;
      display.flush(function displaySyncComplete() {
        for (var index in audioPlayers) {
          var audioPlayer = audioPlayers[index];
          if (audioPlayer)
            audioPlayer.sync();
        }
        if (timestamp !== currentTimestamp) {
          tunnel.sendMessage("sync", timestamp);
          currentTimestamp = timestamp;
        }
      }, timestamp, frames);
      if (currentState === Guacamole.Client.State.WAITING)
        setState(Guacamole.Client.State.CONNECTED);
      if (guac_client.onsync)
        guac_client.onsync(timestamp, frames);
    },
    "transfer": function(parameters) {
      var srcL = getLayer(parseInt(parameters[0]));
      var srcX = parseInt(parameters[1]);
      var srcY = parseInt(parameters[2]);
      var srcWidth = parseInt(parameters[3]);
      var srcHeight = parseInt(parameters[4]);
      var function_index = parseInt(parameters[5]);
      var dstL = getLayer(parseInt(parameters[6]));
      var dstX = parseInt(parameters[7]);
      var dstY = parseInt(parameters[8]);
      if (function_index === 3)
        display.put(
          srcL,
          srcX,
          srcY,
          srcWidth,
          srcHeight,
          dstL,
          dstX,
          dstY
        );
      else if (function_index !== 5)
        display.transfer(
          srcL,
          srcX,
          srcY,
          srcWidth,
          srcHeight,
          dstL,
          dstX,
          dstY,
          Guacamole.Client.DefaultTransferFunction[function_index]
        );
    },
    "transform": function(parameters) {
      var layer = getLayer(parseInt(parameters[0]));
      var a3 = parseFloat(parameters[1]);
      var b3 = parseFloat(parameters[2]);
      var c5 = parseFloat(parameters[3]);
      var d3 = parseFloat(parameters[4]);
      var e7 = parseFloat(parameters[5]);
      var f3 = parseFloat(parameters[6]);
      display.transform(layer, a3, b3, c5, d3, e7, f3);
    },
    "undefine": function handleUndefine(parameters) {
      var objectIndex = parseInt(parameters[0]);
      var object = objects[objectIndex];
      if (object && object.onundefine)
        object.onundefine();
    },
    "video": function(parameters) {
      var stream_index = parseInt(parameters[0]);
      var layer = getLayer(parseInt(parameters[1]));
      var mimetype = parameters[2];
      var stream = streams[stream_index] = new Guacamole.InputStream(guac_client, stream_index);
      var videoPlayer = null;
      if (guac_client.onvideo)
        videoPlayer = guac_client.onvideo(stream, layer, mimetype);
      if (!videoPlayer)
        videoPlayer = Guacamole.VideoPlayer.getInstance(stream, layer, mimetype);
      if (videoPlayer) {
        videoPlayers[stream_index] = videoPlayer;
        guac_client.sendAck(stream_index, "OK", 0);
      } else
        guac_client.sendAck(stream_index, "BAD TYPE", 783);
    }
  };
  var sendKeepAlive = function sendKeepAlive2() {
    tunnel.sendMessage("nop");
    lastSentKeepAlive = (/* @__PURE__ */ new Date()).getTime();
  };
  var scheduleKeepAlive = function scheduleKeepAlive2() {
    window.clearTimeout(keepAliveTimeout);
    var currentTime = (/* @__PURE__ */ new Date()).getTime();
    var keepAliveDelay = Math.max(lastSentKeepAlive + KEEP_ALIVE_FREQUENCY - currentTime, 0);
    if (keepAliveDelay > 0)
      keepAliveTimeout = window.setTimeout(sendKeepAlive, keepAliveDelay);
    else
      sendKeepAlive();
  };
  var stopKeepAlive = function stopKeepAlive2() {
    window.clearTimeout(keepAliveTimeout);
  };
  tunnel.oninstruction = function(opcode, parameters) {
    var handler = instructionHandlers[opcode];
    if (handler)
      handler(parameters);
    scheduleKeepAlive();
  };
  this.disconnect = function() {
    if (currentState != Guacamole.Client.State.DISCONNECTED && currentState != Guacamole.Client.State.DISCONNECTING) {
      setState(Guacamole.Client.State.DISCONNECTING);
      stopKeepAlive();
      tunnel.sendMessage("disconnect");
      tunnel.disconnect();
      setState(Guacamole.Client.State.DISCONNECTED);
    }
  };
  this.connect = function(data) {
    setState(Guacamole.Client.State.CONNECTING);
    try {
      tunnel.connect(data);
    } catch (status) {
      setState(Guacamole.Client.State.IDLE);
      throw status;
    }
    scheduleKeepAlive();
    setState(Guacamole.Client.State.WAITING);
  };
};
Guacamole.Client.State = {
  /**
   * The client is idle, with no active connection.
   * 
   * @type number
   */
  "IDLE": 0,
  /**
   * The client is in the process of establishing a connection.
   * 
   * @type {!number}
   */
  "CONNECTING": 1,
  /**
   * The client is waiting on further information or a remote server to
   * establish the connection.
   * 
   * @type {!number}
   */
  "WAITING": 2,
  /**
   * The client is actively connected to a remote server.
   * 
   * @type {!number}
   */
  "CONNECTED": 3,
  /**
   * The client is in the process of disconnecting from the remote server.
   * 
   * @type {!number}
   */
  "DISCONNECTING": 4,
  /**
   * The client has completed the connection and is no longer connected.
   * 
   * @type {!number}
   */
  "DISCONNECTED": 5
};
Guacamole.Client.DefaultTransferFunction = {
  /* BLACK */
  0: function(src, dst) {
    dst.red = dst.green = dst.blue = 0;
  },
  /* WHITE */
  15: function(src, dst) {
    dst.red = dst.green = dst.blue = 255;
  },
  /* SRC */
  3: function(src, dst) {
    dst.red = src.red;
    dst.green = src.green;
    dst.blue = src.blue;
    dst.alpha = src.alpha;
  },
  /* DEST (no-op) */
  5: function(src, dst) {
  },
  /* Invert SRC */
  12: function(src, dst) {
    dst.red = 255 & ~src.red;
    dst.green = 255 & ~src.green;
    dst.blue = 255 & ~src.blue;
    dst.alpha = src.alpha;
  },
  /* Invert DEST */
  10: function(src, dst) {
    dst.red = 255 & ~dst.red;
    dst.green = 255 & ~dst.green;
    dst.blue = 255 & ~dst.blue;
  },
  /* AND */
  1: function(src, dst) {
    dst.red = src.red & dst.red;
    dst.green = src.green & dst.green;
    dst.blue = src.blue & dst.blue;
  },
  /* NAND */
  14: function(src, dst) {
    dst.red = 255 & ~(src.red & dst.red);
    dst.green = 255 & ~(src.green & dst.green);
    dst.blue = 255 & ~(src.blue & dst.blue);
  },
  /* OR */
  7: function(src, dst) {
    dst.red = src.red | dst.red;
    dst.green = src.green | dst.green;
    dst.blue = src.blue | dst.blue;
  },
  /* NOR */
  8: function(src, dst) {
    dst.red = 255 & ~(src.red | dst.red);
    dst.green = 255 & ~(src.green | dst.green);
    dst.blue = 255 & ~(src.blue | dst.blue);
  },
  /* XOR */
  6: function(src, dst) {
    dst.red = src.red ^ dst.red;
    dst.green = src.green ^ dst.green;
    dst.blue = src.blue ^ dst.blue;
  },
  /* XNOR */
  9: function(src, dst) {
    dst.red = 255 & ~(src.red ^ dst.red);
    dst.green = 255 & ~(src.green ^ dst.green);
    dst.blue = 255 & ~(src.blue ^ dst.blue);
  },
  /* AND inverted source */
  4: function(src, dst) {
    dst.red = 255 & (~src.red & dst.red);
    dst.green = 255 & (~src.green & dst.green);
    dst.blue = 255 & (~src.blue & dst.blue);
  },
  /* OR inverted source */
  13: function(src, dst) {
    dst.red = 255 & (~src.red | dst.red);
    dst.green = 255 & (~src.green | dst.green);
    dst.blue = 255 & (~src.blue | dst.blue);
  },
  /* AND inverted destination */
  2: function(src, dst) {
    dst.red = 255 & (src.red & ~dst.red);
    dst.green = 255 & (src.green & ~dst.green);
    dst.blue = 255 & (src.blue & ~dst.blue);
  },
  /* OR inverted destination */
  11: function(src, dst) {
    dst.red = 255 & (src.red | ~dst.red);
    dst.green = 255 & (src.green | ~dst.green);
    dst.blue = 255 & (src.blue | ~dst.blue);
  }
};
Guacamole.Client.Message = {
  /**
   * A client message that indicates that a user has joined an existing
   * connection. This message expects a single additional argument - the
   * name of the user who has joined the connection.
   * 
   * @type {!number}
   */
  "USER_JOINED": 1,
  /**
   * A client message that indicates that a user has left an existing
   * connection. This message expects a single additional argument - the
   * name of the user who has left the connection.
   * 
   * @type {!number}
   */
  "USER_LEFT": 2
};
var Guacamole = Guacamole || {};
Guacamole.DataURIReader = function(stream, mimetype) {
  var guac_reader = this;
  var uri = "data:" + mimetype + ";base64,";
  stream.onblob = function dataURIReaderBlob(data) {
    uri += data;
  };
  stream.onend = function dataURIReaderEnd() {
    if (guac_reader.onend)
      guac_reader.onend();
  };
  this.getURI = function getURI() {
    return uri;
  };
  this.onend = null;
};
var Guacamole = Guacamole || {};
Guacamole.Display = function() {
  var guac_display = this;
  var displayWidth = 0;
  var displayHeight = 0;
  var displayScale = 1;
  var display = document.createElement("div");
  display.style.position = "relative";
  display.style.width = displayWidth + "px";
  display.style.height = displayHeight + "px";
  display.style.transformOrigin = display.style.webkitTransformOrigin = display.style.MozTransformOrigin = display.style.OTransformOrigin = display.style.msTransformOrigin = "0 0";
  var default_layer = new Guacamole.Display.VisibleLayer(displayWidth, displayHeight);
  var cursor = new Guacamole.Display.VisibleLayer(0, 0);
  cursor.setChannelMask(Guacamole.Layer.SRC);
  display.appendChild(default_layer.getElement());
  display.appendChild(cursor.getElement());
  var bounds = document.createElement("div");
  bounds.style.position = "relative";
  bounds.style.width = displayWidth * displayScale + "px";
  bounds.style.height = displayHeight * displayScale + "px";
  bounds.appendChild(display);
  this.cursorHotspotX = 0;
  this.cursorHotspotY = 0;
  this.cursorX = 0;
  this.cursorY = 0;
  this.statisticWindow = 0;
  this.onresize = null;
  this.oncursor = null;
  this.onstatistics = null;
  var tasks = [];
  var frames = [];
  var inProgressFrame = null;
  var syncFlush = function syncFlush2() {
    var localTimestamp = 0;
    var remoteTimestamp = 0;
    var renderedLogicalFrames = 0;
    var rendered_frames = 0;
    while (rendered_frames < frames.length) {
      var frame = frames[rendered_frames];
      if (!frame.isReady())
        break;
      frame.flush();
      localTimestamp = frame.localTimestamp;
      remoteTimestamp = frame.remoteTimestamp;
      renderedLogicalFrames += frame.logicalFrames;
      rendered_frames++;
    }
    frames.splice(0, rendered_frames);
    if (rendered_frames)
      notifyFlushed(localTimestamp, remoteTimestamp, renderedLogicalFrames);
  };
  var asyncFlush = function asyncFlush2() {
    var continueFlush = function continueFlush2() {
      inProgressFrame = null;
      if (!frames.length)
        return;
      if (frames[0].isReady()) {
        var frame = frames.shift();
        frame.flush();
        notifyFlushed(frame.localTimestamp, frame.remoteTimestamp, frame.logicalFrames);
      }
      if (frames.length)
        inProgressFrame = window.requestAnimationFrame(continueFlush2);
    };
    if (!inProgressFrame)
      inProgressFrame = window.requestAnimationFrame(continueFlush);
  };
  var statistics = [];
  var notifyFlushed = function notifyFlushed2(localTimestamp, remoteTimestamp, logicalFrames) {
    if (!guac_display.statisticWindow)
      return;
    var current = (/* @__PURE__ */ new Date()).getTime();
    for (var first = 0; first < statistics.length; first++) {
      if (current - statistics[first].timestamp <= guac_display.statisticWindow)
        break;
    }
    statistics.splice(0, first - 1);
    statistics.push({
      localTimestamp,
      remoteTimestamp,
      timestamp: current,
      frames: logicalFrames
    });
    var statDuration = (statistics[statistics.length - 1].timestamp - statistics[0].timestamp) / 1e3;
    var remoteDuration = (statistics[statistics.length - 1].remoteTimestamp - statistics[0].remoteTimestamp) / 1e3;
    var localFrames = statistics.length;
    var remoteFrames = statistics.reduce(function sumFrames(prev, stat) {
      return prev + stat.frames;
    }, 0);
    var drops = statistics.reduce(function sumDrops(prev, stat) {
      return prev + Math.max(0, stat.frames - 1);
    }, 0);
    var stats = new Guacamole.Display.Statistics({
      processingLag: current - localTimestamp,
      desktopFps: remoteDuration && remoteFrames ? remoteFrames / remoteDuration : null,
      clientFps: statDuration ? localFrames / statDuration : null,
      serverFps: remoteDuration ? localFrames / remoteDuration : null,
      dropRate: remoteDuration ? drops / remoteDuration : null
    });
    if (guac_display.onstatistics)
      guac_display.onstatistics(stats);
  };
  window.addEventListener("blur", function switchToSyncFlush() {
    if (inProgressFrame && !document.hasFocus()) {
      window.cancelAnimationFrame(inProgressFrame);
      inProgressFrame = null;
      syncFlush();
    }
  }, true);
  function __flush_frames() {
    if (window.requestAnimationFrame && document.hasFocus())
      asyncFlush();
    else
      syncFlush();
  }
  var Frame = function Frame2(callback, tasks2, timestamp, logicalFrames) {
    this.localTimestamp = (/* @__PURE__ */ new Date()).getTime();
    this.remoteTimestamp = timestamp || this.localTimestamp;
    this.logicalFrames = logicalFrames || 0;
    this.cancel = function cancel() {
      callback = null;
      tasks2.forEach(function cancelTask(task) {
        task.cancel();
      });
      tasks2 = [];
    };
    this.isReady = function() {
      for (var i5 = 0; i5 < tasks2.length; i5++) {
        if (tasks2[i5].blocked)
          return false;
      }
      return true;
    };
    this.flush = function() {
      for (var i5 = 0; i5 < tasks2.length; i5++)
        tasks2[i5].execute();
      if (callback)
        callback();
    };
  };
  function Task(taskHandler, blocked) {
    var task = this;
    this.blocked = blocked;
    this.cancel = function cancel() {
      task.blocked = false;
      taskHandler = null;
    };
    this.unblock = function() {
      if (task.blocked) {
        task.blocked = false;
        __flush_frames();
      }
    };
    this.execute = function() {
      if (taskHandler)
        taskHandler();
    };
  }
  function scheduleTask(handler, blocked) {
    var task = new Task(handler, blocked);
    tasks.push(task);
    return task;
  }
  this.getElement = function() {
    return bounds;
  };
  this.getWidth = function() {
    return displayWidth;
  };
  this.getHeight = function() {
    return displayHeight;
  };
  this.getDefaultLayer = function() {
    return default_layer;
  };
  this.getCursorLayer = function() {
    return cursor;
  };
  this.createLayer = function() {
    var layer = new Guacamole.Display.VisibleLayer(displayWidth, displayHeight);
    layer.move(default_layer, 0, 0, 0);
    return layer;
  };
  this.createBuffer = function() {
    var buffer = new Guacamole.Layer(0, 0);
    buffer.autosize = 1;
    return buffer;
  };
  this.flush = function(callback, timestamp, logicalFrames) {
    frames.push(new Frame(callback, tasks, timestamp, logicalFrames));
    tasks = [];
    __flush_frames();
  };
  this.cancel = function cancel() {
    frames.forEach(function cancelFrame(frame) {
      frame.cancel();
    });
    frames = [];
    tasks.forEach(function cancelTask(task) {
      task.cancel();
    });
    tasks = [];
  };
  this.setCursor = function(hotspotX, hotspotY, layer, srcx, srcy, srcw, srch) {
    scheduleTask(function __display_set_cursor() {
      guac_display.cursorHotspotX = hotspotX;
      guac_display.cursorHotspotY = hotspotY;
      cursor.resize(srcw, srch);
      cursor.copy(layer, srcx, srcy, srcw, srch, 0, 0);
      guac_display.moveCursor(guac_display.cursorX, guac_display.cursorY);
      if (guac_display.oncursor)
        guac_display.oncursor(cursor.toCanvas(), hotspotX, hotspotY);
    });
  };
  this.showCursor = function(shown) {
    var element = cursor.getElement();
    var parent = element.parentNode;
    if (shown === false) {
      if (parent)
        parent.removeChild(element);
    } else if (parent !== display)
      display.appendChild(element);
  };
  this.moveCursor = function(x2, y3) {
    cursor.translate(
      x2 - guac_display.cursorHotspotX,
      y3 - guac_display.cursorHotspotY
    );
    guac_display.cursorX = x2;
    guac_display.cursorY = y3;
  };
  this.resize = function(layer, width, height) {
    scheduleTask(function __display_resize() {
      layer.resize(width, height);
      if (layer === default_layer) {
        displayWidth = width;
        displayHeight = height;
        display.style.width = displayWidth + "px";
        display.style.height = displayHeight + "px";
        bounds.style.width = displayWidth * displayScale + "px";
        bounds.style.height = displayHeight * displayScale + "px";
        if (guac_display.onresize)
          guac_display.onresize(width, height);
      }
    });
  };
  this.drawImage = function(layer, x2, y3, image) {
    scheduleTask(function __display_drawImage() {
      layer.drawImage(x2, y3, image);
    });
  };
  this.drawBlob = function(layer, x2, y3, blob) {
    var task;
    if (window.createImageBitmap) {
      var bitmap;
      task = scheduleTask(function drawImageBitmap() {
        layer.drawImage(x2, y3, bitmap);
      }, true);
      window.createImageBitmap(blob).then(function bitmapLoaded(decoded) {
        bitmap = decoded;
        task.unblock();
      });
    } else {
      var url = URL.createObjectURL(blob);
      task = scheduleTask(function __display_drawBlob() {
        if (image.width && image.height)
          layer.drawImage(x2, y3, image);
        URL.revokeObjectURL(url);
      }, true);
      var image = new Image();
      image.onload = task.unblock;
      image.onerror = task.unblock;
      image.src = url;
    }
  };
  this.drawStream = function drawStream(layer, x2, y3, stream, mimetype) {
    if (window.createImageBitmap) {
      var reader = new Guacamole.BlobReader(stream, mimetype);
      reader.onend = function drawImageBlob() {
        guac_display.drawBlob(layer, x2, y3, reader.getBlob());
      };
    } else {
      var reader = new Guacamole.DataURIReader(stream, mimetype);
      reader.onend = function drawImageDataURI() {
        guac_display.draw(layer, x2, y3, reader.getURI());
      };
    }
  };
  this.draw = function(layer, x2, y3, url) {
    var task = scheduleTask(function __display_draw() {
      if (image.width && image.height)
        layer.drawImage(x2, y3, image);
    }, true);
    var image = new Image();
    image.onload = task.unblock;
    image.onerror = task.unblock;
    image.src = url;
  };
  this.play = function(layer, mimetype, duration, url) {
    var video = document.createElement("video");
    video.type = mimetype;
    video.src = url;
    video.addEventListener("play", function() {
      function render_callback() {
        layer.drawImage(0, 0, video);
        if (!video.ended)
          window.setTimeout(render_callback, 20);
      }
      render_callback();
    }, false);
    scheduleTask(video.play);
  };
  this.transfer = function(srcLayer, srcx, srcy, srcw, srch, dstLayer, x2, y3, transferFunction) {
    scheduleTask(function __display_transfer() {
      dstLayer.transfer(srcLayer, srcx, srcy, srcw, srch, x2, y3, transferFunction);
    });
  };
  this.put = function(srcLayer, srcx, srcy, srcw, srch, dstLayer, x2, y3) {
    scheduleTask(function __display_put() {
      dstLayer.put(srcLayer, srcx, srcy, srcw, srch, x2, y3);
    });
  };
  this.copy = function(srcLayer, srcx, srcy, srcw, srch, dstLayer, x2, y3) {
    scheduleTask(function __display_copy() {
      dstLayer.copy(srcLayer, srcx, srcy, srcw, srch, x2, y3);
    });
  };
  this.moveTo = function(layer, x2, y3) {
    scheduleTask(function __display_moveTo() {
      layer.moveTo(x2, y3);
    });
  };
  this.lineTo = function(layer, x2, y3) {
    scheduleTask(function __display_lineTo() {
      layer.lineTo(x2, y3);
    });
  };
  this.arc = function(layer, x2, y3, radius, startAngle, endAngle, negative) {
    scheduleTask(function __display_arc() {
      layer.arc(x2, y3, radius, startAngle, endAngle, negative);
    });
  };
  this.curveTo = function(layer, cp1x, cp1y, cp2x, cp2y, x2, y3) {
    scheduleTask(function __display_curveTo() {
      layer.curveTo(cp1x, cp1y, cp2x, cp2y, x2, y3);
    });
  };
  this.close = function(layer) {
    scheduleTask(function __display_close() {
      layer.close();
    });
  };
  this.rect = function(layer, x2, y3, w2, h3) {
    scheduleTask(function __display_rect() {
      layer.rect(x2, y3, w2, h3);
    });
  };
  this.clip = function(layer) {
    scheduleTask(function __display_clip() {
      layer.clip();
    });
  };
  this.strokeColor = function(layer, cap, join, thickness, r7, g2, b3, a3) {
    scheduleTask(function __display_strokeColor() {
      layer.strokeColor(cap, join, thickness, r7, g2, b3, a3);
    });
  };
  this.fillColor = function(layer, r7, g2, b3, a3) {
    scheduleTask(function __display_fillColor() {
      layer.fillColor(r7, g2, b3, a3);
    });
  };
  this.strokeLayer = function(layer, cap, join, thickness, srcLayer) {
    scheduleTask(function __display_strokeLayer() {
      layer.strokeLayer(cap, join, thickness, srcLayer);
    });
  };
  this.fillLayer = function(layer, srcLayer) {
    scheduleTask(function __display_fillLayer() {
      layer.fillLayer(srcLayer);
    });
  };
  this.push = function(layer) {
    scheduleTask(function __display_push() {
      layer.push();
    });
  };
  this.pop = function(layer) {
    scheduleTask(function __display_pop() {
      layer.pop();
    });
  };
  this.reset = function(layer) {
    scheduleTask(function __display_reset() {
      layer.reset();
    });
  };
  this.setTransform = function(layer, a3, b3, c5, d3, e7, f3) {
    scheduleTask(function __display_setTransform() {
      layer.setTransform(a3, b3, c5, d3, e7, f3);
    });
  };
  this.transform = function(layer, a3, b3, c5, d3, e7, f3) {
    scheduleTask(function __display_transform() {
      layer.transform(a3, b3, c5, d3, e7, f3);
    });
  };
  this.setChannelMask = function(layer, mask) {
    scheduleTask(function __display_setChannelMask() {
      layer.setChannelMask(mask);
    });
  };
  this.setMiterLimit = function(layer, limit) {
    scheduleTask(function __display_setMiterLimit() {
      layer.setMiterLimit(limit);
    });
  };
  this.dispose = function dispose(layer) {
    scheduleTask(function disposeLayer() {
      layer.dispose();
    });
  };
  this.distort = function distort(layer, a3, b3, c5, d3, e7, f3) {
    scheduleTask(function distortLayer() {
      layer.distort(a3, b3, c5, d3, e7, f3);
    });
  };
  this.move = function move(layer, parent, x2, y3, z) {
    scheduleTask(function moveLayer() {
      layer.move(parent, x2, y3, z);
    });
  };
  this.shade = function shade(layer, alpha) {
    scheduleTask(function shadeLayer() {
      layer.shade(alpha);
    });
  };
  this.scale = function(scale) {
    display.style.transform = display.style.WebkitTransform = display.style.MozTransform = display.style.OTransform = display.style.msTransform = "scale(" + scale + "," + scale + ")";
    displayScale = scale;
    bounds.style.width = displayWidth * displayScale + "px";
    bounds.style.height = displayHeight * displayScale + "px";
  };
  this.getScale = function() {
    return displayScale;
  };
  this.flatten = function() {
    var canvas = document.createElement("canvas");
    canvas.width = default_layer.width;
    canvas.height = default_layer.height;
    var context = canvas.getContext("2d");
    function get_children(layer) {
      var children = [];
      for (var index in layer.children)
        children.push(layer.children[index]);
      children.sort(function children_comparator(a3, b3) {
        var diff = a3.z - b3.z;
        if (diff !== 0)
          return diff;
        var a_element = a3.getElement();
        var b_element = b3.getElement();
        var position = b_element.compareDocumentPosition(a_element);
        if (position & Node.DOCUMENT_POSITION_PRECEDING)
          return -1;
        if (position & Node.DOCUMENT_POSITION_FOLLOWING)
          return 1;
        return 0;
      });
      return children;
    }
    function draw_layer(layer, x2, y3) {
      if (layer.width > 0 && layer.height > 0) {
        var initial_alpha = context.globalAlpha;
        context.globalAlpha *= layer.alpha / 255;
        context.drawImage(layer.getCanvas(), x2, y3);
        var children = get_children(layer);
        for (var i5 = 0; i5 < children.length; i5++) {
          var child = children[i5];
          draw_layer(child, x2 + child.x, y3 + child.y);
        }
        context.globalAlpha = initial_alpha;
      }
    }
    draw_layer(default_layer, 0, 0);
    return canvas;
  };
};
Guacamole.Display.VisibleLayer = function(width, height) {
  Guacamole.Layer.apply(this, [width, height]);
  var layer = this;
  this.__unique_id = Guacamole.Display.VisibleLayer.__next_id++;
  this.alpha = 255;
  this.x = 0;
  this.y = 0;
  this.z = 0;
  this.matrix = [1, 0, 0, 1, 0, 0];
  this.parent = null;
  this.children = {};
  var canvas = layer.getCanvas();
  canvas.style.position = "absolute";
  canvas.style.left = "0px";
  canvas.style.top = "0px";
  var div = document.createElement("div");
  div.appendChild(canvas);
  div.style.width = width + "px";
  div.style.height = height + "px";
  div.style.position = "absolute";
  div.style.left = "0px";
  div.style.top = "0px";
  div.style.overflow = "hidden";
  var __super_resize = this.resize;
  this.resize = function(width2, height2) {
    div.style.width = width2 + "px";
    div.style.height = height2 + "px";
    __super_resize(width2, height2);
  };
  this.getElement = function() {
    return div;
  };
  var translate = "translate(0px, 0px)";
  var matrix = "matrix(1, 0, 0, 1, 0, 0)";
  this.translate = function(x2, y3) {
    layer.x = x2;
    layer.y = y3;
    translate = "translate(" + x2 + "px," + y3 + "px)";
    div.style.transform = div.style.WebkitTransform = div.style.MozTransform = div.style.OTransform = div.style.msTransform = translate + " " + matrix;
  };
  this.move = function(parent, x2, y3, z) {
    if (layer.parent !== parent) {
      if (layer.parent)
        delete layer.parent.children[layer.__unique_id];
      layer.parent = parent;
      parent.children[layer.__unique_id] = layer;
      var parent_element = parent.getElement();
      parent_element.appendChild(div);
    }
    layer.translate(x2, y3);
    layer.z = z;
    div.style.zIndex = z;
  };
  this.shade = function(a3) {
    layer.alpha = a3;
    div.style.opacity = a3 / 255;
  };
  this.dispose = function() {
    if (layer.parent) {
      delete layer.parent.children[layer.__unique_id];
      layer.parent = null;
    }
    if (div.parentNode)
      div.parentNode.removeChild(div);
  };
  this.distort = function(a3, b3, c5, d3, e7, f3) {
    layer.matrix = [a3, b3, c5, d3, e7, f3];
    matrix = /* a c e
     * b d f
     * 0 0 1
     */
    "matrix(" + a3 + "," + b3 + "," + c5 + "," + d3 + "," + e7 + "," + f3 + ")";
    div.style.transform = div.style.WebkitTransform = div.style.MozTransform = div.style.OTransform = div.style.msTransform = translate + " " + matrix;
  };
};
Guacamole.Display.VisibleLayer.__next_id = 0;
Guacamole.Display.Statistics = function Statistics(template) {
  template = template || {};
  this.processingLag = template.processingLag;
  this.desktopFps = template.desktopFps;
  this.serverFps = template.serverFps;
  this.clientFps = template.clientFps;
  this.dropRate = template.dropRate;
};
var Guacamole = Guacamole || {};
Guacamole.Event = function Event2(type) {
  this.type = type;
  this.timestamp = (/* @__PURE__ */ new Date()).getTime();
  this.getAge = function getAge() {
    return (/* @__PURE__ */ new Date()).getTime() - this.timestamp;
  };
  this.invokeLegacyHandler = function invokeLegacyHandler(eventTarget) {
  };
};
Guacamole.Event.DOMEvent = function DOMEvent(type, events) {
  Guacamole.Event.call(this, type);
  events = events || [];
  if (!Array.isArray(events))
    events = [events];
  this.preventDefault = function preventDefault() {
    events.forEach(function applyPreventDefault(event) {
      if (event.preventDefault)
        event.preventDefault();
      event.returnValue = false;
    });
  };
  this.stopPropagation = function stopPropagation() {
    events.forEach(function applyStopPropagation(event) {
      event.stopPropagation();
    });
  };
};
Guacamole.Event.DOMEvent.cancelEvent = function cancelEvent(event) {
  event.stopPropagation();
  if (event.preventDefault)
    event.preventDefault();
  event.returnValue = false;
};
Guacamole.Event.Target = function Target() {
  var listeners = {};
  this.on = function on(type, listener) {
    var relevantListeners = listeners[type];
    if (!relevantListeners)
      listeners[type] = relevantListeners = [];
    relevantListeners.push(listener);
  };
  this.onEach = function onEach(types, listener) {
    types.forEach(function addListener(type) {
      this.on(type, listener);
    }, this);
  };
  this.dispatch = function dispatch(event) {
    event.invokeLegacyHandler(this);
    var relevantListeners = listeners[event.type];
    if (relevantListeners) {
      for (var i5 = 0; i5 < relevantListeners.length; i5++) {
        relevantListeners[i5](event, this);
      }
    }
  };
  this.off = function off(type, listener) {
    var relevantListeners = listeners[type];
    if (!relevantListeners)
      return false;
    for (var i5 = 0; i5 < relevantListeners.length; i5++) {
      if (relevantListeners[i5] === listener) {
        relevantListeners.splice(i5, 1);
        return true;
      }
    }
    return false;
  };
  this.offEach = function offEach(types, listener) {
    var changed = false;
    types.forEach(function removeListener(type) {
      changed |= this.off(type, listener);
    }, this);
    return changed;
  };
};
var Guacamole = Guacamole || {};
Guacamole.InputSink = function InputSink() {
  var sink = this;
  var field = document.createElement("textarea");
  field.style.position = "fixed";
  field.style.outline = "none";
  field.style.border = "none";
  field.style.margin = "0";
  field.style.padding = "0";
  field.style.height = "0";
  field.style.width = "0";
  field.style.left = "0";
  field.style.bottom = "0";
  field.style.resize = "none";
  field.style.background = "transparent";
  field.style.color = "transparent";
  field.addEventListener("keypress", function clearKeypress(e7) {
    field.value = "";
  }, false);
  field.addEventListener("compositionend", function clearCompletedComposition(e7) {
    if (e7.data)
      field.value = "";
  }, false);
  field.addEventListener("input", function clearCompletedInput(e7) {
    if (e7.data && !e7.isComposing)
      field.value = "";
  }, false);
  field.addEventListener("focus", function focusReceived() {
    window.setTimeout(function deferRefocus() {
      field.click();
      field.select();
    }, 0);
  }, true);
  this.focus = function focus() {
    window.setTimeout(function deferRefocus() {
      field.focus();
    }, 0);
  };
  this.getElement = function getElement() {
    return field;
  };
  document.addEventListener("keydown", function refocusSink(e7) {
    var focused = document.activeElement;
    if (focused && focused !== document.body) {
      var rect = focused.getBoundingClientRect();
      if (rect.left + rect.width > 0 && rect.top + rect.height > 0)
        return;
    }
    sink.focus();
  }, true);
};
var Guacamole = Guacamole || {};
Guacamole.InputStream = function(client, index) {
  var guac_stream = this;
  this.index = index;
  this.onblob = null;
  this.onend = null;
  this.sendAck = function(message, code) {
    client.sendAck(guac_stream.index, message, code);
  };
};
var Guacamole = Guacamole || {};
Guacamole.IntegerPool = function() {
  var guac_pool = this;
  var pool = [];
  this.next_int = 0;
  this.next = function() {
    if (pool.length > 0)
      return pool.shift();
    return guac_pool.next_int++;
  };
  this.free = function(integer) {
    pool.push(integer);
  };
};
var Guacamole = Guacamole || {};
Guacamole.JSONReader = function guacamoleJSONReader(stream) {
  var guacReader = this;
  var stringReader = new Guacamole.StringReader(stream);
  var json = "";
  this.getLength = function getLength() {
    return json.length;
  };
  this.getJSON = function getJSON() {
    return JSON.parse(json);
  };
  stringReader.ontext = function ontext(text) {
    json += text;
    if (guacReader.onprogress)
      guacReader.onprogress(text.length);
  };
  stringReader.onend = function onend() {
    if (guacReader.onend)
      guacReader.onend();
  };
  this.onprogress = null;
  this.onend = null;
};
var Guacamole = Guacamole || {};
Guacamole.Keyboard = function Keyboard(element) {
  var guac_keyboard = this;
  var guacKeyboardID = Guacamole.Keyboard._nextID++;
  var EVENT_MARKER = "_GUAC_KEYBOARD_HANDLED_BY_" + guacKeyboardID;
  this.onkeydown = null;
  this.onkeyup = null;
  var quirks = {
    /**
     * Whether keyup events are universally unreliable.
     *
     * @type {!boolean}
     */
    keyupUnreliable: false,
    /**
     * Whether the Alt key is actually a modifier for typable keys and is
     * thus never used for keyboard shortcuts.
     *
     * @type {!boolean}
     */
    altIsTypableOnly: false,
    /**
     * Whether we can rely on receiving a keyup event for the Caps Lock
     * key.
     *
     * @type {!boolean}
     */
    capsLockKeyupUnreliable: false
  };
  if (navigator && navigator.platform) {
    if (navigator.platform.match(/ipad|iphone|ipod/i))
      quirks.keyupUnreliable = true;
    else if (navigator.platform.match(/^mac/i)) {
      quirks.altIsTypableOnly = true;
      quirks.capsLockKeyupUnreliable = true;
    }
  }
  var KeyEvent = function KeyEvent2(orig) {
    var key_event = this;
    this.keyCode = orig ? orig.which || orig.keyCode : 0;
    this.keyIdentifier = orig && orig.keyIdentifier;
    this.key = orig && orig.key;
    this.location = orig ? getEventLocation(orig) : 0;
    this.modifiers = orig ? Guacamole.Keyboard.ModifierState.fromKeyboardEvent(orig) : new Guacamole.Keyboard.ModifierState();
    this.timestamp = (/* @__PURE__ */ new Date()).getTime();
    this.defaultPrevented = false;
    this.keysym = null;
    this.reliable = false;
    this.getAge = function() {
      return (/* @__PURE__ */ new Date()).getTime() - key_event.timestamp;
    };
  };
  var KeydownEvent = function KeydownEvent2(orig) {
    KeyEvent.call(this, orig);
    this.keysym = keysym_from_key_identifier(this.key, this.location) || keysym_from_keycode(this.keyCode, this.location);
    this.keyupReliable = !quirks.keyupUnreliable;
    if (this.keysym && !isPrintable(this.keysym))
      this.reliable = true;
    if (!this.keysym && key_identifier_sane(this.keyCode, this.keyIdentifier))
      this.keysym = keysym_from_key_identifier(this.keyIdentifier, this.location, this.modifiers.shift);
    if (this.modifiers.meta && this.keysym !== 65511 && this.keysym !== 65512)
      this.keyupReliable = false;
    else if (this.keysym === 65509 && quirks.capsLockKeyupUnreliable)
      this.keyupReliable = false;
    var prevent_alt = !this.modifiers.ctrl && !quirks.altIsTypableOnly;
    var prevent_ctrl = !this.modifiers.alt;
    if (prevent_ctrl && this.modifiers.ctrl || prevent_alt && this.modifiers.alt || this.modifiers.meta || this.modifiers.hyper)
      this.reliable = true;
    recentKeysym[this.keyCode] = this.keysym;
  };
  KeydownEvent.prototype = new KeyEvent();
  var KeypressEvent = function KeypressEvent2(orig) {
    KeyEvent.call(this, orig);
    this.keysym = keysym_from_charcode(this.keyCode);
    this.reliable = true;
  };
  KeypressEvent.prototype = new KeyEvent();
  var KeyupEvent = function KeyupEvent2(orig) {
    KeyEvent.call(this, orig);
    this.keysym = keysym_from_keycode(this.keyCode, this.location) || keysym_from_key_identifier(this.key, this.location);
    if (!guac_keyboard.pressed[this.keysym])
      this.keysym = recentKeysym[this.keyCode] || this.keysym;
    this.reliable = true;
  };
  KeyupEvent.prototype = new KeyEvent();
  var eventLog = [];
  var keycodeKeysyms = {
    8: [65288],
    // backspace
    9: [65289],
    // tab
    12: [65291, 65291, 65291, 65461],
    // clear       / KP 5
    13: [65293],
    // enter
    16: [65505, 65505, 65506],
    // shift
    17: [65507, 65507, 65508],
    // ctrl
    18: [65513, 65513, 65027],
    // alt
    19: [65299],
    // pause/break
    20: [65509],
    // caps lock
    27: [65307],
    // escape
    32: [32],
    // space
    33: [65365, 65365, 65365, 65465],
    // page up     / KP 9
    34: [65366, 65366, 65366, 65459],
    // page down   / KP 3
    35: [65367, 65367, 65367, 65457],
    // end         / KP 1
    36: [65360, 65360, 65360, 65463],
    // home        / KP 7
    37: [65361, 65361, 65361, 65460],
    // left arrow  / KP 4
    38: [65362, 65362, 65362, 65464],
    // up arrow    / KP 8
    39: [65363, 65363, 65363, 65462],
    // right arrow / KP 6
    40: [65364, 65364, 65364, 65458],
    // down arrow  / KP 2
    45: [65379, 65379, 65379, 65456],
    // insert      / KP 0
    46: [65535, 65535, 65535, 65454],
    // delete      / KP decimal
    91: [65511],
    // left windows/command key (meta_l)
    92: [65512],
    // right window/command key (meta_r)
    93: [65383],
    // menu key
    96: [65456],
    // KP 0
    97: [65457],
    // KP 1
    98: [65458],
    // KP 2
    99: [65459],
    // KP 3
    100: [65460],
    // KP 4
    101: [65461],
    // KP 5
    102: [65462],
    // KP 6
    103: [65463],
    // KP 7
    104: [65464],
    // KP 8
    105: [65465],
    // KP 9
    106: [65450],
    // KP multiply
    107: [65451],
    // KP add
    109: [65453],
    // KP subtract
    110: [65454],
    // KP decimal
    111: [65455],
    // KP divide
    112: [65470],
    // f1
    113: [65471],
    // f2
    114: [65472],
    // f3
    115: [65473],
    // f4
    116: [65474],
    // f5
    117: [65475],
    // f6
    118: [65476],
    // f7
    119: [65477],
    // f8
    120: [65478],
    // f9
    121: [65479],
    // f10
    122: [65480],
    // f11
    123: [65481],
    // f12
    144: [65407],
    // num lock
    145: [65300],
    // scroll lock
    225: [65027]
    // altgraph (iso_level3_shift)
  };
  var keyidentifier_keysym = {
    "Again": [65382],
    "AllCandidates": [65341],
    "Alphanumeric": [65328],
    "Alt": [65513, 65513, 65027],
    "Attn": [64782],
    "AltGraph": [65027],
    "ArrowDown": [65364],
    "ArrowLeft": [65361],
    "ArrowRight": [65363],
    "ArrowUp": [65362],
    "Backspace": [65288],
    "CapsLock": [65509],
    "Cancel": [65385],
    "Clear": [65291],
    "Convert": [65313],
    "Copy": [64789],
    "Crsel": [64796],
    "CrSel": [64796],
    "CodeInput": [65335],
    "Compose": [65312],
    "Control": [65507, 65507, 65508],
    "ContextMenu": [65383],
    "Delete": [65535],
    "Down": [65364],
    "End": [65367],
    "Enter": [65293],
    "EraseEof": [64774],
    "Escape": [65307],
    "Execute": [65378],
    "Exsel": [64797],
    "ExSel": [64797],
    "F1": [65470],
    "F2": [65471],
    "F3": [65472],
    "F4": [65473],
    "F5": [65474],
    "F6": [65475],
    "F7": [65476],
    "F8": [65477],
    "F9": [65478],
    "F10": [65479],
    "F11": [65480],
    "F12": [65481],
    "F13": [65482],
    "F14": [65483],
    "F15": [65484],
    "F16": [65485],
    "F17": [65486],
    "F18": [65487],
    "F19": [65488],
    "F20": [65489],
    "F21": [65490],
    "F22": [65491],
    "F23": [65492],
    "F24": [65493],
    "Find": [65384],
    "GroupFirst": [65036],
    "GroupLast": [65038],
    "GroupNext": [65032],
    "GroupPrevious": [65034],
    "FullWidth": null,
    "HalfWidth": null,
    "HangulMode": [65329],
    "Hankaku": [65321],
    "HanjaMode": [65332],
    "Help": [65386],
    "Hiragana": [65317],
    "HiraganaKatakana": [65319],
    "Home": [65360],
    "Hyper": [65517, 65517, 65518],
    "Insert": [65379],
    "JapaneseHiragana": [65317],
    "JapaneseKatakana": [65318],
    "JapaneseRomaji": [65316],
    "JunjaMode": [65336],
    "KanaMode": [65325],
    "KanjiMode": [65313],
    "Katakana": [65318],
    "Left": [65361],
    "Meta": [65511, 65511, 65512],
    "ModeChange": [65406],
    "NumLock": [65407],
    "PageDown": [65366],
    "PageUp": [65365],
    "Pause": [65299],
    "Play": [64790],
    "PreviousCandidate": [65342],
    "PrintScreen": [65377],
    "Redo": [65382],
    "Right": [65363],
    "RomanCharacters": null,
    "Scroll": [65300],
    "Select": [65376],
    "Separator": [65452],
    "Shift": [65505, 65505, 65506],
    "SingleCandidate": [65340],
    "Super": [65515, 65515, 65516],
    "Tab": [65289],
    "UIKeyInputDownArrow": [65364],
    "UIKeyInputEscape": [65307],
    "UIKeyInputLeftArrow": [65361],
    "UIKeyInputRightArrow": [65363],
    "UIKeyInputUpArrow": [65362],
    "Up": [65362],
    "Undo": [65381],
    "Win": [65511, 65511, 65512],
    "Zenkaku": [65320],
    "ZenkakuHankaku": [65322]
  };
  var no_repeat = {
    65027: true,
    // ISO Level 3 Shift (AltGr)
    65505: true,
    // Left shift
    65506: true,
    // Right shift
    65507: true,
    // Left ctrl 
    65508: true,
    // Right ctrl 
    65509: true,
    // Caps Lock
    65511: true,
    // Left meta 
    65512: true,
    // Right meta 
    65513: true,
    // Left alt
    65514: true,
    // Right alt
    65515: true,
    // Left super/hyper
    65516: true
    // Right super/hyper
  };
  this.modifiers = new Guacamole.Keyboard.ModifierState();
  this.pressed = {};
  var implicitlyPressed = {};
  var last_keydown_result = {};
  var recentKeysym = {};
  var key_repeat_timeout = null;
  var key_repeat_interval = null;
  var get_keysym = function get_keysym2(keysyms, location) {
    if (!keysyms)
      return null;
    return keysyms[location] || keysyms[0];
  };
  var isPrintable = function isPrintable2(keysym) {
    return keysym >= 0 && keysym <= 255 || (keysym & 4294901760) === 16777216;
  };
  function keysym_from_key_identifier(identifier, location, shifted) {
    if (!identifier)
      return null;
    var typedCharacter;
    var unicodePrefixLocation = identifier.indexOf("U+");
    if (unicodePrefixLocation >= 0) {
      var hex = identifier.substring(unicodePrefixLocation + 2);
      typedCharacter = String.fromCharCode(parseInt(hex, 16));
    } else if (identifier.length === 1 && location !== 3)
      typedCharacter = identifier;
    else
      return get_keysym(keyidentifier_keysym[identifier], location);
    if (shifted === true)
      typedCharacter = typedCharacter.toUpperCase();
    else if (shifted === false)
      typedCharacter = typedCharacter.toLowerCase();
    var codepoint = typedCharacter.charCodeAt(0);
    return keysym_from_charcode(codepoint);
  }
  function isControlCharacter(codepoint) {
    return codepoint <= 31 || codepoint >= 127 && codepoint <= 159;
  }
  function keysym_from_charcode(codepoint) {
    if (isControlCharacter(codepoint))
      return 65280 | codepoint;
    if (codepoint >= 0 && codepoint <= 255)
      return codepoint;
    if (codepoint >= 256 && codepoint <= 1114111)
      return 16777216 | codepoint;
    return null;
  }
  function keysym_from_keycode(keyCode, location) {
    return get_keysym(keycodeKeysyms[keyCode], location);
  }
  var key_identifier_sane = function key_identifier_sane2(keyCode, keyIdentifier) {
    if (!keyIdentifier)
      return false;
    var unicodePrefixLocation = keyIdentifier.indexOf("U+");
    if (unicodePrefixLocation === -1)
      return true;
    var codepoint = parseInt(keyIdentifier.substring(unicodePrefixLocation + 2), 16);
    if (keyCode !== codepoint)
      return true;
    if (keyCode >= 65 && keyCode <= 90 || keyCode >= 48 && keyCode <= 57)
      return true;
    return false;
  };
  this.press = function(keysym) {
    if (keysym === null)
      return;
    if (!guac_keyboard.pressed[keysym]) {
      guac_keyboard.pressed[keysym] = true;
      if (guac_keyboard.onkeydown) {
        var result = guac_keyboard.onkeydown(keysym);
        last_keydown_result[keysym] = result;
        window.clearTimeout(key_repeat_timeout);
        window.clearInterval(key_repeat_interval);
        if (!no_repeat[keysym])
          key_repeat_timeout = window.setTimeout(function() {
            key_repeat_interval = window.setInterval(function() {
              guac_keyboard.onkeyup(keysym);
              guac_keyboard.onkeydown(keysym);
            }, 50);
          }, 500);
        return result;
      }
    }
    return last_keydown_result[keysym] || false;
  };
  this.release = function(keysym) {
    if (guac_keyboard.pressed[keysym]) {
      delete guac_keyboard.pressed[keysym];
      delete implicitlyPressed[keysym];
      window.clearTimeout(key_repeat_timeout);
      window.clearInterval(key_repeat_interval);
      if (keysym !== null && guac_keyboard.onkeyup)
        guac_keyboard.onkeyup(keysym);
    }
  };
  this.type = function type(str2) {
    for (var i5 = 0; i5 < str2.length; i5++) {
      var codepoint = str2.codePointAt ? str2.codePointAt(i5) : str2.charCodeAt(i5);
      var keysym = keysym_from_charcode(codepoint);
      guac_keyboard.press(keysym);
      guac_keyboard.release(keysym);
    }
  };
  this.reset = function() {
    for (var keysym in guac_keyboard.pressed)
      guac_keyboard.release(parseInt(keysym));
    eventLog = [];
  };
  var updateModifierState = function updateModifierState2(modifier, keysyms, keyEvent) {
    var localState = keyEvent.modifiers[modifier];
    var remoteState = guac_keyboard.modifiers[modifier];
    var i5;
    if (keysyms.indexOf(keyEvent.keysym) !== -1)
      return;
    if (remoteState && localState === false) {
      for (i5 = 0; i5 < keysyms.length; i5++) {
        guac_keyboard.release(keysyms[i5]);
      }
    } else if (!remoteState && localState) {
      for (i5 = 0; i5 < keysyms.length; i5++) {
        if (guac_keyboard.pressed[keysyms[i5]])
          return;
      }
      var keysym = keysyms[0];
      if (keyEvent.keysym)
        implicitlyPressed[keysym] = true;
      guac_keyboard.press(keysym);
    }
  };
  var syncModifierStates = function syncModifierStates2(keyEvent) {
    updateModifierState("alt", [
      65513,
      // Left alt
      65514,
      // Right alt
      65027
      // AltGr
    ], keyEvent);
    updateModifierState("shift", [
      65505,
      // Left shift
      65506
      // Right shift
    ], keyEvent);
    updateModifierState("ctrl", [
      65507,
      // Left ctrl
      65508
      // Right ctrl
    ], keyEvent);
    updateModifierState("meta", [
      65511,
      // Left meta
      65512
      // Right meta
    ], keyEvent);
    updateModifierState("hyper", [
      65515,
      // Left super/hyper
      65516
      // Right super/hyper
    ], keyEvent);
    guac_keyboard.modifiers = keyEvent.modifiers;
  };
  var isStateImplicit = function isStateImplicit2() {
    for (var keysym in guac_keyboard.pressed) {
      if (!implicitlyPressed[keysym])
        return false;
    }
    return true;
  };
  function interpret_events() {
    var handled_event = interpret_event();
    if (!handled_event)
      return false;
    var last_event;
    do {
      last_event = handled_event;
      handled_event = interpret_event();
    } while (handled_event !== null);
    if (isStateImplicit())
      guac_keyboard.reset();
    return last_event.defaultPrevented;
  }
  var release_simulated_altgr = function release_simulated_altgr2(keysym) {
    if (!guac_keyboard.modifiers.ctrl || !guac_keyboard.modifiers.alt)
      return;
    if (keysym >= 65 && keysym <= 90)
      return;
    if (keysym >= 97 && keysym <= 122)
      return;
    if (keysym <= 255 || (keysym & 4278190080) === 16777216) {
      guac_keyboard.release(65507);
      guac_keyboard.release(65508);
      guac_keyboard.release(65513);
      guac_keyboard.release(65514);
    }
  };
  var interpret_event = function interpret_event2() {
    var first = eventLog[0];
    if (!first)
      return null;
    if (first instanceof KeydownEvent) {
      var keysym = null;
      var accepted_events = [];
      if (first.keysym === 65511 || first.keysym === 65512) {
        if (eventLog.length === 1)
          return null;
        if (eventLog[1].keysym !== first.keysym) {
          if (!eventLog[1].modifiers.meta)
            return eventLog.shift();
        } else if (eventLog[1] instanceof KeydownEvent)
          return eventLog.shift();
      }
      if (first.reliable) {
        keysym = first.keysym;
        accepted_events = eventLog.splice(0, 1);
      } else if (eventLog[1] instanceof KeypressEvent) {
        keysym = eventLog[1].keysym;
        accepted_events = eventLog.splice(0, 2);
      } else if (eventLog[1]) {
        keysym = first.keysym;
        accepted_events = eventLog.splice(0, 1);
      }
      if (accepted_events.length > 0) {
        syncModifierStates(first);
        if (keysym) {
          release_simulated_altgr(keysym);
          var defaultPrevented = !guac_keyboard.press(keysym);
          recentKeysym[first.keyCode] = keysym;
          if (!first.keyupReliable)
            guac_keyboard.release(keysym);
          for (var i5 = 0; i5 < accepted_events.length; i5++)
            accepted_events[i5].defaultPrevented = defaultPrevented;
        }
        return first;
      }
    } else if (first instanceof KeyupEvent && !quirks.keyupUnreliable) {
      var keysym = first.keysym;
      if (keysym) {
        guac_keyboard.release(keysym);
        delete recentKeysym[first.keyCode];
        first.defaultPrevented = true;
      } else {
        guac_keyboard.reset();
        return first;
      }
      syncModifierStates(first);
      return eventLog.shift();
    } else
      return eventLog.shift();
    return null;
  };
  var getEventLocation = function getEventLocation2(e7) {
    if ("location" in e7)
      return e7.location;
    if ("keyLocation" in e7)
      return e7.keyLocation;
    return 0;
  };
  var markEvent = function markEvent2(e7) {
    if (e7[EVENT_MARKER])
      return false;
    e7[EVENT_MARKER] = true;
    return true;
  };
  this.listenTo = function listenTo(element2) {
    element2.addEventListener("keydown", function(e7) {
      if (!guac_keyboard.onkeydown)
        return;
      if (!markEvent(e7))
        return;
      var keydownEvent = new KeydownEvent(e7);
      if (keydownEvent.keyCode === 229)
        return;
      eventLog.push(keydownEvent);
      if (interpret_events())
        e7.preventDefault();
    }, true);
    element2.addEventListener("keypress", function(e7) {
      if (!guac_keyboard.onkeydown && !guac_keyboard.onkeyup)
        return;
      if (!markEvent(e7))
        return;
      eventLog.push(new KeypressEvent(e7));
      if (interpret_events())
        e7.preventDefault();
    }, true);
    element2.addEventListener("keyup", function(e7) {
      if (!guac_keyboard.onkeyup)
        return;
      if (!markEvent(e7))
        return;
      e7.preventDefault();
      eventLog.push(new KeyupEvent(e7));
      interpret_events();
    }, true);
    var handleInput = function handleInput2(e7) {
      if (!guac_keyboard.onkeydown && !guac_keyboard.onkeyup)
        return;
      if (!markEvent(e7))
        return;
      if (e7.data && !e7.isComposing) {
        element2.removeEventListener("compositionend", handleComposition, false);
        guac_keyboard.type(e7.data);
      }
    };
    var handleComposition = function handleComposition2(e7) {
      if (!guac_keyboard.onkeydown && !guac_keyboard.onkeyup)
        return;
      if (!markEvent(e7))
        return;
      if (e7.data) {
        element2.removeEventListener("input", handleInput, false);
        guac_keyboard.type(e7.data);
      }
    };
    element2.addEventListener("input", handleInput, false);
    element2.addEventListener("compositionend", handleComposition, false);
  };
  if (element)
    guac_keyboard.listenTo(element);
};
Guacamole.Keyboard._nextID = 0;
Guacamole.Keyboard.ModifierState = function() {
  this.shift = false;
  this.ctrl = false;
  this.alt = false;
  this.meta = false;
  this.hyper = false;
};
Guacamole.Keyboard.ModifierState.fromKeyboardEvent = function(e7) {
  var state = new Guacamole.Keyboard.ModifierState();
  state.shift = e7.shiftKey;
  state.ctrl = e7.ctrlKey;
  state.alt = e7.altKey;
  state.meta = e7.metaKey;
  if (e7.getModifierState) {
    state.hyper = e7.getModifierState("OS") || e7.getModifierState("Super") || e7.getModifierState("Hyper") || e7.getModifierState("Win");
  }
  return state;
};
var Guacamole = Guacamole || {};
Guacamole.Layer = function(width, height) {
  var layer = this;
  var CANVAS_SIZE_FACTOR = 64;
  var canvas = document.createElement("canvas");
  var context = canvas.getContext("2d");
  context.save();
  var empty = true;
  var pathClosed = true;
  var stackSize = 0;
  var compositeOperation = {
    /* 0x0 NOT IMPLEMENTED */
    1: "destination-in",
    2: "destination-out",
    /* 0x3 NOT IMPLEMENTED */
    4: "source-in",
    /* 0x5 NOT IMPLEMENTED */
    6: "source-atop",
    /* 0x7 NOT IMPLEMENTED */
    8: "source-out",
    9: "destination-atop",
    10: "xor",
    11: "destination-over",
    12: "copy",
    /* 0xD NOT IMPLEMENTED */
    14: "source-over",
    15: "lighter"
  };
  var resize = function resize2(newWidth, newHeight) {
    newWidth = newWidth || 0;
    newHeight = newHeight || 0;
    var canvasWidth = Math.ceil(newWidth / CANVAS_SIZE_FACTOR) * CANVAS_SIZE_FACTOR;
    var canvasHeight = Math.ceil(newHeight / CANVAS_SIZE_FACTOR) * CANVAS_SIZE_FACTOR;
    if (canvas.width !== canvasWidth || canvas.height !== canvasHeight) {
      var oldData = null;
      if (!empty && canvas.width !== 0 && canvas.height !== 0) {
        oldData = document.createElement("canvas");
        oldData.width = Math.min(layer.width, newWidth);
        oldData.height = Math.min(layer.height, newHeight);
        var oldDataContext = oldData.getContext("2d");
        oldDataContext.drawImage(
          canvas,
          0,
          0,
          oldData.width,
          oldData.height,
          0,
          0,
          oldData.width,
          oldData.height
        );
      }
      var oldCompositeOperation = context.globalCompositeOperation;
      canvas.width = canvasWidth;
      canvas.height = canvasHeight;
      if (oldData)
        context.drawImage(
          oldData,
          0,
          0,
          oldData.width,
          oldData.height,
          0,
          0,
          oldData.width,
          oldData.height
        );
      context.globalCompositeOperation = oldCompositeOperation;
      stackSize = 0;
      context.save();
    } else
      layer.reset();
    layer.width = newWidth;
    layer.height = newHeight;
  };
  function fitRect(x2, y3, w2, h3) {
    var opBoundX = w2 + x2;
    var opBoundY = h3 + y3;
    var resizeWidth;
    if (opBoundX > layer.width)
      resizeWidth = opBoundX;
    else
      resizeWidth = layer.width;
    var resizeHeight;
    if (opBoundY > layer.height)
      resizeHeight = opBoundY;
    else
      resizeHeight = layer.height;
    layer.resize(resizeWidth, resizeHeight);
  }
  this.autosize = false;
  this.width = width;
  this.height = height;
  this.getCanvas = function getCanvas() {
    return canvas;
  };
  this.toCanvas = function toCanvas() {
    var canvas2 = document.createElement("canvas");
    canvas2.width = layer.width;
    canvas2.height = layer.height;
    var context2 = canvas2.getContext("2d");
    context2.drawImage(layer.getCanvas(), 0, 0);
    return canvas2;
  };
  this.resize = function(newWidth, newHeight) {
    if (newWidth !== layer.width || newHeight !== layer.height)
      resize(newWidth, newHeight);
  };
  this.drawImage = function(x2, y3, image) {
    if (layer.autosize)
      fitRect(x2, y3, image.width, image.height);
    context.drawImage(image, x2, y3);
    empty = false;
  };
  this.transfer = function(srcLayer, srcx, srcy, srcw, srch, x2, y3, transferFunction) {
    var srcCanvas = srcLayer.getCanvas();
    if (srcx >= srcCanvas.width || srcy >= srcCanvas.height)
      return;
    if (srcx + srcw > srcCanvas.width)
      srcw = srcCanvas.width - srcx;
    if (srcy + srch > srcCanvas.height)
      srch = srcCanvas.height - srcy;
    if (srcw === 0 || srch === 0)
      return;
    if (layer.autosize)
      fitRect(x2, y3, srcw, srch);
    var src = srcLayer.getCanvas().getContext("2d").getImageData(srcx, srcy, srcw, srch);
    var dst = context.getImageData(x2, y3, srcw, srch);
    for (var i5 = 0; i5 < srcw * srch * 4; i5 += 4) {
      var src_pixel = new Guacamole.Layer.Pixel(
        src.data[i5],
        src.data[i5 + 1],
        src.data[i5 + 2],
        src.data[i5 + 3]
      );
      var dst_pixel = new Guacamole.Layer.Pixel(
        dst.data[i5],
        dst.data[i5 + 1],
        dst.data[i5 + 2],
        dst.data[i5 + 3]
      );
      transferFunction(src_pixel, dst_pixel);
      dst.data[i5] = dst_pixel.red;
      dst.data[i5 + 1] = dst_pixel.green;
      dst.data[i5 + 2] = dst_pixel.blue;
      dst.data[i5 + 3] = dst_pixel.alpha;
    }
    context.putImageData(dst, x2, y3);
    empty = false;
  };
  this.put = function(srcLayer, srcx, srcy, srcw, srch, x2, y3) {
    var srcCanvas = srcLayer.getCanvas();
    if (srcx >= srcCanvas.width || srcy >= srcCanvas.height)
      return;
    if (srcx + srcw > srcCanvas.width)
      srcw = srcCanvas.width - srcx;
    if (srcy + srch > srcCanvas.height)
      srch = srcCanvas.height - srcy;
    if (srcw === 0 || srch === 0)
      return;
    if (layer.autosize)
      fitRect(x2, y3, srcw, srch);
    var src = srcLayer.getCanvas().getContext("2d").getImageData(srcx, srcy, srcw, srch);
    context.putImageData(src, x2, y3);
    empty = false;
  };
  this.copy = function(srcLayer, srcx, srcy, srcw, srch, x2, y3) {
    var srcCanvas = srcLayer.getCanvas();
    if (srcx >= srcCanvas.width || srcy >= srcCanvas.height)
      return;
    if (srcx + srcw > srcCanvas.width)
      srcw = srcCanvas.width - srcx;
    if (srcy + srch > srcCanvas.height)
      srch = srcCanvas.height - srcy;
    if (srcw === 0 || srch === 0)
      return;
    if (layer.autosize)
      fitRect(x2, y3, srcw, srch);
    context.drawImage(srcCanvas, srcx, srcy, srcw, srch, x2, y3, srcw, srch);
    empty = false;
  };
  this.moveTo = function(x2, y3) {
    if (pathClosed) {
      context.beginPath();
      pathClosed = false;
    }
    if (layer.autosize)
      fitRect(x2, y3, 0, 0);
    context.moveTo(x2, y3);
  };
  this.lineTo = function(x2, y3) {
    if (pathClosed) {
      context.beginPath();
      pathClosed = false;
    }
    if (layer.autosize)
      fitRect(x2, y3, 0, 0);
    context.lineTo(x2, y3);
  };
  this.arc = function(x2, y3, radius, startAngle, endAngle, negative) {
    if (pathClosed) {
      context.beginPath();
      pathClosed = false;
    }
    if (layer.autosize)
      fitRect(x2, y3, 0, 0);
    context.arc(x2, y3, radius, startAngle, endAngle, negative);
  };
  this.curveTo = function(cp1x, cp1y, cp2x, cp2y, x2, y3) {
    if (pathClosed) {
      context.beginPath();
      pathClosed = false;
    }
    if (layer.autosize)
      fitRect(x2, y3, 0, 0);
    context.bezierCurveTo(cp1x, cp1y, cp2x, cp2y, x2, y3);
  };
  this.close = function() {
    context.closePath();
    pathClosed = true;
  };
  this.rect = function(x2, y3, w2, h3) {
    if (pathClosed) {
      context.beginPath();
      pathClosed = false;
    }
    if (layer.autosize)
      fitRect(x2, y3, w2, h3);
    context.rect(x2, y3, w2, h3);
  };
  this.clip = function() {
    context.clip();
    pathClosed = true;
  };
  this.strokeColor = function(cap, join, thickness, r7, g2, b3, a3) {
    context.lineCap = cap;
    context.lineJoin = join;
    context.lineWidth = thickness;
    context.strokeStyle = "rgba(" + r7 + "," + g2 + "," + b3 + "," + a3 / 255 + ")";
    context.stroke();
    empty = false;
    pathClosed = true;
  };
  this.fillColor = function(r7, g2, b3, a3) {
    context.fillStyle = "rgba(" + r7 + "," + g2 + "," + b3 + "," + a3 / 255 + ")";
    context.fill();
    empty = false;
    pathClosed = true;
  };
  this.strokeLayer = function(cap, join, thickness, srcLayer) {
    context.lineCap = cap;
    context.lineJoin = join;
    context.lineWidth = thickness;
    context.strokeStyle = context.createPattern(
      srcLayer.getCanvas(),
      "repeat"
    );
    context.stroke();
    empty = false;
    pathClosed = true;
  };
  this.fillLayer = function(srcLayer) {
    context.fillStyle = context.createPattern(
      srcLayer.getCanvas(),
      "repeat"
    );
    context.fill();
    empty = false;
    pathClosed = true;
  };
  this.push = function() {
    context.save();
    stackSize++;
  };
  this.pop = function() {
    if (stackSize > 0) {
      context.restore();
      stackSize--;
    }
  };
  this.reset = function() {
    while (stackSize > 0) {
      context.restore();
      stackSize--;
    }
    context.restore();
    context.save();
    context.beginPath();
    pathClosed = false;
  };
  this.setTransform = function(a3, b3, c5, d3, e7, f3) {
    context.setTransform(
      a3,
      b3,
      c5,
      d3,
      e7,
      f3
      /*0, 0, 1*/
    );
  };
  this.transform = function(a3, b3, c5, d3, e7, f3) {
    context.transform(
      a3,
      b3,
      c5,
      d3,
      e7,
      f3
      /*0, 0, 1*/
    );
  };
  this.setChannelMask = function(mask) {
    context.globalCompositeOperation = compositeOperation[mask];
  };
  this.setMiterLimit = function(limit) {
    context.miterLimit = limit;
  };
  resize(width, height);
  canvas.style.zIndex = -1;
};
Guacamole.Layer.ROUT = 2;
Guacamole.Layer.ATOP = 6;
Guacamole.Layer.XOR = 10;
Guacamole.Layer.ROVER = 11;
Guacamole.Layer.OVER = 14;
Guacamole.Layer.PLUS = 15;
Guacamole.Layer.RIN = 1;
Guacamole.Layer.IN = 4;
Guacamole.Layer.OUT = 8;
Guacamole.Layer.RATOP = 9;
Guacamole.Layer.SRC = 12;
Guacamole.Layer.Pixel = function(r7, g2, b3, a3) {
  this.red = r7;
  this.green = g2;
  this.blue = b3;
  this.alpha = a3;
};
var Guacamole = Guacamole || {};
Guacamole.Mouse = function Mouse(element) {
  Guacamole.Mouse.Event.Target.call(this);
  var guac_mouse = this;
  this.touchMouseThreshold = 3;
  this.scrollThreshold = 53;
  this.PIXELS_PER_LINE = 18;
  this.PIXELS_PER_PAGE = this.PIXELS_PER_LINE * 16;
  var MOUSE_BUTTONS = [
    Guacamole.Mouse.State.Buttons.LEFT,
    Guacamole.Mouse.State.Buttons.MIDDLE,
    Guacamole.Mouse.State.Buttons.RIGHT
  ];
  var ignore_mouse = 0;
  var scroll_delta = 0;
  element.addEventListener("contextmenu", function(e7) {
    Guacamole.Event.DOMEvent.cancelEvent(e7);
  }, false);
  element.addEventListener("mousemove", function(e7) {
    if (ignore_mouse) {
      Guacamole.Event.DOMEvent.cancelEvent(e7);
      ignore_mouse--;
      return;
    }
    guac_mouse.move(Guacamole.Position.fromClientPosition(element, e7.clientX, e7.clientY), e7);
  }, false);
  element.addEventListener("mousedown", function(e7) {
    if (ignore_mouse) {
      Guacamole.Event.DOMEvent.cancelEvent(e7);
      return;
    }
    var button = MOUSE_BUTTONS[e7.button];
    if (button)
      guac_mouse.press(button, e7);
  }, false);
  element.addEventListener("mouseup", function(e7) {
    if (ignore_mouse) {
      Guacamole.Event.DOMEvent.cancelEvent(e7);
      return;
    }
    var button = MOUSE_BUTTONS[e7.button];
    if (button)
      guac_mouse.release(button, e7);
  }, false);
  element.addEventListener("mouseout", function(e7) {
    if (!e7)
      e7 = window.event;
    var target = e7.relatedTarget || e7.toElement;
    while (target) {
      if (target === element)
        return;
      target = target.parentNode;
    }
    guac_mouse.reset(e7);
    guac_mouse.out(e7);
  }, false);
  element.addEventListener("selectstart", function(e7) {
    Guacamole.Event.DOMEvent.cancelEvent(e7);
  }, false);
  function ignorePendingMouseEvents() {
    ignore_mouse = guac_mouse.touchMouseThreshold;
  }
  element.addEventListener("touchmove", ignorePendingMouseEvents, false);
  element.addEventListener("touchstart", ignorePendingMouseEvents, false);
  element.addEventListener("touchend", ignorePendingMouseEvents, false);
  function mousewheel_handler(e7) {
    var delta = e7.deltaY || -e7.wheelDeltaY || -e7.wheelDelta;
    if (delta) {
      if (e7.deltaMode === 1)
        delta = e7.deltaY * guac_mouse.PIXELS_PER_LINE;
      else if (e7.deltaMode === 2)
        delta = e7.deltaY * guac_mouse.PIXELS_PER_PAGE;
    } else
      delta = e7.detail * guac_mouse.PIXELS_PER_LINE;
    scroll_delta += delta;
    if (scroll_delta <= -guac_mouse.scrollThreshold) {
      do {
        guac_mouse.click(Guacamole.Mouse.State.Buttons.UP);
        scroll_delta += guac_mouse.scrollThreshold;
      } while (scroll_delta <= -guac_mouse.scrollThreshold);
      scroll_delta = 0;
    }
    if (scroll_delta >= guac_mouse.scrollThreshold) {
      do {
        guac_mouse.click(Guacamole.Mouse.State.Buttons.DOWN);
        scroll_delta -= guac_mouse.scrollThreshold;
      } while (scroll_delta >= guac_mouse.scrollThreshold);
      scroll_delta = 0;
    }
    Guacamole.Event.DOMEvent.cancelEvent(e7);
  }
  element.addEventListener("DOMMouseScroll", mousewheel_handler, false);
  element.addEventListener("mousewheel", mousewheel_handler, false);
  element.addEventListener("wheel", mousewheel_handler, false);
  var CSS3_CURSOR_SUPPORTED = function() {
    var div = document.createElement("div");
    if (!("cursor" in div.style))
      return false;
    try {
      div.style.cursor = "url(data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAAEAAAABAQMAAAAl21bKAAAAA1BMVEX///+nxBvIAAAACklEQVQI12NgAAAAAgAB4iG8MwAAAABJRU5ErkJggg==) 0 0, auto";
    } catch (e7) {
      return false;
    }
    return /\burl\([^()]*\)\s+0\s+0\b/.test(div.style.cursor || "");
  }();
  this.setCursor = function(canvas, x2, y3) {
    if (CSS3_CURSOR_SUPPORTED) {
      var dataURL = canvas.toDataURL("image/png");
      element.style.cursor = "url(" + dataURL + ") " + x2 + " " + y3 + ", auto";
      return true;
    }
    return false;
  };
};
Guacamole.Mouse.State = function State(template) {
  var legacyConstructor = function legacyConstructor2(x2, y3, left, middle, right, up, down) {
    return {
      x: x2,
      y: y3,
      left,
      middle,
      right,
      up,
      down
    };
  };
  if (arguments.length > 1)
    template = legacyConstructor.apply(this, arguments);
  else
    template = template || {};
  Guacamole.Position.call(this, template);
  this.left = template.left || false;
  this.middle = template.middle || false;
  this.right = template.right || false;
  this.up = template.up || false;
  this.down = template.down || false;
};
Guacamole.Mouse.State.Buttons = {
  /**
   * The name of the {@link Guacamole.Mouse.State} property representing the
   * left mouse button.
   *
   * @constant
   * @type {!string}
   */
  LEFT: "left",
  /**
   * The name of the {@link Guacamole.Mouse.State} property representing the
   * middle mouse button.
   *
   * @constant
   * @type {!string}
   */
  MIDDLE: "middle",
  /**
   * The name of the {@link Guacamole.Mouse.State} property representing the
   * right mouse button.
   *
   * @constant
   * @type {!string}
   */
  RIGHT: "right",
  /**
   * The name of the {@link Guacamole.Mouse.State} property representing the
   * up mouse button (the fourth mouse button, clicked when the mouse scroll
   * wheel is scrolled up).
   *
   * @constant
   * @type {!string}
   */
  UP: "up",
  /**
   * The name of the {@link Guacamole.Mouse.State} property representing the
   * down mouse button (the fifth mouse button, clicked when the mouse scroll
   * wheel is scrolled up).
   *
   * @constant
   * @type {!string}
   */
  DOWN: "down"
};
Guacamole.Mouse.Event = function MouseEvent(type, state, events) {
  Guacamole.Event.DOMEvent.call(this, type, events);
  var legacyHandlerName = "on" + this.type;
  this.state = state;
  this.invokeLegacyHandler = function invokeLegacyHandler(target) {
    if (target[legacyHandlerName]) {
      this.preventDefault();
      this.stopPropagation();
      target[legacyHandlerName](this.state);
    }
  };
};
Guacamole.Mouse.Event.Target = function MouseEventTarget() {
  Guacamole.Event.Target.call(this);
  this.currentState = new Guacamole.Mouse.State();
  this.press = function press(button, events) {
    if (!this.currentState[button]) {
      this.currentState[button] = true;
      this.dispatch(new Guacamole.Mouse.Event("mousedown", this.currentState, events));
    }
  };
  this.release = function release(button, events) {
    if (this.currentState[button]) {
      this.currentState[button] = false;
      this.dispatch(new Guacamole.Mouse.Event("mouseup", this.currentState, events));
    }
  };
  this.click = function click(button, events) {
    this.press(button, events);
    this.release(button, events);
  };
  this.move = function move(position, events) {
    if (this.currentState.x !== position.x || this.currentState.y !== position.y) {
      this.currentState.x = position.x;
      this.currentState.y = position.y;
      this.dispatch(new Guacamole.Mouse.Event("mousemove", this.currentState, events));
    }
  };
  this.out = function out(events) {
    this.dispatch(new Guacamole.Mouse.Event("mouseout", this.currentState, events));
  };
  this.reset = function reset(events) {
    for (var button in Guacamole.Mouse.State.Buttons) {
      this.release(Guacamole.Mouse.State.Buttons[button], events);
    }
  };
};
Guacamole.Mouse.Touchpad = function Touchpad(element) {
  Guacamole.Mouse.Event.Target.call(this);
  var guac_touchpad = this;
  this.scrollThreshold = 20 * (window.devicePixelRatio || 1);
  this.clickTimingThreshold = 250;
  this.clickMoveThreshold = 10 * (window.devicePixelRatio || 1);
  this.currentState = new Guacamole.Mouse.State();
  var touch_count = 0;
  var last_touch_x = 0;
  var last_touch_y = 0;
  var last_touch_time = 0;
  var pixels_moved = 0;
  var touch_buttons = {
    1: "left",
    2: "right",
    3: "middle"
  };
  var gesture_in_progress = false;
  var click_release_timeout = null;
  element.addEventListener("touchend", function(e7) {
    e7.preventDefault();
    if (gesture_in_progress && e7.touches.length === 0) {
      var time = (/* @__PURE__ */ new Date()).getTime();
      var button = touch_buttons[touch_count];
      if (guac_touchpad.currentState[button]) {
        guac_touchpad.release(button, e7);
        if (click_release_timeout) {
          window.clearTimeout(click_release_timeout);
          click_release_timeout = null;
        }
      }
      if (time - last_touch_time <= guac_touchpad.clickTimingThreshold && pixels_moved < guac_touchpad.clickMoveThreshold) {
        guac_touchpad.press(button, e7);
        click_release_timeout = window.setTimeout(function() {
          guac_touchpad.release(button, e7);
          gesture_in_progress = false;
        }, guac_touchpad.clickTimingThreshold);
      }
      if (!click_release_timeout)
        gesture_in_progress = false;
    }
  }, false);
  element.addEventListener("touchstart", function(e7) {
    e7.preventDefault();
    touch_count = Math.min(e7.touches.length, 3);
    if (click_release_timeout) {
      window.clearTimeout(click_release_timeout);
      click_release_timeout = null;
    }
    if (!gesture_in_progress) {
      gesture_in_progress = true;
      var starting_touch = e7.touches[0];
      last_touch_x = starting_touch.clientX;
      last_touch_y = starting_touch.clientY;
      last_touch_time = (/* @__PURE__ */ new Date()).getTime();
      pixels_moved = 0;
    }
  }, false);
  element.addEventListener("touchmove", function(e7) {
    e7.preventDefault();
    var touch = e7.touches[0];
    var delta_x = touch.clientX - last_touch_x;
    var delta_y = touch.clientY - last_touch_y;
    pixels_moved += Math.abs(delta_x) + Math.abs(delta_y);
    if (touch_count === 1) {
      var velocity = pixels_moved / ((/* @__PURE__ */ new Date()).getTime() - last_touch_time);
      var scale = 1 + velocity;
      var position = new Guacamole.Position(guac_touchpad.currentState);
      position.x += delta_x * scale;
      position.y += delta_y * scale;
      position.x = Math.min(Math.max(0, position.x), element.offsetWidth - 1);
      position.y = Math.min(Math.max(0, position.y), element.offsetHeight - 1);
      guac_touchpad.move(position, e7);
      last_touch_x = touch.clientX;
      last_touch_y = touch.clientY;
    } else if (touch_count === 2) {
      if (Math.abs(delta_y) >= guac_touchpad.scrollThreshold) {
        var button;
        if (delta_y > 0)
          button = "down";
        else
          button = "up";
        guac_touchpad.click(button, e7);
        last_touch_x = touch.clientX;
        last_touch_y = touch.clientY;
      }
    }
  }, false);
};
Guacamole.Mouse.Touchscreen = function Touchscreen(element) {
  Guacamole.Mouse.Event.Target.call(this);
  var guac_touchscreen = this;
  var gesture_in_progress = false;
  var gesture_start_x = null;
  var gesture_start_y = null;
  var click_release_timeout = null;
  var long_press_timeout = null;
  this.scrollThreshold = 20 * (window.devicePixelRatio || 1);
  this.clickTimingThreshold = 250;
  this.clickMoveThreshold = 16 * (window.devicePixelRatio || 1);
  this.longPressThreshold = 500;
  function finger_moved(e7) {
    var touch = e7.touches[0] || e7.changedTouches[0];
    var delta_x = touch.clientX - gesture_start_x;
    var delta_y = touch.clientY - gesture_start_y;
    return Math.sqrt(delta_x * delta_x + delta_y * delta_y) >= guac_touchscreen.clickMoveThreshold;
  }
  function begin_gesture(e7) {
    var touch = e7.touches[0];
    gesture_in_progress = true;
    gesture_start_x = touch.clientX;
    gesture_start_y = touch.clientY;
  }
  function end_gesture() {
    window.clearTimeout(click_release_timeout);
    window.clearTimeout(long_press_timeout);
    gesture_in_progress = false;
  }
  element.addEventListener("touchend", function(e7) {
    if (!gesture_in_progress)
      return;
    if (e7.touches.length !== 0 || e7.changedTouches.length !== 1) {
      end_gesture();
      return;
    }
    window.clearTimeout(long_press_timeout);
    guac_touchscreen.release(Guacamole.Mouse.State.Buttons.LEFT, e7);
    if (!finger_moved(e7)) {
      e7.preventDefault();
      if (!guac_touchscreen.currentState.left) {
        var touch = e7.changedTouches[0];
        guac_touchscreen.move(Guacamole.Position.fromClientPosition(element, touch.clientX, touch.clientY));
        guac_touchscreen.press(Guacamole.Mouse.State.Buttons.LEFT, e7);
        click_release_timeout = window.setTimeout(function() {
          guac_touchscreen.release(Guacamole.Mouse.State.Buttons.LEFT, e7);
          end_gesture();
        }, guac_touchscreen.clickTimingThreshold);
      }
    }
  }, false);
  element.addEventListener("touchstart", function(e7) {
    if (e7.touches.length !== 1) {
      end_gesture();
      return;
    }
    e7.preventDefault();
    begin_gesture(e7);
    window.clearTimeout(click_release_timeout);
    long_press_timeout = window.setTimeout(function() {
      var touch = e7.touches[0];
      guac_touchscreen.move(Guacamole.Position.fromClientPosition(element, touch.clientX, touch.clientY));
      guac_touchscreen.click(Guacamole.Mouse.State.Buttons.RIGHT, e7);
      end_gesture();
    }, guac_touchscreen.longPressThreshold);
  }, false);
  element.addEventListener("touchmove", function(e7) {
    if (!gesture_in_progress)
      return;
    if (finger_moved(e7))
      window.clearTimeout(long_press_timeout);
    if (e7.touches.length !== 1) {
      end_gesture();
      return;
    }
    if (guac_touchscreen.currentState.left) {
      e7.preventDefault();
      var touch = e7.touches[0];
      guac_touchscreen.move(Guacamole.Position.fromClientPosition(element, touch.clientX, touch.clientY), e7);
    }
  }, false);
};
var Guacamole = Guacamole || {};
var Guacamole = Guacamole || {};
Guacamole.Object = function guacamoleObject(client, index) {
  var guacObject = this;
  var bodyCallbacks = {};
  var dequeueBodyCallback = function dequeueBodyCallback2(name) {
    var callbacks = bodyCallbacks[name];
    if (!callbacks)
      return null;
    var callback = callbacks.shift();
    if (callbacks.length === 0)
      delete bodyCallbacks[name];
    return callback;
  };
  var enqueueBodyCallback = function enqueueBodyCallback2(name, callback) {
    var callbacks = bodyCallbacks[name];
    if (!callbacks) {
      callbacks = [];
      bodyCallbacks[name] = callbacks;
    }
    callbacks.push(callback);
  };
  this.index = index;
  this.onbody = function defaultBodyHandler(inputStream, mimetype, name) {
    var callback = dequeueBodyCallback(name);
    if (callback)
      callback(inputStream, mimetype);
  };
  this.onundefine = null;
  this.requestInputStream = function requestInputStream(name, bodyCallback) {
    if (bodyCallback)
      enqueueBodyCallback(name, bodyCallback);
    client.requestObjectInputStream(guacObject.index, name);
  };
  this.createOutputStream = function createOutputStream(mimetype, name) {
    return client.createObjectOutputStream(guacObject.index, mimetype, name);
  };
};
Guacamole.Object.ROOT_STREAM = "/";
Guacamole.Object.STREAM_INDEX_MIMETYPE = "application/vnd.glyptodon.guacamole.stream-index+json";
var Guacamole = Guacamole || {};
Guacamole.OnScreenKeyboard = function(layout) {
  var osk = this;
  var modifierKeysyms = {};
  var pressed = {};
  var scaledElements = [];
  var addClass = function addClass2(element, classname) {
    if (element.classList)
      element.classList.add(classname);
    else
      element.className += " " + classname;
  };
  var removeClass = function removeClass2(element, classname) {
    if (element.classList)
      element.classList.remove(classname);
    else {
      element.className = element.className.replace(
        /([^ ]+)[ ]*/g,
        function removeMatchingClasses(match, testClassname) {
          if (testClassname === classname)
            return "";
          return match;
        }
      );
    }
  };
  var ignoreMouse = 0;
  var ignorePendingMouseEvents = function ignorePendingMouseEvents2() {
    ignoreMouse = osk.touchMouseThreshold;
  };
  var ScaledElement = function ScaledElement2(element, width, height, scaleFont) {
    this.width = width;
    this.height = height;
    this.scale = function(pixels) {
      element.style.width = width * pixels + "px";
      element.style.height = height * pixels + "px";
      if (scaleFont) {
        element.style.lineHeight = height * pixels + "px";
        element.style.fontSize = pixels + "px";
      }
    };
  };
  var modifiersPressed = function modifiersPressed2(names) {
    for (var i5 = 0; i5 < names.length; i5++) {
      var name = names[i5];
      if (!(name in modifierKeysyms))
        return false;
    }
    return true;
  };
  var getActiveKey = function getActiveKey2(keyName) {
    var keys = osk.keys[keyName];
    if (!keys)
      return null;
    for (var i5 = keys.length - 1; i5 >= 0; i5--) {
      var candidate = keys[i5];
      if (modifiersPressed(candidate.requires))
        return candidate;
    }
    return null;
  };
  var press = function press2(keyName, keyElement) {
    if (!pressed[keyName]) {
      addClass(keyElement, "guac-keyboard-pressed");
      var key = getActiveKey(keyName);
      if (key.modifier) {
        var modifierClass = "guac-keyboard-modifier-" + getCSSName(key.modifier);
        var originalKeysym = modifierKeysyms[key.modifier];
        if (originalKeysym === void 0) {
          addClass(keyboard, modifierClass);
          modifierKeysyms[key.modifier] = key.keysym;
          if (key.keysym && osk.onkeydown)
            osk.onkeydown(key.keysym);
        } else {
          removeClass(keyboard, modifierClass);
          delete modifierKeysyms[key.modifier];
          if (originalKeysym && osk.onkeyup)
            osk.onkeyup(originalKeysym);
        }
      } else if (osk.onkeydown)
        osk.onkeydown(key.keysym);
      pressed[keyName] = true;
    }
  };
  var release = function release2(keyName, keyElement) {
    if (pressed[keyName]) {
      removeClass(keyElement, "guac-keyboard-pressed");
      var key = getActiveKey(keyName);
      if (!key.modifier && osk.onkeyup)
        osk.onkeyup(key.keysym);
      pressed[keyName] = false;
    }
  };
  var keyboard = document.createElement("div");
  keyboard.className = "guac-keyboard";
  keyboard.onselectstart = keyboard.onmousemove = keyboard.onmouseup = keyboard.onmousedown = function handleMouseEvents(e7) {
    if (ignoreMouse)
      ignoreMouse--;
    e7.stopPropagation();
    return false;
  };
  this.touchMouseThreshold = 3;
  this.onkeydown = null;
  this.onkeyup = null;
  this.layout = new Guacamole.OnScreenKeyboard.Layout(layout);
  this.getElement = function() {
    return keyboard;
  };
  this.resize = function(width) {
    var unit = Math.floor(width * 10 / osk.layout.width) / 10;
    for (var i5 = 0; i5 < scaledElements.length; i5++) {
      var scaledElement = scaledElements[i5];
      scaledElement.scale(unit);
    }
  };
  var asKeyArray = function asKeyArray2(name, object) {
    if (object instanceof Array) {
      var keys = [];
      for (var i5 = 0; i5 < object.length; i5++) {
        keys.push(new Guacamole.OnScreenKeyboard.Key(object[i5], name));
      }
      return keys;
    }
    if (typeof object === "number") {
      return [new Guacamole.OnScreenKeyboard.Key({
        name,
        keysym: object
      })];
    }
    if (typeof object === "string") {
      return [new Guacamole.OnScreenKeyboard.Key({
        name,
        title: object
      })];
    }
    return [new Guacamole.OnScreenKeyboard.Key(object, name)];
  };
  var getKeys = function getKeys2(keys) {
    var keyArrays = {};
    for (var name in layout.keys) {
      keyArrays[name] = asKeyArray(name, keys[name]);
    }
    return keyArrays;
  };
  this.keys = getKeys(layout.keys);
  var getCSSName = function getCSSName2(name) {
    var cssName = name.replace(/([a-z])([A-Z])/g, "$1-$2").replace(/[^A-Za-z0-9]+/g, "-").toLowerCase();
    return cssName;
  };
  var appendElements = function appendElements2(element, object, name) {
    var i5;
    var div = document.createElement("div");
    if (name)
      addClass(div, "guac-keyboard-" + getCSSName(name));
    if (object instanceof Array) {
      addClass(div, "guac-keyboard-group");
      for (i5 = 0; i5 < object.length; i5++)
        appendElements2(div, object[i5]);
    } else if (object instanceof Object) {
      addClass(div, "guac-keyboard-group");
      var names = Object.keys(object).sort();
      for (i5 = 0; i5 < names.length; i5++) {
        var name = names[i5];
        appendElements2(div, object[name], name);
      }
    } else if (typeof object === "number") {
      addClass(div, "guac-keyboard-gap");
      scaledElements.push(new ScaledElement(div, object, object));
    } else if (typeof object === "string") {
      var keyName = object;
      if (keyName.length === 1)
        keyName = "0x" + keyName.charCodeAt(0).toString(16);
      addClass(div, "guac-keyboard-key-container");
      var keyElement = document.createElement("div");
      keyElement.className = "guac-keyboard-key guac-keyboard-key-" + getCSSName(keyName);
      var keys = osk.keys[object];
      if (keys) {
        for (i5 = 0; i5 < keys.length; i5++) {
          var key = keys[i5];
          var capElement = document.createElement("div");
          capElement.className = "guac-keyboard-cap";
          capElement.textContent = key.title;
          for (var j2 = 0; j2 < key.requires.length; j2++) {
            var requirement = key.requires[j2];
            addClass(capElement, "guac-keyboard-requires-" + getCSSName(requirement));
            addClass(keyElement, "guac-keyboard-uses-" + getCSSName(requirement));
          }
          keyElement.appendChild(capElement);
        }
      }
      div.appendChild(keyElement);
      scaledElements.push(new ScaledElement(div, osk.layout.keyWidths[object] || 1, 1, true));
      var touchPress = function touchPress2(e7) {
        e7.preventDefault();
        ignoreMouse = osk.touchMouseThreshold;
        press(object, keyElement);
      };
      var touchRelease = function touchRelease2(e7) {
        e7.preventDefault();
        ignoreMouse = osk.touchMouseThreshold;
        release(object, keyElement);
      };
      var mousePress = function mousePress2(e7) {
        e7.preventDefault();
        if (ignoreMouse === 0)
          press(object, keyElement);
      };
      var mouseRelease = function mouseRelease2(e7) {
        e7.preventDefault();
        if (ignoreMouse === 0)
          release(object, keyElement);
      };
      keyElement.addEventListener("touchstart", touchPress, true);
      keyElement.addEventListener("touchend", touchRelease, true);
      keyElement.addEventListener("mousedown", mousePress, true);
      keyElement.addEventListener("mouseup", mouseRelease, true);
      keyElement.addEventListener("mouseout", mouseRelease, true);
    }
    element.appendChild(div);
  };
  appendElements(keyboard, layout.layout);
};
Guacamole.OnScreenKeyboard.Layout = function(template) {
  this.language = template.language;
  this.type = template.type;
  this.keys = template.keys;
  this.layout = template.layout;
  this.width = template.width;
  this.keyWidths = template.keyWidths || {};
};
Guacamole.OnScreenKeyboard.Key = function(template, name) {
  this.name = name || template.name;
  this.title = template.title || this.name;
  this.keysym = template.keysym || function deriveKeysym(title) {
    if (!title || title.length !== 1)
      return null;
    var charCode = title.charCodeAt(0);
    if (charCode >= 0 && charCode <= 255)
      return charCode;
    if (charCode >= 256 && charCode <= 1114111)
      return 16777216 | charCode;
    return null;
  }(this.title);
  this.modifier = template.modifier;
  this.requires = template.requires || [];
};
var Guacamole = Guacamole || {};
Guacamole.OutputStream = function(client, index) {
  var guac_stream = this;
  this.index = index;
  this.onack = null;
  this.sendBlob = function(data) {
    client.sendBlob(guac_stream.index, data);
  };
  this.sendEnd = function() {
    client.endStream(guac_stream.index);
  };
};
var Guacamole = Guacamole || {};
Guacamole.Parser = function() {
  var parser = this;
  var buffer = "";
  var element_buffer = [];
  var element_end = -1;
  var start_index = 0;
  this.receive = function(packet) {
    if (start_index > 4096 && element_end >= start_index) {
      buffer = buffer.substring(start_index);
      element_end -= start_index;
      start_index = 0;
    }
    buffer += packet;
    while (element_end < buffer.length) {
      if (element_end >= start_index) {
        var element = buffer.substring(start_index, element_end);
        var terminator = buffer.substring(element_end, element_end + 1);
        element_buffer.push(element);
        if (terminator == ";") {
          var opcode = element_buffer.shift();
          if (parser.oninstruction != null)
            parser.oninstruction(opcode, element_buffer);
          element_buffer.length = 0;
        } else if (terminator != ",")
          throw new Error("Illegal terminator.");
        start_index = element_end + 1;
      }
      var length_end = buffer.indexOf(".", start_index);
      if (length_end != -1) {
        var length = parseInt(buffer.substring(element_end + 1, length_end));
        if (isNaN(length))
          throw new Error("Non-numeric character in element length.");
        start_index = length_end + 1;
        element_end = start_index + length;
      } else {
        start_index = buffer.length;
        break;
      }
    }
  };
  this.oninstruction = null;
};
var Guacamole = Guacamole || {};
Guacamole.Position = function Position(template) {
  template = template || {};
  this.x = template.x || 0;
  this.y = template.y || 0;
  this.fromClientPosition = function fromClientPosition2(element, clientX, clientY) {
    this.x = clientX - element.offsetLeft;
    this.y = clientY - element.offsetTop;
    var parent = element.offsetParent;
    while (parent && !(parent === document.body)) {
      this.x -= parent.offsetLeft - parent.scrollLeft;
      this.y -= parent.offsetTop - parent.scrollTop;
      parent = parent.offsetParent;
    }
    if (parent) {
      var documentScrollLeft = document.body.scrollLeft || document.documentElement.scrollLeft;
      var documentScrollTop = document.body.scrollTop || document.documentElement.scrollTop;
      this.x -= parent.offsetLeft - documentScrollLeft;
      this.y -= parent.offsetTop - documentScrollTop;
    }
  };
};
Guacamole.Position.fromClientPosition = function fromClientPosition(element, clientX, clientY) {
  var position = new Guacamole.Position();
  position.fromClientPosition(element, clientX, clientY);
  return position;
};
var Guacamole = Guacamole || {};
Guacamole.RawAudioFormat = function RawAudioFormat(template) {
  this.bytesPerSample = template.bytesPerSample;
  this.channels = template.channels;
  this.rate = template.rate;
};
Guacamole.RawAudioFormat.parse = function parseFormat(mimetype) {
  var bytesPerSample;
  var rate = null;
  var channels = 1;
  if (mimetype.substring(0, 9) === "audio/L8;") {
    mimetype = mimetype.substring(9);
    bytesPerSample = 1;
  } else if (mimetype.substring(0, 10) === "audio/L16;") {
    mimetype = mimetype.substring(10);
    bytesPerSample = 2;
  } else
    return null;
  var parameters = mimetype.split(",");
  for (var i5 = 0; i5 < parameters.length; i5++) {
    var parameter = parameters[i5];
    var equals = parameter.indexOf("=");
    if (equals === -1)
      return null;
    var name = parameter.substring(0, equals);
    var value = parameter.substring(equals + 1);
    switch (name) {
      case "channels":
        channels = parseInt(value);
        break;
      case "rate":
        rate = parseInt(value);
        break;
      default:
        return null;
    }
  }
  ;
  if (rate === null)
    return null;
  return new Guacamole.RawAudioFormat({
    bytesPerSample,
    channels,
    rate
  });
};
var Guacamole = Guacamole || {};
Guacamole.SessionRecording = function SessionRecording(source) {
  var recording = this;
  var recordingBlob;
  var tunnel = null;
  var BLOCK_SIZE = 262144;
  var KEYFRAME_CHAR_INTERVAL = 16384;
  var KEYFRAME_TIME_INTERVAL = 5e3;
  var frames = [];
  var lastKeyframe = 0;
  var playbackTunnel = new Guacamole.SessionRecording._PlaybackTunnel();
  var playbackClient = new Guacamole.Client(playbackTunnel);
  var currentFrame = -1;
  var startVideoTimestamp = null;
  var startRealTimestamp = null;
  var activeSeek = null;
  var frameStart = 0;
  var frameEnd = 0;
  var aborted = false;
  var seekCallback = null;
  var parseBlob = function parseBlob2(blob, instructionCallback, completionCallback) {
    if (aborted && blob === recordingBlob)
      return;
    var parser = new Guacamole.Parser();
    parser.oninstruction = instructionCallback;
    var offset = 0;
    var reader = new FileReader();
    var readNextBlock = function readNextBlock2() {
      if (aborted && blob === recordingBlob)
        return;
      if (reader.readyState === 2) {
        try {
          parser.receive(reader.result);
        } catch (parseError) {
          if (recording.onerror) {
            recording.onerror(parseError.message);
          }
          return;
        }
      }
      if (offset >= blob.size) {
        if (completionCallback)
          completionCallback();
      } else {
        var block = blob.slice(offset, offset + BLOCK_SIZE);
        offset += block.size;
        reader.readAsText(block);
      }
    };
    reader.onload = readNextBlock;
    readNextBlock();
  };
  var getElementSize = function getElementSize2(value) {
    var valueLength = value.length;
    var protocolSize = valueLength + 3;
    while (valueLength >= 10) {
      protocolSize++;
      valueLength = Math.floor(valueLength / 10);
    }
    return protocolSize;
  };
  playbackClient.connect();
  playbackClient.getDisplay().showCursor(false);
  var loadInstruction = function loadInstruction2(opcode, args) {
    frameEnd += getElementSize(opcode);
    for (var i5 = 0; i5 < args.length; i5++)
      frameEnd += getElementSize(args[i5]);
    if (opcode === "sync") {
      var timestamp = parseInt(args[0]);
      var frame = new Guacamole.SessionRecording._Frame(timestamp, frameStart, frameEnd);
      frames.push(frame);
      frameStart = frameEnd;
      if (frames.length === 1 || frameEnd - frames[lastKeyframe].start >= KEYFRAME_CHAR_INTERVAL && timestamp - frames[lastKeyframe].timestamp >= KEYFRAME_TIME_INTERVAL) {
        frame.keyframe = true;
        lastKeyframe = frames.length - 1;
      }
      if (recording.onprogress)
        recording.onprogress(recording.getDuration(), frameEnd);
    }
  };
  var notifyLoaded = function notifyLoaded2() {
    if (recording.onload)
      recording.onload();
  };
  if (source instanceof Blob)
    parseBlob(recordingBlob, loadInstruction, notifyLoaded);
  else {
    tunnel = source;
    recordingBlob = new Blob();
    var errorEncountered = false;
    var instructionBuffer = "";
    tunnel.oninstruction = function handleInstruction(opcode, args) {
      instructionBuffer += opcode.length + "." + opcode;
      args.forEach(function appendArg(arg) {
        instructionBuffer += "," + arg.length + "." + arg;
      });
      instructionBuffer += ";";
      if (instructionBuffer.length >= BLOCK_SIZE) {
        recordingBlob = new Blob([recordingBlob, instructionBuffer]);
        instructionBuffer = "";
      }
      loadInstruction(opcode, args);
    };
    tunnel.onerror = function tunnelError(status) {
      errorEncountered = true;
      if (recording.onerror)
        recording.onerror(status.message);
    };
    tunnel.onstatechange = function tunnelStateChanged(state) {
      if (state === Guacamole.Tunnel.State.CLOSED) {
        if (instructionBuffer.length) {
          recordingBlob = new Blob([recordingBlob, instructionBuffer]);
          instructionBuffer = "";
        }
        if (!errorEncountered)
          notifyLoaded();
      }
    };
  }
  var toRelativeTimestamp = function toRelativeTimestamp2(timestamp) {
    if (frames.length === 0)
      return 0;
    return timestamp - frames[0].timestamp;
  };
  var findFrame = function findFrame2(minIndex, maxIndex, timestamp) {
    if (minIndex === maxIndex)
      return minIndex;
    var midIndex = Math.floor((minIndex + maxIndex) / 2);
    var midTimestamp = toRelativeTimestamp(frames[midIndex].timestamp);
    if (timestamp < midTimestamp && midIndex > minIndex)
      return findFrame2(minIndex, midIndex - 1, timestamp);
    if (timestamp > midTimestamp && midIndex < maxIndex)
      return findFrame2(midIndex + 1, maxIndex, timestamp);
    return midIndex;
  };
  var replayFrame = function replayFrame2(index, callback) {
    var frame = frames[index];
    parseBlob(recordingBlob.slice(frame.start, frame.end), function handleInstruction(opcode, args) {
      playbackTunnel.receiveInstruction(opcode, args);
    }, function replayCompleted() {
      if (frame.keyframe && !frame.clientState) {
        playbackClient.exportState(function storeClientState(state) {
          frame.clientState = new Blob([JSON.stringify(state)]);
        });
      }
      currentFrame = index;
      if (callback)
        callback();
    });
  };
  var seekToFrame = function seekToFrame2(index, callback, nextRealTimestamp) {
    abortSeek();
    var thisSeek = activeSeek = {
      aborted: false
    };
    var startIndex = index;
    var continueReplay = function continueReplay2() {
      if (recording.onseek && currentFrame > startIndex) {
        recording.onseek(
          toRelativeTimestamp(frames[currentFrame].timestamp),
          currentFrame - startIndex,
          index - startIndex
        );
      }
      if (thisSeek.aborted)
        return;
      if (currentFrame < index)
        replayFrame(currentFrame + 1, continueReplay2);
      else
        callback();
    };
    var continueAfterRequiredDelay = function continueAfterRequiredDelay2() {
      var delay = nextRealTimestamp ? Math.max(nextRealTimestamp - (/* @__PURE__ */ new Date()).getTime(), 0) : 0;
      if (delay)
        window.setTimeout(continueReplay, delay);
      else
        continueReplay();
    };
    for (; startIndex >= 0; startIndex--) {
      var frame = frames[startIndex];
      if (startIndex === currentFrame)
        break;
      if (frame.clientState) {
        frame.clientState.text().then(function textReady(text) {
          playbackClient.importState(JSON.parse(text));
          currentFrame = startIndex;
          continueAfterRequiredDelay();
        });
        return;
      }
    }
    continueAfterRequiredDelay();
  };
  var abortSeek = function abortSeek2() {
    if (activeSeek) {
      activeSeek.aborted = true;
      activeSeek = null;
    }
  };
  var continuePlayback = function continuePlayback2() {
    if (currentFrame + 1 < frames.length) {
      var next = frames[currentFrame + 1];
      var nextRealTimestamp = next.timestamp - startVideoTimestamp + startRealTimestamp;
      seekToFrame(currentFrame + 1, function frameDelayElapsed() {
        continuePlayback2();
      }, nextRealTimestamp);
    } else
      recording.pause();
  };
  this.onload = null;
  this.onerror = null;
  this.onabort = null;
  this.onprogress = null;
  this.onplay = null;
  this.onpause = null;
  this.onseek = null;
  this.connect = function connect(data) {
    if (tunnel)
      tunnel.connect(data);
  };
  this.disconnect = function disconnect() {
    if (tunnel)
      tunnel.disconnect();
  };
  this.abort = function abort() {
    if (!aborted) {
      aborted = true;
      if (recording.onabort)
        recording.onabort();
      if (tunnel)
        tunnel.disconnect();
    }
  };
  this.getDisplay = function getDisplay() {
    return playbackClient.getDisplay();
  };
  this.isPlaying = function isPlaying() {
    return !!startVideoTimestamp;
  };
  this.getPosition = function getPosition() {
    if (currentFrame === -1)
      return 0;
    return toRelativeTimestamp(frames[currentFrame].timestamp);
  };
  this.getDuration = function getDuration() {
    if (frames.length === 0)
      return 0;
    return toRelativeTimestamp(frames[frames.length - 1].timestamp);
  };
  this.play = function play() {
    if (!recording.isPlaying() && currentFrame + 1 < frames.length) {
      if (recording.onplay)
        recording.onplay();
      var next = frames[currentFrame + 1];
      startVideoTimestamp = next.timestamp;
      startRealTimestamp = (/* @__PURE__ */ new Date()).getTime();
      continuePlayback();
    }
  };
  this.seek = function seek(position, callback) {
    if (frames.length === 0)
      return;
    recording.cancel();
    var originallyPlaying = recording.isPlaying();
    recording.pause();
    seekCallback = function restorePlaybackState() {
      seekCallback = null;
      if (originallyPlaying) {
        recording.play();
        originallyPlaying = null;
      }
      if (callback)
        callback();
    };
    seekToFrame(findFrame(0, frames.length - 1, position), seekCallback);
  };
  this.cancel = function cancel() {
    if (seekCallback) {
      abortSeek();
      seekCallback();
    }
  };
  this.pause = function pause() {
    abortSeek();
    if (recording.isPlaying()) {
      if (recording.onpause)
        recording.onpause();
      startVideoTimestamp = null;
      startRealTimestamp = null;
    }
  };
};
Guacamole.SessionRecording._Frame = function _Frame(timestamp, start, end) {
  this.keyframe = false;
  this.timestamp = timestamp;
  this.start = start;
  this.end = end;
  this.clientState = null;
};
Guacamole.SessionRecording._PlaybackTunnel = function _PlaybackTunnel() {
  var tunnel = this;
  this.connect = function connect(data) {
  };
  this.sendMessage = function sendMessage(elements) {
  };
  this.disconnect = function disconnect() {
  };
  this.receiveInstruction = function receiveInstruction(opcode, args) {
    if (tunnel.oninstruction)
      tunnel.oninstruction(opcode, args);
  };
};
var Guacamole = Guacamole || {};
Guacamole.Status = function(code, message) {
  var guac_status = this;
  this.code = code;
  this.message = message;
  this.isError = function() {
    return guac_status.code < 0 || guac_status.code > 255;
  };
};
Guacamole.Status.Code = {
  /**
   * The operation succeeded.
   *
   * @type {!number}
   */
  "SUCCESS": 0,
  /**
   * The requested operation is unsupported.
   *
   * @type {!number}
   */
  "UNSUPPORTED": 256,
  /**
   * The operation could not be performed due to an internal failure.
   *
   * @type {!number}
   */
  "SERVER_ERROR": 512,
  /**
   * The operation could not be performed as the server is busy.
   *
   * @type {!number}
   */
  "SERVER_BUSY": 513,
  /**
   * The operation could not be performed because the upstream server is not
   * responding.
   *
   * @type {!number}
   */
  "UPSTREAM_TIMEOUT": 514,
  /**
   * The operation was unsuccessful due to an error or otherwise unexpected
   * condition of the upstream server.
   *
   * @type {!number}
   */
  "UPSTREAM_ERROR": 515,
  /**
   * The operation could not be performed as the requested resource does not
   * exist.
   *
   * @type {!number}
   */
  "RESOURCE_NOT_FOUND": 516,
  /**
   * The operation could not be performed as the requested resource is
   * already in use.
   *
   * @type {!number}
   */
  "RESOURCE_CONFLICT": 517,
  /**
   * The operation could not be performed as the requested resource is now
   * closed.
   *
   * @type {!number}
   */
  "RESOURCE_CLOSED": 518,
  /**
   * The operation could not be performed because the upstream server does
   * not appear to exist.
   *
   * @type {!number}
   */
  "UPSTREAM_NOT_FOUND": 519,
  /**
   * The operation could not be performed because the upstream server is not
   * available to service the request.
   *
   * @type {!number}
   */
  "UPSTREAM_UNAVAILABLE": 520,
  /**
   * The session within the upstream server has ended because it conflicted
   * with another session.
   *
   * @type {!number}
   */
  "SESSION_CONFLICT": 521,
  /**
   * The session within the upstream server has ended because it appeared to
   * be inactive.
   *
   * @type {!number}
   */
  "SESSION_TIMEOUT": 522,
  /**
   * The session within the upstream server has been forcibly terminated.
   *
   * @type {!number}
   */
  "SESSION_CLOSED": 523,
  /**
   * The operation could not be performed because bad parameters were given.
   *
   * @type {!number}
   */
  "CLIENT_BAD_REQUEST": 768,
  /**
   * Permission was denied to perform the operation, as the user is not yet
   * authorized (not yet logged in, for example).
   *
   * @type {!number}
   */
  "CLIENT_UNAUTHORIZED": 769,
  /**
   * Permission was denied to perform the operation, and this permission will
   * not be granted even if the user is authorized.
   *
   * @type {!number}
   */
  "CLIENT_FORBIDDEN": 771,
  /**
   * The client took too long to respond.
   *
   * @type {!number}
   */
  "CLIENT_TIMEOUT": 776,
  /**
   * The client sent too much data.
   *
   * @type {!number}
   */
  "CLIENT_OVERRUN": 781,
  /**
   * The client sent data of an unsupported or unexpected type.
   *
   * @type {!number}
   */
  "CLIENT_BAD_TYPE": 783,
  /**
   * The operation failed because the current client is already using too
   * many resources.
   *
   * @type {!number}
   */
  "CLIENT_TOO_MANY": 797
};
Guacamole.Status.Code.fromHTTPCode = function fromHTTPCode(status) {
  switch (status) {
    case 400:
      return Guacamole.Status.Code.CLIENT_BAD_REQUEST;
    case 403:
      return Guacamole.Status.Code.CLIENT_FORBIDDEN;
    case 404:
      return Guacamole.Status.Code.RESOURCE_NOT_FOUND;
    case 429:
      return Guacamole.Status.Code.CLIENT_TOO_MANY;
    case 503:
      return Guacamole.Status.Code.SERVER_BUSY;
  }
  return Guacamole.Status.Code.SERVER_ERROR;
};
Guacamole.Status.Code.fromWebSocketCode = function fromWebSocketCode(code) {
  switch (code) {
    case 1e3:
      return Guacamole.Status.Code.SUCCESS;
    case 1006:
    case 1015:
      return Guacamole.Status.Code.UPSTREAM_NOT_FOUND;
    case 1001:
    case 1012:
    case 1013:
    case 1014:
      return Guacamole.Status.Code.UPSTREAM_UNAVAILABLE;
  }
  return Guacamole.Status.Code.SERVER_ERROR;
};
var Guacamole = Guacamole || {};
Guacamole.StringReader = function(stream) {
  var guac_reader = this;
  var utf8Parser = new Guacamole.UTF8Parser();
  var array_reader = new Guacamole.ArrayBufferReader(stream);
  array_reader.ondata = function(buffer) {
    var text = utf8Parser.decode(buffer);
    if (guac_reader.ontext)
      guac_reader.ontext(text);
  };
  array_reader.onend = function() {
    if (guac_reader.onend)
      guac_reader.onend();
  };
  this.ontext = null;
  this.onend = null;
};
var Guacamole = Guacamole || {};
Guacamole.StringWriter = function(stream) {
  var guac_writer = this;
  var array_writer = new Guacamole.ArrayBufferWriter(stream);
  var buffer = new Uint8Array(8192);
  var length = 0;
  array_writer.onack = function(status) {
    if (guac_writer.onack)
      guac_writer.onack(status);
  };
  function __expand(bytes) {
    if (length + bytes >= buffer.length) {
      var new_buffer = new Uint8Array((length + bytes) * 2);
      new_buffer.set(buffer);
      buffer = new_buffer;
    }
    length += bytes;
  }
  function __append_utf8(codepoint) {
    var mask;
    var bytes;
    if (codepoint <= 127) {
      mask = 0;
      bytes = 1;
    } else if (codepoint <= 2047) {
      mask = 192;
      bytes = 2;
    } else if (codepoint <= 65535) {
      mask = 224;
      bytes = 3;
    } else if (codepoint <= 2097151) {
      mask = 240;
      bytes = 4;
    } else {
      __append_utf8(65533);
      return;
    }
    __expand(bytes);
    var offset = length - 1;
    for (var i5 = 1; i5 < bytes; i5++) {
      buffer[offset--] = 128 | codepoint & 63;
      codepoint >>= 6;
    }
    buffer[offset] = mask | codepoint;
  }
  function __encode_utf8(text) {
    for (var i5 = 0; i5 < text.length; i5++) {
      var codepoint = text.charCodeAt(i5);
      __append_utf8(codepoint);
    }
    if (length > 0) {
      var out_buffer = buffer.subarray(0, length);
      length = 0;
      return out_buffer;
    }
  }
  this.sendText = function(text) {
    if (text.length)
      array_writer.sendData(__encode_utf8(text));
  };
  this.sendEnd = function() {
    array_writer.sendEnd();
  };
  this.onack = null;
};
var Guacamole = Guacamole || {};
Guacamole.Touch = function Touch(element) {
  Guacamole.Event.Target.call(this);
  var guacTouch = this;
  var DEFAULT_CONTACT_RADIUS = Math.floor(16 * window.devicePixelRatio);
  this.touches = {};
  this.activeTouches = 0;
  element.addEventListener("touchstart", function touchstart(e7) {
    for (var i5 = 0; i5 < e7.changedTouches.length; i5++) {
      var changedTouch = e7.changedTouches[i5];
      var identifier = changedTouch.identifier;
      if (guacTouch.touches[identifier])
        continue;
      var touch = guacTouch.touches[identifier] = new Guacamole.Touch.State({
        id: identifier,
        radiusX: changedTouch.radiusX || DEFAULT_CONTACT_RADIUS,
        radiusY: changedTouch.radiusY || DEFAULT_CONTACT_RADIUS,
        angle: changedTouch.angle || 0,
        force: changedTouch.force || 1
        /* Within JavaScript changedTouch events, a force of 0.0 indicates the device does not support reporting changedTouch force */
      });
      guacTouch.activeTouches++;
      touch.fromClientPosition(element, changedTouch.clientX, changedTouch.clientY);
      guacTouch.dispatch(new Guacamole.Touch.Event("touchmove", e7, touch));
    }
  }, false);
  element.addEventListener("touchmove", function touchstart(e7) {
    for (var i5 = 0; i5 < e7.changedTouches.length; i5++) {
      var changedTouch = e7.changedTouches[i5];
      var identifier = changedTouch.identifier;
      var touch = guacTouch.touches[identifier];
      if (!touch)
        continue;
      if (changedTouch.force)
        touch.force = changedTouch.force;
      touch.angle = changedTouch.angle || 0;
      touch.radiusX = changedTouch.radiusX || DEFAULT_CONTACT_RADIUS;
      touch.radiusY = changedTouch.radiusY || DEFAULT_CONTACT_RADIUS;
      touch.fromClientPosition(element, changedTouch.clientX, changedTouch.clientY);
      guacTouch.dispatch(new Guacamole.Touch.Event("touchmove", e7, touch));
    }
  }, false);
  element.addEventListener("touchend", function touchstart(e7) {
    for (var i5 = 0; i5 < e7.changedTouches.length; i5++) {
      var changedTouch = e7.changedTouches[i5];
      var identifier = changedTouch.identifier;
      var touch = guacTouch.touches[identifier];
      if (!touch)
        continue;
      delete guacTouch.touches[identifier];
      guacTouch.activeTouches--;
      touch.force = 0;
      touch.fromClientPosition(element, changedTouch.clientX, changedTouch.clientY);
      guacTouch.dispatch(new Guacamole.Touch.Event("touchend", e7, touch));
    }
  }, false);
};
Guacamole.Touch.State = function State2(template) {
  template = template || {};
  Guacamole.Position.call(this, template);
  this.id = template.id || 0;
  this.radiusX = template.radiusX || 0;
  this.radiusY = template.radiusY || 0;
  this.angle = template.angle || 0;
  this.force = template.force || 1;
};
Guacamole.Touch.Event = function TouchEvent(type, event, state) {
  Guacamole.Event.DOMEvent.call(this, type, [event]);
  this.state = state;
};
var Guacamole = Guacamole || {};
Guacamole.Tunnel = function() {
  this.connect = function(data) {
  };
  this.disconnect = function() {
  };
  this.sendMessage = function(elements) {
  };
  this.setState = function(state) {
    if (state !== this.state) {
      this.state = state;
      if (this.onstatechange)
        this.onstatechange(state);
    }
  };
  this.setUUID = function setUUID(uuid) {
    this.uuid = uuid;
    if (this.onuuid)
      this.onuuid(uuid);
  };
  this.isConnected = function isConnected() {
    return this.state === Guacamole.Tunnel.State.OPEN || this.state === Guacamole.Tunnel.State.UNSTABLE;
  };
  this.state = Guacamole.Tunnel.State.CLOSED;
  this.receiveTimeout = 15e3;
  this.unstableThreshold = 1500;
  this.uuid = null;
  this.onuuid = null;
  this.onerror = null;
  this.onstatechange = null;
  this.oninstruction = null;
};
Guacamole.Tunnel.INTERNAL_DATA_OPCODE = "";
Guacamole.Tunnel.State = {
  /**
   * A connection is in pending. It is not yet known whether connection was
   * successful.
   * 
   * @type {!number}
   */
  "CONNECTING": 0,
  /**
   * Connection was successful, and data is being received.
   * 
   * @type {!number}
   */
  "OPEN": 1,
  /**
   * The connection is closed. Connection may not have been successful, the
   * tunnel may have been explicitly closed by either side, or an error may
   * have occurred.
   * 
   * @type {!number}
   */
  "CLOSED": 2,
  /**
   * The connection is open, but communication through the tunnel appears to
   * be disrupted, and the connection may close as a result.
   *
   * @type {!number}
   */
  "UNSTABLE": 3
};
Guacamole.HTTPTunnel = function(tunnelURL, crossDomain, extraTunnelHeaders) {
  var tunnel = this;
  var TUNNEL_CONNECT = tunnelURL + "?connect";
  var TUNNEL_READ = tunnelURL + "?read:";
  var TUNNEL_WRITE = tunnelURL + "?write:";
  var POLLING_ENABLED = 1;
  var POLLING_DISABLED = 0;
  var pollingMode = POLLING_ENABLED;
  var sendingMessages = false;
  var outputMessageBuffer = "";
  var withCredentials = !!crossDomain;
  var receive_timeout = null;
  var unstableTimeout = null;
  var pingInterval = null;
  var PING_FREQUENCY = 500;
  var extraHeaders = extraTunnelHeaders || {};
  var TUNNEL_TOKEN_HEADER = "Guacamole-Tunnel-Token";
  var tunnelSessionToken = null;
  function addExtraHeaders(request, headers) {
    for (var name in headers) {
      request.setRequestHeader(name, headers[name]);
    }
  }
  var resetTimers = function resetTimers2() {
    window.clearTimeout(receive_timeout);
    window.clearTimeout(unstableTimeout);
    if (tunnel.state === Guacamole.Tunnel.State.UNSTABLE)
      tunnel.setState(Guacamole.Tunnel.State.OPEN);
    receive_timeout = window.setTimeout(function() {
      close_tunnel(new Guacamole.Status(Guacamole.Status.Code.UPSTREAM_TIMEOUT, "Server timeout."));
    }, tunnel.receiveTimeout);
    unstableTimeout = window.setTimeout(function() {
      tunnel.setState(Guacamole.Tunnel.State.UNSTABLE);
    }, tunnel.unstableThreshold);
  };
  function close_tunnel(status) {
    window.clearTimeout(receive_timeout);
    window.clearTimeout(unstableTimeout);
    window.clearInterval(pingInterval);
    if (tunnel.state === Guacamole.Tunnel.State.CLOSED)
      return;
    if (status.code !== Guacamole.Status.Code.SUCCESS && tunnel.onerror) {
      if (tunnel.state === Guacamole.Tunnel.State.CONNECTING || status.code !== Guacamole.Status.Code.RESOURCE_NOT_FOUND)
        tunnel.onerror(status);
    }
    sendingMessages = false;
    tunnel.setState(Guacamole.Tunnel.State.CLOSED);
  }
  this.sendMessage = function() {
    if (!tunnel.isConnected())
      return;
    if (arguments.length === 0)
      return;
    function getElement(value) {
      var string = new String(value);
      return string.length + "." + string;
    }
    var message = getElement(arguments[0]);
    for (var i5 = 1; i5 < arguments.length; i5++)
      message += "," + getElement(arguments[i5]);
    message += ";";
    outputMessageBuffer += message;
    if (!sendingMessages)
      sendPendingMessages();
  };
  function sendPendingMessages() {
    if (!tunnel.isConnected())
      return;
    if (outputMessageBuffer.length > 0) {
      sendingMessages = true;
      var message_xmlhttprequest = new XMLHttpRequest();
      message_xmlhttprequest.open("POST", TUNNEL_WRITE + tunnel.uuid);
      message_xmlhttprequest.withCredentials = withCredentials;
      addExtraHeaders(message_xmlhttprequest, extraHeaders);
      message_xmlhttprequest.setRequestHeader("Content-type", "application/octet-stream");
      message_xmlhttprequest.setRequestHeader(TUNNEL_TOKEN_HEADER, tunnelSessionToken);
      message_xmlhttprequest.onreadystatechange = function() {
        if (message_xmlhttprequest.readyState === 4) {
          resetTimers();
          if (message_xmlhttprequest.status !== 200)
            handleHTTPTunnelError(message_xmlhttprequest);
          else
            sendPendingMessages();
        }
      };
      message_xmlhttprequest.send(outputMessageBuffer);
      outputMessageBuffer = "";
    } else
      sendingMessages = false;
  }
  function handleHTTPTunnelError(xmlhttprequest) {
    var code = parseInt(xmlhttprequest.getResponseHeader("Guacamole-Status-Code"));
    if (code) {
      var message = xmlhttprequest.getResponseHeader("Guacamole-Error-Message");
      close_tunnel(new Guacamole.Status(code, message));
    } else if (xmlhttprequest.status)
      close_tunnel(new Guacamole.Status(
        Guacamole.Status.Code.fromHTTPCode(xmlhttprequest.status),
        xmlhttprequest.statusText
      ));
    else
      close_tunnel(new Guacamole.Status(Guacamole.Status.Code.UPSTREAM_NOT_FOUND));
  }
  function handleResponse(xmlhttprequest) {
    var interval = null;
    var nextRequest = null;
    var dataUpdateEvents = 0;
    var elementEnd = -1;
    var startIndex = 0;
    var elements = new Array();
    function parseResponse() {
      if (!tunnel.isConnected()) {
        if (interval !== null)
          clearInterval(interval);
        return;
      }
      if (xmlhttprequest.readyState < 2)
        return;
      var status;
      try {
        status = xmlhttprequest.status;
      } catch (e7) {
        status = 200;
      }
      if (!nextRequest && status === 200)
        nextRequest = makeRequest();
      if (xmlhttprequest.readyState === 3 || xmlhttprequest.readyState === 4) {
        resetTimers();
        if (pollingMode === POLLING_ENABLED) {
          if (xmlhttprequest.readyState === 3 && !interval)
            interval = setInterval(parseResponse, 30);
          else if (xmlhttprequest.readyState === 4 && interval)
            clearInterval(interval);
        }
        if (xmlhttprequest.status === 0) {
          tunnel.disconnect();
          return;
        } else if (xmlhttprequest.status !== 200) {
          handleHTTPTunnelError(xmlhttprequest);
          return;
        }
        var current;
        try {
          current = xmlhttprequest.responseText;
        } catch (e7) {
          return;
        }
        while (elementEnd < current.length) {
          if (elementEnd >= startIndex) {
            var element = current.substring(startIndex, elementEnd);
            var terminator = current.substring(elementEnd, elementEnd + 1);
            elements.push(element);
            if (terminator === ";") {
              var opcode = elements.shift();
              if (tunnel.oninstruction)
                tunnel.oninstruction(opcode, elements);
              elements.length = 0;
            }
            startIndex = elementEnd + 1;
          }
          var lengthEnd = current.indexOf(".", startIndex);
          if (lengthEnd !== -1) {
            var length = parseInt(current.substring(elementEnd + 1, lengthEnd));
            if (length === 0) {
              if (interval)
                clearInterval(interval);
              xmlhttprequest.onreadystatechange = null;
              xmlhttprequest.abort();
              if (nextRequest)
                handleResponse(nextRequest);
              break;
            }
            startIndex = lengthEnd + 1;
            elementEnd = startIndex + length;
          } else {
            startIndex = current.length;
            break;
          }
        }
      }
    }
    if (pollingMode === POLLING_ENABLED) {
      xmlhttprequest.onreadystatechange = function() {
        if (xmlhttprequest.readyState === 3) {
          dataUpdateEvents++;
          if (dataUpdateEvents >= 2) {
            pollingMode = POLLING_DISABLED;
            xmlhttprequest.onreadystatechange = parseResponse;
          }
        }
        parseResponse();
      };
    } else
      xmlhttprequest.onreadystatechange = parseResponse;
    parseResponse();
  }
  var request_id = 0;
  function makeRequest() {
    var xmlhttprequest = new XMLHttpRequest();
    xmlhttprequest.open("GET", TUNNEL_READ + tunnel.uuid + ":" + request_id++);
    xmlhttprequest.setRequestHeader(TUNNEL_TOKEN_HEADER, tunnelSessionToken);
    xmlhttprequest.withCredentials = withCredentials;
    addExtraHeaders(xmlhttprequest, extraHeaders);
    xmlhttprequest.send(null);
    return xmlhttprequest;
  }
  this.connect = function(data) {
    resetTimers();
    tunnel.setState(Guacamole.Tunnel.State.CONNECTING);
    var connect_xmlhttprequest = new XMLHttpRequest();
    connect_xmlhttprequest.onreadystatechange = function() {
      if (connect_xmlhttprequest.readyState !== 4)
        return;
      if (connect_xmlhttprequest.status !== 200) {
        handleHTTPTunnelError(connect_xmlhttprequest);
        return;
      }
      resetTimers();
      tunnel.setUUID(connect_xmlhttprequest.responseText);
      tunnelSessionToken = connect_xmlhttprequest.getResponseHeader(TUNNEL_TOKEN_HEADER);
      if (!tunnelSessionToken) {
        close_tunnel(new Guacamole.Status(Guacamole.Status.Code.UPSTREAM_NOT_FOUND));
        return;
      }
      tunnel.setState(Guacamole.Tunnel.State.OPEN);
      pingInterval = setInterval(function sendPing() {
        tunnel.sendMessage("nop");
      }, PING_FREQUENCY);
      handleResponse(makeRequest());
    };
    connect_xmlhttprequest.open("POST", TUNNEL_CONNECT, true);
    connect_xmlhttprequest.withCredentials = withCredentials;
    addExtraHeaders(connect_xmlhttprequest, extraHeaders);
    connect_xmlhttprequest.setRequestHeader("Content-type", "application/x-www-form-urlencoded; charset=UTF-8");
    connect_xmlhttprequest.send(data);
  };
  this.disconnect = function() {
    close_tunnel(new Guacamole.Status(Guacamole.Status.Code.SUCCESS, "Manually closed."));
  };
};
Guacamole.HTTPTunnel.prototype = new Guacamole.Tunnel();
Guacamole.WebSocketTunnel = function(tunnelURL) {
  var tunnel = this;
  var socket = null;
  var receive_timeout = null;
  var unstableTimeout = null;
  var pingTimeout = null;
  var ws_protocol = {
    "http:": "ws:",
    "https:": "wss:"
  };
  var PING_FREQUENCY = 500;
  var lastSentPing = 0;
  if (tunnelURL.substring(0, 3) !== "ws:" && tunnelURL.substring(0, 4) !== "wss:") {
    var protocol = ws_protocol[window.location.protocol];
    if (tunnelURL.substring(0, 1) === "/")
      tunnelURL = protocol + "//" + window.location.host + tunnelURL;
    else {
      var slash = window.location.pathname.lastIndexOf("/");
      var path = window.location.pathname.substring(0, slash + 1);
      tunnelURL = protocol + "//" + window.location.host + path + tunnelURL;
    }
  }
  var sendPing = function sendPing2() {
    var currentTime = (/* @__PURE__ */ new Date()).getTime();
    tunnel.sendMessage(Guacamole.Tunnel.INTERNAL_DATA_OPCODE, "ping", currentTime);
    lastSentPing = currentTime;
  };
  var resetTimers = function resetTimers2() {
    window.clearTimeout(receive_timeout);
    window.clearTimeout(unstableTimeout);
    window.clearTimeout(pingTimeout);
    if (tunnel.state === Guacamole.Tunnel.State.UNSTABLE)
      tunnel.setState(Guacamole.Tunnel.State.OPEN);
    receive_timeout = window.setTimeout(function() {
      close_tunnel(new Guacamole.Status(Guacamole.Status.Code.UPSTREAM_TIMEOUT, "Server timeout."));
    }, tunnel.receiveTimeout);
    unstableTimeout = window.setTimeout(function() {
      tunnel.setState(Guacamole.Tunnel.State.UNSTABLE);
    }, tunnel.unstableThreshold);
    var currentTime = (/* @__PURE__ */ new Date()).getTime();
    var pingDelay = Math.max(lastSentPing + PING_FREQUENCY - currentTime, 0);
    if (pingDelay > 0)
      pingTimeout = window.setTimeout(sendPing, pingDelay);
    else
      sendPing();
  };
  function close_tunnel(status) {
    window.clearTimeout(receive_timeout);
    window.clearTimeout(unstableTimeout);
    window.clearTimeout(pingTimeout);
    if (tunnel.state === Guacamole.Tunnel.State.CLOSED)
      return;
    if (status.code !== Guacamole.Status.Code.SUCCESS && tunnel.onerror)
      tunnel.onerror(status);
    tunnel.setState(Guacamole.Tunnel.State.CLOSED);
    socket.close();
  }
  this.sendMessage = function(elements) {
    if (!tunnel.isConnected())
      return;
    if (arguments.length === 0)
      return;
    function getElement(value) {
      var string = new String(value);
      return string.length + "." + string;
    }
    var message = getElement(arguments[0]);
    for (var i5 = 1; i5 < arguments.length; i5++)
      message += "," + getElement(arguments[i5]);
    message += ";";
    socket.send(message);
  };
  this.connect = function(data) {
    resetTimers();
    tunnel.setState(Guacamole.Tunnel.State.CONNECTING);
    socket = new WebSocket(tunnelURL + "?" + data, "guacamole");
    socket.onopen = function(event) {
      resetTimers();
    };
    socket.onclose = function(event) {
      if (event.reason)
        close_tunnel(new Guacamole.Status(parseInt(event.reason), event.reason));
      else if (event.code)
        close_tunnel(new Guacamole.Status(Guacamole.Status.Code.fromWebSocketCode(event.code)));
      else
        close_tunnel(new Guacamole.Status(Guacamole.Status.Code.UPSTREAM_NOT_FOUND));
    };
    socket.onmessage = function(event) {
      resetTimers();
      var message = event.data;
      var startIndex = 0;
      var elementEnd;
      var elements = [];
      do {
        var lengthEnd = message.indexOf(".", startIndex);
        if (lengthEnd !== -1) {
          var length = parseInt(message.substring(elementEnd + 1, lengthEnd));
          startIndex = lengthEnd + 1;
          elementEnd = startIndex + length;
        } else
          close_tunnel(new Guacamole.Status(Guacamole.Status.Code.SERVER_ERROR, "Incomplete instruction."));
        var element = message.substring(startIndex, elementEnd);
        var terminator = message.substring(elementEnd, elementEnd + 1);
        elements.push(element);
        if (terminator === ";") {
          var opcode = elements.shift();
          if (tunnel.uuid === null) {
            if (opcode === Guacamole.Tunnel.INTERNAL_DATA_OPCODE && elements.length === 1)
              tunnel.setUUID(elements[0]);
            tunnel.setState(Guacamole.Tunnel.State.OPEN);
          }
          if (opcode !== Guacamole.Tunnel.INTERNAL_DATA_OPCODE && tunnel.oninstruction)
            tunnel.oninstruction(opcode, elements);
          elements.length = 0;
        }
        startIndex = elementEnd + 1;
      } while (startIndex < message.length);
    };
  };
  this.disconnect = function() {
    close_tunnel(new Guacamole.Status(Guacamole.Status.Code.SUCCESS, "Manually closed."));
  };
};
Guacamole.WebSocketTunnel.prototype = new Guacamole.Tunnel();
Guacamole.ChainedTunnel = function(tunnelChain) {
  var chained_tunnel = this;
  var connect_data;
  var tunnels = [];
  var committedTunnel = null;
  for (var i5 = 0; i5 < arguments.length; i5++)
    tunnels.push(arguments[i5]);
  function attach(tunnel) {
    chained_tunnel.disconnect = tunnel.disconnect;
    chained_tunnel.sendMessage = tunnel.sendMessage;
    var failTunnel = function failTunnel2(status) {
      if (status && status.code === Guacamole.Status.Code.UPSTREAM_TIMEOUT) {
        tunnels = [];
        return null;
      }
      var next_tunnel = tunnels.shift();
      if (next_tunnel) {
        tunnel.onerror = null;
        tunnel.oninstruction = null;
        tunnel.onstatechange = null;
        attach(next_tunnel);
      }
      return next_tunnel;
    };
    function commit_tunnel() {
      tunnel.onstatechange = chained_tunnel.onstatechange;
      tunnel.oninstruction = chained_tunnel.oninstruction;
      tunnel.onerror = chained_tunnel.onerror;
      if (tunnel.uuid)
        chained_tunnel.setUUID(tunnel.uuid);
      tunnel.onuuid = function uuidReceived(uuid) {
        chained_tunnel.setUUID(uuid);
      };
      committedTunnel = tunnel;
    }
    tunnel.onstatechange = function(state) {
      switch (state) {
        case Guacamole.Tunnel.State.OPEN:
          commit_tunnel();
          if (chained_tunnel.onstatechange)
            chained_tunnel.onstatechange(state);
          break;
        case Guacamole.Tunnel.State.CLOSED:
          if (!failTunnel() && chained_tunnel.onstatechange)
            chained_tunnel.onstatechange(state);
          break;
      }
    };
    tunnel.oninstruction = function(opcode, elements) {
      commit_tunnel();
      if (chained_tunnel.oninstruction)
        chained_tunnel.oninstruction(opcode, elements);
    };
    tunnel.onerror = function(status) {
      if (!failTunnel(status) && chained_tunnel.onerror)
        chained_tunnel.onerror(status);
    };
    tunnel.connect(connect_data);
  }
  this.connect = function(data) {
    connect_data = data;
    var next_tunnel = committedTunnel ? committedTunnel : tunnels.shift();
    if (next_tunnel)
      attach(next_tunnel);
    else if (chained_tunnel.onerror)
      chained_tunnel.onerror(Guacamole.Status.Code.SERVER_ERROR, "No tunnels to try.");
  };
};
Guacamole.ChainedTunnel.prototype = new Guacamole.Tunnel();
Guacamole.StaticHTTPTunnel = function StaticHTTPTunnel(url, crossDomain, extraTunnelHeaders) {
  var tunnel = this;
  var abortController = null;
  var extraHeaders = extraTunnelHeaders || {};
  this.size = null;
  this.sendMessage = function sendMessage(elements) {
  };
  this.connect = function connect(data) {
    tunnel.disconnect();
    tunnel.setState(Guacamole.Tunnel.State.CONNECTING);
    var parser = new Guacamole.Parser();
    var utf8Parser = new Guacamole.UTF8Parser();
    parser.oninstruction = function instructionReceived(opcode, args) {
      if (tunnel.oninstruction)
        tunnel.oninstruction(opcode, args);
    };
    abortController = new AbortController();
    fetch(url, {
      headers: extraHeaders,
      credentials: crossDomain ? "include" : "same-origin",
      signal: abortController.signal
    }).then(function gotResponse(response) {
      if (!response.ok) {
        if (tunnel.onerror)
          tunnel.onerror(new Guacamole.Status(
            Guacamole.Status.Code.fromHTTPCode(response.status),
            response.statusText
          ));
        tunnel.disconnect();
        return;
      }
      tunnel.size = response.headers.get("Content-Length");
      tunnel.setState(Guacamole.Tunnel.State.OPEN);
      var reader = response.body.getReader();
      var processReceivedText = function processReceivedText2(result) {
        if (result.done) {
          tunnel.disconnect();
          return;
        }
        parser.receive(utf8Parser.decode(result.value));
        reader.read().then(processReceivedText2);
      };
      reader.read().then(processReceivedText);
    });
  };
  this.disconnect = function disconnect() {
    if (abortController) {
      abortController.abort();
      abortController = null;
    }
    tunnel.setState(Guacamole.Tunnel.State.CLOSED);
  };
};
Guacamole.StaticHTTPTunnel.prototype = new Guacamole.Tunnel();
var Guacamole = Guacamole || {};
Guacamole.UTF8Parser = function UTF8Parser() {
  var bytesRemaining = 0;
  var codepoint = 0;
  this.decode = function decode(buffer) {
    var text = "";
    var bytes = new Uint8Array(buffer);
    for (var i5 = 0; i5 < bytes.length; i5++) {
      var value = bytes[i5];
      if (bytesRemaining === 0) {
        if ((value | 127) === 127)
          text += String.fromCharCode(value);
        else if ((value | 31) === 223) {
          codepoint = value & 31;
          bytesRemaining = 1;
        } else if ((value | 15) === 239) {
          codepoint = value & 15;
          bytesRemaining = 2;
        } else if ((value | 7) === 247) {
          codepoint = value & 7;
          bytesRemaining = 3;
        } else
          text += "\uFFFD";
      } else if ((value | 63) === 191) {
        codepoint = codepoint << 6 | value & 63;
        bytesRemaining--;
        if (bytesRemaining === 0)
          text += String.fromCharCode(codepoint);
      } else {
        bytesRemaining = 0;
        text += "\uFFFD";
      }
    }
    return text;
  };
};
var Guacamole = Guacamole || {};
Guacamole.API_VERSION = "1.5.0";
var Guacamole = Guacamole || {};
Guacamole.VideoPlayer = function VideoPlayer() {
  this.sync = function sync() {
  };
};
Guacamole.VideoPlayer.isSupportedType = function isSupportedType5(mimetype) {
  return false;
};
Guacamole.VideoPlayer.getSupportedTypes = function getSupportedTypes5() {
  return [];
};
Guacamole.VideoPlayer.getInstance = function getInstance3(stream, layer, mimetype) {
  return null;
};
var guacamole_common_default = Guacamole;

// node_modules/@patternfly/patternfly/components/Content/content.css
var content_default = ".pf-c-content {\n  --pf-c-content--MarginBottom: var(--pf-global--spacer--md);\n  --pf-c-content--LineHeight: var(--pf-global--LineHeight--md);\n  --pf-c-content--FontSize: var(--pf-global--FontSize--md);\n  --pf-c-content--FontWeight: var(--pf-global--FontWeight--normal);\n  --pf-c-content--Color: var(--pf-global--Color--100);\n  --pf-c-content--heading--FontFamily: var(--pf-global--FontFamily--heading--sans-serif);\n  --pf-c-content--h1--MarginTop: var(--pf-global--spacer--lg);\n  --pf-c-content--h1--MarginBottom: var(--pf-global--spacer--sm);\n  --pf-c-content--h1--LineHeight: var(--pf-global--LineHeight--sm);\n  --pf-c-content--h1--FontSize: var(--pf-global--FontSize--2xl);\n  --pf-c-content--h1--FontWeight: var(--pf-global--FontWeight--normal);\n  --pf-c-content--h2--MarginTop: var(--pf-global--spacer--lg);\n  --pf-c-content--h2--MarginBottom: var(--pf-global--spacer--sm);\n  --pf-c-content--h2--LineHeight: var(--pf-global--LineHeight--md);\n  --pf-c-content--h2--FontSize: var(--pf-global--FontSize--xl);\n  --pf-c-content--h2--FontWeight: var(--pf-global--FontWeight--normal);\n  --pf-c-content--h3--MarginTop: var(--pf-global--spacer--lg);\n  --pf-c-content--h3--MarginBottom: var(--pf-global--spacer--sm);\n  --pf-c-content--h3--LineHeight: var(--pf-global--LineHeight--md);\n  --pf-c-content--h3--FontSize: var(--pf-global--FontSize--lg);\n  --pf-c-content--h3--FontWeight: var(--pf-global--FontWeight--normal);\n  --pf-c-content--h4--MarginTop: var(--pf-global--spacer--lg);\n  --pf-c-content--h4--MarginBottom: var(--pf-global--spacer--sm);\n  --pf-c-content--h4--LineHeight: var(--pf-global--LineHeight--md);\n  --pf-c-content--h4--FontSize: var(--pf-global--FontSize--md);\n  --pf-c-content--h4--FontWeight: var(--pf-global--FontWeight--normal);\n  --pf-c-content--h5--MarginTop: var(--pf-global--spacer--lg);\n  --pf-c-content--h5--MarginBottom: var(--pf-global--spacer--sm);\n  --pf-c-content--h5--LineHeight: var(--pf-global--LineHeight--md);\n  --pf-c-content--h5--FontSize: var(--pf-global--FontSize--md);\n  --pf-c-content--h5--FontWeight: var(--pf-global--FontWeight--normal);\n  --pf-c-content--h6--MarginTop: var(--pf-global--spacer--lg);\n  --pf-c-content--h6--MarginBottom: var(--pf-global--spacer--sm);\n  --pf-c-content--h6--LineHeight: var(--pf-global--LineHeight--md);\n  --pf-c-content--h6--FontSize: var(--pf-global--FontSize--md);\n  --pf-c-content--h6--FontWeight: var(--pf-global--FontWeight--normal);\n  --pf-c-content--small--MarginBottom: var(--pf-global--spacer--md);\n  --pf-c-content--small--LineHeight: var(--pf-global--LineHeight--md);\n  --pf-c-content--small--FontSize: var(--pf-global--FontSize--sm);\n  --pf-c-content--small--Color: var(--pf-global--Color--200);\n  --pf-c-content--a--Color: var(--pf-global--link--Color);\n  --pf-c-content--a--TextDecoration: var(--pf-global--link--TextDecoration);\n  --pf-c-content--a--hover--Color: var(--pf-global--link--Color--hover);\n  --pf-c-content--a--hover--TextDecoration: var(--pf-global--link--TextDecoration--hover);\n  --pf-c-content--a--visited--Color: var(--pf-global--link--Color--visited);\n  --pf-c-content--blockquote--PaddingTop: var(--pf-global--spacer--md);\n  --pf-c-content--blockquote--PaddingRight: var(--pf-global--spacer--md);\n  --pf-c-content--blockquote--PaddingBottom: var(--pf-global--spacer--md);\n  --pf-c-content--blockquote--PaddingLeft: var(--pf-global--spacer--md);\n  --pf-c-content--blockquote--Color: var(--pf-global--Color--200);\n  --pf-c-content--blockquote--BorderLeftColor: var(--pf-global--BorderColor--100);\n  --pf-c-content--blockquote--BorderLeftWidth: var(--pf-global--BorderWidth--lg);\n  --pf-c-content--ol--PaddingLeft: var(--pf-global--spacer--lg);\n  --pf-c-content--ol--MarginLeft: var(--pf-global--spacer--lg);\n  --pf-c-content--ol--nested--MarginTop: var(--pf-global--spacer--sm);\n  --pf-c-content--ol--nested--MarginLeft: var(--pf-global--spacer--sm);\n  --pf-c-content--ul--PaddingLeft: var(--pf-global--spacer--lg);\n  --pf-c-content--ul--MarginLeft: var(--pf-global--spacer--lg);\n  --pf-c-content--ul--nested--MarginTop: var(--pf-global--spacer--sm);\n  --pf-c-content--ul--nested--MarginLeft: var(--pf-global--spacer--sm);\n  --pf-c-content--ul--ListStyle: var(--pf-global--ListStyle);\n  --pf-c-content--li--MarginTop: var(--pf-global--spacer--sm);\n  --pf-c-content--dl--ColumnGap: var(--pf-global--spacer--2xl);\n  --pf-c-content--dl--RowGap: var(--pf-global--spacer--md);\n  --pf-c-content--dt--FontWeight: var(--pf-global--FontWeight--semi-bold);\n  --pf-c-content--dt--MarginTop: var(--pf-global--spacer--md);\n  --pf-c-content--dt--sm--MarginTop: 0;\n  --pf-c-content--hr--Height: var(--pf-global--BorderWidth--sm);\n  --pf-c-content--hr--BackgroundColor: var(--pf-global--BorderColor--100);\n  font-size: var(--pf-c-content--FontSize);\n  line-height: var(--pf-c-content--LineHeight);\n  color: var(--pf-c-content--Color);\n}\n.pf-c-content a {\n  color: var(--pf-c-content--a--Color);\n  text-decoration: var(--pf-c-content--a--TextDecoration);\n}\n.pf-c-content a:hover {\n  --pf-c-content--a--Color: var(--pf-c-content--a--hover--Color);\n  --pf-c-content--a--TextDecoration: var(--pf-c-content--a--hover--TextDecoration);\n}\n.pf-c-content.pf-m-visited a:visited,\n.pf-c-content a.pf-m-visited:visited {\n  color: var(--pf-c-content--a--visited--Color);\n}\n.pf-c-content li + li {\n  margin-top: var(--pf-c-content--li--MarginTop);\n}\n.pf-c-content p:not(:last-child),\n.pf-c-content dl:not(:last-child),\n.pf-c-content ol:not(:last-child),\n.pf-c-content ul:not(:last-child),\n.pf-c-content blockquote:not(:last-child),\n.pf-c-content small:not(:last-child),\n.pf-c-content pre:not(:last-child),\n.pf-c-content table:not(:last-child),\n.pf-c-content hr:not(:last-child) {\n  margin-bottom: var(--pf-c-content--MarginBottom);\n}\n.pf-c-content h1,\n.pf-c-content h2,\n.pf-c-content h3,\n.pf-c-content h4,\n.pf-c-content h5,\n.pf-c-content h6 {\n  margin: 0;\n  font-family: var(--pf-c-content--heading--FontFamily);\n}\n.pf-c-content h1:first-child,\n.pf-c-content h2:first-child,\n.pf-c-content h3:first-child,\n.pf-c-content h4:first-child,\n.pf-c-content h5:first-child,\n.pf-c-content h6:first-child {\n  margin-top: 0;\n}\n.pf-c-content h1:last-child,\n.pf-c-content h2:last-child,\n.pf-c-content h3:last-child,\n.pf-c-content h4:last-child,\n.pf-c-content h5:last-child,\n.pf-c-content h6:last-child {\n  margin-bottom: 0;\n}\n.pf-c-content ol,\n.pf-c-content ul {\n  margin: 0;\n}\n.pf-c-content ol.pf-m-plain,\n.pf-c-content ul.pf-m-plain {\n  padding-left: 0;\n  margin-left: 0;\n  list-style: none;\n}\n.pf-c-content h1 {\n  margin-top: var(--pf-c-content--h1--MarginTop);\n  margin-bottom: var(--pf-c-content--h1--MarginBottom);\n  font-size: var(--pf-c-content--h1--FontSize);\n  font-weight: var(--pf-c-content--h1--FontWeight);\n  line-height: var(--pf-c-content--h1--LineHeight);\n}\n.pf-c-content h2 {\n  margin-top: var(--pf-c-content--h2--MarginTop);\n  margin-bottom: var(--pf-c-content--h2--MarginBottom);\n  font-size: var(--pf-c-content--h2--FontSize);\n  font-weight: var(--pf-c-content--h2--FontWeight);\n  line-height: var(--pf-c-content--h2--LineHeight);\n}\n.pf-c-content h3 {\n  margin-top: var(--pf-c-content--h3--MarginTop);\n  margin-bottom: var(--pf-c-content--h3--MarginBottom);\n  font-size: var(--pf-c-content--h3--FontSize);\n  font-weight: var(--pf-c-content--h3--FontWeight);\n  line-height: var(--pf-c-content--h3--LineHeight);\n}\n.pf-c-content h4 {\n  margin-top: var(--pf-c-content--h4--MarginTop);\n  margin-bottom: var(--pf-c-content--h4--MarginBottom);\n  font-size: var(--pf-c-content--h4--FontSize);\n  font-weight: var(--pf-c-content--h4--FontWeight);\n  line-height: var(--pf-c-content--h4--LineHeight);\n}\n.pf-c-content h5 {\n  margin-top: var(--pf-c-content--h5--MarginTop);\n  margin-bottom: var(--pf-c-content--h5--MarginBottom);\n  font-size: var(--pf-c-content--h5--FontSize);\n  font-weight: var(--pf-c-content--h5--FontWeight);\n  line-height: var(--pf-c-content--h5--LineHeight);\n}\n.pf-c-content h6 {\n  margin-top: var(--pf-c-content--h6--MarginTop);\n  margin-bottom: var(--pf-c-content--h6--MarginBottom);\n  font-size: var(--pf-c-content--h6--FontSize);\n  font-weight: var(--pf-c-content--h6--FontWeight);\n  line-height: var(--pf-c-content--h6--LineHeight);\n}\n.pf-c-content small {\n  display: block;\n  font-size: var(--pf-c-content--small--FontSize);\n  line-height: var(--pf-c-content--small--LineHeight);\n  color: var(--pf-c-content--small--Color);\n}\n.pf-c-content small:not(:last-child) {\n  margin-bottom: var(--pf-c-content--small--MarginBottom);\n}\n.pf-c-content blockquote {\n  padding: var(--pf-c-content--blockquote--PaddingTop) var(--pf-c-content--blockquote--PaddingRight) var(--pf-c-content--blockquote--PaddingBottom) var(--pf-c-content--blockquote--PaddingLeft);\n  color: var(--pf-c-content--blockquote--Color);\n  border-left: var(--pf-c-content--blockquote--BorderLeftWidth) solid var(--pf-c-content--blockquote--BorderLeftColor);\n}\n.pf-c-content hr {\n  height: var(--pf-c-content--hr--Height);\n  background-color: var(--pf-c-content--hr--BackgroundColor);\n  border: none;\n}\n.pf-c-content ol {\n  padding-left: var(--pf-c-content--ol--PaddingLeft);\n  margin-left: var(--pf-c-content--ol--MarginLeft);\n}\n.pf-c-content ol ul {\n  margin-top: var(--pf-c-content--ul--nested--MarginTop);\n  --pf-c-content--ul--MarginLeft: var(--pf-c-content--ul--nested--MarginLeft);\n}\n.pf-c-content ol ol {\n  margin-top: var(--pf-c-content--ol--nested--MarginTop);\n  --pf-c-content--ol--MarginLeft: var(--pf-c-content--ol--nested--MarginLeft);\n}\n.pf-c-content ul {\n  padding-left: var(--pf-c-content--ul--PaddingLeft);\n  margin-left: var(--pf-c-content--ul--MarginLeft);\n  list-style: var(--pf-c-content--ul--ListStyle);\n}\n.pf-c-content ul ul {\n  margin-top: var(--pf-c-content--ul--nested--MarginTop);\n  --pf-c-content--ul--MarginLeft: var(--pf-c-content--ul--nested--MarginLeft);\n}\n.pf-c-content ul ol {\n  margin-top: var(--pf-c-content--ol--nested--MarginTop);\n  --pf-c-content--ol--MarginLeft: var(--pf-c-content--ol--nested--MarginLeft);\n}\n.pf-c-content dl {\n  display: grid;\n  grid-template-columns: 1fr;\n}\n@media screen and (min-width: 576px) {\n  .pf-c-content dl {\n    grid-template: auto/auto 1fr;\n    grid-column-gap: var(--pf-c-content--dl--ColumnGap);\n    grid-row-gap: var(--pf-c-content--dl--RowGap);\n  }\n}\n.pf-c-content dt {\n  font-weight: var(--pf-c-content--dt--FontWeight);\n}\n.pf-c-content dt:not(:first-child) {\n  margin-top: var(--pf-c-content--dt--MarginTop);\n}\n@media screen and (min-width: 576px) {\n  .pf-c-content dt:not(:first-child) {\n    --pf-c-content--dt--MarginTop: var(--pf-c-content--dt--sm--MarginTop);\n  }\n}\n@media screen and (min-width: 576px) {\n  .pf-c-content dt {\n    grid-column: 1;\n  }\n}\n@media screen and (min-width: 576px) {\n  .pf-c-content dd {\n    grid-column: 2;\n  }\n}\n\n.pf-m-overpass-font .pf-c-content {\n  --pf-c-content--h2--LineHeight: var(--pf-global--LineHeight--sm);\n  --pf-c-content--h4--FontWeight: var(--pf-global--FontWeight--semi-bold);\n  --pf-c-content--h5--FontWeight: var(--pf-global--FontWeight--semi-bold);\n  --pf-c-content--h6--FontWeight: var(--pf-global--FontWeight--semi-bold);\n}\n.pf-m-overpass-font .pf-c-content blockquote {\n  font-weight: var(--pf-global--FontWeight--light);\n}";

// node_modules/@patternfly/patternfly/components/Page/page.css
var page_default = '.pf-c-page__sidebar.pf-m-light {\n  --pf-global--Color--100: var(--pf-global--Color--dark-100);\n  --pf-global--Color--200: var(--pf-global--Color--dark-200);\n  --pf-global--BorderColor--100: var(--pf-global--BorderColor--dark-100);\n  --pf-global--primary-color--100: var(--pf-global--primary-color--dark-100);\n  --pf-global--link--Color: var(--pf-global--link--Color--dark);\n  --pf-global--link--Color--hover: var(--pf-global--link--Color--dark--hover);\n  --pf-global--BackgroundColor--100: var(--pf-global--BackgroundColor--light-100);\n}\n\n.pf-c-page__main-section[class*=pf-m-dark-], .pf-c-page__sidebar-body.pf-m-menu .pf-c-context-selector, .pf-c-page__header {\n  --pf-global--Color--100: var(--pf-global--Color--light-100);\n  --pf-global--Color--200: var(--pf-global--Color--light-200);\n  --pf-global--BorderColor--100: var(--pf-global--BorderColor--light-100);\n  --pf-global--primary-color--100: var(--pf-global--primary-color--light-100);\n  --pf-global--link--Color: var(--pf-global--link--Color--light);\n  --pf-global--link--Color--hover: var(--pf-global--link--Color--light);\n  --pf-global--BackgroundColor--100: var(--pf-global--BackgroundColor--dark-100);\n}\n.pf-c-page__main-section[class*=pf-m-dark-] .pf-c-card, .pf-c-page__sidebar-body.pf-m-menu .pf-c-context-selector .pf-c-card, .pf-c-page__header .pf-c-card {\n  --pf-c-card--BackgroundColor: var(--pf-global--BackgroundColor--dark-transparent-200);\n}\n.pf-c-page__main-section[class*=pf-m-dark-] .pf-c-button, .pf-c-page__sidebar-body.pf-m-menu .pf-c-context-selector .pf-c-button, .pf-c-page__header .pf-c-button {\n  --pf-c-button--m-primary--Color: var(--pf-global--primary-color--dark-100);\n  --pf-c-button--m-primary--hover--Color: var(--pf-global--primary-color--dark-100);\n  --pf-c-button--m-primary--focus--Color: var(--pf-global--primary-color--dark-100);\n  --pf-c-button--m-primary--active--Color: var(--pf-global--primary-color--dark-100);\n  --pf-c-button--m-primary--BackgroundColor: var(--pf-global--BackgroundColor--light-100);\n  --pf-c-button--m-primary--hover--BackgroundColor: var(--pf-global--BackgroundColor--light-300);\n  --pf-c-button--m-primary--focus--BackgroundColor: var(--pf-global--BackgroundColor--light-300);\n  --pf-c-button--m-primary--active--BackgroundColor: var(--pf-global--BackgroundColor--light-300);\n  --pf-c-button--m-secondary--Color: var(--pf-global--Color--light-100);\n  --pf-c-button--m-secondary--hover--Color: var(--pf-global--Color--light-100);\n  --pf-c-button--m-secondary--focus--Color: var(--pf-global--Color--light-100);\n  --pf-c-button--m-secondary--active--Color: var(--pf-global--Color--light-100);\n  --pf-c-button--m-secondary--BorderColor: var(--pf-global--Color--light-100);\n  --pf-c-button--m-secondary--hover--BorderColor: var(--pf-global--Color--light-100);\n  --pf-c-button--m-secondary--focus--BorderColor: var(--pf-global--Color--light-100);\n  --pf-c-button--m-secondary--active--BorderColor: var(--pf-global--Color--light-100);\n}\n\n.pf-c-page__header-tools-item, .pf-c-page__header-tools-group {\n  --pf-hidden-visible--visible--Visibility: visible;\n  --pf-hidden-visible--hidden--Display: none;\n  --pf-hidden-visible--hidden--Visibility: hidden;\n  --pf-hidden-visible--Display: var(--pf-hidden-visible--visible--Display);\n  --pf-hidden-visible--Visibility: var(--pf-hidden-visible--visible--Visibility);\n  display: var(--pf-hidden-visible--Display);\n  visibility: var(--pf-hidden-visible--Visibility);\n}\n.pf-m-hidden.pf-c-page__header-tools-item, .pf-m-hidden.pf-c-page__header-tools-group {\n  --pf-hidden-visible--Display: var(--pf-hidden-visible--hidden--Display);\n  --pf-hidden-visible--Visibility: var(--pf-hidden-visible--hidden--Visibility);\n}\n@media screen and (min-width: 576px) {\n  .pf-m-hidden-on-sm.pf-c-page__header-tools-item, .pf-m-hidden-on-sm.pf-c-page__header-tools-group {\n    --pf-hidden-visible--Display: var(--pf-hidden-visible--hidden--Display);\n    --pf-hidden-visible--Visibility: var(--pf-hidden-visible--hidden--Visibility);\n  }\n  .pf-m-visible-on-sm.pf-c-page__header-tools-item, .pf-m-visible-on-sm.pf-c-page__header-tools-group {\n    --pf-hidden-visible--Display: var(--pf-hidden-visible--visible--Display);\n    --pf-hidden-visible--Visibility: var(--pf-hidden-visible--visible--Visibility);\n  }\n}\n@media screen and (min-width: 768px) {\n  .pf-m-hidden-on-md.pf-c-page__header-tools-item, .pf-m-hidden-on-md.pf-c-page__header-tools-group {\n    --pf-hidden-visible--Display: var(--pf-hidden-visible--hidden--Display);\n    --pf-hidden-visible--Visibility: var(--pf-hidden-visible--hidden--Visibility);\n  }\n  .pf-m-visible-on-md.pf-c-page__header-tools-item, .pf-m-visible-on-md.pf-c-page__header-tools-group {\n    --pf-hidden-visible--Display: var(--pf-hidden-visible--visible--Display);\n    --pf-hidden-visible--Visibility: var(--pf-hidden-visible--visible--Visibility);\n  }\n}\n@media screen and (min-width: 992px) {\n  .pf-m-hidden-on-lg.pf-c-page__header-tools-item, .pf-m-hidden-on-lg.pf-c-page__header-tools-group {\n    --pf-hidden-visible--Display: var(--pf-hidden-visible--hidden--Display);\n    --pf-hidden-visible--Visibility: var(--pf-hidden-visible--hidden--Visibility);\n  }\n  .pf-m-visible-on-lg.pf-c-page__header-tools-item, .pf-m-visible-on-lg.pf-c-page__header-tools-group {\n    --pf-hidden-visible--Display: var(--pf-hidden-visible--visible--Display);\n    --pf-hidden-visible--Visibility: var(--pf-hidden-visible--visible--Visibility);\n  }\n}\n@media screen and (min-width: 1200px) {\n  .pf-m-hidden-on-xl.pf-c-page__header-tools-item, .pf-m-hidden-on-xl.pf-c-page__header-tools-group {\n    --pf-hidden-visible--Display: var(--pf-hidden-visible--hidden--Display);\n    --pf-hidden-visible--Visibility: var(--pf-hidden-visible--hidden--Visibility);\n  }\n  .pf-m-visible-on-xl.pf-c-page__header-tools-item, .pf-m-visible-on-xl.pf-c-page__header-tools-group {\n    --pf-hidden-visible--Display: var(--pf-hidden-visible--visible--Display);\n    --pf-hidden-visible--Visibility: var(--pf-hidden-visible--visible--Visibility);\n  }\n}\n@media screen and (min-width: 1450px) {\n  .pf-m-hidden-on-2xl.pf-c-page__header-tools-item, .pf-m-hidden-on-2xl.pf-c-page__header-tools-group {\n    --pf-hidden-visible--Display: var(--pf-hidden-visible--hidden--Display);\n    --pf-hidden-visible--Visibility: var(--pf-hidden-visible--hidden--Visibility);\n  }\n  .pf-m-visible-on-2xl.pf-c-page__header-tools-item, .pf-m-visible-on-2xl.pf-c-page__header-tools-group {\n    --pf-hidden-visible--Display: var(--pf-hidden-visible--visible--Display);\n    --pf-hidden-visible--Visibility: var(--pf-hidden-visible--visible--Visibility);\n  }\n}\n\n.pf-c-page {\n  --pf-c-page--BackgroundColor: var(--pf-global--BackgroundColor--light-300);\n  --pf-c-page__header--BackgroundColor: var(--pf-global--BackgroundColor--dark-100);\n  --pf-c-page__header--ZIndex: var(--pf-global--ZIndex--md);\n  --pf-c-page__header--MinHeight: 4.75rem;\n  --pf-c-page__header-brand--PaddingLeft: var(--pf-global--spacer--md);\n  --pf-c-page__header-brand--xl--PaddingRight: var(--pf-global--spacer--xl);\n  --pf-c-page__header-brand--xl--PaddingLeft: var(--pf-global--spacer--lg);\n  --pf-c-page__header-sidebar-toggle__c-button--PaddingTop: var(--pf-global--spacer--sm);\n  --pf-c-page__header-sidebar-toggle__c-button--PaddingRight: var(--pf-global--spacer--sm);\n  --pf-c-page__header-sidebar-toggle__c-button--PaddingBottom: var(--pf-global--spacer--sm);\n  --pf-c-page__header-sidebar-toggle__c-button--PaddingLeft: var(--pf-global--spacer--sm);\n  --pf-c-page__header-sidebar-toggle__c-button--MarginRight: var(--pf-global--spacer--md);\n  --pf-c-page__header-sidebar-toggle__c-button--MarginLeft: calc(var(--pf-c-page__header-sidebar-toggle__c-button--PaddingLeft) * -1);\n  --pf-c-page__header-sidebar-toggle__c-button--FontSize: var(--pf-global--FontSize--2xl);\n  --pf-c-page__header-brand-link--c-brand--MaxHeight: 3.75rem;\n  --pf-c-page__header-nav--BackgroundColor: var(--pf-global--BackgroundColor--dark-300);\n  --pf-c-page__header-nav--xl--BackgroundColor: transparent;\n  --pf-c-page__header-nav--xl--PaddingRight: var(--pf-global--spacer--xl);\n  --pf-c-page__header-nav--xl--PaddingLeft: var(--pf-global--spacer--xl);\n  --pf-c-page__header-tools--MarginRight: var(--pf-global--spacer--md);\n  --pf-c-page__header-tools--xl--MarginRight: var(--pf-global--spacer--lg);\n  --pf-c-page__header-tools--c-avatar--MarginLeft: var(--pf-global--spacer--md);\n  --pf-c-page__header-tools-group--MarginLeft: var(--pf-global--spacer--xl);\n  --pf-c-page__header-tools-group--Display: flex;\n  --pf-c-page__header-tools-item--Display: block;\n  --pf-c-page__header-tools-item--c-notification-badge--hover--BackgroundColor: var(--pf-global--BackgroundColor--dark-200);\n  --pf-c-page__header-tools--c-button--notification-badge--m-unread--after--BackgroundColor: var(--pf-global--primary-color--200);\n  --pf-c-page__header-tools--c-button--notification-badge--m-attention--after--BackgroundColor: var(--pf-global--danger-color--200);\n  --pf-c-page__header-tools--c-button--m-selected--notification-badge--m-unread--after--BackgroundColor: var(--pf-global--primary-color--200);\n  --pf-c-page__header-tools--c-button--m-selected--notification-badge--m-attention--after--BackgroundColor: var(--pf-global--danger-color--200);\n  --pf-c-page__header-tools--c-button--m-selected--before--Width: auto;\n  --pf-c-page__header-tools--c-button--m-selected--before--Height: auto;\n  --pf-c-page__header-tools--c-button--m-selected--before--BackgroundColor: var(--pf-global--BackgroundColor--dark-200);\n  --pf-c-page__header-tools--c-button--m-selected--before--BorderRadius: var(--pf-global--BorderRadius--sm);\n  --pf-c-page__header-tools--c-button--m-selected--c-notification-badge--m-unread--after--BorderColor: transparent;\n  --pf-c-page__sidebar--ZIndex: var(--pf-global--ZIndex--sm);\n  --pf-c-page__sidebar--Width: 18.125rem;\n  --pf-c-page__sidebar--BackgroundColor: var(--pf-global--BackgroundColor--dark-300);\n  --pf-c-page__sidebar--m-light--BackgroundColor: var(--pf-global--BackgroundColor--light-100);\n  --pf-c-page__sidebar--m-light--BorderRightWidth: var(--pf-global--BorderWidth--sm);\n  --pf-c-page__sidebar--m-light--BorderRightColor: var(--pf-global--BorderColor--100);\n  --pf-c-page__sidebar--BoxShadow: var(--pf-global--BoxShadow--lg-right);\n  --pf-c-page__sidebar--Transition: var(--pf-global--Transition);\n  --pf-c-page__sidebar--TranslateX: -100%;\n  --pf-c-page__sidebar--TranslateZ: 0;\n  --pf-c-page__sidebar--m-expanded--TranslateX: 0;\n  --pf-c-page__sidebar--xl--TranslateX: 0;\n  --pf-c-page__sidebar-body--PaddingTop: var(--pf-global--spacer--sm);\n  --pf-c-page__sidebar-body--PaddingBottom: var(--pf-global--spacer--md);\n  --pf-c-page__sidebar-body--m-menu--PaddingTop: 0;\n  --pf-c-page__sidebar-body--m-menu--PaddingBottom: 0;\n  --pf-c-page__sidebar-body--m-menu--BorderTopColor: var(--pf-global--BackgroundColor--dark-200);\n  --pf-c-page__sidebar-body--m-menu--BorderTopWidth: var(--pf-global--BorderWidth--sm);\n  --pf-c-page__sidebar-body--m-menu--c-context-selector--BorderBottomColor: var(--pf-global--BackgroundColor--dark-200);\n  --pf-c-page__main--ZIndex: var(--pf-global--ZIndex--xs);\n  --pf-c-page__main-section--PaddingTop: var(--pf-global--spacer--md);\n  --pf-c-page__main-section--PaddingRight: var(--pf-global--spacer--md);\n  --pf-c-page__main-section--PaddingBottom: var(--pf-global--spacer--md);\n  --pf-c-page__main-section--PaddingLeft: var(--pf-global--spacer--md);\n  --pf-c-page__main-section--xl--PaddingTop: var(--pf-global--spacer--lg);\n  --pf-c-page__main-section--xl--PaddingRight: var(--pf-global--spacer--lg);\n  --pf-c-page__main-section--xl--PaddingBottom: var(--pf-global--spacer--lg);\n  --pf-c-page__main-section--xl--PaddingLeft: var(--pf-global--spacer--lg);\n  --pf-c-page__main-breadcrumb--main-section--PaddingTop: var(--pf-global--spacer--md);\n  --pf-c-page__main-section--BackgroundColor: var(--pf-global--BackgroundColor--light-300);\n  --pf-c-page__main-section--m-light--BackgroundColor: var(--pf-global--BackgroundColor--light-100);\n  --pf-c-page__main-section--m-light-100--BackgroundColor: var(--pf-global--BackgroundColor--150);\n  --pf-c-page__main-section--m-dark-100--BackgroundColor: var(--pf-global--BackgroundColor--dark-transparent-100);\n  --pf-c-page__main-section--m-dark-200--BackgroundColor: var(--pf-global--BackgroundColor--dark-transparent-200);\n  --pf-c-page__main-breadcrumb--page__main-tabs--PaddingTop: var(--pf-global--spacer--md);\n  --pf-c-page__main-nav--page__main-tabs--PaddingTop: var(--pf-global--spacer--md);\n  --pf-c-page--section--m-limit-width--MaxWidth: calc(125rem - var(--pf-c-page__sidebar--Width));\n  --pf-c-page--section--m-sticky-top--ZIndex: var(--pf-global--ZIndex--md);\n  --pf-c-page--section--m-sticky-top--BoxShadow: var(--pf-global--BoxShadow--sm-bottom);\n  --pf-c-page--section--m-sticky-bottom--ZIndex: var(--pf-global--ZIndex--md);\n  --pf-c-page--section--m-sticky-bottom--BoxShadow: var(--pf-global--BoxShadow--sm-top);\n  --pf-c-page--section--m-shadow-bottom--BoxShadow: var(--pf-global--BoxShadow--sm-bottom);\n  --pf-c-page--section--m-shadow-bottom--ZIndex: var(--pf-global--ZIndex--xs);\n  --pf-c-page--section--m-shadow-top--BoxShadow: var(--pf-global--BoxShadow--sm-top);\n  --pf-c-page--section--m-shadow-top--ZIndex: var(--pf-global--ZIndex--xs);\n  --pf-c-page__main-nav--BackgroundColor: var(--pf-global--BackgroundColor--light-100);\n  --pf-c-page__main-nav--PaddingTop: var(--pf-global--spacer--md);\n  --pf-c-page__main-nav--PaddingRight: 0;\n  --pf-c-page__main-nav--PaddingLeft: 0;\n  --pf-c-page__main-nav--m-sticky-top--PaddingBottom: var(--pf-global--spacer--md);\n  --pf-c-page__main-nav--xl--PaddingRight: var(--pf-global--spacer--sm);\n  --pf-c-page__main-nav--xl--PaddingLeft: var(--pf-global--spacer--sm);\n  --pf-c-page__main-subnav--BackgroundColor: var(--pf-global--BackgroundColor--dark-300);\n  --pf-c-page__main-subnav--BorderTopWidth: var(--pf-global--BorderWidth--sm);\n  --pf-c-page__main-subnav--BorderTopColor: var(--pf-global--palette--black-800);\n  --pf-c-page__main-subnav--BorderLeftWidth: 0;\n  --pf-c-page__main-subnav--BorderLeftColor: var(--pf-global--palette--black-800);\n  --pf-c-page__sidebar--main__main-subnav--BorderLeftWidth: var(--pf-global--BorderWidth--sm);\n  --pf-c-page__sidebar--m-collapsed--main__main-subnav--BorderLeftWidth: 0;\n  --pf-c-page__main-breadcrumb--BackgroundColor: var(--pf-global--BackgroundColor--light-100);\n  --pf-c-page__main-breadcrumb--PaddingTop: var(--pf-global--spacer--md);\n  --pf-c-page__main-breadcrumb--PaddingRight: var(--pf-global--spacer--md);\n  --pf-c-page__main-breadcrumb--PaddingBottom: 0;\n  --pf-c-page__main-breadcrumb--PaddingLeft: var(--pf-global--spacer--md);\n  --pf-c-page__main-breadcrumb--m-sticky-top--PaddingBottom: var(--pf-global--spacer--md);\n  --pf-c-page__main-breadcrumb--xl--PaddingRight: var(--pf-global--spacer--lg);\n  --pf-c-page__main-breadcrumb--xl--PaddingLeft: var(--pf-global--spacer--lg);\n  --pf-c-page__main-tabs--PaddingTop: 0;\n  --pf-c-page__main-tabs--PaddingRight: 0;\n  --pf-c-page__main-tabs--PaddingBottom: 0;\n  --pf-c-page__main-tabs--PaddingLeft: 0;\n  --pf-c-page__main-tabs--BackgroundColor: var(--pf-global--BackgroundColor--light-100);\n  --pf-c-page__main-wizard--BackgroundColor: var(--pf-global--BackgroundColor--light-100);\n  --pf-c-page__main-wizard--BorderTopColor: var(--pf-global--BorderColor--100);\n  --pf-c-page__main-wizard--BorderTopWidth: var(--pf-global--BorderWidth--sm);\n  --pf-c-page__main-wizard--m-light-200--BackgroundColor: var(--pf-global--BackgroundColor--200);\n  display: grid;\n  height: 100%;\n  grid-template-columns: 1fr;\n  grid-template-rows: max-content 1fr;\n  grid-template-areas: "header" "main";\n  background-color: var(--pf-c-page--BackgroundColor);\n}\n@media (min-width: 1200px) {\n  .pf-c-page {\n    --pf-c-page__header-brand--PaddingLeft: var(--pf-c-page__header-brand--xl--PaddingLeft);\n  }\n}\n@media screen and (min-width: 1200px) {\n  .pf-c-page {\n    --pf-c-page__header-nav--BackgroundColor: var(--pf-c-page__header-nav--xl--BackgroundColor);\n    --pf-c-page__header-nav--PaddingRight: var(--pf-c-page__header-nav--xl--PaddingRight);\n    --pf-c-page__header-nav--PaddingLeft: var(--pf-c-page__header-nav--xl--PaddingLeft);\n  }\n}\n@media screen and (min-width: 1200px) {\n  .pf-c-page {\n    --pf-c-page__header-tools--MarginRight: var(--pf-c-page__header-tools--xl--MarginRight);\n  }\n}\n@media screen and (min-width: 1200px) {\n  .pf-c-page {\n    --pf-c-page__sidebar--TranslateX: var(--pf-c-page__sidebar--xl--TranslateX);\n  }\n}\n@media screen and (min-width: 1200px) {\n  .pf-c-page {\n    --pf-c-page__main-section--PaddingTop: var(--pf-c-page__main-section--xl--PaddingTop);\n    --pf-c-page__main-section--PaddingRight: var(--pf-c-page__main-section--xl--PaddingRight);\n    --pf-c-page__main-section--PaddingBottom: var(--pf-c-page__main-section--xl--PaddingBottom);\n    --pf-c-page__main-section--PaddingLeft: var(--pf-c-page__main-section--xl--PaddingLeft);\n  }\n}\n@media screen and (min-width: 1200px) {\n  .pf-c-page {\n    --pf-c-page__main-nav--PaddingRight: var(--pf-c-page__main-nav--xl--PaddingRight);\n    --pf-c-page__main-nav--PaddingLeft: var(--pf-c-page__main-nav--xl--PaddingLeft);\n  }\n}\n@media screen and (min-width: 1200px) {\n  .pf-c-page {\n    --pf-c-page__main-breadcrumb--PaddingRight: var(--pf-c-page__main-breadcrumb--xl--PaddingRight);\n    --pf-c-page__main-breadcrumb--PaddingLeft: var(--pf-c-page__main-breadcrumb--xl--PaddingLeft);\n  }\n}\n@media (min-width: 1200px) {\n  .pf-c-page {\n    grid-template-columns: max-content 1fr;\n    grid-template-areas: "header header" "nav main";\n  }\n}\n.pf-c-page.pf-m-full-height {\n  height: 100vh;\n  height: 100dvh;\n  max-height: 100%;\n}\n\n.pf-c-page__header,\n.pf-c-page > .pf-c-masthead {\n  grid-area: header;\n  z-index: var(--pf-c-page__header--ZIndex);\n}\n\n.pf-c-page__header {\n  color: var(--pf-global--Color--100);\n  grid-template-columns: auto auto;\n  display: grid;\n  align-items: center;\n  min-width: 0;\n  min-height: var(--pf-c-page__header--MinHeight);\n  background-color: var(--pf-c-page__header--BackgroundColor);\n}\n.pf-c-page__header > * {\n  display: flex;\n  align-items: center;\n}\n@media screen and (min-width: 992px) {\n  .pf-c-page__header {\n    grid-template-columns: auto 1fr auto;\n  }\n}\n.pf-c-page__header .pf-c-masthead {\n  grid-column: span 2;\n  align-self: stretch;\n}\n\n.pf-c-page__header-brand {\n  grid-column: 1/2;\n  padding-left: var(--pf-c-page__header-brand--PaddingLeft);\n}\n@media (min-width: 1200px) {\n  .pf-c-page__header-brand {\n    padding-right: var(--pf-c-page__header-brand--xl--PaddingRight);\n  }\n}\n\n.pf-c-page__header-brand-link {\n  display: flex;\n  flex: 1;\n  align-items: center;\n}\n.pf-c-page__header-brand-link .pf-c-brand {\n  max-height: var(--pf-c-page__header-brand-link--c-brand--MaxHeight);\n}\n\n.pf-c-page__header-brand-toggle .pf-c-button {\n  padding: var(--pf-c-page__header-sidebar-toggle__c-button--PaddingTop) var(--pf-c-page__header-sidebar-toggle__c-button--PaddingRight) var(--pf-c-page__header-sidebar-toggle__c-button--PaddingBottom) var(--pf-c-page__header-sidebar-toggle__c-button--PaddingLeft);\n  margin-right: var(--pf-c-page__header-sidebar-toggle__c-button--MarginRight);\n  margin-left: var(--pf-c-page__header-sidebar-toggle__c-button--MarginLeft);\n  font-size: var(--pf-c-page__header-sidebar-toggle__c-button--FontSize);\n  line-height: 1;\n}\n\n.pf-c-page__header-nav {\n  align-self: stretch;\n  min-width: 0;\n  padding-right: var(--pf-c-page__header-nav--PaddingRight);\n  padding-left: var(--pf-c-page__header-nav--PaddingLeft);\n  background-color: var(--pf-c-page__header-nav--BackgroundColor);\n  grid-column: 1/-1;\n  grid-row: 2/3;\n}\n@media screen and (min-width: 1200px) {\n  .pf-c-page__header-nav {\n    grid-column: 2/3;\n    grid-row: 1/2;\n  }\n}\n.pf-c-page__header-nav .pf-c-nav {\n  align-self: stretch;\n}\n\n.pf-c-page__header-tools {\n  grid-column: 2/3;\n  margin-right: var(--pf-c-page__header-tools--MarginRight);\n  margin-left: auto;\n}\n.pf-c-page__header-tools .pf-c-avatar {\n  margin-left: var(--pf-c-page__header-tools--c-avatar--MarginLeft);\n}\n@media screen and (min-width: 992px) {\n  .pf-c-page__header-tools {\n    grid-column: 3/4;\n  }\n}\n\n.pf-c-page__header-tools-group {\n  --pf-hidden-visible--visible--Display: var(--pf-c-page__header-tools-group--Display);\n  align-items: center;\n}\n.pf-c-page__header-tools-group + .pf-c-page__header-tools-group {\n  margin-left: var(--pf-c-page__header-tools-group--MarginLeft);\n}\n\n.pf-c-page__header-tools-item {\n  --pf-hidden-visible--visible--Display: var(--pf-c-page__header-tools-item--Display);\n}\n.pf-c-page__header-tools-item .pf-c-notification-badge.pf-m-read:hover {\n  --pf-c-notification-badge--after--BackgroundColor: var(--pf-c-page__header-tools-item--c-notification-badge--hover--BackgroundColor);\n}\n.pf-c-page__header-tools-item.pf-m-selected .pf-c-button {\n  background-color: var(--pf-c-page__header-tools--c-button--m-selected--before--BackgroundColor);\n  border-radius: var(--pf-c-page__header-tools--c-button--m-selected--before--BorderRadius);\n}\n.pf-c-page__header-tools-item.pf-m-selected .pf-c-button::before {\n  position: absolute;\n  top: 0;\n  right: 0;\n  bottom: 0;\n  left: 0;\n  width: var(--pf-c-page__header-tools--c-button--m-selected--before--Width);\n  height: var(--pf-c-page__header-tools--c-button--m-selected--before--Height);\n  content: "";\n}\n.pf-c-page__header-tools-item.pf-m-selected .pf-c-button .pf-c-notification-badge.pf-m-unread {\n  --pf-c-notification-badge--after--BackgroundColor: var(--pf-c-page__header-tools--c-button--m-selected--notification-badge--m-unread--after--BackgroundColor);\n}\n.pf-c-page__header-tools-item.pf-m-selected .pf-c-button .pf-c-notification-badge.pf-m-unread::after {\n  border-color: var(--pf-c-page__header-tools--c-button--m-selected--c-notification-badge--m-unread--after--BorderColor);\n}\n.pf-c-page__header-tools-item.pf-m-selected .pf-c-button .pf-c-notification-badge.pf-m-attention {\n  --pf-c-notification-badge--after--BackgroundColor: var(--pf-global--danger-color--200);\n}\n.pf-c-page__header-tools-item .pf-c-button:focus .pf-c-notification-badge.pf-m-unread {\n  --pf-c-notification-badge--after--BackgroundColor: var(--pf-c-page__header-tools--c-button--notification-badge--m-unread--after--BackgroundColor);\n}\n.pf-c-page__header-tools-item .pf-c-button:focus .pf-c-notification-badge.pf-m-attention {\n  --pf-c-notification-badge--after--BackgroundColor: var(--pf-c-page__header-tools--c-button--notification-badge--m-attention--after--BackgroundColor);\n}\n\n.pf-c-page__sidebar {\n  grid-area: nav;\n  grid-row-start: 2;\n  grid-column-start: 1;\n  z-index: var(--pf-c-page__sidebar--ZIndex);\n  width: var(--pf-c-page__sidebar--Width);\n  overflow-x: hidden;\n  overflow-y: auto;\n  -webkit-overflow-scrolling: touch;\n  background-color: var(--pf-c-page__sidebar--BackgroundColor);\n  transition: var(--pf-c-page__sidebar--Transition);\n  transform: translateX(var(--pf-c-page__sidebar--TranslateX)) translateZ(var(--pf-c-page__sidebar--TranslateZ));\n}\n.pf-c-page__sidebar.pf-m-expanded {\n  --pf-c-page__sidebar--TranslateX: var(--pf-c-page__sidebar--m-expanded--TranslateX);\n  box-shadow: var(--pf-c-page__sidebar--BoxShadow);\n}\n@media screen and (min-width: 1200px) {\n  .pf-c-page__sidebar.pf-m-expanded {\n    --pf-c-page__sidebar--BoxShadow: none;\n  }\n}\n.pf-c-page__sidebar.pf-m-collapsed {\n  max-width: 0;\n  overflow: hidden;\n}\n.pf-c-page__sidebar.pf-m-light {\n  color: var(--pf-global--Color--100);\n  --pf-c-page__sidebar--BackgroundColor: var(--pf-c-page__sidebar--m-light--BackgroundColor);\n  border-right: var(--pf-c-page__sidebar--m-light--BorderRightWidth) solid var(--pf-c-page__sidebar--m-light--BorderRightColor);\n}\n\n.pf-c-page__sidebar-body {\n  padding-top: var(--pf-c-page__sidebar-body--PaddingTop);\n  padding-bottom: var(--pf-c-page__sidebar-body--PaddingBottom);\n}\n.pf-c-page__sidebar-body.pf-m-menu {\n  --pf-c-page__sidebar-body--PaddingTop: var(--pf-c-page__sidebar-body--m-menu--PaddingTop);\n  --pf-c-page__sidebar-body--PaddingBottom: var(--pf-c-page__sidebar-body--m-menu--PaddingBottom);\n  background-color: var(--pf-global--palette--black-900);\n  border-top: var(--pf-c-page__sidebar-body--m-menu--BorderTopWidth) solid var(--pf-c-page__sidebar-body--m-menu--BorderTopColor);\n}\n.pf-c-page__sidebar-body.pf-m-menu + .pf-c-page__sidebar-body.pf-m-menu {\n  --pf-c-page__sidebar-body--m-menu--BorderTopWidth: 0;\n}\n.pf-c-page__sidebar-body.pf-m-menu .pf-c-context-selector {\n  --pf-c-context-selector__toggle--BorderTopColor: transparent;\n  --pf-c-context-selector__toggle--BorderRightColor: transparent;\n  --pf-c-context-selector__toggle--BorderBottomColor: var(--pf-c-page__sidebar-body--m-menu--c-context-selector--BorderBottomColor);\n  --pf-c-context-selector__toggle--BorderLeftColor: transparent;\n  --pf-c-context-selector__menu--Top: 100%;\n  color: var(--pf-global--Color--100);\n  width: 100%;\n}\n\n.pf-c-page__main-nav.pf-m-limit-width,\n.pf-c-page__main-breadcrumb.pf-m-limit-width,\n.pf-c-page__main-tabs.pf-m-limit-width,\n.pf-c-page__main-section.pf-m-limit-width,\n.pf-c-page__main-wizard.pf-m-limit-width {\n  display: flex;\n  flex-direction: column;\n  padding: 0;\n}\n.pf-c-page__main-nav.pf-m-limit-width > .pf-c-page__main-body,\n.pf-c-page__main-breadcrumb.pf-m-limit-width > .pf-c-page__main-body,\n.pf-c-page__main-tabs.pf-m-limit-width > .pf-c-page__main-body,\n.pf-c-page__main-section.pf-m-limit-width > .pf-c-page__main-body,\n.pf-c-page__main-wizard.pf-m-limit-width > .pf-c-page__main-body {\n  flex: 1;\n  max-width: var(--pf-c-page--section--m-limit-width--MaxWidth);\n}\n.pf-c-page__main-nav.pf-m-limit-width.pf-m-align-center,\n.pf-c-page__main-breadcrumb.pf-m-limit-width.pf-m-align-center,\n.pf-c-page__main-tabs.pf-m-limit-width.pf-m-align-center,\n.pf-c-page__main-section.pf-m-limit-width.pf-m-align-center,\n.pf-c-page__main-wizard.pf-m-limit-width.pf-m-align-center {\n  align-items: center;\n}\n.pf-c-page__main-nav.pf-m-limit-width.pf-m-align-center > .pf-c-page__main-body,\n.pf-c-page__main-breadcrumb.pf-m-limit-width.pf-m-align-center > .pf-c-page__main-body,\n.pf-c-page__main-tabs.pf-m-limit-width.pf-m-align-center > .pf-c-page__main-body,\n.pf-c-page__main-section.pf-m-limit-width.pf-m-align-center > .pf-c-page__main-body,\n.pf-c-page__main-wizard.pf-m-limit-width.pf-m-align-center > .pf-c-page__main-body {\n  width: 100%;\n}\n\n.pf-c-page__main-nav,\n.pf-c-page__main-breadcrumb,\n.pf-c-page__main-tabs,\n.pf-c-page__main-section,\n.pf-c-page__main-wizard,\n.pf-c-page__main-group,\n.pf-c-page__main-subnav {\n  flex-shrink: 0;\n}\n.pf-c-page__main-nav.pf-m-overflow-scroll,\n.pf-c-page__main-breadcrumb.pf-m-overflow-scroll,\n.pf-c-page__main-tabs.pf-m-overflow-scroll,\n.pf-c-page__main-section.pf-m-overflow-scroll,\n.pf-c-page__main-wizard.pf-m-overflow-scroll,\n.pf-c-page__main-group.pf-m-overflow-scroll,\n.pf-c-page__main-subnav.pf-m-overflow-scroll {\n  position: relative;\n  flex-shrink: 1;\n  overflow: auto;\n}\n.pf-c-page__main-nav.pf-m-shadow-bottom,\n.pf-c-page__main-breadcrumb.pf-m-shadow-bottom,\n.pf-c-page__main-tabs.pf-m-shadow-bottom,\n.pf-c-page__main-section.pf-m-shadow-bottom,\n.pf-c-page__main-wizard.pf-m-shadow-bottom,\n.pf-c-page__main-group.pf-m-shadow-bottom,\n.pf-c-page__main-subnav.pf-m-shadow-bottom {\n  z-index: var(--pf-c-page--section--m-shadow-bottom--ZIndex);\n  box-shadow: var(--pf-c-page--section--m-shadow-bottom--BoxShadow);\n}\n.pf-c-page__main-nav.pf-m-shadow-top,\n.pf-c-page__main-breadcrumb.pf-m-shadow-top,\n.pf-c-page__main-tabs.pf-m-shadow-top,\n.pf-c-page__main-section.pf-m-shadow-top,\n.pf-c-page__main-wizard.pf-m-shadow-top,\n.pf-c-page__main-group.pf-m-shadow-top,\n.pf-c-page__main-subnav.pf-m-shadow-top {\n  z-index: var(--pf-c-page--section--m-shadow-top--ZIndex);\n  box-shadow: var(--pf-c-page--section--m-shadow-top--BoxShadow);\n}\n.pf-c-page__main-nav.pf-m-sticky-top,\n.pf-c-page__main-breadcrumb.pf-m-sticky-top,\n.pf-c-page__main-tabs.pf-m-sticky-top,\n.pf-c-page__main-section.pf-m-sticky-top,\n.pf-c-page__main-wizard.pf-m-sticky-top,\n.pf-c-page__main-group.pf-m-sticky-top,\n.pf-c-page__main-subnav.pf-m-sticky-top {\n  position: sticky;\n  top: 0;\n  z-index: var(--pf-c-page--section--m-sticky-top--ZIndex);\n  box-shadow: var(--pf-c-page--section--m-sticky-top--BoxShadow);\n}\n.pf-c-page__main-nav.pf-m-sticky-bottom,\n.pf-c-page__main-breadcrumb.pf-m-sticky-bottom,\n.pf-c-page__main-tabs.pf-m-sticky-bottom,\n.pf-c-page__main-section.pf-m-sticky-bottom,\n.pf-c-page__main-wizard.pf-m-sticky-bottom,\n.pf-c-page__main-group.pf-m-sticky-bottom,\n.pf-c-page__main-subnav.pf-m-sticky-bottom {\n  position: sticky;\n  bottom: 0;\n  z-index: var(--pf-c-page--section--m-sticky-bottom--ZIndex);\n  box-shadow: var(--pf-c-page--section--m-sticky-bottom--BoxShadow);\n}\n@media (min-height: 0) {\n  .pf-c-page__main-nav.pf-m-sticky-top-on-sm-height,\n.pf-c-page__main-breadcrumb.pf-m-sticky-top-on-sm-height,\n.pf-c-page__main-tabs.pf-m-sticky-top-on-sm-height,\n.pf-c-page__main-section.pf-m-sticky-top-on-sm-height,\n.pf-c-page__main-wizard.pf-m-sticky-top-on-sm-height,\n.pf-c-page__main-group.pf-m-sticky-top-on-sm-height,\n.pf-c-page__main-subnav.pf-m-sticky-top-on-sm-height {\n    position: sticky;\n    top: 0;\n    z-index: var(--pf-c-page--section--m-sticky-top--ZIndex);\n    box-shadow: var(--pf-c-page--section--m-sticky-top--BoxShadow);\n  }\n  .pf-c-page__main-nav.pf-m-sticky-bottom-on-sm-height,\n.pf-c-page__main-breadcrumb.pf-m-sticky-bottom-on-sm-height,\n.pf-c-page__main-tabs.pf-m-sticky-bottom-on-sm-height,\n.pf-c-page__main-section.pf-m-sticky-bottom-on-sm-height,\n.pf-c-page__main-wizard.pf-m-sticky-bottom-on-sm-height,\n.pf-c-page__main-group.pf-m-sticky-bottom-on-sm-height,\n.pf-c-page__main-subnav.pf-m-sticky-bottom-on-sm-height {\n    position: sticky;\n    bottom: 0;\n    z-index: var(--pf-c-page--section--m-sticky-bottom--ZIndex);\n    box-shadow: var(--pf-c-page--section--m-sticky-bottom--BoxShadow);\n  }\n}\n@media (min-height: 40rem) {\n  .pf-c-page__main-nav.pf-m-sticky-top-on-md-height,\n.pf-c-page__main-breadcrumb.pf-m-sticky-top-on-md-height,\n.pf-c-page__main-tabs.pf-m-sticky-top-on-md-height,\n.pf-c-page__main-section.pf-m-sticky-top-on-md-height,\n.pf-c-page__main-wizard.pf-m-sticky-top-on-md-height,\n.pf-c-page__main-group.pf-m-sticky-top-on-md-height,\n.pf-c-page__main-subnav.pf-m-sticky-top-on-md-height {\n    position: sticky;\n    top: 0;\n    z-index: var(--pf-c-page--section--m-sticky-top--ZIndex);\n    box-shadow: var(--pf-c-page--section--m-sticky-top--BoxShadow);\n  }\n  .pf-c-page__main-nav.pf-m-sticky-bottom-on-md-height,\n.pf-c-page__main-breadcrumb.pf-m-sticky-bottom-on-md-height,\n.pf-c-page__main-tabs.pf-m-sticky-bottom-on-md-height,\n.pf-c-page__main-section.pf-m-sticky-bottom-on-md-height,\n.pf-c-page__main-wizard.pf-m-sticky-bottom-on-md-height,\n.pf-c-page__main-group.pf-m-sticky-bottom-on-md-height,\n.pf-c-page__main-subnav.pf-m-sticky-bottom-on-md-height {\n    position: sticky;\n    bottom: 0;\n    z-index: var(--pf-c-page--section--m-sticky-bottom--ZIndex);\n    box-shadow: var(--pf-c-page--section--m-sticky-bottom--BoxShadow);\n  }\n}\n@media (min-height: 48rem) {\n  .pf-c-page__main-nav.pf-m-sticky-top-on-lg-height,\n.pf-c-page__main-breadcrumb.pf-m-sticky-top-on-lg-height,\n.pf-c-page__main-tabs.pf-m-sticky-top-on-lg-height,\n.pf-c-page__main-section.pf-m-sticky-top-on-lg-height,\n.pf-c-page__main-wizard.pf-m-sticky-top-on-lg-height,\n.pf-c-page__main-group.pf-m-sticky-top-on-lg-height,\n.pf-c-page__main-subnav.pf-m-sticky-top-on-lg-height {\n    position: sticky;\n    top: 0;\n    z-index: var(--pf-c-page--section--m-sticky-top--ZIndex);\n    box-shadow: var(--pf-c-page--section--m-sticky-top--BoxShadow);\n  }\n  .pf-c-page__main-nav.pf-m-sticky-bottom-on-lg-height,\n.pf-c-page__main-breadcrumb.pf-m-sticky-bottom-on-lg-height,\n.pf-c-page__main-tabs.pf-m-sticky-bottom-on-lg-height,\n.pf-c-page__main-section.pf-m-sticky-bottom-on-lg-height,\n.pf-c-page__main-wizard.pf-m-sticky-bottom-on-lg-height,\n.pf-c-page__main-group.pf-m-sticky-bottom-on-lg-height,\n.pf-c-page__main-subnav.pf-m-sticky-bottom-on-lg-height {\n    position: sticky;\n    bottom: 0;\n    z-index: var(--pf-c-page--section--m-sticky-bottom--ZIndex);\n    box-shadow: var(--pf-c-page--section--m-sticky-bottom--BoxShadow);\n  }\n}\n@media (min-height: 60rem) {\n  .pf-c-page__main-nav.pf-m-sticky-top-on-xl-height,\n.pf-c-page__main-breadcrumb.pf-m-sticky-top-on-xl-height,\n.pf-c-page__main-tabs.pf-m-sticky-top-on-xl-height,\n.pf-c-page__main-section.pf-m-sticky-top-on-xl-height,\n.pf-c-page__main-wizard.pf-m-sticky-top-on-xl-height,\n.pf-c-page__main-group.pf-m-sticky-top-on-xl-height,\n.pf-c-page__main-subnav.pf-m-sticky-top-on-xl-height {\n    position: sticky;\n    top: 0;\n    z-index: var(--pf-c-page--section--m-sticky-top--ZIndex);\n    box-shadow: var(--pf-c-page--section--m-sticky-top--BoxShadow);\n  }\n  .pf-c-page__main-nav.pf-m-sticky-bottom-on-xl-height,\n.pf-c-page__main-breadcrumb.pf-m-sticky-bottom-on-xl-height,\n.pf-c-page__main-tabs.pf-m-sticky-bottom-on-xl-height,\n.pf-c-page__main-section.pf-m-sticky-bottom-on-xl-height,\n.pf-c-page__main-wizard.pf-m-sticky-bottom-on-xl-height,\n.pf-c-page__main-group.pf-m-sticky-bottom-on-xl-height,\n.pf-c-page__main-subnav.pf-m-sticky-bottom-on-xl-height {\n    position: sticky;\n    bottom: 0;\n    z-index: var(--pf-c-page--section--m-sticky-bottom--ZIndex);\n    box-shadow: var(--pf-c-page--section--m-sticky-bottom--BoxShadow);\n  }\n}\n@media (min-height: 80rem) {\n  .pf-c-page__main-nav.pf-m-sticky-top-on-2xl-height,\n.pf-c-page__main-breadcrumb.pf-m-sticky-top-on-2xl-height,\n.pf-c-page__main-tabs.pf-m-sticky-top-on-2xl-height,\n.pf-c-page__main-section.pf-m-sticky-top-on-2xl-height,\n.pf-c-page__main-wizard.pf-m-sticky-top-on-2xl-height,\n.pf-c-page__main-group.pf-m-sticky-top-on-2xl-height,\n.pf-c-page__main-subnav.pf-m-sticky-top-on-2xl-height {\n    position: sticky;\n    top: 0;\n    z-index: var(--pf-c-page--section--m-sticky-top--ZIndex);\n    box-shadow: var(--pf-c-page--section--m-sticky-top--BoxShadow);\n  }\n  .pf-c-page__main-nav.pf-m-sticky-bottom-on-2xl-height,\n.pf-c-page__main-breadcrumb.pf-m-sticky-bottom-on-2xl-height,\n.pf-c-page__main-tabs.pf-m-sticky-bottom-on-2xl-height,\n.pf-c-page__main-section.pf-m-sticky-bottom-on-2xl-height,\n.pf-c-page__main-wizard.pf-m-sticky-bottom-on-2xl-height,\n.pf-c-page__main-group.pf-m-sticky-bottom-on-2xl-height,\n.pf-c-page__main-subnav.pf-m-sticky-bottom-on-2xl-height {\n    position: sticky;\n    bottom: 0;\n    z-index: var(--pf-c-page--section--m-sticky-bottom--ZIndex);\n    box-shadow: var(--pf-c-page--section--m-sticky-bottom--BoxShadow);\n  }\n}\n\n.pf-c-page__main,\n.pf-c-page__drawer {\n  grid-area: main;\n  z-index: var(--pf-c-page__main--ZIndex);\n  overflow-x: hidden;\n  overflow-y: auto;\n  -webkit-overflow-scrolling: touch;\n}\n.pf-c-page__main:focus,\n.pf-c-page__drawer:focus {\n  outline: 0;\n}\n\n.pf-c-page__main,\n.pf-c-page__main-drawer,\n.pf-c-page__main-group {\n  display: flex;\n  flex-direction: column;\n}\n\n.pf-c-page__main-nav {\n  padding-top: var(--pf-c-page__main-nav--PaddingTop);\n  padding-right: var(--pf-c-page__main-nav--PaddingRight);\n  padding-left: var(--pf-c-page__main-nav--PaddingLeft);\n  background-color: var(--pf-c-page__main-nav--BackgroundColor);\n}\n.pf-c-page__main-nav.pf-m-sticky-top, .pf-c-page__main-group.pf-m-sticky-top .pf-c-page__main-nav:last-child {\n  padding-bottom: var(--pf-c-page__main-nav--m-sticky-top--PaddingBottom);\n}\n@media (min-height: 0) {\n  .pf-c-page__main-nav.pf-m-sticky-top-on-sm-height, .pf-c-page__main-group.pf-m-sticky-top-on-sm-height .pf-c-page__main-nav:last-child {\n    padding-bottom: var(--pf-c-page__main-nav--m-sticky-top--PaddingBottom);\n  }\n}\n@media (min-height: 40rem) {\n  .pf-c-page__main-nav.pf-m-sticky-top-on-md-height, .pf-c-page__main-group.pf-m-sticky-top-on-md-height .pf-c-page__main-nav:last-child {\n    padding-bottom: var(--pf-c-page__main-nav--m-sticky-top--PaddingBottom);\n  }\n}\n@media (min-height: 48rem) {\n  .pf-c-page__main-nav.pf-m-sticky-top-on-lg-height, .pf-c-page__main-group.pf-m-sticky-top-on-lg-height .pf-c-page__main-nav:last-child {\n    padding-bottom: var(--pf-c-page__main-nav--m-sticky-top--PaddingBottom);\n  }\n}\n@media (min-height: 60rem) {\n  .pf-c-page__main-nav.pf-m-sticky-top-on-xl-height, .pf-c-page__main-group.pf-m-sticky-top-on-xl-height .pf-c-page__main-nav:last-child {\n    padding-bottom: var(--pf-c-page__main-nav--m-sticky-top--PaddingBottom);\n  }\n}\n@media (min-height: 80rem) {\n  .pf-c-page__main-nav.pf-m-sticky-top-on-2xl-height, .pf-c-page__main-group.pf-m-sticky-top-on-2xl-height .pf-c-page__main-nav:last-child {\n    padding-bottom: var(--pf-c-page__main-nav--m-sticky-top--PaddingBottom);\n  }\n}\n\n.pf-c-page__main-subnav {\n  background-color: var(--pf-c-page__main-subnav--BackgroundColor);\n  border-top: var(--pf-c-page__main-subnav--BorderTopWidth) solid var(--pf-c-page__main-subnav--BorderTopColor);\n  border-left: var(--pf-c-page__main-subnav--BorderLeftWidth) solid var(--pf-c-page__main-subnav--BorderLeftColor);\n}\n@media screen and (min-width: 1200px) {\n  .pf-c-page__sidebar ~ .pf-c-page__main {\n    --pf-c-page__main-subnav--BorderLeftWidth: var(--pf-c-page__sidebar--main__main-subnav--BorderLeftWidth);\n  }\n}\n.pf-c-page__sidebar.pf-m-collapsed ~ .pf-c-page__main {\n  --pf-c-page__main-subnav--BorderLeftWidth: var(--pf-c-page__sidebar--m-collapsed--main__main-subnav--BorderLeftWidth);\n}\n\n.pf-c-page__main-breadcrumb {\n  padding: var(--pf-c-page__main-breadcrumb--PaddingTop) var(--pf-c-page__main-breadcrumb--PaddingRight) var(--pf-c-page__main-breadcrumb--PaddingBottom) var(--pf-c-page__main-breadcrumb--PaddingLeft);\n  background-color: var(--pf-c-page__main-breadcrumb--BackgroundColor);\n}\n.pf-c-page__main-breadcrumb + .pf-c-page__main-section {\n  --pf-c-page__main-section--PaddingTop: var(--pf-c-page__main-breadcrumb--main-section--PaddingTop);\n}\n.pf-c-page__main-breadcrumb.pf-m-sticky-top, .pf-c-page__main-group.pf-m-sticky-top .pf-c-page__main-breadcrumb:last-child {\n  --pf-c-page__main-breadcrumb--PaddingBottom: var(--pf-c-page__main-breadcrumb--m-sticky-top--PaddingBottom);\n}\n@media (min-height: 0) {\n  .pf-c-page__main-breadcrumb.pf-m-sticky-top-on-sm-height, .pf-c-page__main-group.pf-m-sticky-top-on-sm-height .pf-c-page__main-breadcrumb:last-child {\n    --pf-c-page__main-breadcrumb--PaddingBottom: var(--pf-c-page__main-breadcrumb--m-sticky-top--PaddingBottom);\n  }\n}\n@media (min-height: 40rem) {\n  .pf-c-page__main-breadcrumb.pf-m-sticky-top-on-md-height, .pf-c-page__main-group.pf-m-sticky-top-on-md-height .pf-c-page__main-breadcrumb:last-child {\n    --pf-c-page__main-breadcrumb--PaddingBottom: var(--pf-c-page__main-breadcrumb--m-sticky-top--PaddingBottom);\n  }\n}\n@media (min-height: 48rem) {\n  .pf-c-page__main-breadcrumb.pf-m-sticky-top-on-lg-height, .pf-c-page__main-group.pf-m-sticky-top-on-lg-height .pf-c-page__main-breadcrumb:last-child {\n    --pf-c-page__main-breadcrumb--PaddingBottom: var(--pf-c-page__main-breadcrumb--m-sticky-top--PaddingBottom);\n  }\n}\n@media (min-height: 60rem) {\n  .pf-c-page__main-breadcrumb.pf-m-sticky-top-on-xl-height, .pf-c-page__main-group.pf-m-sticky-top-on-xl-height .pf-c-page__main-breadcrumb:last-child {\n    --pf-c-page__main-breadcrumb--PaddingBottom: var(--pf-c-page__main-breadcrumb--m-sticky-top--PaddingBottom);\n  }\n}\n@media (min-height: 80rem) {\n  .pf-c-page__main-breadcrumb.pf-m-sticky-top-on-2xl-height, .pf-c-page__main-group.pf-m-sticky-top-on-2xl-height .pf-c-page__main-breadcrumb:last-child {\n    --pf-c-page__main-breadcrumb--PaddingBottom: var(--pf-c-page__main-breadcrumb--m-sticky-top--PaddingBottom);\n  }\n}\n\n.pf-c-page__main-tabs {\n  padding: var(--pf-c-page__main-tabs--PaddingTop) var(--pf-c-page__main-tabs--PaddingRight) var(--pf-c-page__main-tabs--PaddingBottom) var(--pf-c-page__main-tabs--PaddingLeft);\n  background-color: var(--pf-c-page__main-tabs--BackgroundColor);\n}\n.pf-c-page__main-nav + .pf-c-page__main-tabs {\n  --pf-c-page__main-tabs--PaddingTop: var(--pf-c-page__main-nav--page__main-tabs--PaddingTop);\n}\n.pf-c-page__main-breadcrumb + .pf-c-page__main-tabs {\n  --pf-c-page__main-tabs--PaddingTop: var(--pf-c-page__main-breadcrumb--page__main-tabs--PaddingTop);\n}\n\n.pf-c-page__main-section:last-child, .pf-c-page__main-section:only-child, .pf-c-page__main-section.pf-m-fill,\n.pf-c-page__main-group:last-child,\n.pf-c-page__main-group:only-child,\n.pf-c-page__main-group.pf-m-fill,\n.pf-c-page__main-wizard:last-child,\n.pf-c-page__main-wizard:only-child,\n.pf-c-page__main-wizard.pf-m-fill {\n  flex-grow: 1;\n}\n.pf-c-page__main-section.pf-m-no-fill,\n.pf-c-page__main-group.pf-m-no-fill,\n.pf-c-page__main-wizard.pf-m-no-fill {\n  flex-grow: 0;\n}\n\n.pf-c-page__main-section {\n  padding: var(--pf-c-page__main-section--PaddingTop) var(--pf-c-page__main-section--PaddingRight) var(--pf-c-page__main-section--PaddingBottom) var(--pf-c-page__main-section--PaddingLeft);\n  background-color: var(--pf-c-page__main-section--BackgroundColor);\n}\n.pf-c-page__main-section.pf-m-light {\n  --pf-c-page__main-section--BackgroundColor: var(--pf-c-page__main-section--m-light--BackgroundColor);\n}\n.pf-c-page__main-section.pf-m-light-100 {\n  --pf-c-page__main-section--BackgroundColor: var(--pf-c-page__main-section--m-light-100--BackgroundColor);\n}\n.pf-c-page__main-section[class*=pf-m-dark-] {\n  color: var(--pf-global--Color--100);\n}\n.pf-c-page__main-section.pf-m-dark-100 {\n  --pf-c-page__main-section--BackgroundColor: var(--pf-c-page__main-section--m-dark-100--BackgroundColor);\n}\n.pf-c-page__main-section.pf-m-dark-200 {\n  --pf-c-page__main-section--BackgroundColor: var(--pf-c-page__main-section--m-dark-200--BackgroundColor);\n}\n.pf-c-page__main-section.pf-m-padding {\n  padding: var(--pf-c-page__main-section--PaddingTop) var(--pf-c-page__main-section--PaddingRight) var(--pf-c-page__main-section--PaddingBottom) var(--pf-c-page__main-section--PaddingLeft);\n}\n.pf-c-page__main-section.pf-m-padding.pf-m-limit-width {\n  padding: 0;\n}\n.pf-c-page__main-section.pf-m-padding.pf-m-limit-width .pf-c-page__main-body {\n  padding: var(--pf-c-page__main-section--PaddingTop) var(--pf-c-page__main-section--PaddingRight) var(--pf-c-page__main-section--PaddingBottom) var(--pf-c-page__main-section--PaddingLeft);\n}\n.pf-c-page__main-section.pf-m-no-padding, .pf-c-page__main-section.pf-m-no-padding.pf-m-limit-width .pf-c-page__main-body {\n  padding: 0;\n}\n@media (min-width: 576px) {\n  .pf-c-page__main-section.pf-m-padding-on-sm {\n    padding: var(--pf-c-page__main-section--PaddingTop) var(--pf-c-page__main-section--PaddingRight) var(--pf-c-page__main-section--PaddingBottom) var(--pf-c-page__main-section--PaddingLeft);\n  }\n  .pf-c-page__main-section.pf-m-padding-on-sm.pf-m-limit-width {\n    padding: 0;\n  }\n  .pf-c-page__main-section.pf-m-padding-on-sm.pf-m-limit-width .pf-c-page__main-body {\n    padding: var(--pf-c-page__main-section--PaddingTop) var(--pf-c-page__main-section--PaddingRight) var(--pf-c-page__main-section--PaddingBottom) var(--pf-c-page__main-section--PaddingLeft);\n  }\n  .pf-c-page__main-section.pf-m-no-padding-on-sm, .pf-c-page__main-section.pf-m-no-padding-on-sm.pf-m-limit-width .pf-c-page__main-body {\n    padding: 0;\n  }\n}\n@media (min-width: 768px) {\n  .pf-c-page__main-section.pf-m-padding-on-md {\n    padding: var(--pf-c-page__main-section--PaddingTop) var(--pf-c-page__main-section--PaddingRight) var(--pf-c-page__main-section--PaddingBottom) var(--pf-c-page__main-section--PaddingLeft);\n  }\n  .pf-c-page__main-section.pf-m-padding-on-md.pf-m-limit-width {\n    padding: 0;\n  }\n  .pf-c-page__main-section.pf-m-padding-on-md.pf-m-limit-width .pf-c-page__main-body {\n    padding: var(--pf-c-page__main-section--PaddingTop) var(--pf-c-page__main-section--PaddingRight) var(--pf-c-page__main-section--PaddingBottom) var(--pf-c-page__main-section--PaddingLeft);\n  }\n  .pf-c-page__main-section.pf-m-no-padding-on-md, .pf-c-page__main-section.pf-m-no-padding-on-md.pf-m-limit-width .pf-c-page__main-body {\n    padding: 0;\n  }\n}\n@media (min-width: 992px) {\n  .pf-c-page__main-section.pf-m-padding-on-lg {\n    padding: var(--pf-c-page__main-section--PaddingTop) var(--pf-c-page__main-section--PaddingRight) var(--pf-c-page__main-section--PaddingBottom) var(--pf-c-page__main-section--PaddingLeft);\n  }\n  .pf-c-page__main-section.pf-m-padding-on-lg.pf-m-limit-width {\n    padding: 0;\n  }\n  .pf-c-page__main-section.pf-m-padding-on-lg.pf-m-limit-width .pf-c-page__main-body {\n    padding: var(--pf-c-page__main-section--PaddingTop) var(--pf-c-page__main-section--PaddingRight) var(--pf-c-page__main-section--PaddingBottom) var(--pf-c-page__main-section--PaddingLeft);\n  }\n  .pf-c-page__main-section.pf-m-no-padding-on-lg, .pf-c-page__main-section.pf-m-no-padding-on-lg.pf-m-limit-width .pf-c-page__main-body {\n    padding: 0;\n  }\n}\n@media (min-width: 1200px) {\n  .pf-c-page__main-section.pf-m-padding-on-xl {\n    padding: var(--pf-c-page__main-section--PaddingTop) var(--pf-c-page__main-section--PaddingRight) var(--pf-c-page__main-section--PaddingBottom) var(--pf-c-page__main-section--PaddingLeft);\n  }\n  .pf-c-page__main-section.pf-m-padding-on-xl.pf-m-limit-width {\n    padding: 0;\n  }\n  .pf-c-page__main-section.pf-m-padding-on-xl.pf-m-limit-width .pf-c-page__main-body {\n    padding: var(--pf-c-page__main-section--PaddingTop) var(--pf-c-page__main-section--PaddingRight) var(--pf-c-page__main-section--PaddingBottom) var(--pf-c-page__main-section--PaddingLeft);\n  }\n  .pf-c-page__main-section.pf-m-no-padding-on-xl, .pf-c-page__main-section.pf-m-no-padding-on-xl.pf-m-limit-width .pf-c-page__main-body {\n    padding: 0;\n  }\n}\n@media (min-width: 1450px) {\n  .pf-c-page__main-section.pf-m-padding-on-2xl {\n    padding: var(--pf-c-page__main-section--PaddingTop) var(--pf-c-page__main-section--PaddingRight) var(--pf-c-page__main-section--PaddingBottom) var(--pf-c-page__main-section--PaddingLeft);\n  }\n  .pf-c-page__main-section.pf-m-padding-on-2xl.pf-m-limit-width {\n    padding: 0;\n  }\n  .pf-c-page__main-section.pf-m-padding-on-2xl.pf-m-limit-width .pf-c-page__main-body {\n    padding: var(--pf-c-page__main-section--PaddingTop) var(--pf-c-page__main-section--PaddingRight) var(--pf-c-page__main-section--PaddingBottom) var(--pf-c-page__main-section--PaddingLeft);\n  }\n  .pf-c-page__main-section.pf-m-no-padding-on-2xl, .pf-c-page__main-section.pf-m-no-padding-on-2xl.pf-m-limit-width .pf-c-page__main-body {\n    padding: 0;\n  }\n}\n\n.pf-c-page__main-wizard {\n  flex: 1 1;\n  min-height: 0;\n  background-color: var(--pf-c-page__main-wizard--BackgroundColor);\n  border-top: var(--pf-c-page__main-wizard--BorderTopWidth) solid var(--pf-c-page__main-wizard--BorderTopColor);\n}\n.pf-c-page__main-wizard:first-child {\n  --pf-c-page__main-wizard--BorderTopWidth: 0;\n}\n.pf-c-page__main-wizard.pf-m-light-200 {\n  --pf-c-page__main-wizard--BackgroundColor: var(--pf-c-page__main-wizard--m-light-200--BackgroundColor);\n}\n\n.pf-c-page__main-wizard .pf-c-page__main-body {\n  min-height: 0;\n}\n\n.pf-c-page__main-group {\n  flex-shrink: 0;\n}\n\n.pf-c-page__main-nav .pf-c-page__main-body {\n  padding-top: var(--pf-c-page__main-nav--PaddingTop);\n  padding-right: var(--pf-c-page__main-nav--PaddingRight);\n  padding-left: var(--pf-c-page__main-nav--PaddingLeft);\n}\n.pf-c-page__main-breadcrumb .pf-c-page__main-body {\n  padding: var(--pf-c-page__main-breadcrumb--PaddingTop) var(--pf-c-page__main-breadcrumb--PaddingRight) var(--pf-c-page__main-breadcrumb--PaddingBottom) var(--pf-c-page__main-breadcrumb--PaddingLeft);\n}\n.pf-c-page__main-section .pf-c-page__main-body {\n  padding: var(--pf-c-page__main-section--PaddingTop) var(--pf-c-page__main-section--PaddingRight) var(--pf-c-page__main-section--PaddingBottom) var(--pf-c-page__main-section--PaddingLeft);\n}\n.pf-c-page__main-tabs .pf-c-page__main-body {\n  padding: var(--pf-c-page__main-tabs--PaddingTop) var(--pf-c-page__main-tabs--PaddingRight) var(--pf-c-page__main-tabs--PaddingBottom) var(--pf-c-page__main-tabs--PaddingLeft);\n}\n\n.pf-c-page__drawer {\n  grid-area: main;\n}\n.pf-c-page__drawer > .pf-c-drawer {\n  flex: 1 0 auto;\n}\n\n:where(.pf-theme-dark) .pf-c-page__sidebar-body.pf-m-menu .pf-c-context-selector,\n:where(.pf-theme-dark) .pf-c-page__main-section[class*=pf-m-dark-],\n:where(.pf-theme-dark) .pf-c-page__header {\n  --pf-global--Color--100: #e0e0e0;\n  --pf-global--Color--200: #aaabac;\n  --pf-global--BorderColor--100: #444548;\n  --pf-global--primary-color--100: #1fa7f8;\n  --pf-global--link--Color: #1fa7f8;\n  --pf-global--link--Color--hover: #73bcf7;\n  --pf-global--BackgroundColor--100: #1b1d21;\n}\n:where(.pf-theme-dark) .pf-c-page__sidebar-body.pf-m-menu .pf-c-context-selector .pf-c-card,\n:where(.pf-theme-dark) .pf-c-page__main-section[class*=pf-m-dark-] .pf-c-card,\n:where(.pf-theme-dark) .pf-c-page__header .pf-c-card {\n  --pf-c-card--BackgroundColor: var(--pf-global--BackgroundColor--100);\n}\n:where(.pf-theme-dark) .pf-c-page__sidebar-body.pf-m-menu .pf-c-context-selector .pf-c-button,\n:where(.pf-theme-dark) .pf-c-page__main-section[class*=pf-m-dark-] .pf-c-button,\n:where(.pf-theme-dark) .pf-c-page__header .pf-c-button {\n  --pf-c-button--m-primary--Color: var(--pf-global--Color--light-100);\n  --pf-c-button--m-primary--hover--Color: var(--pf-global--Color--light-100);\n  --pf-c-button--m-primary--focus--Color: var(--pf-global--Color--light-100);\n  --pf-c-button--m-primary--active--Color: var(--pf-global--Color--light-100);\n  --pf-c-button--m-primary--BackgroundColor: var(--pf-global--primary-color--300);\n  --pf-c-button--m-primary--hover--BackgroundColor: var(--pf-global--primary-color--200);\n  --pf-c-button--m-primary--focus--BackgroundColor: var(--pf-global--primary-color--200);\n  --pf-c-button--m-primary--active--BackgroundColor: var(--pf-global--primary-color--200);\n  --pf-c-button--m-secondary--Color: var(--pf-global--primary-color--100);\n  --pf-c-button--m-secondary--hover--Color: var(--pf-global--primary-color--100);\n  --pf-c-button--m-secondary--focus--Color: var(--pf-global--primary-color--100);\n  --pf-c-button--m-secondary--active--Color: var(--pf-global--primary-color--100);\n}\n\n:where(.pf-theme-dark) .pf-c-page {\n  --pf-c-page__main-section--BackgroundColor: var(--pf-global--BackgroundColor--200);\n  --pf-c-page__header-tools--c-button--m-selected--before--BackgroundColor: var(--pf-global--BackgroundColor--300);\n  --pf-c-page__sidebar--BackgroundColor: var(--pf-global--BackgroundColor--100);\n  --pf-c-page__header--BackgroundColor: var(--pf-global--palette--black-1000);\n}\n:where(.pf-theme-dark) .pf-c-page__header-tools-item.pf-m-selected .pf-c-button {\n  color: var(--pf-global--Color--100);\n}\n:where(.pf-theme-dark) .pf-c-page__header-tools-item.pf-m-selected .pf-c-button .pf-c-notification-badge:hover::before {\n  background-color: var(--pf-c-page__header-tools--c-button--m-selected--before--BackgroundColor);\n}\n:where(.pf-theme-dark) .pf-c-page__sidebar {\n  border-right: var(--pf-global--BorderWidth--sm) solid var(--pf-global--BorderColor--100);\n}\n:where(.pf-theme-dark) .pf-c-page__main-nav.pf-m-sticky-top, :where(.pf-theme-dark) .pf-c-page__main-nav.pf-m-sticky-bottom {\n  --pf-c-page__main-nav--BackgroundColor: var(--pf-global--BackgroundColor--300);\n}\n:where(.pf-theme-dark) .pf-c-page__main-breadcrumb.pf-m-sticky-top, :where(.pf-theme-dark) .pf-c-page__main-breadcrumb.pf-m-sticky-bottom {\n  --pf-c-page__main-breadcrumb--BackgroundColor: var(--pf-global--BackgroundColor--300);\n}\n:where(.pf-theme-dark) .pf-c-page__main-group.pf-m-sticky-top, :where(.pf-theme-dark) .pf-c-page__main-group.pf-m-sticky-bottom {\n  --pf-c-page__main-section--m-light--BackgroundColor: var(--pf-global--BackgroundColor--300);\n  --pf-c-page__main-section--BackgroundColor: var(--pf-global--BackgroundColor--300);\n  --pf-c-page__main-breadcrumb--BackgroundColor: var(--pf-global--BackgroundColor--300);\n  --pf-c-page__main-nav--BackgroundColor: var(--pf-global--BackgroundColor--300);\n}\n:where(.pf-theme-dark) .pf-c-page__main-section.pf-m-sticky-top, :where(.pf-theme-dark) .pf-c-page__main-section.pf-m-sticky-bottom {\n  --pf-c-page__main-section--BackgroundColor: var(--pf-global--BackgroundColor--300);\n}\n:where(.pf-theme-dark) .pf-c-page__sidebar-body.pf-m-menu .pf-c-context-selector,\n:where(.pf-theme-dark) .pf-c-page__main-section[class*=pf-m-dark-],\n:where(.pf-theme-dark) .pf-c-page__header {\n  color: var(--pf-global--Color--100);\n}';

// src/enterprise/rac/index.ts
var AUDIO_INPUT_MIMETYPE = "audio/L16;rate=44100,channels=2";
var RECONNECT_ATTEMPTS_INITIAL = 5;
var RECONNECT_ATTEMPTS = 5;
var RacInterface = class extends Interface {
  constructor() {
    super();
    this.reconnectingMessage = "";
    this.clipboardWatcherTimer = 0;
    // Set to `true` if we've successfully connected once
    this.hasConnected = false;
    // Keep track of current connection attempt
    this.connectionAttempt = 0;
    this.initKeyboard();
    this.checkClipboard();
    this.clipboardWatcherTimer = setInterval(
      this.checkClipboard.bind(this),
      500
    );
  }
  static get styles() {
    return [
      patternfly_base_default,
      page_default,
      content_default,
      authentik_default,
      i`
                :host {
                    cursor: none;
                }
                canvas {
                    z-index: unset !important;
                }
                .container {
                    overflow: hidden;
                    height: 100vh;
                    background-color: black;
                    display: flex;
                    justify-content: center;
                    align-items: center;
                }
                ak-loading-overlay {
                    z-index: 5;
                }
            `
    ];
  }
  static domSize() {
    const size = document.body.getBoundingClientRect();
    return {
      width: size.width * window.devicePixelRatio,
      height: size.height * window.devicePixelRatio
    };
  }
  connectedCallback() {
    super.connectedCallback();
    window.addEventListener(
      "focus",
      () => {
        this.checkClipboard();
      },
      {
        capture: false
      }
    );
    window.addEventListener("resize", () => {
      this.client?.sendSize(
        Math.floor(RacInterface.domSize().width),
        Math.floor(RacInterface.domSize().height)
      );
    });
  }
  disconnectedCallback() {
    super.disconnectedCallback();
    clearInterval(this.clipboardWatcherTimer);
  }
  async firstUpdated() {
    this.updateTitle();
    const wsUrl = `${window.location.protocol.replace("http", "ws")}//${window.location.host}/ws/rac/${this.token}/`;
    this.tunnel = new guacamole_common_default.WebSocketTunnel(wsUrl);
    this.tunnel.receiveTimeout = 10 * 1e3;
    this.tunnel.onerror = (status) => {
      console.debug("authentik/rac: tunnel error: ", status);
      this.reconnect();
    };
    this.client = new guacamole_common_default.Client(this.tunnel);
    this.client.onerror = (err) => {
      console.debug("authentik/rac: error: ", err);
      this.reconnect();
    };
    this.client.onstatechange = (state) => {
      this.clientState = state;
      if (state === 3 /* CONNECTED */) {
        this.onConnected();
      }
    };
    this.client.onclipboard = (stream, mimetype) => {
      if (/^text\//.exec(mimetype)) {
        const reader = new guacamole_common_default.StringReader(stream);
        let data = "";
        reader.ontext = (text) => {
          data += text;
        };
        reader.onend = () => {
          this._previousClipboardValue = data;
          navigator.clipboard.writeText(data);
        };
      } else {
        const reader = new guacamole_common_default.BlobReader(stream, mimetype);
        reader.onend = () => {
          const blob = reader.getBlob();
          navigator.clipboard.write([
            new ClipboardItem({
              [blob.type]: blob
            })
          ]);
        };
      }
      console.debug("authentik/rac: updated clipboard from remote");
    };
    const params = new URLSearchParams();
    params.set("screen_width", Math.floor(RacInterface.domSize().width).toString());
    params.set("screen_height", Math.floor(RacInterface.domSize().height).toString());
    params.set("screen_dpi", (window.devicePixelRatio * 96).toString());
    this.client.connect(params.toString());
  }
  reconnect() {
    this.clientState = void 0;
    this.connectionAttempt += 1;
    if (!this.hasConnected) {
      if (this.connectionAttempt >= RECONNECT_ATTEMPTS_INITIAL) {
        this.hasConnected = true;
        this.reconnectingMessage = msg(
          str`Connection failed after ${this.connectionAttempt} attempts.`
        );
        return;
      }
    } else {
      if (this.connectionAttempt >= RECONNECT_ATTEMPTS) {
        this.reconnectingMessage = msg(
          str`Connection failed after ${this.connectionAttempt} attempts.`
        );
        return;
      }
    }
    const delay = 500 * this.connectionAttempt;
    this.reconnectingMessage = msg(
      str`Re-connecting in ${Math.max(1, delay / 1e3)} second(s).`
    );
    setTimeout(() => {
      this.firstUpdated();
    }, delay);
  }
  updateTitle() {
    let title = this.brand?.brandingTitle || TITLE_DEFAULT;
    if (this.endpointName) {
      title = `${this.endpointName} - ${title}`;
    }
    document.title = `${title}`;
  }
  onConnected() {
    console.debug("authentik/rac: connected");
    if (!this.client) {
      return;
    }
    this.hasConnected = true;
    this.container = this.client.getDisplay().getElement();
    this.initMouse(this.container);
    this.client?.sendSize(
      Math.floor(RacInterface.domSize().width),
      Math.floor(RacInterface.domSize().height)
    );
  }
  initMouse(container) {
    const mouse = new guacamole_common_default.Mouse(container);
    const handler = (mouseState, scaleMouse = false) => {
      if (!this.client)
        return;
      if (scaleMouse) {
        mouseState.y = mouseState.y / this.client.getDisplay().getScale();
        mouseState.x = mouseState.x / this.client.getDisplay().getScale();
      }
      this.client.sendMouseState(mouseState);
    };
    mouse.onEach(["mouseup", "mousedown"], (ev) => {
      this.container?.focus();
      handler(ev.state);
    });
    mouse.on("mousemove", (ev) => {
      handler(ev.state, true);
    });
  }
  initAudioInput() {
    const stream = this.client?.createAudioStream(AUDIO_INPUT_MIMETYPE);
    if (!stream)
      return;
    const recorder = guacamole_common_default.AudioRecorder.getInstance(stream, AUDIO_INPUT_MIMETYPE);
    if (!recorder) {
      stream.sendEnd();
      return;
    }
    recorder.onclose = this.initAudioInput.bind(this);
  }
  initKeyboard() {
    const keyboard = new guacamole_common_default.Keyboard(document);
    keyboard.onkeydown = (keysym) => {
      this.client?.sendKeyEvent(1, keysym);
    };
    keyboard.onkeyup = (keysym) => {
      this.client?.sendKeyEvent(0, keysym);
    };
  }
  async checkClipboard() {
    try {
      if (!this._previousClipboardValue) {
        this._previousClipboardValue = await navigator.clipboard.readText();
        return;
      }
      const newValue = await navigator.clipboard.readText();
      if (newValue !== this._previousClipboardValue) {
        console.debug(`authentik/rac: new clipboard value: ${newValue}`);
        this._previousClipboardValue = newValue;
        this.writeClipboard(newValue);
      }
    } catch (ex) {
      if (ex instanceof DOMException) {
        return;
      }
      console.warn("authentik/rac: error reading clipboard", ex);
    }
  }
  writeClipboard(value) {
    if (!this.client) {
      return;
    }
    const stream = this.client.createClipboardStream("text/plain");
    const writer = new guacamole_common_default.StringWriter(stream);
    writer.sendText(value);
    writer.sendEnd();
    console.debug("authentik/rac: Sent clipboard");
  }
  render() {
    return x`
            ${this.clientState !== 3 /* CONNECTED */ ? x`
                      <ak-loading-overlay>
                          <span slot="body">
                              ${this.hasConnected ? x`${this.reconnectingMessage}` : x`${msg("Connecting...")}`}
                          </span>
                      </ak-loading-overlay>
                  ` : x``}
            <div class="container">${this.container}</div>
        `;
  }
};
__decorateClass([
  r6()
], RacInterface.prototype, "container", 2);
__decorateClass([
  r6()
], RacInterface.prototype, "clientState", 2);
__decorateClass([
  r6()
], RacInterface.prototype, "reconnectingMessage", 2);
__decorateClass([
  n4()
], RacInterface.prototype, "token", 2);
__decorateClass([
  n4()
], RacInterface.prototype, "endpointName", 2);
__decorateClass([
  r6()
], RacInterface.prototype, "clipboardWatcherTimer", 2);
RacInterface = __decorateClass([
  t3("ak-rac")
], RacInterface);
export {
  RacInterface
};
/*! Bundled license information:

@lit/reactive-element/css-tag.js:
  (**
   * @license
   * Copyright 2019 Google LLC
   * SPDX-License-Identifier: BSD-3-Clause
   *)

@lit/reactive-element/reactive-element.js:
  (**
   * @license
   * Copyright 2017 Google LLC
   * SPDX-License-Identifier: BSD-3-Clause
   *)

lit-html/lit-html.js:
  (**
   * @license
   * Copyright 2017 Google LLC
   * SPDX-License-Identifier: BSD-3-Clause
   *)

lit-element/lit-element.js:
  (**
   * @license
   * Copyright 2017 Google LLC
   * SPDX-License-Identifier: BSD-3-Clause
   *)

lit-html/is-server.js:
  (**
   * @license
   * Copyright 2022 Google LLC
   * SPDX-License-Identifier: BSD-3-Clause
   *)

@lit/reactive-element/decorators/custom-element.js:
  (**
   * @license
   * Copyright 2017 Google LLC
   * SPDX-License-Identifier: BSD-3-Clause
   *)

@lit/reactive-element/decorators/property.js:
  (**
   * @license
   * Copyright 2017 Google LLC
   * SPDX-License-Identifier: BSD-3-Clause
   *)

@lit/reactive-element/decorators/state.js:
  (**
   * @license
   * Copyright 2017 Google LLC
   * SPDX-License-Identifier: BSD-3-Clause
   *)

@lit/reactive-element/decorators/event-options.js:
  (**
   * @license
   * Copyright 2017 Google LLC
   * SPDX-License-Identifier: BSD-3-Clause
   *)

@lit/reactive-element/decorators/base.js:
  (**
   * @license
   * Copyright 2017 Google LLC
   * SPDX-License-Identifier: BSD-3-Clause
   *)

@lit/reactive-element/decorators/query.js:
  (**
   * @license
   * Copyright 2017 Google LLC
   * SPDX-License-Identifier: BSD-3-Clause
   *)

@lit/reactive-element/decorators/query-all.js:
  (**
   * @license
   * Copyright 2017 Google LLC
   * SPDX-License-Identifier: BSD-3-Clause
   *)

@lit/reactive-element/decorators/query-async.js:
  (**
   * @license
   * Copyright 2017 Google LLC
   * SPDX-License-Identifier: BSD-3-Clause
   *)

@lit/reactive-element/decorators/query-assigned-elements.js:
  (**
   * @license
   * Copyright 2021 Google LLC
   * SPDX-License-Identifier: BSD-3-Clause
   *)

@lit/reactive-element/decorators/query-assigned-nodes.js:
  (**
   * @license
   * Copyright 2017 Google LLC
   * SPDX-License-Identifier: BSD-3-Clause
   *)

@lit/localize/internal/str-tag.js:
  (**
   * @license
   * Copyright 2021 Google LLC
   * SPDX-License-Identifier: BSD-3-Clause
   *)

@lit/localize/internal/default-msg.js:
  (**
   * @license
   * Copyright 2021 Google LLC
   * SPDX-License-Identifier: BSD-3-Clause
   *)

@lit/localize/internal/locale-status-event.js:
  (**
   * @license
   * Copyright 2021 Google LLC
   * SPDX-License-Identifier: BSD-3-Clause
   *)

@lit/localize/internal/types.js:
  (**
   * @license
   * Copyright 2021 Google LLC
   * SPDX-License-Identifier: BSD-3-Clause
   *)

@lit/localize/internal/localized-controller.js:
  (**
   * @license
   * Copyright 2021 Google LLC
   * SPDX-License-Identifier: BSD-3-Clause
   *)

@lit/localize/internal/localized-decorator.js:
  (**
   * @license
   * Copyright 2021 Google LLC
   * SPDX-License-Identifier: BSD-3-Clause
   *)

@lit/localize/internal/deferred.js:
  (**
   * @license
   * Copyright 2020 Google LLC
   * SPDX-License-Identifier: BSD-3-Clause
   *)

@lit/localize/internal/fnv1a64.js:
  (**
   * @license
   * Copyright 2014 Travis Webb
   * SPDX-License-Identifier: MIT
   *)

@lit/localize/internal/id-generation.js:
  (**
   * @license
   * Copyright 2020 Google LLC
   * SPDX-License-Identifier: BSD-3-Clause
   *)

@lit/localize/internal/runtime-msg.js:
  (**
   * @license
   * Copyright 2021 Google LLC
   * SPDX-License-Identifier: BSD-3-Clause
   *)

@lit/localize/init/runtime.js:
  (**
   * @license
   * Copyright 2021 Google LLC
   * SPDX-License-Identifier: BSD-3-Clause
   *)

@lit/localize/init/transform.js:
  (**
   * @license
   * Copyright 2021 Google LLC
   * SPDX-License-Identifier: BSD-3-Clause
   *)

@lit/localize/lit-localize.js:
  (**
   * @license
   * Copyright 2020 Google LLC
   * SPDX-License-Identifier: BSD-3-Clause
   *)

@lit/context/lib/context-request-event.js:
  (**
   * @license
   * Copyright 2021 Google LLC
   * SPDX-License-Identifier: BSD-3-Clause
   *)

@lit/context/lib/create-context.js:
  (**
   * @license
   * Copyright 2021 Google LLC
   * SPDX-License-Identifier: BSD-3-Clause
   *)

@lit/context/lib/controllers/context-consumer.js:
  (**
   * @license
   * Copyright 2021 Google LLC
   * SPDX-License-Identifier: BSD-3-Clause
   *)

@lit/context/lib/value-notifier.js:
  (**
   * @license
   * Copyright 2021 Google LLC
   * SPDX-License-Identifier: BSD-3-Clause
   *)

@lit/context/lib/controllers/context-provider.js:
  (**
   * @license
   * Copyright 2021 Google LLC
   * SPDX-License-Identifier: BSD-3-Clause
   *)

@lit/context/lib/context-root.js:
  (**
   * @license
   * Copyright 2021 Google LLC
   * SPDX-License-Identifier: BSD-3-Clause
   *)

@lit/context/lib/decorators/provide.js:
  (**
   * @license
   * Copyright 2017 Google LLC
   * SPDX-License-Identifier: BSD-3-Clause
   *)

@lit/context/lib/decorators/consume.js:
  (**
   * @license
   * Copyright 2022 Google LLC
   * SPDX-License-Identifier: BSD-3-Clause
   *)
*/
//# sourceMappingURL=index.js.map
