import {
  en_exports
} from "./chunk-RBLIAEPY.js";
import {
  T,
  configureLocalization,
  f,
  i,
  localized,
  msg,
  n,
  r,
  s,
  u,
  x
} from "./chunk-7CCBVH6Q.js";
import {
  __decorateClass
} from "./chunk-CZCFTIBB.js";

// src/common/constants.ts
var VERSION = "2024.4.3";
var EVENT_REFRESH = "ak-refresh";
var EVENT_SIDEBAR_TOGGLE = "ak-sidebar-toggle";
var EVENT_LOCALE_CHANGE = "ak-locale-change";
var EVENT_LOCALE_REQUEST = "ak-locale-request";
var EVENT_REQUEST_POST = "ak-request-post";
var EVENT_THEME_CHANGE = "ak-theme-change";
var EVENT_REFRESH_ENTERPRISE = "ak-refresh-enterprise";

// node_modules/@goauthentik/api/dist/esm/runtime.js
var __awaiter = function(thisArg, _arguments, P, generator) {
  function adopt(value) {
    return value instanceof P ? value : new P(function(resolve) {
      resolve(value);
    });
  }
  return new (P || (P = Promise))(function(resolve, reject) {
    function fulfilled(value) {
      try {
        step(generator.next(value));
      } catch (e4) {
        reject(e4);
      }
    }
    function rejected(value) {
      try {
        step(generator["throw"](value));
      } catch (e4) {
        reject(e4);
      }
    }
    function step(result) {
      result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected);
    }
    step((generator = generator.apply(thisArg, _arguments || [])).next());
  });
};
var BASE_PATH = "http://localhost/api/v3".replace(/\/+$/, "");
var Configuration = class {
  constructor(configuration = {}) {
    this.configuration = configuration;
  }
  set config(configuration) {
    this.configuration = configuration;
  }
  get basePath() {
    return this.configuration.basePath != null ? this.configuration.basePath : BASE_PATH;
  }
  get fetchApi() {
    return this.configuration.fetchApi;
  }
  get middleware() {
    return this.configuration.middleware || [];
  }
  get queryParamsStringify() {
    return this.configuration.queryParamsStringify || querystring;
  }
  get username() {
    return this.configuration.username;
  }
  get password() {
    return this.configuration.password;
  }
  get apiKey() {
    const apiKey = this.configuration.apiKey;
    if (apiKey) {
      return typeof apiKey === "function" ? apiKey : () => apiKey;
    }
    return void 0;
  }
  get accessToken() {
    const accessToken = this.configuration.accessToken;
    if (accessToken) {
      return typeof accessToken === "function" ? accessToken : () => __awaiter(this, void 0, void 0, function* () {
        return accessToken;
      });
    }
    return void 0;
  }
  get headers() {
    return this.configuration.headers;
  }
  get credentials() {
    return this.configuration.credentials;
  }
};
var DefaultConfig = new Configuration();
var BaseAPI = class _BaseAPI {
  constructor(configuration = DefaultConfig) {
    this.configuration = configuration;
    this.fetchApi = (url, init) => __awaiter(this, void 0, void 0, function* () {
      let fetchParams = { url, init };
      for (const middleware of this.middleware) {
        if (middleware.pre) {
          fetchParams = (yield middleware.pre(Object.assign({ fetch: this.fetchApi }, fetchParams))) || fetchParams;
        }
      }
      let response = void 0;
      try {
        response = yield (this.configuration.fetchApi || fetch)(fetchParams.url, fetchParams.init);
      } catch (e4) {
        for (const middleware of this.middleware) {
          if (middleware.onError) {
            response = (yield middleware.onError({
              fetch: this.fetchApi,
              url: fetchParams.url,
              init: fetchParams.init,
              error: e4,
              response: response ? response.clone() : void 0
            })) || response;
          }
        }
        if (response === void 0) {
          if (e4 instanceof Error) {
            throw new FetchError(e4, "The request failed and the interceptors did not return an alternative response");
          } else {
            throw e4;
          }
        }
      }
      for (const middleware of this.middleware) {
        if (middleware.post) {
          response = (yield middleware.post({
            fetch: this.fetchApi,
            url: fetchParams.url,
            init: fetchParams.init,
            response: response.clone()
          })) || response;
        }
      }
      return response;
    });
    this.middleware = configuration.middleware;
  }
  withMiddleware(...middlewares) {
    const next = this.clone();
    next.middleware = next.middleware.concat(...middlewares);
    return next;
  }
  withPreMiddleware(...preMiddlewares) {
    const middlewares = preMiddlewares.map((pre) => ({ pre }));
    return this.withMiddleware(...middlewares);
  }
  withPostMiddleware(...postMiddlewares) {
    const middlewares = postMiddlewares.map((post) => ({ post }));
    return this.withMiddleware(...middlewares);
  }
  /**
   * Check if the given MIME is a JSON MIME.
   * JSON MIME examples:
   *   application/json
   *   application/json; charset=UTF8
   *   APPLICATION/JSON
   *   application/vnd.company+json
   * @param mime - MIME (Multipurpose Internet Mail Extensions)
   * @return True if the given MIME is JSON, false otherwise.
   */
  isJsonMime(mime) {
    if (!mime) {
      return false;
    }
    return _BaseAPI.jsonRegex.test(mime);
  }
  request(context, initOverrides) {
    return __awaiter(this, void 0, void 0, function* () {
      const { url, init } = yield this.createFetchParams(context, initOverrides);
      const response = yield this.fetchApi(url, init);
      if (response && (response.status >= 200 && response.status < 300)) {
        return response;
      }
      throw new ResponseError(response, "Response returned an error code");
    });
  }
  createFetchParams(context, initOverrides) {
    return __awaiter(this, void 0, void 0, function* () {
      let url = this.configuration.basePath + context.path;
      if (context.query !== void 0 && Object.keys(context.query).length !== 0) {
        url += "?" + this.configuration.queryParamsStringify(context.query);
      }
      const headers = Object.assign({}, this.configuration.headers, context.headers);
      Object.keys(headers).forEach((key) => headers[key] === void 0 ? delete headers[key] : {});
      const initOverrideFn = typeof initOverrides === "function" ? initOverrides : () => __awaiter(this, void 0, void 0, function* () {
        return initOverrides;
      });
      const initParams = {
        method: context.method,
        headers,
        body: context.body,
        credentials: this.configuration.credentials
      };
      const overriddenInit = Object.assign(Object.assign({}, initParams), yield initOverrideFn({
        init: initParams,
        context
      }));
      const init = Object.assign(Object.assign({}, overriddenInit), { body: isFormData(overriddenInit.body) || overriddenInit.body instanceof URLSearchParams || isBlob(overriddenInit.body) ? overriddenInit.body : JSON.stringify(overriddenInit.body) });
      return { url, init };
    });
  }
  /**
   * Create a shallow clone of `this` by constructing a new instance
   * and then shallow cloning data members.
   */
  clone() {
    const constructor = this.constructor;
    const next = new constructor(this.configuration);
    next.middleware = this.middleware.slice();
    return next;
  }
};
BaseAPI.jsonRegex = new RegExp("^(:?application/json|[^;/ 	]+/[^;/ 	]+[+]json)[ 	]*(:?;.*)?$", "i");
function isBlob(value) {
  return typeof Blob !== "undefined" && value instanceof Blob;
}
function isFormData(value) {
  return typeof FormData !== "undefined" && value instanceof FormData;
}
var ResponseError = class extends Error {
  constructor(response, msg2) {
    super(msg2);
    this.response = response;
    this.name = "ResponseError";
  }
};
var FetchError = class extends Error {
  constructor(cause, msg2) {
    super(msg2);
    this.cause = cause;
    this.name = "FetchError";
  }
};
var RequiredError = class extends Error {
  constructor(field, msg2) {
    super(msg2);
    this.field = field;
    this.name = "RequiredError";
  }
};
function exists(json, key) {
  const value = json[key];
  return value !== null && value !== void 0;
}
function querystring(params, prefix = "") {
  return Object.keys(params).map((key) => querystringSingleKey(key, params[key], prefix)).filter((part) => part.length > 0).join("&");
}
function querystringSingleKey(key, value, keyPrefix = "") {
  const fullKey = keyPrefix + (keyPrefix.length ? `[${key}]` : key);
  if (value instanceof Array) {
    const multiValue = value.map((singleValue) => encodeURIComponent(String(singleValue))).join(`&${encodeURIComponent(fullKey)}=`);
    return `${encodeURIComponent(fullKey)}=${multiValue}`;
  }
  if (value instanceof Set) {
    const valueAsArray = Array.from(value);
    return querystringSingleKey(key, valueAsArray, keyPrefix);
  }
  if (value instanceof Date) {
    return `${encodeURIComponent(fullKey)}=${encodeURIComponent(value.toISOString())}`;
  }
  if (value instanceof Object) {
    return querystring(value, fullKey);
  }
  return `${encodeURIComponent(fullKey)}=${encodeURIComponent(String(value))}`;
}
function canConsumeForm(consumes) {
  for (const consume of consumes) {
    if ("multipart/form-data" === consume.contentType) {
      return true;
    }
  }
  return false;
}
var JSONApiResponse = class {
  constructor(raw, transformer = (jsonValue) => jsonValue) {
    this.raw = raw;
    this.transformer = transformer;
  }
  value() {
    return __awaiter(this, void 0, void 0, function* () {
      return this.transformer(yield this.raw.json());
    });
  }
};
var VoidApiResponse = class {
  constructor(raw) {
    this.raw = raw;
  }
  value() {
    return __awaiter(this, void 0, void 0, function* () {
      return void 0;
    });
  }
};

// node_modules/@goauthentik/api/dist/esm/models/PolicyEngineMode.js
function PolicyEngineModeFromJSON(json) {
  return PolicyEngineModeFromJSONTyped(json, false);
}
function PolicyEngineModeFromJSONTyped(json, ignoreDiscriminator) {
  return json;
}
function PolicyEngineModeToJSON(value) {
  return value;
}

// node_modules/@goauthentik/api/dist/esm/models/Provider.js
function ProviderFromJSON(json) {
  return ProviderFromJSONTyped(json, false);
}
function ProviderFromJSONTyped(json, ignoreDiscriminator) {
  if (json === void 0 || json === null) {
    return json;
  }
  return {
    "pk": json["pk"],
    "name": json["name"],
    "authenticationFlow": !exists(json, "authentication_flow") ? void 0 : json["authentication_flow"],
    "authorizationFlow": json["authorization_flow"],
    "propertyMappings": !exists(json, "property_mappings") ? void 0 : json["property_mappings"],
    "component": json["component"],
    "assignedApplicationSlug": json["assigned_application_slug"],
    "assignedApplicationName": json["assigned_application_name"],
    "assignedBackchannelApplicationSlug": json["assigned_backchannel_application_slug"],
    "assignedBackchannelApplicationName": json["assigned_backchannel_application_name"],
    "verboseName": json["verbose_name"],
    "verboseNamePlural": json["verbose_name_plural"],
    "metaModelName": json["meta_model_name"]
  };
}

// node_modules/@goauthentik/api/dist/esm/models/Application.js
function ApplicationFromJSON(json) {
  return ApplicationFromJSONTyped(json, false);
}
function ApplicationFromJSONTyped(json, ignoreDiscriminator) {
  if (json === void 0 || json === null) {
    return json;
  }
  return {
    "pk": json["pk"],
    "name": json["name"],
    "slug": json["slug"],
    "provider": !exists(json, "provider") ? void 0 : json["provider"],
    "providerObj": ProviderFromJSON(json["provider_obj"]),
    "backchannelProviders": !exists(json, "backchannel_providers") ? void 0 : json["backchannel_providers"],
    "backchannelProvidersObj": json["backchannel_providers_obj"].map(ProviderFromJSON),
    "launchUrl": json["launch_url"],
    "openInNewTab": !exists(json, "open_in_new_tab") ? void 0 : json["open_in_new_tab"],
    "metaLaunchUrl": !exists(json, "meta_launch_url") ? void 0 : json["meta_launch_url"],
    "metaIcon": json["meta_icon"],
    "metaDescription": !exists(json, "meta_description") ? void 0 : json["meta_description"],
    "metaPublisher": !exists(json, "meta_publisher") ? void 0 : json["meta_publisher"],
    "policyEngineMode": !exists(json, "policy_engine_mode") ? void 0 : PolicyEngineModeFromJSON(json["policy_engine_mode"]),
    "group": !exists(json, "group") ? void 0 : json["group"]
  };
}

// node_modules/@goauthentik/api/dist/esm/models/ApplicationRequest.js
function ApplicationRequestToJSON(value) {
  if (value === void 0) {
    return void 0;
  }
  if (value === null) {
    return null;
  }
  return {
    "name": value.name,
    "slug": value.slug,
    "provider": value.provider,
    "backchannel_providers": value.backchannelProviders,
    "open_in_new_tab": value.openInNewTab,
    "meta_launch_url": value.metaLaunchUrl,
    "meta_description": value.metaDescription,
    "meta_publisher": value.metaPublisher,
    "policy_engine_mode": PolicyEngineModeToJSON(value.policyEngineMode),
    "group": value.group
  };
}

// node_modules/@goauthentik/api/dist/esm/models/AuthenticatedSessionAsn.js
function AuthenticatedSessionAsnFromJSON(json) {
  return AuthenticatedSessionAsnFromJSONTyped(json, false);
}
function AuthenticatedSessionAsnFromJSONTyped(json, ignoreDiscriminator) {
  if (json === void 0 || json === null) {
    return json;
  }
  return {
    "asn": json["asn"],
    "asOrg": json["as_org"],
    "network": json["network"]
  };
}

// node_modules/@goauthentik/api/dist/esm/models/AuthenticatedSessionGeoIp.js
function AuthenticatedSessionGeoIpFromJSON(json) {
  return AuthenticatedSessionGeoIpFromJSONTyped(json, false);
}
function AuthenticatedSessionGeoIpFromJSONTyped(json, ignoreDiscriminator) {
  if (json === void 0 || json === null) {
    return json;
  }
  return {
    "continent": json["continent"],
    "country": json["country"],
    "lat": json["lat"],
    "_long": json["long"],
    "city": json["city"]
  };
}

// node_modules/@goauthentik/api/dist/esm/models/AuthenticatedSessionUserAgentDevice.js
function AuthenticatedSessionUserAgentDeviceFromJSON(json) {
  return AuthenticatedSessionUserAgentDeviceFromJSONTyped(json, false);
}
function AuthenticatedSessionUserAgentDeviceFromJSONTyped(json, ignoreDiscriminator) {
  if (json === void 0 || json === null) {
    return json;
  }
  return {
    "brand": json["brand"],
    "family": json["family"],
    "model": json["model"]
  };
}

// node_modules/@goauthentik/api/dist/esm/models/AuthenticatedSessionUserAgentOs.js
function AuthenticatedSessionUserAgentOsFromJSON(json) {
  return AuthenticatedSessionUserAgentOsFromJSONTyped(json, false);
}
function AuthenticatedSessionUserAgentOsFromJSONTyped(json, ignoreDiscriminator) {
  if (json === void 0 || json === null) {
    return json;
  }
  return {
    "family": json["family"],
    "major": json["major"],
    "minor": json["minor"],
    "patch": json["patch"],
    "patchMinor": json["patch_minor"]
  };
}

// node_modules/@goauthentik/api/dist/esm/models/AuthenticatedSessionUserAgentUserAgent.js
function AuthenticatedSessionUserAgentUserAgentFromJSON(json) {
  return AuthenticatedSessionUserAgentUserAgentFromJSONTyped(json, false);
}
function AuthenticatedSessionUserAgentUserAgentFromJSONTyped(json, ignoreDiscriminator) {
  if (json === void 0 || json === null) {
    return json;
  }
  return {
    "family": json["family"],
    "major": json["major"],
    "minor": json["minor"],
    "patch": json["patch"]
  };
}

// node_modules/@goauthentik/api/dist/esm/models/AuthenticatedSessionUserAgent.js
function AuthenticatedSessionUserAgentFromJSON(json) {
  return AuthenticatedSessionUserAgentFromJSONTyped(json, false);
}
function AuthenticatedSessionUserAgentFromJSONTyped(json, ignoreDiscriminator) {
  if (json === void 0 || json === null) {
    return json;
  }
  return {
    "device": AuthenticatedSessionUserAgentDeviceFromJSON(json["device"]),
    "os": AuthenticatedSessionUserAgentOsFromJSON(json["os"]),
    "userAgent": AuthenticatedSessionUserAgentUserAgentFromJSON(json["user_agent"]),
    "string": json["string"]
  };
}

// node_modules/@goauthentik/api/dist/esm/models/AuthenticatedSession.js
function AuthenticatedSessionFromJSON(json) {
  return AuthenticatedSessionFromJSONTyped(json, false);
}
function AuthenticatedSessionFromJSONTyped(json, ignoreDiscriminator) {
  if (json === void 0 || json === null) {
    return json;
  }
  return {
    "uuid": !exists(json, "uuid") ? void 0 : json["uuid"],
    "current": json["current"],
    "userAgent": AuthenticatedSessionUserAgentFromJSON(json["user_agent"]),
    "geoIp": AuthenticatedSessionGeoIpFromJSON(json["geo_ip"]),
    "asn": AuthenticatedSessionAsnFromJSON(json["asn"]),
    "user": json["user"],
    "lastIp": json["last_ip"],
    "lastUserAgent": !exists(json, "last_user_agent") ? void 0 : json["last_user_agent"],
    "lastUsed": new Date(json["last_used"]),
    "expires": !exists(json, "expires") ? void 0 : json["expires"] === null ? null : new Date(json["expires"])
  };
}

// node_modules/@goauthentik/api/dist/esm/models/Brand.js
function BrandFromJSON(json) {
  return BrandFromJSONTyped(json, false);
}
function BrandFromJSONTyped(json, ignoreDiscriminator) {
  if (json === void 0 || json === null) {
    return json;
  }
  return {
    "brandUuid": json["brand_uuid"],
    "domain": json["domain"],
    "_default": !exists(json, "default") ? void 0 : json["default"],
    "brandingTitle": !exists(json, "branding_title") ? void 0 : json["branding_title"],
    "brandingLogo": !exists(json, "branding_logo") ? void 0 : json["branding_logo"],
    "brandingFavicon": !exists(json, "branding_favicon") ? void 0 : json["branding_favicon"],
    "flowAuthentication": !exists(json, "flow_authentication") ? void 0 : json["flow_authentication"],
    "flowInvalidation": !exists(json, "flow_invalidation") ? void 0 : json["flow_invalidation"],
    "flowRecovery": !exists(json, "flow_recovery") ? void 0 : json["flow_recovery"],
    "flowUnenrollment": !exists(json, "flow_unenrollment") ? void 0 : json["flow_unenrollment"],
    "flowUserSettings": !exists(json, "flow_user_settings") ? void 0 : json["flow_user_settings"],
    "flowDeviceCode": !exists(json, "flow_device_code") ? void 0 : json["flow_device_code"],
    "webCertificate": !exists(json, "web_certificate") ? void 0 : json["web_certificate"],
    "attributes": !exists(json, "attributes") ? void 0 : json["attributes"]
  };
}

// node_modules/@goauthentik/api/dist/esm/models/BrandRequest.js
function BrandRequestToJSON(value) {
  if (value === void 0) {
    return void 0;
  }
  if (value === null) {
    return null;
  }
  return {
    "domain": value.domain,
    "default": value._default,
    "branding_title": value.brandingTitle,
    "branding_logo": value.brandingLogo,
    "branding_favicon": value.brandingFavicon,
    "flow_authentication": value.flowAuthentication,
    "flow_invalidation": value.flowInvalidation,
    "flow_recovery": value.flowRecovery,
    "flow_unenrollment": value.flowUnenrollment,
    "flow_user_settings": value.flowUserSettings,
    "flow_device_code": value.flowDeviceCode,
    "web_certificate": value.webCertificate,
    "attributes": value.attributes
  };
}

// node_modules/@goauthentik/api/dist/esm/models/CapabilitiesEnum.js
function CapabilitiesEnumFromJSON(json) {
  return CapabilitiesEnumFromJSONTyped(json, false);
}
function CapabilitiesEnumFromJSONTyped(json, ignoreDiscriminator) {
  return json;
}

// node_modules/@goauthentik/api/dist/esm/models/ClientTypeEnum.js
function ClientTypeEnumToJSON(value) {
  return value;
}

// node_modules/@goauthentik/api/dist/esm/models/ErrorReportingConfig.js
function ErrorReportingConfigFromJSON(json) {
  return ErrorReportingConfigFromJSONTyped(json, false);
}
function ErrorReportingConfigFromJSONTyped(json, ignoreDiscriminator) {
  if (json === void 0 || json === null) {
    return json;
  }
  return {
    "enabled": json["enabled"],
    "sentryDsn": json["sentry_dsn"],
    "environment": json["environment"],
    "sendPii": json["send_pii"],
    "tracesSampleRate": json["traces_sample_rate"]
  };
}

// node_modules/@goauthentik/api/dist/esm/models/Config.js
function ConfigFromJSON(json) {
  return ConfigFromJSONTyped(json, false);
}
function ConfigFromJSONTyped(json, ignoreDiscriminator) {
  if (json === void 0 || json === null) {
    return json;
  }
  return {
    "errorReporting": ErrorReportingConfigFromJSON(json["error_reporting"]),
    "capabilities": json["capabilities"].map(CapabilitiesEnumFromJSON),
    "cacheTimeout": json["cache_timeout"],
    "cacheTimeoutFlows": json["cache_timeout_flows"],
    "cacheTimeoutPolicies": json["cache_timeout_policies"],
    "cacheTimeoutReputation": json["cache_timeout_reputation"]
  };
}

// node_modules/@goauthentik/api/dist/esm/models/GroupMember.js
function GroupMemberFromJSON(json) {
  return GroupMemberFromJSONTyped(json, false);
}
function GroupMemberFromJSONTyped(json, ignoreDiscriminator) {
  if (json === void 0 || json === null) {
    return json;
  }
  return {
    "pk": json["pk"],
    "username": json["username"],
    "name": json["name"],
    "isActive": !exists(json, "is_active") ? void 0 : json["is_active"],
    "lastLogin": !exists(json, "last_login") ? void 0 : json["last_login"] === null ? null : new Date(json["last_login"]),
    "email": !exists(json, "email") ? void 0 : json["email"],
    "attributes": !exists(json, "attributes") ? void 0 : json["attributes"],
    "uid": json["uid"]
  };
}

// node_modules/@goauthentik/api/dist/esm/models/Coordinate.js
function CoordinateFromJSON(json) {
  return CoordinateFromJSONTyped(json, false);
}
function CoordinateFromJSONTyped(json, ignoreDiscriminator) {
  if (json === void 0 || json === null) {
    return json;
  }
  return {
    "xCord": json["x_cord"],
    "yCord": json["y_cord"]
  };
}

// node_modules/@goauthentik/api/dist/esm/models/FooterLink.js
function FooterLinkFromJSON(json) {
  return FooterLinkFromJSONTyped(json, false);
}
function FooterLinkFromJSONTyped(json, ignoreDiscriminator) {
  if (json === void 0 || json === null) {
    return json;
  }
  return {
    "href": json["href"],
    "name": json["name"]
  };
}

// node_modules/@goauthentik/api/dist/esm/models/UiThemeEnum.js
var UiThemeEnum = {
  Automatic: "automatic",
  Light: "light",
  Dark: "dark",
  UnknownDefaultOpenApi: "11184809"
};
function UiThemeEnumFromJSON(json) {
  return UiThemeEnumFromJSONTyped(json, false);
}
function UiThemeEnumFromJSONTyped(json, ignoreDiscriminator) {
  return json;
}

// node_modules/@goauthentik/api/dist/esm/models/CurrentBrand.js
function CurrentBrandFromJSON(json) {
  return CurrentBrandFromJSONTyped(json, false);
}
function CurrentBrandFromJSONTyped(json, ignoreDiscriminator) {
  if (json === void 0 || json === null) {
    return json;
  }
  return {
    "matchedDomain": json["matched_domain"],
    "brandingTitle": json["branding_title"],
    "brandingLogo": json["branding_logo"],
    "brandingFavicon": json["branding_favicon"],
    "uiFooterLinks": json["ui_footer_links"].map(FooterLinkFromJSON),
    "uiTheme": UiThemeEnumFromJSON(json["ui_theme"]),
    "flowAuthentication": !exists(json, "flow_authentication") ? void 0 : json["flow_authentication"],
    "flowInvalidation": !exists(json, "flow_invalidation") ? void 0 : json["flow_invalidation"],
    "flowRecovery": !exists(json, "flow_recovery") ? void 0 : json["flow_recovery"],
    "flowUnenrollment": !exists(json, "flow_unenrollment") ? void 0 : json["flow_unenrollment"],
    "flowUserSettings": !exists(json, "flow_user_settings") ? void 0 : json["flow_user_settings"],
    "flowDeviceCode": !exists(json, "flow_device_code") ? void 0 : json["flow_device_code"],
    "defaultLocale": json["default_locale"]
  };
}

// node_modules/@goauthentik/api/dist/esm/models/DigestAlgorithmEnum.js
function DigestAlgorithmEnumToJSON(value) {
  return value;
}

// node_modules/@goauthentik/api/dist/esm/models/IssuerModeEnum.js
function IssuerModeEnumToJSON(value) {
  return value;
}

// node_modules/@goauthentik/api/dist/esm/models/SubModeEnum.js
function SubModeEnumToJSON(value) {
  return value;
}

// node_modules/@goauthentik/api/dist/esm/models/UserGroup.js
function UserGroupFromJSON(json) {
  return UserGroupFromJSONTyped(json, false);
}
function UserGroupFromJSONTyped(json, ignoreDiscriminator) {
  if (json === void 0 || json === null) {
    return json;
  }
  return {
    "pk": json["pk"],
    "numPk": json["num_pk"],
    "name": json["name"],
    "isSuperuser": !exists(json, "is_superuser") ? void 0 : json["is_superuser"],
    "parent": !exists(json, "parent") ? void 0 : json["parent"],
    "parentName": json["parent_name"],
    "attributes": !exists(json, "attributes") ? void 0 : json["attributes"]
  };
}

// node_modules/@goauthentik/api/dist/esm/models/UserTypeEnum.js
function UserTypeEnumFromJSON(json) {
  return UserTypeEnumFromJSONTyped(json, false);
}
function UserTypeEnumFromJSONTyped(json, ignoreDiscriminator) {
  return json;
}
function UserTypeEnumToJSON(value) {
  return value;
}

// node_modules/@goauthentik/api/dist/esm/models/User.js
function UserFromJSON(json) {
  return UserFromJSONTyped(json, false);
}
function UserFromJSONTyped(json, ignoreDiscriminator) {
  if (json === void 0 || json === null) {
    return json;
  }
  return {
    "pk": json["pk"],
    "username": json["username"],
    "name": json["name"],
    "isActive": !exists(json, "is_active") ? void 0 : json["is_active"],
    "lastLogin": !exists(json, "last_login") ? void 0 : json["last_login"] === null ? null : new Date(json["last_login"]),
    "isSuperuser": json["is_superuser"],
    "groups": !exists(json, "groups") ? void 0 : json["groups"],
    "groupsObj": json["groups_obj"] === null ? null : json["groups_obj"].map(UserGroupFromJSON),
    "email": !exists(json, "email") ? void 0 : json["email"],
    "avatar": json["avatar"],
    "attributes": !exists(json, "attributes") ? void 0 : json["attributes"],
    "uid": json["uid"],
    "path": !exists(json, "path") ? void 0 : json["path"],
    "type": !exists(json, "type") ? void 0 : UserTypeEnumFromJSON(json["type"]),
    "uuid": json["uuid"]
  };
}

// node_modules/@goauthentik/api/dist/esm/models/FilePathRequest.js
function FilePathRequestToJSON(value) {
  if (value === void 0) {
    return void 0;
  }
  if (value === null) {
    return null;
  }
  return {
    "url": value.url
  };
}

// node_modules/@goauthentik/api/dist/esm/models/LogLevelEnum.js
function LogLevelEnumFromJSON(json) {
  return LogLevelEnumFromJSONTyped(json, false);
}
function LogLevelEnumFromJSONTyped(json, ignoreDiscriminator) {
  return json;
}

// node_modules/@goauthentik/api/dist/esm/models/LogEvent.js
function LogEventFromJSON(json) {
  return LogEventFromJSONTyped(json, false);
}
function LogEventFromJSONTyped(json, ignoreDiscriminator) {
  if (json === void 0 || json === null) {
    return json;
  }
  return {
    "timestamp": new Date(json["timestamp"]),
    "logLevel": LogLevelEnumFromJSON(json["log_level"]),
    "logger": json["logger"],
    "event": json["event"],
    "attributes": json["attributes"]
  };
}

// node_modules/@goauthentik/api/dist/esm/models/Role.js
function RoleFromJSON(json) {
  return RoleFromJSONTyped(json, false);
}
function RoleFromJSONTyped(json, ignoreDiscriminator) {
  if (json === void 0 || json === null) {
    return json;
  }
  return {
    "pk": json["pk"],
    "name": json["name"]
  };
}

// node_modules/@goauthentik/api/dist/esm/models/Group.js
function GroupFromJSON(json) {
  return GroupFromJSONTyped(json, false);
}
function GroupFromJSONTyped(json, ignoreDiscriminator) {
  if (json === void 0 || json === null) {
    return json;
  }
  return {
    "pk": json["pk"],
    "numPk": json["num_pk"],
    "name": json["name"],
    "isSuperuser": !exists(json, "is_superuser") ? void 0 : json["is_superuser"],
    "parent": !exists(json, "parent") ? void 0 : json["parent"],
    "parentName": json["parent_name"],
    "users": !exists(json, "users") ? void 0 : json["users"],
    "usersObj": json["users_obj"] === null ? null : json["users_obj"].map(GroupMemberFromJSON),
    "attributes": !exists(json, "attributes") ? void 0 : json["attributes"],
    "roles": !exists(json, "roles") ? void 0 : json["roles"],
    "rolesObj": json["roles_obj"].map(RoleFromJSON)
  };
}

// node_modules/@goauthentik/api/dist/esm/models/GroupRequest.js
function GroupRequestToJSON(value) {
  if (value === void 0) {
    return void 0;
  }
  if (value === null) {
    return null;
  }
  return {
    "name": value.name,
    "is_superuser": value.isSuperuser,
    "parent": value.parent,
    "users": value.users,
    "attributes": value.attributes,
    "roles": value.roles
  };
}

// node_modules/@goauthentik/api/dist/esm/models/InstallID.js
function InstallIDFromJSON(json) {
  return InstallIDFromJSONTyped(json, false);
}
function InstallIDFromJSONTyped(json, ignoreDiscriminator) {
  if (json === void 0 || json === null) {
    return json;
  }
  return {
    "installId": json["install_id"]
  };
}

// node_modules/@goauthentik/api/dist/esm/models/IntentEnum.js
function IntentEnumFromJSON(json) {
  return IntentEnumFromJSONTyped(json, false);
}
function IntentEnumFromJSONTyped(json, ignoreDiscriminator) {
  return json;
}
function IntentEnumToJSON(value) {
  return value;
}

// node_modules/@goauthentik/api/dist/esm/models/LDAPAPIAccessMode.js
function LDAPAPIAccessModeToJSON(value) {
  return value;
}

// node_modules/@goauthentik/api/dist/esm/models/LDAPProviderRequest.js
function LDAPProviderRequestToJSON(value) {
  if (value === void 0) {
    return void 0;
  }
  if (value === null) {
    return null;
  }
  return {
    "name": value.name,
    "authentication_flow": value.authenticationFlow,
    "authorization_flow": value.authorizationFlow,
    "property_mappings": value.propertyMappings,
    "base_dn": value.baseDn,
    "search_group": value.searchGroup,
    "certificate": value.certificate,
    "tls_server_name": value.tlsServerName,
    "uid_start_number": value.uidStartNumber,
    "gid_start_number": value.gidStartNumber,
    "search_mode": LDAPAPIAccessModeToJSON(value.searchMode),
    "bind_mode": LDAPAPIAccessModeToJSON(value.bindMode),
    "mfa_support": value.mfaSupport
  };
}

// node_modules/@goauthentik/api/dist/esm/models/License.js
function LicenseFromJSON(json) {
  return LicenseFromJSONTyped(json, false);
}
function LicenseFromJSONTyped(json, ignoreDiscriminator) {
  if (json === void 0 || json === null) {
    return json;
  }
  return {
    "licenseUuid": json["license_uuid"],
    "name": json["name"],
    "key": json["key"],
    "expiry": new Date(json["expiry"]),
    "internalUsers": json["internal_users"],
    "externalUsers": json["external_users"]
  };
}

// node_modules/@goauthentik/api/dist/esm/models/LicenseForecast.js
function LicenseForecastFromJSON(json) {
  return LicenseForecastFromJSONTyped(json, false);
}
function LicenseForecastFromJSONTyped(json, ignoreDiscriminator) {
  if (json === void 0 || json === null) {
    return json;
  }
  return {
    "internalUsers": json["internal_users"],
    "externalUsers": json["external_users"],
    "forecastedInternalUsers": json["forecasted_internal_users"],
    "forecastedExternalUsers": json["forecasted_external_users"]
  };
}

// node_modules/@goauthentik/api/dist/esm/models/LicenseRequest.js
function LicenseRequestToJSON(value) {
  if (value === void 0) {
    return void 0;
  }
  if (value === null) {
    return null;
  }
  return {
    "key": value.key
  };
}

// node_modules/@goauthentik/api/dist/esm/models/LicenseSummary.js
function LicenseSummaryFromJSON(json) {
  return LicenseSummaryFromJSONTyped(json, false);
}
function LicenseSummaryFromJSONTyped(json, ignoreDiscriminator) {
  if (json === void 0 || json === null) {
    return json;
  }
  return {
    "internalUsers": json["internal_users"],
    "externalUsers": json["external_users"],
    "valid": json["valid"],
    "showAdminWarning": json["show_admin_warning"],
    "showUserWarning": json["show_user_warning"],
    "readOnly": json["read_only"],
    "latestValid": new Date(json["latest_valid"]),
    "hasLicense": json["has_license"]
  };
}

// node_modules/@goauthentik/api/dist/esm/models/Link.js
function LinkFromJSON(json) {
  return LinkFromJSONTyped(json, false);
}
function LinkFromJSONTyped(json, ignoreDiscriminator) {
  if (json === void 0 || json === null) {
    return json;
  }
  return {
    "link": json["link"]
  };
}

// node_modules/@goauthentik/api/dist/esm/models/OAuth2ProviderRequest.js
function OAuth2ProviderRequestToJSON(value) {
  if (value === void 0) {
    return void 0;
  }
  if (value === null) {
    return null;
  }
  return {
    "name": value.name,
    "authentication_flow": value.authenticationFlow,
    "authorization_flow": value.authorizationFlow,
    "property_mappings": value.propertyMappings,
    "client_type": ClientTypeEnumToJSON(value.clientType),
    "client_id": value.clientId,
    "client_secret": value.clientSecret,
    "access_code_validity": value.accessCodeValidity,
    "access_token_validity": value.accessTokenValidity,
    "refresh_token_validity": value.refreshTokenValidity,
    "include_claims_in_id_token": value.includeClaimsInIdToken,
    "signing_key": value.signingKey,
    "redirect_uris": value.redirectUris,
    "sub_mode": SubModeEnumToJSON(value.subMode),
    "issuer_mode": IssuerModeEnumToJSON(value.issuerMode),
    "jwks_sources": value.jwksSources
  };
}

// node_modules/@goauthentik/api/dist/esm/models/ProxyMode.js
function ProxyModeToJSON(value) {
  return value;
}

// node_modules/@goauthentik/api/dist/esm/models/ProxyProviderRequest.js
function ProxyProviderRequestToJSON(value) {
  if (value === void 0) {
    return void 0;
  }
  if (value === null) {
    return null;
  }
  return {
    "name": value.name,
    "authentication_flow": value.authenticationFlow,
    "authorization_flow": value.authorizationFlow,
    "property_mappings": value.propertyMappings,
    "internal_host": value.internalHost,
    "external_host": value.externalHost,
    "internal_host_ssl_validation": value.internalHostSslValidation,
    "certificate": value.certificate,
    "skip_path_regex": value.skipPathRegex,
    "basic_auth_enabled": value.basicAuthEnabled,
    "basic_auth_password_attribute": value.basicAuthPasswordAttribute,
    "basic_auth_user_attribute": value.basicAuthUserAttribute,
    "mode": ProxyModeToJSON(value.mode),
    "intercept_header_auth": value.interceptHeaderAuth,
    "cookie_domain": value.cookieDomain,
    "jwks_sources": value.jwksSources,
    "access_token_validity": value.accessTokenValidity,
    "refresh_token_validity": value.refreshTokenValidity
  };
}

// node_modules/@goauthentik/api/dist/esm/models/RACProviderRequest.js
function RACProviderRequestToJSON(value) {
  if (value === void 0) {
    return void 0;
  }
  if (value === null) {
    return null;
  }
  return {
    "name": value.name,
    "authentication_flow": value.authenticationFlow,
    "authorization_flow": value.authorizationFlow,
    "property_mappings": value.propertyMappings,
    "settings": value.settings,
    "connection_expiry": value.connectionExpiry,
    "delete_token_on_disconnect": value.deleteTokenOnDisconnect
  };
}

// node_modules/@goauthentik/api/dist/esm/models/RadiusProviderRequest.js
function RadiusProviderRequestToJSON(value) {
  if (value === void 0) {
    return void 0;
  }
  if (value === null) {
    return null;
  }
  return {
    "name": value.name,
    "authentication_flow": value.authenticationFlow,
    "authorization_flow": value.authorizationFlow,
    "property_mappings": value.propertyMappings,
    "client_networks": value.clientNetworks,
    "shared_secret": value.sharedSecret,
    "mfa_support": value.mfaSupport
  };
}

// node_modules/@goauthentik/api/dist/esm/models/SignatureAlgorithmEnum.js
function SignatureAlgorithmEnumToJSON(value) {
  return value;
}

// node_modules/@goauthentik/api/dist/esm/models/SpBindingEnum.js
function SpBindingEnumToJSON(value) {
  return value;
}

// node_modules/@goauthentik/api/dist/esm/models/SAMLProviderRequest.js
function SAMLProviderRequestToJSON(value) {
  if (value === void 0) {
    return void 0;
  }
  if (value === null) {
    return null;
  }
  return {
    "name": value.name,
    "authentication_flow": value.authenticationFlow,
    "authorization_flow": value.authorizationFlow,
    "property_mappings": value.propertyMappings,
    "acs_url": value.acsUrl,
    "audience": value.audience,
    "issuer": value.issuer,
    "assertion_valid_not_before": value.assertionValidNotBefore,
    "assertion_valid_not_on_or_after": value.assertionValidNotOnOrAfter,
    "session_valid_not_on_or_after": value.sessionValidNotOnOrAfter,
    "name_id_mapping": value.nameIdMapping,
    "digest_algorithm": DigestAlgorithmEnumToJSON(value.digestAlgorithm),
    "signature_algorithm": SignatureAlgorithmEnumToJSON(value.signatureAlgorithm),
    "signing_kp": value.signingKp,
    "verification_kp": value.verificationKp,
    "sp_binding": SpBindingEnumToJSON(value.spBinding),
    "default_relay_state": value.defaultRelayState
  };
}

// node_modules/@goauthentik/api/dist/esm/models/SCIMProviderRequest.js
function SCIMProviderRequestToJSON(value) {
  if (value === void 0) {
    return void 0;
  }
  if (value === null) {
    return null;
  }
  return {
    "name": value.name,
    "property_mappings": value.propertyMappings,
    "property_mappings_group": value.propertyMappingsGroup,
    "url": value.url,
    "token": value.token,
    "exclude_users_service_account": value.excludeUsersServiceAccount,
    "filter_group": value.filterGroup
  };
}

// node_modules/@goauthentik/api/dist/esm/models/ModelRequest.js
function ModelRequestToJSON(value) {
  if (value === void 0) {
    return void 0;
  }
  if (value === null) {
    return null;
  }
  switch (value["providerModel"]) {
    case "authentik_providers_ldap.ldapprovider":
      return LDAPProviderRequestToJSON(value);
    case "authentik_providers_oauth2.oauth2provider":
      return OAuth2ProviderRequestToJSON(value);
    case "authentik_providers_proxy.proxyprovider":
      return ProxyProviderRequestToJSON(value);
    case "authentik_providers_rac.racprovider":
      return RACProviderRequestToJSON(value);
    case "authentik_providers_radius.radiusprovider":
      return RadiusProviderRequestToJSON(value);
    case "authentik_providers_saml.samlprovider":
      return SAMLProviderRequestToJSON(value);
    case "authentik_providers_scim.scimprovider":
      return SCIMProviderRequestToJSON(value);
    default:
      throw new Error(`No variant of ModelRequest exists with 'providerModel=${value["providerModel"]}'`);
  }
}

// node_modules/@goauthentik/api/dist/esm/models/Pagination.js
function PaginationFromJSON(json) {
  return PaginationFromJSONTyped(json, false);
}
function PaginationFromJSONTyped(json, ignoreDiscriminator) {
  if (json === void 0 || json === null) {
    return json;
  }
  return {
    "next": json["next"],
    "previous": json["previous"],
    "count": json["count"],
    "current": json["current"],
    "totalPages": json["total_pages"],
    "startIndex": json["start_index"],
    "endIndex": json["end_index"]
  };
}

// node_modules/@goauthentik/api/dist/esm/models/PaginatedApplicationList.js
function PaginatedApplicationListFromJSON(json) {
  return PaginatedApplicationListFromJSONTyped(json, false);
}
function PaginatedApplicationListFromJSONTyped(json, ignoreDiscriminator) {
  if (json === void 0 || json === null) {
    return json;
  }
  return {
    "pagination": PaginationFromJSON(json["pagination"]),
    "results": json["results"].map(ApplicationFromJSON)
  };
}

// node_modules/@goauthentik/api/dist/esm/models/PaginatedAuthenticatedSessionList.js
function PaginatedAuthenticatedSessionListFromJSON(json) {
  return PaginatedAuthenticatedSessionListFromJSONTyped(json, false);
}
function PaginatedAuthenticatedSessionListFromJSONTyped(json, ignoreDiscriminator) {
  if (json === void 0 || json === null) {
    return json;
  }
  return {
    "pagination": PaginationFromJSON(json["pagination"]),
    "results": json["results"].map(AuthenticatedSessionFromJSON)
  };
}

// node_modules/@goauthentik/api/dist/esm/models/PaginatedBrandList.js
function PaginatedBrandListFromJSON(json) {
  return PaginatedBrandListFromJSONTyped(json, false);
}
function PaginatedBrandListFromJSONTyped(json, ignoreDiscriminator) {
  if (json === void 0 || json === null) {
    return json;
  }
  return {
    "pagination": PaginationFromJSON(json["pagination"]),
    "results": json["results"].map(BrandFromJSON)
  };
}

// node_modules/@goauthentik/api/dist/esm/models/PaginatedGroupList.js
function PaginatedGroupListFromJSON(json) {
  return PaginatedGroupListFromJSONTyped(json, false);
}
function PaginatedGroupListFromJSONTyped(json, ignoreDiscriminator) {
  if (json === void 0 || json === null) {
    return json;
  }
  return {
    "pagination": PaginationFromJSON(json["pagination"]),
    "results": json["results"].map(GroupFromJSON)
  };
}

// node_modules/@goauthentik/api/dist/esm/models/PaginatedLicenseList.js
function PaginatedLicenseListFromJSON(json) {
  return PaginatedLicenseListFromJSONTyped(json, false);
}
function PaginatedLicenseListFromJSONTyped(json, ignoreDiscriminator) {
  if (json === void 0 || json === null) {
    return json;
  }
  return {
    "pagination": PaginationFromJSON(json["pagination"]),
    "results": json["results"].map(LicenseFromJSON)
  };
}

// node_modules/@goauthentik/api/dist/esm/models/Token.js
function TokenFromJSON(json) {
  return TokenFromJSONTyped(json, false);
}
function TokenFromJSONTyped(json, ignoreDiscriminator) {
  if (json === void 0 || json === null) {
    return json;
  }
  return {
    "pk": json["pk"],
    "managed": !exists(json, "managed") ? void 0 : json["managed"],
    "identifier": json["identifier"],
    "intent": !exists(json, "intent") ? void 0 : IntentEnumFromJSON(json["intent"]),
    "user": !exists(json, "user") ? void 0 : json["user"],
    "userObj": UserFromJSON(json["user_obj"]),
    "description": !exists(json, "description") ? void 0 : json["description"],
    "expires": !exists(json, "expires") ? void 0 : json["expires"] === null ? null : new Date(json["expires"]),
    "expiring": !exists(json, "expiring") ? void 0 : json["expiring"]
  };
}

// node_modules/@goauthentik/api/dist/esm/models/PaginatedTokenList.js
function PaginatedTokenListFromJSON(json) {
  return PaginatedTokenListFromJSONTyped(json, false);
}
function PaginatedTokenListFromJSONTyped(json, ignoreDiscriminator) {
  if (json === void 0 || json === null) {
    return json;
  }
  return {
    "pagination": PaginationFromJSON(json["pagination"]),
    "results": json["results"].map(TokenFromJSON)
  };
}

// node_modules/@goauthentik/api/dist/esm/models/UserConsent.js
function UserConsentFromJSON(json) {
  return UserConsentFromJSONTyped(json, false);
}
function UserConsentFromJSONTyped(json, ignoreDiscriminator) {
  if (json === void 0 || json === null) {
    return json;
  }
  return {
    "pk": json["pk"],
    "expires": !exists(json, "expires") ? void 0 : json["expires"] === null ? null : new Date(json["expires"]),
    "expiring": !exists(json, "expiring") ? void 0 : json["expiring"],
    "user": UserFromJSON(json["user"]),
    "application": ApplicationFromJSON(json["application"]),
    "permissions": !exists(json, "permissions") ? void 0 : json["permissions"]
  };
}

// node_modules/@goauthentik/api/dist/esm/models/PaginatedUserConsentList.js
function PaginatedUserConsentListFromJSON(json) {
  return PaginatedUserConsentListFromJSONTyped(json, false);
}
function PaginatedUserConsentListFromJSONTyped(json, ignoreDiscriminator) {
  if (json === void 0 || json === null) {
    return json;
  }
  return {
    "pagination": PaginationFromJSON(json["pagination"]),
    "results": json["results"].map(UserConsentFromJSON)
  };
}

// node_modules/@goauthentik/api/dist/esm/models/PaginatedUserList.js
function PaginatedUserListFromJSON(json) {
  return PaginatedUserListFromJSONTyped(json, false);
}
function PaginatedUserListFromJSONTyped(json, ignoreDiscriminator) {
  if (json === void 0 || json === null) {
    return json;
  }
  return {
    "pagination": PaginationFromJSON(json["pagination"]),
    "results": json["results"].map(UserFromJSON)
  };
}

// node_modules/@goauthentik/api/dist/esm/models/PatchedApplicationRequest.js
function PatchedApplicationRequestToJSON(value) {
  if (value === void 0) {
    return void 0;
  }
  if (value === null) {
    return null;
  }
  return {
    "name": value.name,
    "slug": value.slug,
    "provider": value.provider,
    "backchannel_providers": value.backchannelProviders,
    "open_in_new_tab": value.openInNewTab,
    "meta_launch_url": value.metaLaunchUrl,
    "meta_description": value.metaDescription,
    "meta_publisher": value.metaPublisher,
    "policy_engine_mode": PolicyEngineModeToJSON(value.policyEngineMode),
    "group": value.group
  };
}

// node_modules/@goauthentik/api/dist/esm/models/PatchedBrandRequest.js
function PatchedBrandRequestToJSON(value) {
  if (value === void 0) {
    return void 0;
  }
  if (value === null) {
    return null;
  }
  return {
    "domain": value.domain,
    "default": value._default,
    "branding_title": value.brandingTitle,
    "branding_logo": value.brandingLogo,
    "branding_favicon": value.brandingFavicon,
    "flow_authentication": value.flowAuthentication,
    "flow_invalidation": value.flowInvalidation,
    "flow_recovery": value.flowRecovery,
    "flow_unenrollment": value.flowUnenrollment,
    "flow_user_settings": value.flowUserSettings,
    "flow_device_code": value.flowDeviceCode,
    "web_certificate": value.webCertificate,
    "attributes": value.attributes
  };
}

// node_modules/@goauthentik/api/dist/esm/models/PatchedGroupRequest.js
function PatchedGroupRequestToJSON(value) {
  if (value === void 0) {
    return void 0;
  }
  if (value === null) {
    return null;
  }
  return {
    "name": value.name,
    "is_superuser": value.isSuperuser,
    "parent": value.parent,
    "users": value.users,
    "attributes": value.attributes,
    "roles": value.roles
  };
}

// node_modules/@goauthentik/api/dist/esm/models/PatchedLicenseRequest.js
function PatchedLicenseRequestToJSON(value) {
  if (value === void 0) {
    return void 0;
  }
  if (value === null) {
    return null;
  }
  return {
    "key": value.key
  };
}

// node_modules/@goauthentik/api/dist/esm/models/PatchedTokenRequest.js
function PatchedTokenRequestToJSON(value) {
  if (value === void 0) {
    return void 0;
  }
  if (value === null) {
    return null;
  }
  return {
    "managed": value.managed,
    "identifier": value.identifier,
    "intent": IntentEnumToJSON(value.intent),
    "user": value.user,
    "description": value.description,
    "expires": value.expires === void 0 ? void 0 : value.expires === null ? null : value.expires.toISOString(),
    "expiring": value.expiring
  };
}

// node_modules/@goauthentik/api/dist/esm/models/PatchedUserRequest.js
function PatchedUserRequestToJSON(value) {
  if (value === void 0) {
    return void 0;
  }
  if (value === null) {
    return null;
  }
  return {
    "username": value.username,
    "name": value.name,
    "is_active": value.isActive,
    "last_login": value.lastLogin === void 0 ? void 0 : value.lastLogin === null ? null : value.lastLogin.toISOString(),
    "groups": value.groups,
    "email": value.email,
    "attributes": value.attributes,
    "path": value.path,
    "type": UserTypeEnumToJSON(value.type)
  };
}

// node_modules/@goauthentik/api/dist/esm/models/PolicyTestResult.js
function PolicyTestResultFromJSON(json) {
  return PolicyTestResultFromJSONTyped(json, false);
}
function PolicyTestResultFromJSONTyped(json, ignoreDiscriminator) {
  if (json === void 0 || json === null) {
    return json;
  }
  return {
    "passing": json["passing"],
    "messages": json["messages"],
    "logMessages": json["log_messages"].map(LogEventFromJSON)
  };
}

// node_modules/@goauthentik/api/dist/esm/models/ProviderModelEnum.js
function ProviderModelEnumToJSON(value) {
  return value;
}

// node_modules/@goauthentik/api/dist/esm/models/UserSelfGroups.js
function UserSelfGroupsFromJSON(json) {
  return UserSelfGroupsFromJSONTyped(json, false);
}
function UserSelfGroupsFromJSONTyped(json, ignoreDiscriminator) {
  if (json === void 0 || json === null) {
    return json;
  }
  return {
    "name": json["name"],
    "pk": json["pk"]
  };
}

// node_modules/@goauthentik/api/dist/esm/models/UserSelf.js
function UserSelfFromJSON(json) {
  return UserSelfFromJSONTyped(json, false);
}
function UserSelfFromJSONTyped(json, ignoreDiscriminator) {
  if (json === void 0 || json === null) {
    return json;
  }
  return {
    "pk": json["pk"],
    "username": json["username"],
    "name": json["name"],
    "isActive": json["is_active"],
    "isSuperuser": json["is_superuser"],
    "groups": json["groups"].map(UserSelfGroupsFromJSON),
    "email": !exists(json, "email") ? void 0 : json["email"],
    "avatar": json["avatar"],
    "uid": json["uid"],
    "settings": json["settings"],
    "type": !exists(json, "type") ? void 0 : UserTypeEnumFromJSON(json["type"]),
    "systemPermissions": json["system_permissions"]
  };
}

// node_modules/@goauthentik/api/dist/esm/models/SessionUser.js
function SessionUserFromJSON(json) {
  return SessionUserFromJSONTyped(json, false);
}
function SessionUserFromJSONTyped(json, ignoreDiscriminator) {
  if (json === void 0 || json === null) {
    return json;
  }
  return {
    "user": UserSelfFromJSON(json["user"]),
    "original": !exists(json, "original") ? void 0 : UserSelfFromJSON(json["original"])
  };
}

// node_modules/@goauthentik/api/dist/esm/models/TokenRequest.js
function TokenRequestToJSON(value) {
  if (value === void 0) {
    return void 0;
  }
  if (value === null) {
    return null;
  }
  return {
    "managed": value.managed,
    "identifier": value.identifier,
    "intent": IntentEnumToJSON(value.intent),
    "user": value.user,
    "description": value.description,
    "expires": value.expires === void 0 ? void 0 : value.expires === null ? null : value.expires.toISOString(),
    "expiring": value.expiring
  };
}

// node_modules/@goauthentik/api/dist/esm/models/TokenSetKeyRequest.js
function TokenSetKeyRequestToJSON(value) {
  if (value === void 0) {
    return void 0;
  }
  if (value === null) {
    return null;
  }
  return {
    "key": value.key
  };
}

// node_modules/@goauthentik/api/dist/esm/models/TokenView.js
function TokenViewFromJSON(json) {
  return TokenViewFromJSONTyped(json, false);
}
function TokenViewFromJSONTyped(json, ignoreDiscriminator) {
  if (json === void 0 || json === null) {
    return json;
  }
  return {
    "key": json["key"]
  };
}

// node_modules/@goauthentik/api/dist/esm/models/TransactionApplicationRequest.js
function TransactionApplicationRequestToJSON(value) {
  if (value === void 0) {
    return void 0;
  }
  if (value === null) {
    return null;
  }
  return {
    "app": ApplicationRequestToJSON(value.app),
    "provider_model": ProviderModelEnumToJSON(value.providerModel),
    "provider": ModelRequestToJSON(value.provider)
  };
}

// node_modules/@goauthentik/api/dist/esm/models/TransactionApplicationResponse.js
function TransactionApplicationResponseFromJSON(json) {
  return TransactionApplicationResponseFromJSONTyped(json, false);
}
function TransactionApplicationResponseFromJSONTyped(json, ignoreDiscriminator) {
  if (json === void 0 || json === null) {
    return json;
  }
  return {
    "applied": json["applied"],
    "logs": json["logs"]
  };
}

// node_modules/@goauthentik/api/dist/esm/models/UsedByActionEnum.js
function UsedByActionEnumFromJSON(json) {
  return UsedByActionEnumFromJSONTyped(json, false);
}
function UsedByActionEnumFromJSONTyped(json, ignoreDiscriminator) {
  return json;
}

// node_modules/@goauthentik/api/dist/esm/models/UsedBy.js
function UsedByFromJSON(json) {
  return UsedByFromJSONTyped(json, false);
}
function UsedByFromJSONTyped(json, ignoreDiscriminator) {
  if (json === void 0 || json === null) {
    return json;
  }
  return {
    "app": json["app"],
    "modelName": json["model_name"],
    "pk": json["pk"],
    "name": json["name"],
    "action": UsedByActionEnumFromJSON(json["action"])
  };
}

// node_modules/@goauthentik/api/dist/esm/models/UserAccountRequest.js
function UserAccountRequestToJSON(value) {
  if (value === void 0) {
    return void 0;
  }
  if (value === null) {
    return null;
  }
  return {
    "pk": value.pk
  };
}

// node_modules/@goauthentik/api/dist/esm/models/UserMetrics.js
function UserMetricsFromJSON(json) {
  return UserMetricsFromJSONTyped(json, false);
}
function UserMetricsFromJSONTyped(json, ignoreDiscriminator) {
  if (json === void 0 || json === null) {
    return json;
  }
  return {
    "logins": json["logins"].map(CoordinateFromJSON),
    "loginsFailed": json["logins_failed"].map(CoordinateFromJSON),
    "authorizations": json["authorizations"].map(CoordinateFromJSON)
  };
}

// node_modules/@goauthentik/api/dist/esm/models/UserPasswordSetRequest.js
function UserPasswordSetRequestToJSON(value) {
  if (value === void 0) {
    return void 0;
  }
  if (value === null) {
    return null;
  }
  return {
    "password": value.password
  };
}

// node_modules/@goauthentik/api/dist/esm/models/UserPath.js
function UserPathFromJSON(json) {
  return UserPathFromJSONTyped(json, false);
}
function UserPathFromJSONTyped(json, ignoreDiscriminator) {
  if (json === void 0 || json === null) {
    return json;
  }
  return {
    "paths": json["paths"]
  };
}

// node_modules/@goauthentik/api/dist/esm/models/UserRequest.js
function UserRequestToJSON(value) {
  if (value === void 0) {
    return void 0;
  }
  if (value === null) {
    return null;
  }
  return {
    "username": value.username,
    "name": value.name,
    "is_active": value.isActive,
    "last_login": value.lastLogin === void 0 ? void 0 : value.lastLogin === null ? null : value.lastLogin.toISOString(),
    "groups": value.groups,
    "email": value.email,
    "attributes": value.attributes,
    "path": value.path,
    "type": UserTypeEnumToJSON(value.type)
  };
}

// node_modules/@goauthentik/api/dist/esm/models/UserServiceAccountRequest.js
function UserServiceAccountRequestToJSON(value) {
  if (value === void 0) {
    return void 0;
  }
  if (value === null) {
    return null;
  }
  return {
    "name": value.name,
    "create_group": value.createGroup,
    "expiring": value.expiring,
    "expires": value.expires === void 0 ? void 0 : value.expires.toISOString()
  };
}

// node_modules/@goauthentik/api/dist/esm/models/UserServiceAccountResponse.js
function UserServiceAccountResponseFromJSON(json) {
  return UserServiceAccountResponseFromJSONTyped(json, false);
}
function UserServiceAccountResponseFromJSONTyped(json, ignoreDiscriminator) {
  if (json === void 0 || json === null) {
    return json;
  }
  return {
    "username": json["username"],
    "token": json["token"],
    "userUid": json["user_uid"],
    "userPk": json["user_pk"],
    "groupPk": !exists(json, "group_pk") ? void 0 : json["group_pk"]
  };
}

// node_modules/@goauthentik/api/dist/esm/apis/CoreApi.js
var __awaiter2 = function(thisArg, _arguments, P, generator) {
  function adopt(value) {
    return value instanceof P ? value : new P(function(resolve) {
      resolve(value);
    });
  }
  return new (P || (P = Promise))(function(resolve, reject) {
    function fulfilled(value) {
      try {
        step(generator.next(value));
      } catch (e4) {
        reject(e4);
      }
    }
    function rejected(value) {
      try {
        step(generator["throw"](value));
      } catch (e4) {
        reject(e4);
      }
    }
    function step(result) {
      result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected);
    }
    step((generator = generator.apply(thisArg, _arguments || [])).next());
  });
};
var CoreApi = class extends BaseAPI {
  /**
   * Check access to a single application by slug
   */
  coreApplicationsCheckAccessRetrieveRaw(requestParameters, initOverrides) {
    return __awaiter2(this, void 0, void 0, function* () {
      if (requestParameters.slug === null || requestParameters.slug === void 0) {
        throw new RequiredError("slug", "Required parameter requestParameters.slug was null or undefined when calling coreApplicationsCheckAccessRetrieve.");
      }
      const queryParameters = {};
      if (requestParameters.forUser !== void 0) {
        queryParameters["for_user"] = requestParameters.forUser;
      }
      const headerParameters = {};
      if (this.configuration && this.configuration.accessToken) {
        const token = this.configuration.accessToken;
        const tokenString = yield token("authentik", []);
        if (tokenString) {
          headerParameters["Authorization"] = `Bearer ${tokenString}`;
        }
      }
      const response = yield this.request({
        path: `/core/applications/{slug}/check_access/`.replace(`{${"slug"}}`, encodeURIComponent(String(requestParameters.slug))),
        method: "GET",
        headers: headerParameters,
        query: queryParameters
      }, initOverrides);
      return new JSONApiResponse(response, (jsonValue) => PolicyTestResultFromJSON(jsonValue));
    });
  }
  /**
   * Check access to a single application by slug
   */
  coreApplicationsCheckAccessRetrieve(requestParameters, initOverrides) {
    return __awaiter2(this, void 0, void 0, function* () {
      const response = yield this.coreApplicationsCheckAccessRetrieveRaw(requestParameters, initOverrides);
      return yield response.value();
    });
  }
  /**
   * Application Viewset
   */
  coreApplicationsCreateRaw(requestParameters, initOverrides) {
    return __awaiter2(this, void 0, void 0, function* () {
      if (requestParameters.applicationRequest === null || requestParameters.applicationRequest === void 0) {
        throw new RequiredError("applicationRequest", "Required parameter requestParameters.applicationRequest was null or undefined when calling coreApplicationsCreate.");
      }
      const queryParameters = {};
      const headerParameters = {};
      headerParameters["Content-Type"] = "application/json";
      if (this.configuration && this.configuration.accessToken) {
        const token = this.configuration.accessToken;
        const tokenString = yield token("authentik", []);
        if (tokenString) {
          headerParameters["Authorization"] = `Bearer ${tokenString}`;
        }
      }
      const response = yield this.request({
        path: `/core/applications/`,
        method: "POST",
        headers: headerParameters,
        query: queryParameters,
        body: ApplicationRequestToJSON(requestParameters.applicationRequest)
      }, initOverrides);
      return new JSONApiResponse(response, (jsonValue) => ApplicationFromJSON(jsonValue));
    });
  }
  /**
   * Application Viewset
   */
  coreApplicationsCreate(requestParameters, initOverrides) {
    return __awaiter2(this, void 0, void 0, function* () {
      const response = yield this.coreApplicationsCreateRaw(requestParameters, initOverrides);
      return yield response.value();
    });
  }
  /**
   * Application Viewset
   */
  coreApplicationsDestroyRaw(requestParameters, initOverrides) {
    return __awaiter2(this, void 0, void 0, function* () {
      if (requestParameters.slug === null || requestParameters.slug === void 0) {
        throw new RequiredError("slug", "Required parameter requestParameters.slug was null or undefined when calling coreApplicationsDestroy.");
      }
      const queryParameters = {};
      const headerParameters = {};
      if (this.configuration && this.configuration.accessToken) {
        const token = this.configuration.accessToken;
        const tokenString = yield token("authentik", []);
        if (tokenString) {
          headerParameters["Authorization"] = `Bearer ${tokenString}`;
        }
      }
      const response = yield this.request({
        path: `/core/applications/{slug}/`.replace(`{${"slug"}}`, encodeURIComponent(String(requestParameters.slug))),
        method: "DELETE",
        headers: headerParameters,
        query: queryParameters
      }, initOverrides);
      return new VoidApiResponse(response);
    });
  }
  /**
   * Application Viewset
   */
  coreApplicationsDestroy(requestParameters, initOverrides) {
    return __awaiter2(this, void 0, void 0, function* () {
      yield this.coreApplicationsDestroyRaw(requestParameters, initOverrides);
    });
  }
  /**
   * Custom list method that checks Policy based access instead of guardian
   */
  coreApplicationsListRaw(requestParameters, initOverrides) {
    return __awaiter2(this, void 0, void 0, function* () {
      const queryParameters = {};
      if (requestParameters.forUser !== void 0) {
        queryParameters["for_user"] = requestParameters.forUser;
      }
      if (requestParameters.group !== void 0) {
        queryParameters["group"] = requestParameters.group;
      }
      if (requestParameters.metaDescription !== void 0) {
        queryParameters["meta_description"] = requestParameters.metaDescription;
      }
      if (requestParameters.metaLaunchUrl !== void 0) {
        queryParameters["meta_launch_url"] = requestParameters.metaLaunchUrl;
      }
      if (requestParameters.metaPublisher !== void 0) {
        queryParameters["meta_publisher"] = requestParameters.metaPublisher;
      }
      if (requestParameters.name !== void 0) {
        queryParameters["name"] = requestParameters.name;
      }
      if (requestParameters.ordering !== void 0) {
        queryParameters["ordering"] = requestParameters.ordering;
      }
      if (requestParameters.page !== void 0) {
        queryParameters["page"] = requestParameters.page;
      }
      if (requestParameters.pageSize !== void 0) {
        queryParameters["page_size"] = requestParameters.pageSize;
      }
      if (requestParameters.search !== void 0) {
        queryParameters["search"] = requestParameters.search;
      }
      if (requestParameters.slug !== void 0) {
        queryParameters["slug"] = requestParameters.slug;
      }
      if (requestParameters.superuserFullList !== void 0) {
        queryParameters["superuser_full_list"] = requestParameters.superuserFullList;
      }
      const headerParameters = {};
      if (this.configuration && this.configuration.accessToken) {
        const token = this.configuration.accessToken;
        const tokenString = yield token("authentik", []);
        if (tokenString) {
          headerParameters["Authorization"] = `Bearer ${tokenString}`;
        }
      }
      const response = yield this.request({
        path: `/core/applications/`,
        method: "GET",
        headers: headerParameters,
        query: queryParameters
      }, initOverrides);
      return new JSONApiResponse(response, (jsonValue) => PaginatedApplicationListFromJSON(jsonValue));
    });
  }
  /**
   * Custom list method that checks Policy based access instead of guardian
   */
  coreApplicationsList(requestParameters = {}, initOverrides) {
    return __awaiter2(this, void 0, void 0, function* () {
      const response = yield this.coreApplicationsListRaw(requestParameters, initOverrides);
      return yield response.value();
    });
  }
  /**
   * Metrics for application logins
   */
  coreApplicationsMetricsListRaw(requestParameters, initOverrides) {
    return __awaiter2(this, void 0, void 0, function* () {
      if (requestParameters.slug === null || requestParameters.slug === void 0) {
        throw new RequiredError("slug", "Required parameter requestParameters.slug was null or undefined when calling coreApplicationsMetricsList.");
      }
      const queryParameters = {};
      const headerParameters = {};
      if (this.configuration && this.configuration.accessToken) {
        const token = this.configuration.accessToken;
        const tokenString = yield token("authentik", []);
        if (tokenString) {
          headerParameters["Authorization"] = `Bearer ${tokenString}`;
        }
      }
      const response = yield this.request({
        path: `/core/applications/{slug}/metrics/`.replace(`{${"slug"}}`, encodeURIComponent(String(requestParameters.slug))),
        method: "GET",
        headers: headerParameters,
        query: queryParameters
      }, initOverrides);
      return new JSONApiResponse(response, (jsonValue) => jsonValue.map(CoordinateFromJSON));
    });
  }
  /**
   * Metrics for application logins
   */
  coreApplicationsMetricsList(requestParameters, initOverrides) {
    return __awaiter2(this, void 0, void 0, function* () {
      const response = yield this.coreApplicationsMetricsListRaw(requestParameters, initOverrides);
      return yield response.value();
    });
  }
  /**
   * Application Viewset
   */
  coreApplicationsPartialUpdateRaw(requestParameters, initOverrides) {
    return __awaiter2(this, void 0, void 0, function* () {
      if (requestParameters.slug === null || requestParameters.slug === void 0) {
        throw new RequiredError("slug", "Required parameter requestParameters.slug was null or undefined when calling coreApplicationsPartialUpdate.");
      }
      const queryParameters = {};
      const headerParameters = {};
      headerParameters["Content-Type"] = "application/json";
      if (this.configuration && this.configuration.accessToken) {
        const token = this.configuration.accessToken;
        const tokenString = yield token("authentik", []);
        if (tokenString) {
          headerParameters["Authorization"] = `Bearer ${tokenString}`;
        }
      }
      const response = yield this.request({
        path: `/core/applications/{slug}/`.replace(`{${"slug"}}`, encodeURIComponent(String(requestParameters.slug))),
        method: "PATCH",
        headers: headerParameters,
        query: queryParameters,
        body: PatchedApplicationRequestToJSON(requestParameters.patchedApplicationRequest)
      }, initOverrides);
      return new JSONApiResponse(response, (jsonValue) => ApplicationFromJSON(jsonValue));
    });
  }
  /**
   * Application Viewset
   */
  coreApplicationsPartialUpdate(requestParameters, initOverrides) {
    return __awaiter2(this, void 0, void 0, function* () {
      const response = yield this.coreApplicationsPartialUpdateRaw(requestParameters, initOverrides);
      return yield response.value();
    });
  }
  /**
   * Application Viewset
   */
  coreApplicationsRetrieveRaw(requestParameters, initOverrides) {
    return __awaiter2(this, void 0, void 0, function* () {
      if (requestParameters.slug === null || requestParameters.slug === void 0) {
        throw new RequiredError("slug", "Required parameter requestParameters.slug was null or undefined when calling coreApplicationsRetrieve.");
      }
      const queryParameters = {};
      const headerParameters = {};
      if (this.configuration && this.configuration.accessToken) {
        const token = this.configuration.accessToken;
        const tokenString = yield token("authentik", []);
        if (tokenString) {
          headerParameters["Authorization"] = `Bearer ${tokenString}`;
        }
      }
      const response = yield this.request({
        path: `/core/applications/{slug}/`.replace(`{${"slug"}}`, encodeURIComponent(String(requestParameters.slug))),
        method: "GET",
        headers: headerParameters,
        query: queryParameters
      }, initOverrides);
      return new JSONApiResponse(response, (jsonValue) => ApplicationFromJSON(jsonValue));
    });
  }
  /**
   * Application Viewset
   */
  coreApplicationsRetrieve(requestParameters, initOverrides) {
    return __awaiter2(this, void 0, void 0, function* () {
      const response = yield this.coreApplicationsRetrieveRaw(requestParameters, initOverrides);
      return yield response.value();
    });
  }
  /**
   * Set application icon
   */
  coreApplicationsSetIconCreateRaw(requestParameters, initOverrides) {
    return __awaiter2(this, void 0, void 0, function* () {
      if (requestParameters.slug === null || requestParameters.slug === void 0) {
        throw new RequiredError("slug", "Required parameter requestParameters.slug was null or undefined when calling coreApplicationsSetIconCreate.");
      }
      const queryParameters = {};
      const headerParameters = {};
      if (this.configuration && this.configuration.accessToken) {
        const token = this.configuration.accessToken;
        const tokenString = yield token("authentik", []);
        if (tokenString) {
          headerParameters["Authorization"] = `Bearer ${tokenString}`;
        }
      }
      const consumes = [
        { contentType: "multipart/form-data" }
      ];
      const canConsumeForm2 = canConsumeForm(consumes);
      let formParams;
      let useForm = false;
      useForm = canConsumeForm2;
      if (useForm) {
        formParams = new FormData();
      } else {
        formParams = new URLSearchParams();
      }
      if (requestParameters.file !== void 0) {
        formParams.append("file", requestParameters.file);
      }
      if (requestParameters.clear !== void 0) {
        formParams.append("clear", requestParameters.clear);
      }
      const response = yield this.request({
        path: `/core/applications/{slug}/set_icon/`.replace(`{${"slug"}}`, encodeURIComponent(String(requestParameters.slug))),
        method: "POST",
        headers: headerParameters,
        query: queryParameters,
        body: formParams
      }, initOverrides);
      return new VoidApiResponse(response);
    });
  }
  /**
   * Set application icon
   */
  coreApplicationsSetIconCreate(requestParameters, initOverrides) {
    return __awaiter2(this, void 0, void 0, function* () {
      yield this.coreApplicationsSetIconCreateRaw(requestParameters, initOverrides);
    });
  }
  /**
   * Set application icon (as URL)
   */
  coreApplicationsSetIconUrlCreateRaw(requestParameters, initOverrides) {
    return __awaiter2(this, void 0, void 0, function* () {
      if (requestParameters.slug === null || requestParameters.slug === void 0) {
        throw new RequiredError("slug", "Required parameter requestParameters.slug was null or undefined when calling coreApplicationsSetIconUrlCreate.");
      }
      if (requestParameters.filePathRequest === null || requestParameters.filePathRequest === void 0) {
        throw new RequiredError("filePathRequest", "Required parameter requestParameters.filePathRequest was null or undefined when calling coreApplicationsSetIconUrlCreate.");
      }
      const queryParameters = {};
      const headerParameters = {};
      headerParameters["Content-Type"] = "application/json";
      if (this.configuration && this.configuration.accessToken) {
        const token = this.configuration.accessToken;
        const tokenString = yield token("authentik", []);
        if (tokenString) {
          headerParameters["Authorization"] = `Bearer ${tokenString}`;
        }
      }
      const response = yield this.request({
        path: `/core/applications/{slug}/set_icon_url/`.replace(`{${"slug"}}`, encodeURIComponent(String(requestParameters.slug))),
        method: "POST",
        headers: headerParameters,
        query: queryParameters,
        body: FilePathRequestToJSON(requestParameters.filePathRequest)
      }, initOverrides);
      return new VoidApiResponse(response);
    });
  }
  /**
   * Set application icon (as URL)
   */
  coreApplicationsSetIconUrlCreate(requestParameters, initOverrides) {
    return __awaiter2(this, void 0, void 0, function* () {
      yield this.coreApplicationsSetIconUrlCreateRaw(requestParameters, initOverrides);
    });
  }
  /**
   * Application Viewset
   */
  coreApplicationsUpdateRaw(requestParameters, initOverrides) {
    return __awaiter2(this, void 0, void 0, function* () {
      if (requestParameters.slug === null || requestParameters.slug === void 0) {
        throw new RequiredError("slug", "Required parameter requestParameters.slug was null or undefined when calling coreApplicationsUpdate.");
      }
      if (requestParameters.applicationRequest === null || requestParameters.applicationRequest === void 0) {
        throw new RequiredError("applicationRequest", "Required parameter requestParameters.applicationRequest was null or undefined when calling coreApplicationsUpdate.");
      }
      const queryParameters = {};
      const headerParameters = {};
      headerParameters["Content-Type"] = "application/json";
      if (this.configuration && this.configuration.accessToken) {
        const token = this.configuration.accessToken;
        const tokenString = yield token("authentik", []);
        if (tokenString) {
          headerParameters["Authorization"] = `Bearer ${tokenString}`;
        }
      }
      const response = yield this.request({
        path: `/core/applications/{slug}/`.replace(`{${"slug"}}`, encodeURIComponent(String(requestParameters.slug))),
        method: "PUT",
        headers: headerParameters,
        query: queryParameters,
        body: ApplicationRequestToJSON(requestParameters.applicationRequest)
      }, initOverrides);
      return new JSONApiResponse(response, (jsonValue) => ApplicationFromJSON(jsonValue));
    });
  }
  /**
   * Application Viewset
   */
  coreApplicationsUpdate(requestParameters, initOverrides) {
    return __awaiter2(this, void 0, void 0, function* () {
      const response = yield this.coreApplicationsUpdateRaw(requestParameters, initOverrides);
      return yield response.value();
    });
  }
  /**
   * Get a list of all objects that use this object
   */
  coreApplicationsUsedByListRaw(requestParameters, initOverrides) {
    return __awaiter2(this, void 0, void 0, function* () {
      if (requestParameters.slug === null || requestParameters.slug === void 0) {
        throw new RequiredError("slug", "Required parameter requestParameters.slug was null or undefined when calling coreApplicationsUsedByList.");
      }
      const queryParameters = {};
      const headerParameters = {};
      if (this.configuration && this.configuration.accessToken) {
        const token = this.configuration.accessToken;
        const tokenString = yield token("authentik", []);
        if (tokenString) {
          headerParameters["Authorization"] = `Bearer ${tokenString}`;
        }
      }
      const response = yield this.request({
        path: `/core/applications/{slug}/used_by/`.replace(`{${"slug"}}`, encodeURIComponent(String(requestParameters.slug))),
        method: "GET",
        headers: headerParameters,
        query: queryParameters
      }, initOverrides);
      return new JSONApiResponse(response, (jsonValue) => jsonValue.map(UsedByFromJSON));
    });
  }
  /**
   * Get a list of all objects that use this object
   */
  coreApplicationsUsedByList(requestParameters, initOverrides) {
    return __awaiter2(this, void 0, void 0, function* () {
      const response = yield this.coreApplicationsUsedByListRaw(requestParameters, initOverrides);
      return yield response.value();
    });
  }
  /**
   * AuthenticatedSession Viewset
   */
  coreAuthenticatedSessionsDestroyRaw(requestParameters, initOverrides) {
    return __awaiter2(this, void 0, void 0, function* () {
      if (requestParameters.uuid === null || requestParameters.uuid === void 0) {
        throw new RequiredError("uuid", "Required parameter requestParameters.uuid was null or undefined when calling coreAuthenticatedSessionsDestroy.");
      }
      const queryParameters = {};
      const headerParameters = {};
      if (this.configuration && this.configuration.accessToken) {
        const token = this.configuration.accessToken;
        const tokenString = yield token("authentik", []);
        if (tokenString) {
          headerParameters["Authorization"] = `Bearer ${tokenString}`;
        }
      }
      const response = yield this.request({
        path: `/core/authenticated_sessions/{uuid}/`.replace(`{${"uuid"}}`, encodeURIComponent(String(requestParameters.uuid))),
        method: "DELETE",
        headers: headerParameters,
        query: queryParameters
      }, initOverrides);
      return new VoidApiResponse(response);
    });
  }
  /**
   * AuthenticatedSession Viewset
   */
  coreAuthenticatedSessionsDestroy(requestParameters, initOverrides) {
    return __awaiter2(this, void 0, void 0, function* () {
      yield this.coreAuthenticatedSessionsDestroyRaw(requestParameters, initOverrides);
    });
  }
  /**
   * AuthenticatedSession Viewset
   */
  coreAuthenticatedSessionsListRaw(requestParameters, initOverrides) {
    return __awaiter2(this, void 0, void 0, function* () {
      const queryParameters = {};
      if (requestParameters.lastIp !== void 0) {
        queryParameters["last_ip"] = requestParameters.lastIp;
      }
      if (requestParameters.lastUserAgent !== void 0) {
        queryParameters["last_user_agent"] = requestParameters.lastUserAgent;
      }
      if (requestParameters.ordering !== void 0) {
        queryParameters["ordering"] = requestParameters.ordering;
      }
      if (requestParameters.page !== void 0) {
        queryParameters["page"] = requestParameters.page;
      }
      if (requestParameters.pageSize !== void 0) {
        queryParameters["page_size"] = requestParameters.pageSize;
      }
      if (requestParameters.search !== void 0) {
        queryParameters["search"] = requestParameters.search;
      }
      if (requestParameters.userUsername !== void 0) {
        queryParameters["user__username"] = requestParameters.userUsername;
      }
      const headerParameters = {};
      if (this.configuration && this.configuration.accessToken) {
        const token = this.configuration.accessToken;
        const tokenString = yield token("authentik", []);
        if (tokenString) {
          headerParameters["Authorization"] = `Bearer ${tokenString}`;
        }
      }
      const response = yield this.request({
        path: `/core/authenticated_sessions/`,
        method: "GET",
        headers: headerParameters,
        query: queryParameters
      }, initOverrides);
      return new JSONApiResponse(response, (jsonValue) => PaginatedAuthenticatedSessionListFromJSON(jsonValue));
    });
  }
  /**
   * AuthenticatedSession Viewset
   */
  coreAuthenticatedSessionsList(requestParameters = {}, initOverrides) {
    return __awaiter2(this, void 0, void 0, function* () {
      const response = yield this.coreAuthenticatedSessionsListRaw(requestParameters, initOverrides);
      return yield response.value();
    });
  }
  /**
   * AuthenticatedSession Viewset
   */
  coreAuthenticatedSessionsRetrieveRaw(requestParameters, initOverrides) {
    return __awaiter2(this, void 0, void 0, function* () {
      if (requestParameters.uuid === null || requestParameters.uuid === void 0) {
        throw new RequiredError("uuid", "Required parameter requestParameters.uuid was null or undefined when calling coreAuthenticatedSessionsRetrieve.");
      }
      const queryParameters = {};
      const headerParameters = {};
      if (this.configuration && this.configuration.accessToken) {
        const token = this.configuration.accessToken;
        const tokenString = yield token("authentik", []);
        if (tokenString) {
          headerParameters["Authorization"] = `Bearer ${tokenString}`;
        }
      }
      const response = yield this.request({
        path: `/core/authenticated_sessions/{uuid}/`.replace(`{${"uuid"}}`, encodeURIComponent(String(requestParameters.uuid))),
        method: "GET",
        headers: headerParameters,
        query: queryParameters
      }, initOverrides);
      return new JSONApiResponse(response, (jsonValue) => AuthenticatedSessionFromJSON(jsonValue));
    });
  }
  /**
   * AuthenticatedSession Viewset
   */
  coreAuthenticatedSessionsRetrieve(requestParameters, initOverrides) {
    return __awaiter2(this, void 0, void 0, function* () {
      const response = yield this.coreAuthenticatedSessionsRetrieveRaw(requestParameters, initOverrides);
      return yield response.value();
    });
  }
  /**
   * Get a list of all objects that use this object
   */
  coreAuthenticatedSessionsUsedByListRaw(requestParameters, initOverrides) {
    return __awaiter2(this, void 0, void 0, function* () {
      if (requestParameters.uuid === null || requestParameters.uuid === void 0) {
        throw new RequiredError("uuid", "Required parameter requestParameters.uuid was null or undefined when calling coreAuthenticatedSessionsUsedByList.");
      }
      const queryParameters = {};
      const headerParameters = {};
      if (this.configuration && this.configuration.accessToken) {
        const token = this.configuration.accessToken;
        const tokenString = yield token("authentik", []);
        if (tokenString) {
          headerParameters["Authorization"] = `Bearer ${tokenString}`;
        }
      }
      const response = yield this.request({
        path: `/core/authenticated_sessions/{uuid}/used_by/`.replace(`{${"uuid"}}`, encodeURIComponent(String(requestParameters.uuid))),
        method: "GET",
        headers: headerParameters,
        query: queryParameters
      }, initOverrides);
      return new JSONApiResponse(response, (jsonValue) => jsonValue.map(UsedByFromJSON));
    });
  }
  /**
   * Get a list of all objects that use this object
   */
  coreAuthenticatedSessionsUsedByList(requestParameters, initOverrides) {
    return __awaiter2(this, void 0, void 0, function* () {
      const response = yield this.coreAuthenticatedSessionsUsedByListRaw(requestParameters, initOverrides);
      return yield response.value();
    });
  }
  /**
   * Brand Viewset
   */
  coreBrandsCreateRaw(requestParameters, initOverrides) {
    return __awaiter2(this, void 0, void 0, function* () {
      if (requestParameters.brandRequest === null || requestParameters.brandRequest === void 0) {
        throw new RequiredError("brandRequest", "Required parameter requestParameters.brandRequest was null or undefined when calling coreBrandsCreate.");
      }
      const queryParameters = {};
      const headerParameters = {};
      headerParameters["Content-Type"] = "application/json";
      if (this.configuration && this.configuration.accessToken) {
        const token = this.configuration.accessToken;
        const tokenString = yield token("authentik", []);
        if (tokenString) {
          headerParameters["Authorization"] = `Bearer ${tokenString}`;
        }
      }
      const response = yield this.request({
        path: `/core/brands/`,
        method: "POST",
        headers: headerParameters,
        query: queryParameters,
        body: BrandRequestToJSON(requestParameters.brandRequest)
      }, initOverrides);
      return new JSONApiResponse(response, (jsonValue) => BrandFromJSON(jsonValue));
    });
  }
  /**
   * Brand Viewset
   */
  coreBrandsCreate(requestParameters, initOverrides) {
    return __awaiter2(this, void 0, void 0, function* () {
      const response = yield this.coreBrandsCreateRaw(requestParameters, initOverrides);
      return yield response.value();
    });
  }
  /**
   * Get current brand
   */
  coreBrandsCurrentRetrieveRaw(initOverrides) {
    return __awaiter2(this, void 0, void 0, function* () {
      const queryParameters = {};
      const headerParameters = {};
      if (this.configuration && this.configuration.accessToken) {
        const token = this.configuration.accessToken;
        const tokenString = yield token("authentik", []);
        if (tokenString) {
          headerParameters["Authorization"] = `Bearer ${tokenString}`;
        }
      }
      const response = yield this.request({
        path: `/core/brands/current/`,
        method: "GET",
        headers: headerParameters,
        query: queryParameters
      }, initOverrides);
      return new JSONApiResponse(response, (jsonValue) => CurrentBrandFromJSON(jsonValue));
    });
  }
  /**
   * Get current brand
   */
  coreBrandsCurrentRetrieve(initOverrides) {
    return __awaiter2(this, void 0, void 0, function* () {
      const response = yield this.coreBrandsCurrentRetrieveRaw(initOverrides);
      return yield response.value();
    });
  }
  /**
   * Brand Viewset
   */
  coreBrandsDestroyRaw(requestParameters, initOverrides) {
    return __awaiter2(this, void 0, void 0, function* () {
      if (requestParameters.brandUuid === null || requestParameters.brandUuid === void 0) {
        throw new RequiredError("brandUuid", "Required parameter requestParameters.brandUuid was null or undefined when calling coreBrandsDestroy.");
      }
      const queryParameters = {};
      const headerParameters = {};
      if (this.configuration && this.configuration.accessToken) {
        const token = this.configuration.accessToken;
        const tokenString = yield token("authentik", []);
        if (tokenString) {
          headerParameters["Authorization"] = `Bearer ${tokenString}`;
        }
      }
      const response = yield this.request({
        path: `/core/brands/{brand_uuid}/`.replace(`{${"brand_uuid"}}`, encodeURIComponent(String(requestParameters.brandUuid))),
        method: "DELETE",
        headers: headerParameters,
        query: queryParameters
      }, initOverrides);
      return new VoidApiResponse(response);
    });
  }
  /**
   * Brand Viewset
   */
  coreBrandsDestroy(requestParameters, initOverrides) {
    return __awaiter2(this, void 0, void 0, function* () {
      yield this.coreBrandsDestroyRaw(requestParameters, initOverrides);
    });
  }
  /**
   * Brand Viewset
   */
  coreBrandsListRaw(requestParameters, initOverrides) {
    return __awaiter2(this, void 0, void 0, function* () {
      const queryParameters = {};
      if (requestParameters.brandUuid !== void 0) {
        queryParameters["brand_uuid"] = requestParameters.brandUuid;
      }
      if (requestParameters.brandingFavicon !== void 0) {
        queryParameters["branding_favicon"] = requestParameters.brandingFavicon;
      }
      if (requestParameters.brandingLogo !== void 0) {
        queryParameters["branding_logo"] = requestParameters.brandingLogo;
      }
      if (requestParameters.brandingTitle !== void 0) {
        queryParameters["branding_title"] = requestParameters.brandingTitle;
      }
      if (requestParameters._default !== void 0) {
        queryParameters["default"] = requestParameters._default;
      }
      if (requestParameters.domain !== void 0) {
        queryParameters["domain"] = requestParameters.domain;
      }
      if (requestParameters.flowAuthentication !== void 0) {
        queryParameters["flow_authentication"] = requestParameters.flowAuthentication;
      }
      if (requestParameters.flowDeviceCode !== void 0) {
        queryParameters["flow_device_code"] = requestParameters.flowDeviceCode;
      }
      if (requestParameters.flowInvalidation !== void 0) {
        queryParameters["flow_invalidation"] = requestParameters.flowInvalidation;
      }
      if (requestParameters.flowRecovery !== void 0) {
        queryParameters["flow_recovery"] = requestParameters.flowRecovery;
      }
      if (requestParameters.flowUnenrollment !== void 0) {
        queryParameters["flow_unenrollment"] = requestParameters.flowUnenrollment;
      }
      if (requestParameters.flowUserSettings !== void 0) {
        queryParameters["flow_user_settings"] = requestParameters.flowUserSettings;
      }
      if (requestParameters.ordering !== void 0) {
        queryParameters["ordering"] = requestParameters.ordering;
      }
      if (requestParameters.page !== void 0) {
        queryParameters["page"] = requestParameters.page;
      }
      if (requestParameters.pageSize !== void 0) {
        queryParameters["page_size"] = requestParameters.pageSize;
      }
      if (requestParameters.search !== void 0) {
        queryParameters["search"] = requestParameters.search;
      }
      if (requestParameters.webCertificate !== void 0) {
        queryParameters["web_certificate"] = requestParameters.webCertificate;
      }
      const headerParameters = {};
      if (this.configuration && this.configuration.accessToken) {
        const token = this.configuration.accessToken;
        const tokenString = yield token("authentik", []);
        if (tokenString) {
          headerParameters["Authorization"] = `Bearer ${tokenString}`;
        }
      }
      const response = yield this.request({
        path: `/core/brands/`,
        method: "GET",
        headers: headerParameters,
        query: queryParameters
      }, initOverrides);
      return new JSONApiResponse(response, (jsonValue) => PaginatedBrandListFromJSON(jsonValue));
    });
  }
  /**
   * Brand Viewset
   */
  coreBrandsList(requestParameters = {}, initOverrides) {
    return __awaiter2(this, void 0, void 0, function* () {
      const response = yield this.coreBrandsListRaw(requestParameters, initOverrides);
      return yield response.value();
    });
  }
  /**
   * Brand Viewset
   */
  coreBrandsPartialUpdateRaw(requestParameters, initOverrides) {
    return __awaiter2(this, void 0, void 0, function* () {
      if (requestParameters.brandUuid === null || requestParameters.brandUuid === void 0) {
        throw new RequiredError("brandUuid", "Required parameter requestParameters.brandUuid was null or undefined when calling coreBrandsPartialUpdate.");
      }
      const queryParameters = {};
      const headerParameters = {};
      headerParameters["Content-Type"] = "application/json";
      if (this.configuration && this.configuration.accessToken) {
        const token = this.configuration.accessToken;
        const tokenString = yield token("authentik", []);
        if (tokenString) {
          headerParameters["Authorization"] = `Bearer ${tokenString}`;
        }
      }
      const response = yield this.request({
        path: `/core/brands/{brand_uuid}/`.replace(`{${"brand_uuid"}}`, encodeURIComponent(String(requestParameters.brandUuid))),
        method: "PATCH",
        headers: headerParameters,
        query: queryParameters,
        body: PatchedBrandRequestToJSON(requestParameters.patchedBrandRequest)
      }, initOverrides);
      return new JSONApiResponse(response, (jsonValue) => BrandFromJSON(jsonValue));
    });
  }
  /**
   * Brand Viewset
   */
  coreBrandsPartialUpdate(requestParameters, initOverrides) {
    return __awaiter2(this, void 0, void 0, function* () {
      const response = yield this.coreBrandsPartialUpdateRaw(requestParameters, initOverrides);
      return yield response.value();
    });
  }
  /**
   * Brand Viewset
   */
  coreBrandsRetrieveRaw(requestParameters, initOverrides) {
    return __awaiter2(this, void 0, void 0, function* () {
      if (requestParameters.brandUuid === null || requestParameters.brandUuid === void 0) {
        throw new RequiredError("brandUuid", "Required parameter requestParameters.brandUuid was null or undefined when calling coreBrandsRetrieve.");
      }
      const queryParameters = {};
      const headerParameters = {};
      if (this.configuration && this.configuration.accessToken) {
        const token = this.configuration.accessToken;
        const tokenString = yield token("authentik", []);
        if (tokenString) {
          headerParameters["Authorization"] = `Bearer ${tokenString}`;
        }
      }
      const response = yield this.request({
        path: `/core/brands/{brand_uuid}/`.replace(`{${"brand_uuid"}}`, encodeURIComponent(String(requestParameters.brandUuid))),
        method: "GET",
        headers: headerParameters,
        query: queryParameters
      }, initOverrides);
      return new JSONApiResponse(response, (jsonValue) => BrandFromJSON(jsonValue));
    });
  }
  /**
   * Brand Viewset
   */
  coreBrandsRetrieve(requestParameters, initOverrides) {
    return __awaiter2(this, void 0, void 0, function* () {
      const response = yield this.coreBrandsRetrieveRaw(requestParameters, initOverrides);
      return yield response.value();
    });
  }
  /**
   * Brand Viewset
   */
  coreBrandsUpdateRaw(requestParameters, initOverrides) {
    return __awaiter2(this, void 0, void 0, function* () {
      if (requestParameters.brandUuid === null || requestParameters.brandUuid === void 0) {
        throw new RequiredError("brandUuid", "Required parameter requestParameters.brandUuid was null or undefined when calling coreBrandsUpdate.");
      }
      if (requestParameters.brandRequest === null || requestParameters.brandRequest === void 0) {
        throw new RequiredError("brandRequest", "Required parameter requestParameters.brandRequest was null or undefined when calling coreBrandsUpdate.");
      }
      const queryParameters = {};
      const headerParameters = {};
      headerParameters["Content-Type"] = "application/json";
      if (this.configuration && this.configuration.accessToken) {
        const token = this.configuration.accessToken;
        const tokenString = yield token("authentik", []);
        if (tokenString) {
          headerParameters["Authorization"] = `Bearer ${tokenString}`;
        }
      }
      const response = yield this.request({
        path: `/core/brands/{brand_uuid}/`.replace(`{${"brand_uuid"}}`, encodeURIComponent(String(requestParameters.brandUuid))),
        method: "PUT",
        headers: headerParameters,
        query: queryParameters,
        body: BrandRequestToJSON(requestParameters.brandRequest)
      }, initOverrides);
      return new JSONApiResponse(response, (jsonValue) => BrandFromJSON(jsonValue));
    });
  }
  /**
   * Brand Viewset
   */
  coreBrandsUpdate(requestParameters, initOverrides) {
    return __awaiter2(this, void 0, void 0, function* () {
      const response = yield this.coreBrandsUpdateRaw(requestParameters, initOverrides);
      return yield response.value();
    });
  }
  /**
   * Get a list of all objects that use this object
   */
  coreBrandsUsedByListRaw(requestParameters, initOverrides) {
    return __awaiter2(this, void 0, void 0, function* () {
      if (requestParameters.brandUuid === null || requestParameters.brandUuid === void 0) {
        throw new RequiredError("brandUuid", "Required parameter requestParameters.brandUuid was null or undefined when calling coreBrandsUsedByList.");
      }
      const queryParameters = {};
      const headerParameters = {};
      if (this.configuration && this.configuration.accessToken) {
        const token = this.configuration.accessToken;
        const tokenString = yield token("authentik", []);
        if (tokenString) {
          headerParameters["Authorization"] = `Bearer ${tokenString}`;
        }
      }
      const response = yield this.request({
        path: `/core/brands/{brand_uuid}/used_by/`.replace(`{${"brand_uuid"}}`, encodeURIComponent(String(requestParameters.brandUuid))),
        method: "GET",
        headers: headerParameters,
        query: queryParameters
      }, initOverrides);
      return new JSONApiResponse(response, (jsonValue) => jsonValue.map(UsedByFromJSON));
    });
  }
  /**
   * Get a list of all objects that use this object
   */
  coreBrandsUsedByList(requestParameters, initOverrides) {
    return __awaiter2(this, void 0, void 0, function* () {
      const response = yield this.coreBrandsUsedByListRaw(requestParameters, initOverrides);
      return yield response.value();
    });
  }
  /**
   * Add user to group
   */
  coreGroupsAddUserCreateRaw(requestParameters, initOverrides) {
    return __awaiter2(this, void 0, void 0, function* () {
      if (requestParameters.groupUuid === null || requestParameters.groupUuid === void 0) {
        throw new RequiredError("groupUuid", "Required parameter requestParameters.groupUuid was null or undefined when calling coreGroupsAddUserCreate.");
      }
      if (requestParameters.userAccountRequest === null || requestParameters.userAccountRequest === void 0) {
        throw new RequiredError("userAccountRequest", "Required parameter requestParameters.userAccountRequest was null or undefined when calling coreGroupsAddUserCreate.");
      }
      const queryParameters = {};
      const headerParameters = {};
      headerParameters["Content-Type"] = "application/json";
      if (this.configuration && this.configuration.accessToken) {
        const token = this.configuration.accessToken;
        const tokenString = yield token("authentik", []);
        if (tokenString) {
          headerParameters["Authorization"] = `Bearer ${tokenString}`;
        }
      }
      const response = yield this.request({
        path: `/core/groups/{group_uuid}/add_user/`.replace(`{${"group_uuid"}}`, encodeURIComponent(String(requestParameters.groupUuid))),
        method: "POST",
        headers: headerParameters,
        query: queryParameters,
        body: UserAccountRequestToJSON(requestParameters.userAccountRequest)
      }, initOverrides);
      return new VoidApiResponse(response);
    });
  }
  /**
   * Add user to group
   */
  coreGroupsAddUserCreate(requestParameters, initOverrides) {
    return __awaiter2(this, void 0, void 0, function* () {
      yield this.coreGroupsAddUserCreateRaw(requestParameters, initOverrides);
    });
  }
  /**
   * Group Viewset
   */
  coreGroupsCreateRaw(requestParameters, initOverrides) {
    return __awaiter2(this, void 0, void 0, function* () {
      if (requestParameters.groupRequest === null || requestParameters.groupRequest === void 0) {
        throw new RequiredError("groupRequest", "Required parameter requestParameters.groupRequest was null or undefined when calling coreGroupsCreate.");
      }
      const queryParameters = {};
      const headerParameters = {};
      headerParameters["Content-Type"] = "application/json";
      if (this.configuration && this.configuration.accessToken) {
        const token = this.configuration.accessToken;
        const tokenString = yield token("authentik", []);
        if (tokenString) {
          headerParameters["Authorization"] = `Bearer ${tokenString}`;
        }
      }
      const response = yield this.request({
        path: `/core/groups/`,
        method: "POST",
        headers: headerParameters,
        query: queryParameters,
        body: GroupRequestToJSON(requestParameters.groupRequest)
      }, initOverrides);
      return new JSONApiResponse(response, (jsonValue) => GroupFromJSON(jsonValue));
    });
  }
  /**
   * Group Viewset
   */
  coreGroupsCreate(requestParameters, initOverrides) {
    return __awaiter2(this, void 0, void 0, function* () {
      const response = yield this.coreGroupsCreateRaw(requestParameters, initOverrides);
      return yield response.value();
    });
  }
  /**
   * Group Viewset
   */
  coreGroupsDestroyRaw(requestParameters, initOverrides) {
    return __awaiter2(this, void 0, void 0, function* () {
      if (requestParameters.groupUuid === null || requestParameters.groupUuid === void 0) {
        throw new RequiredError("groupUuid", "Required parameter requestParameters.groupUuid was null or undefined when calling coreGroupsDestroy.");
      }
      const queryParameters = {};
      const headerParameters = {};
      if (this.configuration && this.configuration.accessToken) {
        const token = this.configuration.accessToken;
        const tokenString = yield token("authentik", []);
        if (tokenString) {
          headerParameters["Authorization"] = `Bearer ${tokenString}`;
        }
      }
      const response = yield this.request({
        path: `/core/groups/{group_uuid}/`.replace(`{${"group_uuid"}}`, encodeURIComponent(String(requestParameters.groupUuid))),
        method: "DELETE",
        headers: headerParameters,
        query: queryParameters
      }, initOverrides);
      return new VoidApiResponse(response);
    });
  }
  /**
   * Group Viewset
   */
  coreGroupsDestroy(requestParameters, initOverrides) {
    return __awaiter2(this, void 0, void 0, function* () {
      yield this.coreGroupsDestroyRaw(requestParameters, initOverrides);
    });
  }
  /**
   * Group Viewset
   */
  coreGroupsListRaw(requestParameters, initOverrides) {
    return __awaiter2(this, void 0, void 0, function* () {
      const queryParameters = {};
      if (requestParameters.attributes !== void 0) {
        queryParameters["attributes"] = requestParameters.attributes;
      }
      if (requestParameters.includeUsers !== void 0) {
        queryParameters["include_users"] = requestParameters.includeUsers;
      }
      if (requestParameters.isSuperuser !== void 0) {
        queryParameters["is_superuser"] = requestParameters.isSuperuser;
      }
      if (requestParameters.membersByPk) {
        queryParameters["members_by_pk"] = requestParameters.membersByPk;
      }
      if (requestParameters.membersByUsername) {
        queryParameters["members_by_username"] = requestParameters.membersByUsername;
      }
      if (requestParameters.name !== void 0) {
        queryParameters["name"] = requestParameters.name;
      }
      if (requestParameters.ordering !== void 0) {
        queryParameters["ordering"] = requestParameters.ordering;
      }
      if (requestParameters.page !== void 0) {
        queryParameters["page"] = requestParameters.page;
      }
      if (requestParameters.pageSize !== void 0) {
        queryParameters["page_size"] = requestParameters.pageSize;
      }
      if (requestParameters.search !== void 0) {
        queryParameters["search"] = requestParameters.search;
      }
      const headerParameters = {};
      if (this.configuration && this.configuration.accessToken) {
        const token = this.configuration.accessToken;
        const tokenString = yield token("authentik", []);
        if (tokenString) {
          headerParameters["Authorization"] = `Bearer ${tokenString}`;
        }
      }
      const response = yield this.request({
        path: `/core/groups/`,
        method: "GET",
        headers: headerParameters,
        query: queryParameters
      }, initOverrides);
      return new JSONApiResponse(response, (jsonValue) => PaginatedGroupListFromJSON(jsonValue));
    });
  }
  /**
   * Group Viewset
   */
  coreGroupsList(requestParameters = {}, initOverrides) {
    return __awaiter2(this, void 0, void 0, function* () {
      const response = yield this.coreGroupsListRaw(requestParameters, initOverrides);
      return yield response.value();
    });
  }
  /**
   * Group Viewset
   */
  coreGroupsPartialUpdateRaw(requestParameters, initOverrides) {
    return __awaiter2(this, void 0, void 0, function* () {
      if (requestParameters.groupUuid === null || requestParameters.groupUuid === void 0) {
        throw new RequiredError("groupUuid", "Required parameter requestParameters.groupUuid was null or undefined when calling coreGroupsPartialUpdate.");
      }
      const queryParameters = {};
      const headerParameters = {};
      headerParameters["Content-Type"] = "application/json";
      if (this.configuration && this.configuration.accessToken) {
        const token = this.configuration.accessToken;
        const tokenString = yield token("authentik", []);
        if (tokenString) {
          headerParameters["Authorization"] = `Bearer ${tokenString}`;
        }
      }
      const response = yield this.request({
        path: `/core/groups/{group_uuid}/`.replace(`{${"group_uuid"}}`, encodeURIComponent(String(requestParameters.groupUuid))),
        method: "PATCH",
        headers: headerParameters,
        query: queryParameters,
        body: PatchedGroupRequestToJSON(requestParameters.patchedGroupRequest)
      }, initOverrides);
      return new JSONApiResponse(response, (jsonValue) => GroupFromJSON(jsonValue));
    });
  }
  /**
   * Group Viewset
   */
  coreGroupsPartialUpdate(requestParameters, initOverrides) {
    return __awaiter2(this, void 0, void 0, function* () {
      const response = yield this.coreGroupsPartialUpdateRaw(requestParameters, initOverrides);
      return yield response.value();
    });
  }
  /**
   * Add user to group
   */
  coreGroupsRemoveUserCreateRaw(requestParameters, initOverrides) {
    return __awaiter2(this, void 0, void 0, function* () {
      if (requestParameters.groupUuid === null || requestParameters.groupUuid === void 0) {
        throw new RequiredError("groupUuid", "Required parameter requestParameters.groupUuid was null or undefined when calling coreGroupsRemoveUserCreate.");
      }
      if (requestParameters.userAccountRequest === null || requestParameters.userAccountRequest === void 0) {
        throw new RequiredError("userAccountRequest", "Required parameter requestParameters.userAccountRequest was null or undefined when calling coreGroupsRemoveUserCreate.");
      }
      const queryParameters = {};
      const headerParameters = {};
      headerParameters["Content-Type"] = "application/json";
      if (this.configuration && this.configuration.accessToken) {
        const token = this.configuration.accessToken;
        const tokenString = yield token("authentik", []);
        if (tokenString) {
          headerParameters["Authorization"] = `Bearer ${tokenString}`;
        }
      }
      const response = yield this.request({
        path: `/core/groups/{group_uuid}/remove_user/`.replace(`{${"group_uuid"}}`, encodeURIComponent(String(requestParameters.groupUuid))),
        method: "POST",
        headers: headerParameters,
        query: queryParameters,
        body: UserAccountRequestToJSON(requestParameters.userAccountRequest)
      }, initOverrides);
      return new VoidApiResponse(response);
    });
  }
  /**
   * Add user to group
   */
  coreGroupsRemoveUserCreate(requestParameters, initOverrides) {
    return __awaiter2(this, void 0, void 0, function* () {
      yield this.coreGroupsRemoveUserCreateRaw(requestParameters, initOverrides);
    });
  }
  /**
   * Group Viewset
   */
  coreGroupsRetrieveRaw(requestParameters, initOverrides) {
    return __awaiter2(this, void 0, void 0, function* () {
      if (requestParameters.groupUuid === null || requestParameters.groupUuid === void 0) {
        throw new RequiredError("groupUuid", "Required parameter requestParameters.groupUuid was null or undefined when calling coreGroupsRetrieve.");
      }
      const queryParameters = {};
      const headerParameters = {};
      if (this.configuration && this.configuration.accessToken) {
        const token = this.configuration.accessToken;
        const tokenString = yield token("authentik", []);
        if (tokenString) {
          headerParameters["Authorization"] = `Bearer ${tokenString}`;
        }
      }
      const response = yield this.request({
        path: `/core/groups/{group_uuid}/`.replace(`{${"group_uuid"}}`, encodeURIComponent(String(requestParameters.groupUuid))),
        method: "GET",
        headers: headerParameters,
        query: queryParameters
      }, initOverrides);
      return new JSONApiResponse(response, (jsonValue) => GroupFromJSON(jsonValue));
    });
  }
  /**
   * Group Viewset
   */
  coreGroupsRetrieve(requestParameters, initOverrides) {
    return __awaiter2(this, void 0, void 0, function* () {
      const response = yield this.coreGroupsRetrieveRaw(requestParameters, initOverrides);
      return yield response.value();
    });
  }
  /**
   * Group Viewset
   */
  coreGroupsUpdateRaw(requestParameters, initOverrides) {
    return __awaiter2(this, void 0, void 0, function* () {
      if (requestParameters.groupUuid === null || requestParameters.groupUuid === void 0) {
        throw new RequiredError("groupUuid", "Required parameter requestParameters.groupUuid was null or undefined when calling coreGroupsUpdate.");
      }
      if (requestParameters.groupRequest === null || requestParameters.groupRequest === void 0) {
        throw new RequiredError("groupRequest", "Required parameter requestParameters.groupRequest was null or undefined when calling coreGroupsUpdate.");
      }
      const queryParameters = {};
      const headerParameters = {};
      headerParameters["Content-Type"] = "application/json";
      if (this.configuration && this.configuration.accessToken) {
        const token = this.configuration.accessToken;
        const tokenString = yield token("authentik", []);
        if (tokenString) {
          headerParameters["Authorization"] = `Bearer ${tokenString}`;
        }
      }
      const response = yield this.request({
        path: `/core/groups/{group_uuid}/`.replace(`{${"group_uuid"}}`, encodeURIComponent(String(requestParameters.groupUuid))),
        method: "PUT",
        headers: headerParameters,
        query: queryParameters,
        body: GroupRequestToJSON(requestParameters.groupRequest)
      }, initOverrides);
      return new JSONApiResponse(response, (jsonValue) => GroupFromJSON(jsonValue));
    });
  }
  /**
   * Group Viewset
   */
  coreGroupsUpdate(requestParameters, initOverrides) {
    return __awaiter2(this, void 0, void 0, function* () {
      const response = yield this.coreGroupsUpdateRaw(requestParameters, initOverrides);
      return yield response.value();
    });
  }
  /**
   * Get a list of all objects that use this object
   */
  coreGroupsUsedByListRaw(requestParameters, initOverrides) {
    return __awaiter2(this, void 0, void 0, function* () {
      if (requestParameters.groupUuid === null || requestParameters.groupUuid === void 0) {
        throw new RequiredError("groupUuid", "Required parameter requestParameters.groupUuid was null or undefined when calling coreGroupsUsedByList.");
      }
      const queryParameters = {};
      const headerParameters = {};
      if (this.configuration && this.configuration.accessToken) {
        const token = this.configuration.accessToken;
        const tokenString = yield token("authentik", []);
        if (tokenString) {
          headerParameters["Authorization"] = `Bearer ${tokenString}`;
        }
      }
      const response = yield this.request({
        path: `/core/groups/{group_uuid}/used_by/`.replace(`{${"group_uuid"}}`, encodeURIComponent(String(requestParameters.groupUuid))),
        method: "GET",
        headers: headerParameters,
        query: queryParameters
      }, initOverrides);
      return new JSONApiResponse(response, (jsonValue) => jsonValue.map(UsedByFromJSON));
    });
  }
  /**
   * Get a list of all objects that use this object
   */
  coreGroupsUsedByList(requestParameters, initOverrides) {
    return __awaiter2(this, void 0, void 0, function* () {
      const response = yield this.coreGroupsUsedByListRaw(requestParameters, initOverrides);
      return yield response.value();
    });
  }
  /**
   * Token Viewset
   */
  coreTokensCreateRaw(requestParameters, initOverrides) {
    return __awaiter2(this, void 0, void 0, function* () {
      if (requestParameters.tokenRequest === null || requestParameters.tokenRequest === void 0) {
        throw new RequiredError("tokenRequest", "Required parameter requestParameters.tokenRequest was null or undefined when calling coreTokensCreate.");
      }
      const queryParameters = {};
      const headerParameters = {};
      headerParameters["Content-Type"] = "application/json";
      if (this.configuration && this.configuration.accessToken) {
        const token = this.configuration.accessToken;
        const tokenString = yield token("authentik", []);
        if (tokenString) {
          headerParameters["Authorization"] = `Bearer ${tokenString}`;
        }
      }
      const response = yield this.request({
        path: `/core/tokens/`,
        method: "POST",
        headers: headerParameters,
        query: queryParameters,
        body: TokenRequestToJSON(requestParameters.tokenRequest)
      }, initOverrides);
      return new JSONApiResponse(response, (jsonValue) => TokenFromJSON(jsonValue));
    });
  }
  /**
   * Token Viewset
   */
  coreTokensCreate(requestParameters, initOverrides) {
    return __awaiter2(this, void 0, void 0, function* () {
      const response = yield this.coreTokensCreateRaw(requestParameters, initOverrides);
      return yield response.value();
    });
  }
  /**
   * Token Viewset
   */
  coreTokensDestroyRaw(requestParameters, initOverrides) {
    return __awaiter2(this, void 0, void 0, function* () {
      if (requestParameters.identifier === null || requestParameters.identifier === void 0) {
        throw new RequiredError("identifier", "Required parameter requestParameters.identifier was null or undefined when calling coreTokensDestroy.");
      }
      const queryParameters = {};
      const headerParameters = {};
      if (this.configuration && this.configuration.accessToken) {
        const token = this.configuration.accessToken;
        const tokenString = yield token("authentik", []);
        if (tokenString) {
          headerParameters["Authorization"] = `Bearer ${tokenString}`;
        }
      }
      const response = yield this.request({
        path: `/core/tokens/{identifier}/`.replace(`{${"identifier"}}`, encodeURIComponent(String(requestParameters.identifier))),
        method: "DELETE",
        headers: headerParameters,
        query: queryParameters
      }, initOverrides);
      return new VoidApiResponse(response);
    });
  }
  /**
   * Token Viewset
   */
  coreTokensDestroy(requestParameters, initOverrides) {
    return __awaiter2(this, void 0, void 0, function* () {
      yield this.coreTokensDestroyRaw(requestParameters, initOverrides);
    });
  }
  /**
   * Token Viewset
   */
  coreTokensListRaw(requestParameters, initOverrides) {
    return __awaiter2(this, void 0, void 0, function* () {
      const queryParameters = {};
      if (requestParameters.description !== void 0) {
        queryParameters["description"] = requestParameters.description;
      }
      if (requestParameters.expires !== void 0) {
        queryParameters["expires"] = requestParameters.expires.toISOString();
      }
      if (requestParameters.expiring !== void 0) {
        queryParameters["expiring"] = requestParameters.expiring;
      }
      if (requestParameters.identifier !== void 0) {
        queryParameters["identifier"] = requestParameters.identifier;
      }
      if (requestParameters.intent !== void 0) {
        queryParameters["intent"] = requestParameters.intent;
      }
      if (requestParameters.managed !== void 0) {
        queryParameters["managed"] = requestParameters.managed;
      }
      if (requestParameters.ordering !== void 0) {
        queryParameters["ordering"] = requestParameters.ordering;
      }
      if (requestParameters.page !== void 0) {
        queryParameters["page"] = requestParameters.page;
      }
      if (requestParameters.pageSize !== void 0) {
        queryParameters["page_size"] = requestParameters.pageSize;
      }
      if (requestParameters.search !== void 0) {
        queryParameters["search"] = requestParameters.search;
      }
      if (requestParameters.userUsername !== void 0) {
        queryParameters["user__username"] = requestParameters.userUsername;
      }
      const headerParameters = {};
      if (this.configuration && this.configuration.accessToken) {
        const token = this.configuration.accessToken;
        const tokenString = yield token("authentik", []);
        if (tokenString) {
          headerParameters["Authorization"] = `Bearer ${tokenString}`;
        }
      }
      const response = yield this.request({
        path: `/core/tokens/`,
        method: "GET",
        headers: headerParameters,
        query: queryParameters
      }, initOverrides);
      return new JSONApiResponse(response, (jsonValue) => PaginatedTokenListFromJSON(jsonValue));
    });
  }
  /**
   * Token Viewset
   */
  coreTokensList(requestParameters = {}, initOverrides) {
    return __awaiter2(this, void 0, void 0, function* () {
      const response = yield this.coreTokensListRaw(requestParameters, initOverrides);
      return yield response.value();
    });
  }
  /**
   * Token Viewset
   */
  coreTokensPartialUpdateRaw(requestParameters, initOverrides) {
    return __awaiter2(this, void 0, void 0, function* () {
      if (requestParameters.identifier === null || requestParameters.identifier === void 0) {
        throw new RequiredError("identifier", "Required parameter requestParameters.identifier was null or undefined when calling coreTokensPartialUpdate.");
      }
      const queryParameters = {};
      const headerParameters = {};
      headerParameters["Content-Type"] = "application/json";
      if (this.configuration && this.configuration.accessToken) {
        const token = this.configuration.accessToken;
        const tokenString = yield token("authentik", []);
        if (tokenString) {
          headerParameters["Authorization"] = `Bearer ${tokenString}`;
        }
      }
      const response = yield this.request({
        path: `/core/tokens/{identifier}/`.replace(`{${"identifier"}}`, encodeURIComponent(String(requestParameters.identifier))),
        method: "PATCH",
        headers: headerParameters,
        query: queryParameters,
        body: PatchedTokenRequestToJSON(requestParameters.patchedTokenRequest)
      }, initOverrides);
      return new JSONApiResponse(response, (jsonValue) => TokenFromJSON(jsonValue));
    });
  }
  /**
   * Token Viewset
   */
  coreTokensPartialUpdate(requestParameters, initOverrides) {
    return __awaiter2(this, void 0, void 0, function* () {
      const response = yield this.coreTokensPartialUpdateRaw(requestParameters, initOverrides);
      return yield response.value();
    });
  }
  /**
   * Token Viewset
   */
  coreTokensRetrieveRaw(requestParameters, initOverrides) {
    return __awaiter2(this, void 0, void 0, function* () {
      if (requestParameters.identifier === null || requestParameters.identifier === void 0) {
        throw new RequiredError("identifier", "Required parameter requestParameters.identifier was null or undefined when calling coreTokensRetrieve.");
      }
      const queryParameters = {};
      const headerParameters = {};
      if (this.configuration && this.configuration.accessToken) {
        const token = this.configuration.accessToken;
        const tokenString = yield token("authentik", []);
        if (tokenString) {
          headerParameters["Authorization"] = `Bearer ${tokenString}`;
        }
      }
      const response = yield this.request({
        path: `/core/tokens/{identifier}/`.replace(`{${"identifier"}}`, encodeURIComponent(String(requestParameters.identifier))),
        method: "GET",
        headers: headerParameters,
        query: queryParameters
      }, initOverrides);
      return new JSONApiResponse(response, (jsonValue) => TokenFromJSON(jsonValue));
    });
  }
  /**
   * Token Viewset
   */
  coreTokensRetrieve(requestParameters, initOverrides) {
    return __awaiter2(this, void 0, void 0, function* () {
      const response = yield this.coreTokensRetrieveRaw(requestParameters, initOverrides);
      return yield response.value();
    });
  }
  /**
   * Set token key. Action is logged as event. `authentik_core.set_token_key` permission is required.
   */
  coreTokensSetKeyCreateRaw(requestParameters, initOverrides) {
    return __awaiter2(this, void 0, void 0, function* () {
      if (requestParameters.identifier === null || requestParameters.identifier === void 0) {
        throw new RequiredError("identifier", "Required parameter requestParameters.identifier was null or undefined when calling coreTokensSetKeyCreate.");
      }
      if (requestParameters.tokenSetKeyRequest === null || requestParameters.tokenSetKeyRequest === void 0) {
        throw new RequiredError("tokenSetKeyRequest", "Required parameter requestParameters.tokenSetKeyRequest was null or undefined when calling coreTokensSetKeyCreate.");
      }
      const queryParameters = {};
      const headerParameters = {};
      headerParameters["Content-Type"] = "application/json";
      if (this.configuration && this.configuration.accessToken) {
        const token = this.configuration.accessToken;
        const tokenString = yield token("authentik", []);
        if (tokenString) {
          headerParameters["Authorization"] = `Bearer ${tokenString}`;
        }
      }
      const response = yield this.request({
        path: `/core/tokens/{identifier}/set_key/`.replace(`{${"identifier"}}`, encodeURIComponent(String(requestParameters.identifier))),
        method: "POST",
        headers: headerParameters,
        query: queryParameters,
        body: TokenSetKeyRequestToJSON(requestParameters.tokenSetKeyRequest)
      }, initOverrides);
      return new VoidApiResponse(response);
    });
  }
  /**
   * Set token key. Action is logged as event. `authentik_core.set_token_key` permission is required.
   */
  coreTokensSetKeyCreate(requestParameters, initOverrides) {
    return __awaiter2(this, void 0, void 0, function* () {
      yield this.coreTokensSetKeyCreateRaw(requestParameters, initOverrides);
    });
  }
  /**
   * Token Viewset
   */
  coreTokensUpdateRaw(requestParameters, initOverrides) {
    return __awaiter2(this, void 0, void 0, function* () {
      if (requestParameters.identifier === null || requestParameters.identifier === void 0) {
        throw new RequiredError("identifier", "Required parameter requestParameters.identifier was null or undefined when calling coreTokensUpdate.");
      }
      if (requestParameters.tokenRequest === null || requestParameters.tokenRequest === void 0) {
        throw new RequiredError("tokenRequest", "Required parameter requestParameters.tokenRequest was null or undefined when calling coreTokensUpdate.");
      }
      const queryParameters = {};
      const headerParameters = {};
      headerParameters["Content-Type"] = "application/json";
      if (this.configuration && this.configuration.accessToken) {
        const token = this.configuration.accessToken;
        const tokenString = yield token("authentik", []);
        if (tokenString) {
          headerParameters["Authorization"] = `Bearer ${tokenString}`;
        }
      }
      const response = yield this.request({
        path: `/core/tokens/{identifier}/`.replace(`{${"identifier"}}`, encodeURIComponent(String(requestParameters.identifier))),
        method: "PUT",
        headers: headerParameters,
        query: queryParameters,
        body: TokenRequestToJSON(requestParameters.tokenRequest)
      }, initOverrides);
      return new JSONApiResponse(response, (jsonValue) => TokenFromJSON(jsonValue));
    });
  }
  /**
   * Token Viewset
   */
  coreTokensUpdate(requestParameters, initOverrides) {
    return __awaiter2(this, void 0, void 0, function* () {
      const response = yield this.coreTokensUpdateRaw(requestParameters, initOverrides);
      return yield response.value();
    });
  }
  /**
   * Get a list of all objects that use this object
   */
  coreTokensUsedByListRaw(requestParameters, initOverrides) {
    return __awaiter2(this, void 0, void 0, function* () {
      if (requestParameters.identifier === null || requestParameters.identifier === void 0) {
        throw new RequiredError("identifier", "Required parameter requestParameters.identifier was null or undefined when calling coreTokensUsedByList.");
      }
      const queryParameters = {};
      const headerParameters = {};
      if (this.configuration && this.configuration.accessToken) {
        const token = this.configuration.accessToken;
        const tokenString = yield token("authentik", []);
        if (tokenString) {
          headerParameters["Authorization"] = `Bearer ${tokenString}`;
        }
      }
      const response = yield this.request({
        path: `/core/tokens/{identifier}/used_by/`.replace(`{${"identifier"}}`, encodeURIComponent(String(requestParameters.identifier))),
        method: "GET",
        headers: headerParameters,
        query: queryParameters
      }, initOverrides);
      return new JSONApiResponse(response, (jsonValue) => jsonValue.map(UsedByFromJSON));
    });
  }
  /**
   * Get a list of all objects that use this object
   */
  coreTokensUsedByList(requestParameters, initOverrides) {
    return __awaiter2(this, void 0, void 0, function* () {
      const response = yield this.coreTokensUsedByListRaw(requestParameters, initOverrides);
      return yield response.value();
    });
  }
  /**
   * Return token key and log access
   */
  coreTokensViewKeyRetrieveRaw(requestParameters, initOverrides) {
    return __awaiter2(this, void 0, void 0, function* () {
      if (requestParameters.identifier === null || requestParameters.identifier === void 0) {
        throw new RequiredError("identifier", "Required parameter requestParameters.identifier was null or undefined when calling coreTokensViewKeyRetrieve.");
      }
      const queryParameters = {};
      const headerParameters = {};
      if (this.configuration && this.configuration.accessToken) {
        const token = this.configuration.accessToken;
        const tokenString = yield token("authentik", []);
        if (tokenString) {
          headerParameters["Authorization"] = `Bearer ${tokenString}`;
        }
      }
      const response = yield this.request({
        path: `/core/tokens/{identifier}/view_key/`.replace(`{${"identifier"}}`, encodeURIComponent(String(requestParameters.identifier))),
        method: "GET",
        headers: headerParameters,
        query: queryParameters
      }, initOverrides);
      return new JSONApiResponse(response, (jsonValue) => TokenViewFromJSON(jsonValue));
    });
  }
  /**
   * Return token key and log access
   */
  coreTokensViewKeyRetrieve(requestParameters, initOverrides) {
    return __awaiter2(this, void 0, void 0, function* () {
      const response = yield this.coreTokensViewKeyRetrieveRaw(requestParameters, initOverrides);
      return yield response.value();
    });
  }
  /**
   * Convert data into a blueprint, validate it and apply it
   */
  coreTransactionalApplicationsUpdateRaw(requestParameters, initOverrides) {
    return __awaiter2(this, void 0, void 0, function* () {
      if (requestParameters.transactionApplicationRequest === null || requestParameters.transactionApplicationRequest === void 0) {
        throw new RequiredError("transactionApplicationRequest", "Required parameter requestParameters.transactionApplicationRequest was null or undefined when calling coreTransactionalApplicationsUpdate.");
      }
      const queryParameters = {};
      const headerParameters = {};
      headerParameters["Content-Type"] = "application/json";
      if (this.configuration && this.configuration.accessToken) {
        const token = this.configuration.accessToken;
        const tokenString = yield token("authentik", []);
        if (tokenString) {
          headerParameters["Authorization"] = `Bearer ${tokenString}`;
        }
      }
      const response = yield this.request({
        path: `/core/transactional/applications/`,
        method: "PUT",
        headers: headerParameters,
        query: queryParameters,
        body: TransactionApplicationRequestToJSON(requestParameters.transactionApplicationRequest)
      }, initOverrides);
      return new JSONApiResponse(response, (jsonValue) => TransactionApplicationResponseFromJSON(jsonValue));
    });
  }
  /**
   * Convert data into a blueprint, validate it and apply it
   */
  coreTransactionalApplicationsUpdate(requestParameters, initOverrides) {
    return __awaiter2(this, void 0, void 0, function* () {
      const response = yield this.coreTransactionalApplicationsUpdateRaw(requestParameters, initOverrides);
      return yield response.value();
    });
  }
  /**
   * UserConsent Viewset
   */
  coreUserConsentDestroyRaw(requestParameters, initOverrides) {
    return __awaiter2(this, void 0, void 0, function* () {
      if (requestParameters.id === null || requestParameters.id === void 0) {
        throw new RequiredError("id", "Required parameter requestParameters.id was null or undefined when calling coreUserConsentDestroy.");
      }
      const queryParameters = {};
      const headerParameters = {};
      if (this.configuration && this.configuration.accessToken) {
        const token = this.configuration.accessToken;
        const tokenString = yield token("authentik", []);
        if (tokenString) {
          headerParameters["Authorization"] = `Bearer ${tokenString}`;
        }
      }
      const response = yield this.request({
        path: `/core/user_consent/{id}/`.replace(`{${"id"}}`, encodeURIComponent(String(requestParameters.id))),
        method: "DELETE",
        headers: headerParameters,
        query: queryParameters
      }, initOverrides);
      return new VoidApiResponse(response);
    });
  }
  /**
   * UserConsent Viewset
   */
  coreUserConsentDestroy(requestParameters, initOverrides) {
    return __awaiter2(this, void 0, void 0, function* () {
      yield this.coreUserConsentDestroyRaw(requestParameters, initOverrides);
    });
  }
  /**
   * UserConsent Viewset
   */
  coreUserConsentListRaw(requestParameters, initOverrides) {
    return __awaiter2(this, void 0, void 0, function* () {
      const queryParameters = {};
      if (requestParameters.application !== void 0) {
        queryParameters["application"] = requestParameters.application;
      }
      if (requestParameters.ordering !== void 0) {
        queryParameters["ordering"] = requestParameters.ordering;
      }
      if (requestParameters.page !== void 0) {
        queryParameters["page"] = requestParameters.page;
      }
      if (requestParameters.pageSize !== void 0) {
        queryParameters["page_size"] = requestParameters.pageSize;
      }
      if (requestParameters.search !== void 0) {
        queryParameters["search"] = requestParameters.search;
      }
      if (requestParameters.user !== void 0) {
        queryParameters["user"] = requestParameters.user;
      }
      const headerParameters = {};
      if (this.configuration && this.configuration.accessToken) {
        const token = this.configuration.accessToken;
        const tokenString = yield token("authentik", []);
        if (tokenString) {
          headerParameters["Authorization"] = `Bearer ${tokenString}`;
        }
      }
      const response = yield this.request({
        path: `/core/user_consent/`,
        method: "GET",
        headers: headerParameters,
        query: queryParameters
      }, initOverrides);
      return new JSONApiResponse(response, (jsonValue) => PaginatedUserConsentListFromJSON(jsonValue));
    });
  }
  /**
   * UserConsent Viewset
   */
  coreUserConsentList(requestParameters = {}, initOverrides) {
    return __awaiter2(this, void 0, void 0, function* () {
      const response = yield this.coreUserConsentListRaw(requestParameters, initOverrides);
      return yield response.value();
    });
  }
  /**
   * UserConsent Viewset
   */
  coreUserConsentRetrieveRaw(requestParameters, initOverrides) {
    return __awaiter2(this, void 0, void 0, function* () {
      if (requestParameters.id === null || requestParameters.id === void 0) {
        throw new RequiredError("id", "Required parameter requestParameters.id was null or undefined when calling coreUserConsentRetrieve.");
      }
      const queryParameters = {};
      const headerParameters = {};
      if (this.configuration && this.configuration.accessToken) {
        const token = this.configuration.accessToken;
        const tokenString = yield token("authentik", []);
        if (tokenString) {
          headerParameters["Authorization"] = `Bearer ${tokenString}`;
        }
      }
      const response = yield this.request({
        path: `/core/user_consent/{id}/`.replace(`{${"id"}}`, encodeURIComponent(String(requestParameters.id))),
        method: "GET",
        headers: headerParameters,
        query: queryParameters
      }, initOverrides);
      return new JSONApiResponse(response, (jsonValue) => UserConsentFromJSON(jsonValue));
    });
  }
  /**
   * UserConsent Viewset
   */
  coreUserConsentRetrieve(requestParameters, initOverrides) {
    return __awaiter2(this, void 0, void 0, function* () {
      const response = yield this.coreUserConsentRetrieveRaw(requestParameters, initOverrides);
      return yield response.value();
    });
  }
  /**
   * Get a list of all objects that use this object
   */
  coreUserConsentUsedByListRaw(requestParameters, initOverrides) {
    return __awaiter2(this, void 0, void 0, function* () {
      if (requestParameters.id === null || requestParameters.id === void 0) {
        throw new RequiredError("id", "Required parameter requestParameters.id was null or undefined when calling coreUserConsentUsedByList.");
      }
      const queryParameters = {};
      const headerParameters = {};
      if (this.configuration && this.configuration.accessToken) {
        const token = this.configuration.accessToken;
        const tokenString = yield token("authentik", []);
        if (tokenString) {
          headerParameters["Authorization"] = `Bearer ${tokenString}`;
        }
      }
      const response = yield this.request({
        path: `/core/user_consent/{id}/used_by/`.replace(`{${"id"}}`, encodeURIComponent(String(requestParameters.id))),
        method: "GET",
        headers: headerParameters,
        query: queryParameters
      }, initOverrides);
      return new JSONApiResponse(response, (jsonValue) => jsonValue.map(UsedByFromJSON));
    });
  }
  /**
   * Get a list of all objects that use this object
   */
  coreUserConsentUsedByList(requestParameters, initOverrides) {
    return __awaiter2(this, void 0, void 0, function* () {
      const response = yield this.coreUserConsentUsedByListRaw(requestParameters, initOverrides);
      return yield response.value();
    });
  }
  /**
   * User Viewset
   */
  coreUsersCreateRaw(requestParameters, initOverrides) {
    return __awaiter2(this, void 0, void 0, function* () {
      if (requestParameters.userRequest === null || requestParameters.userRequest === void 0) {
        throw new RequiredError("userRequest", "Required parameter requestParameters.userRequest was null or undefined when calling coreUsersCreate.");
      }
      const queryParameters = {};
      const headerParameters = {};
      headerParameters["Content-Type"] = "application/json";
      if (this.configuration && this.configuration.accessToken) {
        const token = this.configuration.accessToken;
        const tokenString = yield token("authentik", []);
        if (tokenString) {
          headerParameters["Authorization"] = `Bearer ${tokenString}`;
        }
      }
      const response = yield this.request({
        path: `/core/users/`,
        method: "POST",
        headers: headerParameters,
        query: queryParameters,
        body: UserRequestToJSON(requestParameters.userRequest)
      }, initOverrides);
      return new JSONApiResponse(response, (jsonValue) => UserFromJSON(jsonValue));
    });
  }
  /**
   * User Viewset
   */
  coreUsersCreate(requestParameters, initOverrides) {
    return __awaiter2(this, void 0, void 0, function* () {
      const response = yield this.coreUsersCreateRaw(requestParameters, initOverrides);
      return yield response.value();
    });
  }
  /**
   * User Viewset
   */
  coreUsersDestroyRaw(requestParameters, initOverrides) {
    return __awaiter2(this, void 0, void 0, function* () {
      if (requestParameters.id === null || requestParameters.id === void 0) {
        throw new RequiredError("id", "Required parameter requestParameters.id was null or undefined when calling coreUsersDestroy.");
      }
      const queryParameters = {};
      const headerParameters = {};
      if (this.configuration && this.configuration.accessToken) {
        const token = this.configuration.accessToken;
        const tokenString = yield token("authentik", []);
        if (tokenString) {
          headerParameters["Authorization"] = `Bearer ${tokenString}`;
        }
      }
      const response = yield this.request({
        path: `/core/users/{id}/`.replace(`{${"id"}}`, encodeURIComponent(String(requestParameters.id))),
        method: "DELETE",
        headers: headerParameters,
        query: queryParameters
      }, initOverrides);
      return new VoidApiResponse(response);
    });
  }
  /**
   * User Viewset
   */
  coreUsersDestroy(requestParameters, initOverrides) {
    return __awaiter2(this, void 0, void 0, function* () {
      yield this.coreUsersDestroyRaw(requestParameters, initOverrides);
    });
  }
  /**
   * Impersonate a user
   */
  coreUsersImpersonateCreateRaw(requestParameters, initOverrides) {
    return __awaiter2(this, void 0, void 0, function* () {
      if (requestParameters.id === null || requestParameters.id === void 0) {
        throw new RequiredError("id", "Required parameter requestParameters.id was null or undefined when calling coreUsersImpersonateCreate.");
      }
      const queryParameters = {};
      const headerParameters = {};
      if (this.configuration && this.configuration.accessToken) {
        const token = this.configuration.accessToken;
        const tokenString = yield token("authentik", []);
        if (tokenString) {
          headerParameters["Authorization"] = `Bearer ${tokenString}`;
        }
      }
      const response = yield this.request({
        path: `/core/users/{id}/impersonate/`.replace(`{${"id"}}`, encodeURIComponent(String(requestParameters.id))),
        method: "POST",
        headers: headerParameters,
        query: queryParameters
      }, initOverrides);
      return new VoidApiResponse(response);
    });
  }
  /**
   * Impersonate a user
   */
  coreUsersImpersonateCreate(requestParameters, initOverrides) {
    return __awaiter2(this, void 0, void 0, function* () {
      yield this.coreUsersImpersonateCreateRaw(requestParameters, initOverrides);
    });
  }
  /**
   * End Impersonation a user
   */
  coreUsersImpersonateEndRetrieveRaw(initOverrides) {
    return __awaiter2(this, void 0, void 0, function* () {
      const queryParameters = {};
      const headerParameters = {};
      if (this.configuration && this.configuration.accessToken) {
        const token = this.configuration.accessToken;
        const tokenString = yield token("authentik", []);
        if (tokenString) {
          headerParameters["Authorization"] = `Bearer ${tokenString}`;
        }
      }
      const response = yield this.request({
        path: `/core/users/impersonate_end/`,
        method: "GET",
        headers: headerParameters,
        query: queryParameters
      }, initOverrides);
      return new VoidApiResponse(response);
    });
  }
  /**
   * End Impersonation a user
   */
  coreUsersImpersonateEndRetrieve(initOverrides) {
    return __awaiter2(this, void 0, void 0, function* () {
      yield this.coreUsersImpersonateEndRetrieveRaw(initOverrides);
    });
  }
  /**
   * User Viewset
   */
  coreUsersListRaw(requestParameters, initOverrides) {
    return __awaiter2(this, void 0, void 0, function* () {
      const queryParameters = {};
      if (requestParameters.attributes !== void 0) {
        queryParameters["attributes"] = requestParameters.attributes;
      }
      if (requestParameters.email !== void 0) {
        queryParameters["email"] = requestParameters.email;
      }
      if (requestParameters.groupsByName) {
        queryParameters["groups_by_name"] = requestParameters.groupsByName;
      }
      if (requestParameters.groupsByPk) {
        queryParameters["groups_by_pk"] = requestParameters.groupsByPk;
      }
      if (requestParameters.includeGroups !== void 0) {
        queryParameters["include_groups"] = requestParameters.includeGroups;
      }
      if (requestParameters.isActive !== void 0) {
        queryParameters["is_active"] = requestParameters.isActive;
      }
      if (requestParameters.isSuperuser !== void 0) {
        queryParameters["is_superuser"] = requestParameters.isSuperuser;
      }
      if (requestParameters.name !== void 0) {
        queryParameters["name"] = requestParameters.name;
      }
      if (requestParameters.ordering !== void 0) {
        queryParameters["ordering"] = requestParameters.ordering;
      }
      if (requestParameters.page !== void 0) {
        queryParameters["page"] = requestParameters.page;
      }
      if (requestParameters.pageSize !== void 0) {
        queryParameters["page_size"] = requestParameters.pageSize;
      }
      if (requestParameters.path !== void 0) {
        queryParameters["path"] = requestParameters.path;
      }
      if (requestParameters.pathStartswith !== void 0) {
        queryParameters["path_startswith"] = requestParameters.pathStartswith;
      }
      if (requestParameters.search !== void 0) {
        queryParameters["search"] = requestParameters.search;
      }
      if (requestParameters.type) {
        queryParameters["type"] = requestParameters.type;
      }
      if (requestParameters.username !== void 0) {
        queryParameters["username"] = requestParameters.username;
      }
      if (requestParameters.uuid !== void 0) {
        queryParameters["uuid"] = requestParameters.uuid;
      }
      const headerParameters = {};
      if (this.configuration && this.configuration.accessToken) {
        const token = this.configuration.accessToken;
        const tokenString = yield token("authentik", []);
        if (tokenString) {
          headerParameters["Authorization"] = `Bearer ${tokenString}`;
        }
      }
      const response = yield this.request({
        path: `/core/users/`,
        method: "GET",
        headers: headerParameters,
        query: queryParameters
      }, initOverrides);
      return new JSONApiResponse(response, (jsonValue) => PaginatedUserListFromJSON(jsonValue));
    });
  }
  /**
   * User Viewset
   */
  coreUsersList(requestParameters = {}, initOverrides) {
    return __awaiter2(this, void 0, void 0, function* () {
      const response = yield this.coreUsersListRaw(requestParameters, initOverrides);
      return yield response.value();
    });
  }
  /**
   * Get information about current user
   */
  coreUsersMeRetrieveRaw(initOverrides) {
    return __awaiter2(this, void 0, void 0, function* () {
      const queryParameters = {};
      const headerParameters = {};
      if (this.configuration && this.configuration.accessToken) {
        const token = this.configuration.accessToken;
        const tokenString = yield token("authentik", []);
        if (tokenString) {
          headerParameters["Authorization"] = `Bearer ${tokenString}`;
        }
      }
      const response = yield this.request({
        path: `/core/users/me/`,
        method: "GET",
        headers: headerParameters,
        query: queryParameters
      }, initOverrides);
      return new JSONApiResponse(response, (jsonValue) => SessionUserFromJSON(jsonValue));
    });
  }
  /**
   * Get information about current user
   */
  coreUsersMeRetrieve(initOverrides) {
    return __awaiter2(this, void 0, void 0, function* () {
      const response = yield this.coreUsersMeRetrieveRaw(initOverrides);
      return yield response.value();
    });
  }
  /**
   * User metrics per 1h
   */
  coreUsersMetricsRetrieveRaw(requestParameters, initOverrides) {
    return __awaiter2(this, void 0, void 0, function* () {
      if (requestParameters.id === null || requestParameters.id === void 0) {
        throw new RequiredError("id", "Required parameter requestParameters.id was null or undefined when calling coreUsersMetricsRetrieve.");
      }
      const queryParameters = {};
      const headerParameters = {};
      if (this.configuration && this.configuration.accessToken) {
        const token = this.configuration.accessToken;
        const tokenString = yield token("authentik", []);
        if (tokenString) {
          headerParameters["Authorization"] = `Bearer ${tokenString}`;
        }
      }
      const response = yield this.request({
        path: `/core/users/{id}/metrics/`.replace(`{${"id"}}`, encodeURIComponent(String(requestParameters.id))),
        method: "GET",
        headers: headerParameters,
        query: queryParameters
      }, initOverrides);
      return new JSONApiResponse(response, (jsonValue) => UserMetricsFromJSON(jsonValue));
    });
  }
  /**
   * User metrics per 1h
   */
  coreUsersMetricsRetrieve(requestParameters, initOverrides) {
    return __awaiter2(this, void 0, void 0, function* () {
      const response = yield this.coreUsersMetricsRetrieveRaw(requestParameters, initOverrides);
      return yield response.value();
    });
  }
  /**
   * User Viewset
   */
  coreUsersPartialUpdateRaw(requestParameters, initOverrides) {
    return __awaiter2(this, void 0, void 0, function* () {
      if (requestParameters.id === null || requestParameters.id === void 0) {
        throw new RequiredError("id", "Required parameter requestParameters.id was null or undefined when calling coreUsersPartialUpdate.");
      }
      const queryParameters = {};
      const headerParameters = {};
      headerParameters["Content-Type"] = "application/json";
      if (this.configuration && this.configuration.accessToken) {
        const token = this.configuration.accessToken;
        const tokenString = yield token("authentik", []);
        if (tokenString) {
          headerParameters["Authorization"] = `Bearer ${tokenString}`;
        }
      }
      const response = yield this.request({
        path: `/core/users/{id}/`.replace(`{${"id"}}`, encodeURIComponent(String(requestParameters.id))),
        method: "PATCH",
        headers: headerParameters,
        query: queryParameters,
        body: PatchedUserRequestToJSON(requestParameters.patchedUserRequest)
      }, initOverrides);
      return new JSONApiResponse(response, (jsonValue) => UserFromJSON(jsonValue));
    });
  }
  /**
   * User Viewset
   */
  coreUsersPartialUpdate(requestParameters, initOverrides) {
    return __awaiter2(this, void 0, void 0, function* () {
      const response = yield this.coreUsersPartialUpdateRaw(requestParameters, initOverrides);
      return yield response.value();
    });
  }
  /**
   * Get all user paths
   */
  coreUsersPathsRetrieveRaw(requestParameters, initOverrides) {
    return __awaiter2(this, void 0, void 0, function* () {
      const queryParameters = {};
      if (requestParameters.search !== void 0) {
        queryParameters["search"] = requestParameters.search;
      }
      const headerParameters = {};
      if (this.configuration && this.configuration.accessToken) {
        const token = this.configuration.accessToken;
        const tokenString = yield token("authentik", []);
        if (tokenString) {
          headerParameters["Authorization"] = `Bearer ${tokenString}`;
        }
      }
      const response = yield this.request({
        path: `/core/users/paths/`,
        method: "GET",
        headers: headerParameters,
        query: queryParameters
      }, initOverrides);
      return new JSONApiResponse(response, (jsonValue) => UserPathFromJSON(jsonValue));
    });
  }
  /**
   * Get all user paths
   */
  coreUsersPathsRetrieve(requestParameters = {}, initOverrides) {
    return __awaiter2(this, void 0, void 0, function* () {
      const response = yield this.coreUsersPathsRetrieveRaw(requestParameters, initOverrides);
      return yield response.value();
    });
  }
  /**
   * Create a temporary link that a user can use to recover their accounts
   */
  coreUsersRecoveryCreateRaw(requestParameters, initOverrides) {
    return __awaiter2(this, void 0, void 0, function* () {
      if (requestParameters.id === null || requestParameters.id === void 0) {
        throw new RequiredError("id", "Required parameter requestParameters.id was null or undefined when calling coreUsersRecoveryCreate.");
      }
      const queryParameters = {};
      const headerParameters = {};
      if (this.configuration && this.configuration.accessToken) {
        const token = this.configuration.accessToken;
        const tokenString = yield token("authentik", []);
        if (tokenString) {
          headerParameters["Authorization"] = `Bearer ${tokenString}`;
        }
      }
      const response = yield this.request({
        path: `/core/users/{id}/recovery/`.replace(`{${"id"}}`, encodeURIComponent(String(requestParameters.id))),
        method: "POST",
        headers: headerParameters,
        query: queryParameters
      }, initOverrides);
      return new JSONApiResponse(response, (jsonValue) => LinkFromJSON(jsonValue));
    });
  }
  /**
   * Create a temporary link that a user can use to recover their accounts
   */
  coreUsersRecoveryCreate(requestParameters, initOverrides) {
    return __awaiter2(this, void 0, void 0, function* () {
      const response = yield this.coreUsersRecoveryCreateRaw(requestParameters, initOverrides);
      return yield response.value();
    });
  }
  /**
   * Create a temporary link that a user can use to recover their accounts
   */
  coreUsersRecoveryEmailCreateRaw(requestParameters, initOverrides) {
    return __awaiter2(this, void 0, void 0, function* () {
      if (requestParameters.emailStage === null || requestParameters.emailStage === void 0) {
        throw new RequiredError("emailStage", "Required parameter requestParameters.emailStage was null or undefined when calling coreUsersRecoveryEmailCreate.");
      }
      if (requestParameters.id === null || requestParameters.id === void 0) {
        throw new RequiredError("id", "Required parameter requestParameters.id was null or undefined when calling coreUsersRecoveryEmailCreate.");
      }
      const queryParameters = {};
      if (requestParameters.emailStage !== void 0) {
        queryParameters["email_stage"] = requestParameters.emailStage;
      }
      const headerParameters = {};
      if (this.configuration && this.configuration.accessToken) {
        const token = this.configuration.accessToken;
        const tokenString = yield token("authentik", []);
        if (tokenString) {
          headerParameters["Authorization"] = `Bearer ${tokenString}`;
        }
      }
      const response = yield this.request({
        path: `/core/users/{id}/recovery_email/`.replace(`{${"id"}}`, encodeURIComponent(String(requestParameters.id))),
        method: "POST",
        headers: headerParameters,
        query: queryParameters
      }, initOverrides);
      return new VoidApiResponse(response);
    });
  }
  /**
   * Create a temporary link that a user can use to recover their accounts
   */
  coreUsersRecoveryEmailCreate(requestParameters, initOverrides) {
    return __awaiter2(this, void 0, void 0, function* () {
      yield this.coreUsersRecoveryEmailCreateRaw(requestParameters, initOverrides);
    });
  }
  /**
   * User Viewset
   */
  coreUsersRetrieveRaw(requestParameters, initOverrides) {
    return __awaiter2(this, void 0, void 0, function* () {
      if (requestParameters.id === null || requestParameters.id === void 0) {
        throw new RequiredError("id", "Required parameter requestParameters.id was null or undefined when calling coreUsersRetrieve.");
      }
      const queryParameters = {};
      const headerParameters = {};
      if (this.configuration && this.configuration.accessToken) {
        const token = this.configuration.accessToken;
        const tokenString = yield token("authentik", []);
        if (tokenString) {
          headerParameters["Authorization"] = `Bearer ${tokenString}`;
        }
      }
      const response = yield this.request({
        path: `/core/users/{id}/`.replace(`{${"id"}}`, encodeURIComponent(String(requestParameters.id))),
        method: "GET",
        headers: headerParameters,
        query: queryParameters
      }, initOverrides);
      return new JSONApiResponse(response, (jsonValue) => UserFromJSON(jsonValue));
    });
  }
  /**
   * User Viewset
   */
  coreUsersRetrieve(requestParameters, initOverrides) {
    return __awaiter2(this, void 0, void 0, function* () {
      const response = yield this.coreUsersRetrieveRaw(requestParameters, initOverrides);
      return yield response.value();
    });
  }
  /**
   * Create a new user account that is marked as a service account
   */
  coreUsersServiceAccountCreateRaw(requestParameters, initOverrides) {
    return __awaiter2(this, void 0, void 0, function* () {
      if (requestParameters.userServiceAccountRequest === null || requestParameters.userServiceAccountRequest === void 0) {
        throw new RequiredError("userServiceAccountRequest", "Required parameter requestParameters.userServiceAccountRequest was null or undefined when calling coreUsersServiceAccountCreate.");
      }
      const queryParameters = {};
      const headerParameters = {};
      headerParameters["Content-Type"] = "application/json";
      if (this.configuration && this.configuration.accessToken) {
        const token = this.configuration.accessToken;
        const tokenString = yield token("authentik", []);
        if (tokenString) {
          headerParameters["Authorization"] = `Bearer ${tokenString}`;
        }
      }
      const response = yield this.request({
        path: `/core/users/service_account/`,
        method: "POST",
        headers: headerParameters,
        query: queryParameters,
        body: UserServiceAccountRequestToJSON(requestParameters.userServiceAccountRequest)
      }, initOverrides);
      return new JSONApiResponse(response, (jsonValue) => UserServiceAccountResponseFromJSON(jsonValue));
    });
  }
  /**
   * Create a new user account that is marked as a service account
   */
  coreUsersServiceAccountCreate(requestParameters, initOverrides) {
    return __awaiter2(this, void 0, void 0, function* () {
      const response = yield this.coreUsersServiceAccountCreateRaw(requestParameters, initOverrides);
      return yield response.value();
    });
  }
  /**
   * Set password for user
   */
  coreUsersSetPasswordCreateRaw(requestParameters, initOverrides) {
    return __awaiter2(this, void 0, void 0, function* () {
      if (requestParameters.id === null || requestParameters.id === void 0) {
        throw new RequiredError("id", "Required parameter requestParameters.id was null or undefined when calling coreUsersSetPasswordCreate.");
      }
      if (requestParameters.userPasswordSetRequest === null || requestParameters.userPasswordSetRequest === void 0) {
        throw new RequiredError("userPasswordSetRequest", "Required parameter requestParameters.userPasswordSetRequest was null or undefined when calling coreUsersSetPasswordCreate.");
      }
      const queryParameters = {};
      const headerParameters = {};
      headerParameters["Content-Type"] = "application/json";
      if (this.configuration && this.configuration.accessToken) {
        const token = this.configuration.accessToken;
        const tokenString = yield token("authentik", []);
        if (tokenString) {
          headerParameters["Authorization"] = `Bearer ${tokenString}`;
        }
      }
      const response = yield this.request({
        path: `/core/users/{id}/set_password/`.replace(`{${"id"}}`, encodeURIComponent(String(requestParameters.id))),
        method: "POST",
        headers: headerParameters,
        query: queryParameters,
        body: UserPasswordSetRequestToJSON(requestParameters.userPasswordSetRequest)
      }, initOverrides);
      return new VoidApiResponse(response);
    });
  }
  /**
   * Set password for user
   */
  coreUsersSetPasswordCreate(requestParameters, initOverrides) {
    return __awaiter2(this, void 0, void 0, function* () {
      yield this.coreUsersSetPasswordCreateRaw(requestParameters, initOverrides);
    });
  }
  /**
   * User Viewset
   */
  coreUsersUpdateRaw(requestParameters, initOverrides) {
    return __awaiter2(this, void 0, void 0, function* () {
      if (requestParameters.id === null || requestParameters.id === void 0) {
        throw new RequiredError("id", "Required parameter requestParameters.id was null or undefined when calling coreUsersUpdate.");
      }
      if (requestParameters.userRequest === null || requestParameters.userRequest === void 0) {
        throw new RequiredError("userRequest", "Required parameter requestParameters.userRequest was null or undefined when calling coreUsersUpdate.");
      }
      const queryParameters = {};
      const headerParameters = {};
      headerParameters["Content-Type"] = "application/json";
      if (this.configuration && this.configuration.accessToken) {
        const token = this.configuration.accessToken;
        const tokenString = yield token("authentik", []);
        if (tokenString) {
          headerParameters["Authorization"] = `Bearer ${tokenString}`;
        }
      }
      const response = yield this.request({
        path: `/core/users/{id}/`.replace(`{${"id"}}`, encodeURIComponent(String(requestParameters.id))),
        method: "PUT",
        headers: headerParameters,
        query: queryParameters,
        body: UserRequestToJSON(requestParameters.userRequest)
      }, initOverrides);
      return new JSONApiResponse(response, (jsonValue) => UserFromJSON(jsonValue));
    });
  }
  /**
   * User Viewset
   */
  coreUsersUpdate(requestParameters, initOverrides) {
    return __awaiter2(this, void 0, void 0, function* () {
      const response = yield this.coreUsersUpdateRaw(requestParameters, initOverrides);
      return yield response.value();
    });
  }
  /**
   * Get a list of all objects that use this object
   */
  coreUsersUsedByListRaw(requestParameters, initOverrides) {
    return __awaiter2(this, void 0, void 0, function* () {
      if (requestParameters.id === null || requestParameters.id === void 0) {
        throw new RequiredError("id", "Required parameter requestParameters.id was null or undefined when calling coreUsersUsedByList.");
      }
      const queryParameters = {};
      const headerParameters = {};
      if (this.configuration && this.configuration.accessToken) {
        const token = this.configuration.accessToken;
        const tokenString = yield token("authentik", []);
        if (tokenString) {
          headerParameters["Authorization"] = `Bearer ${tokenString}`;
        }
      }
      const response = yield this.request({
        path: `/core/users/{id}/used_by/`.replace(`{${"id"}}`, encodeURIComponent(String(requestParameters.id))),
        method: "GET",
        headers: headerParameters,
        query: queryParameters
      }, initOverrides);
      return new JSONApiResponse(response, (jsonValue) => jsonValue.map(UsedByFromJSON));
    });
  }
  /**
   * Get a list of all objects that use this object
   */
  coreUsersUsedByList(requestParameters, initOverrides) {
    return __awaiter2(this, void 0, void 0, function* () {
      const response = yield this.coreUsersUsedByListRaw(requestParameters, initOverrides);
      return yield response.value();
    });
  }
};

// node_modules/@goauthentik/api/dist/esm/apis/EnterpriseApi.js
var __awaiter3 = function(thisArg, _arguments, P, generator) {
  function adopt(value) {
    return value instanceof P ? value : new P(function(resolve) {
      resolve(value);
    });
  }
  return new (P || (P = Promise))(function(resolve, reject) {
    function fulfilled(value) {
      try {
        step(generator.next(value));
      } catch (e4) {
        reject(e4);
      }
    }
    function rejected(value) {
      try {
        step(generator["throw"](value));
      } catch (e4) {
        reject(e4);
      }
    }
    function step(result) {
      result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected);
    }
    step((generator = generator.apply(thisArg, _arguments || [])).next());
  });
};
var EnterpriseApi = class extends BaseAPI {
  /**
   * License Viewset
   */
  enterpriseLicenseCreateRaw(requestParameters, initOverrides) {
    return __awaiter3(this, void 0, void 0, function* () {
      if (requestParameters.licenseRequest === null || requestParameters.licenseRequest === void 0) {
        throw new RequiredError("licenseRequest", "Required parameter requestParameters.licenseRequest was null or undefined when calling enterpriseLicenseCreate.");
      }
      const queryParameters = {};
      const headerParameters = {};
      headerParameters["Content-Type"] = "application/json";
      if (this.configuration && this.configuration.accessToken) {
        const token = this.configuration.accessToken;
        const tokenString = yield token("authentik", []);
        if (tokenString) {
          headerParameters["Authorization"] = `Bearer ${tokenString}`;
        }
      }
      const response = yield this.request({
        path: `/enterprise/license/`,
        method: "POST",
        headers: headerParameters,
        query: queryParameters,
        body: LicenseRequestToJSON(requestParameters.licenseRequest)
      }, initOverrides);
      return new JSONApiResponse(response, (jsonValue) => LicenseFromJSON(jsonValue));
    });
  }
  /**
   * License Viewset
   */
  enterpriseLicenseCreate(requestParameters, initOverrides) {
    return __awaiter3(this, void 0, void 0, function* () {
      const response = yield this.enterpriseLicenseCreateRaw(requestParameters, initOverrides);
      return yield response.value();
    });
  }
  /**
   * License Viewset
   */
  enterpriseLicenseDestroyRaw(requestParameters, initOverrides) {
    return __awaiter3(this, void 0, void 0, function* () {
      if (requestParameters.licenseUuid === null || requestParameters.licenseUuid === void 0) {
        throw new RequiredError("licenseUuid", "Required parameter requestParameters.licenseUuid was null or undefined when calling enterpriseLicenseDestroy.");
      }
      const queryParameters = {};
      const headerParameters = {};
      if (this.configuration && this.configuration.accessToken) {
        const token = this.configuration.accessToken;
        const tokenString = yield token("authentik", []);
        if (tokenString) {
          headerParameters["Authorization"] = `Bearer ${tokenString}`;
        }
      }
      const response = yield this.request({
        path: `/enterprise/license/{license_uuid}/`.replace(`{${"license_uuid"}}`, encodeURIComponent(String(requestParameters.licenseUuid))),
        method: "DELETE",
        headers: headerParameters,
        query: queryParameters
      }, initOverrides);
      return new VoidApiResponse(response);
    });
  }
  /**
   * License Viewset
   */
  enterpriseLicenseDestroy(requestParameters, initOverrides) {
    return __awaiter3(this, void 0, void 0, function* () {
      yield this.enterpriseLicenseDestroyRaw(requestParameters, initOverrides);
    });
  }
  /**
   * Forecast how many users will be required in a year
   */
  enterpriseLicenseForecastRetrieveRaw(initOverrides) {
    return __awaiter3(this, void 0, void 0, function* () {
      const queryParameters = {};
      const headerParameters = {};
      if (this.configuration && this.configuration.accessToken) {
        const token = this.configuration.accessToken;
        const tokenString = yield token("authentik", []);
        if (tokenString) {
          headerParameters["Authorization"] = `Bearer ${tokenString}`;
        }
      }
      const response = yield this.request({
        path: `/enterprise/license/forecast/`,
        method: "GET",
        headers: headerParameters,
        query: queryParameters
      }, initOverrides);
      return new JSONApiResponse(response, (jsonValue) => LicenseForecastFromJSON(jsonValue));
    });
  }
  /**
   * Forecast how many users will be required in a year
   */
  enterpriseLicenseForecastRetrieve(initOverrides) {
    return __awaiter3(this, void 0, void 0, function* () {
      const response = yield this.enterpriseLicenseForecastRetrieveRaw(initOverrides);
      return yield response.value();
    });
  }
  /**
   * Get install_id
   */
  enterpriseLicenseGetInstallIdRetrieveRaw(initOverrides) {
    return __awaiter3(this, void 0, void 0, function* () {
      const queryParameters = {};
      const headerParameters = {};
      if (this.configuration && this.configuration.accessToken) {
        const token = this.configuration.accessToken;
        const tokenString = yield token("authentik", []);
        if (tokenString) {
          headerParameters["Authorization"] = `Bearer ${tokenString}`;
        }
      }
      const response = yield this.request({
        path: `/enterprise/license/get_install_id/`,
        method: "GET",
        headers: headerParameters,
        query: queryParameters
      }, initOverrides);
      return new JSONApiResponse(response, (jsonValue) => InstallIDFromJSON(jsonValue));
    });
  }
  /**
   * Get install_id
   */
  enterpriseLicenseGetInstallIdRetrieve(initOverrides) {
    return __awaiter3(this, void 0, void 0, function* () {
      const response = yield this.enterpriseLicenseGetInstallIdRetrieveRaw(initOverrides);
      return yield response.value();
    });
  }
  /**
   * License Viewset
   */
  enterpriseLicenseListRaw(requestParameters, initOverrides) {
    return __awaiter3(this, void 0, void 0, function* () {
      const queryParameters = {};
      if (requestParameters.name !== void 0) {
        queryParameters["name"] = requestParameters.name;
      }
      if (requestParameters.ordering !== void 0) {
        queryParameters["ordering"] = requestParameters.ordering;
      }
      if (requestParameters.page !== void 0) {
        queryParameters["page"] = requestParameters.page;
      }
      if (requestParameters.pageSize !== void 0) {
        queryParameters["page_size"] = requestParameters.pageSize;
      }
      if (requestParameters.search !== void 0) {
        queryParameters["search"] = requestParameters.search;
      }
      const headerParameters = {};
      if (this.configuration && this.configuration.accessToken) {
        const token = this.configuration.accessToken;
        const tokenString = yield token("authentik", []);
        if (tokenString) {
          headerParameters["Authorization"] = `Bearer ${tokenString}`;
        }
      }
      const response = yield this.request({
        path: `/enterprise/license/`,
        method: "GET",
        headers: headerParameters,
        query: queryParameters
      }, initOverrides);
      return new JSONApiResponse(response, (jsonValue) => PaginatedLicenseListFromJSON(jsonValue));
    });
  }
  /**
   * License Viewset
   */
  enterpriseLicenseList(requestParameters = {}, initOverrides) {
    return __awaiter3(this, void 0, void 0, function* () {
      const response = yield this.enterpriseLicenseListRaw(requestParameters, initOverrides);
      return yield response.value();
    });
  }
  /**
   * License Viewset
   */
  enterpriseLicensePartialUpdateRaw(requestParameters, initOverrides) {
    return __awaiter3(this, void 0, void 0, function* () {
      if (requestParameters.licenseUuid === null || requestParameters.licenseUuid === void 0) {
        throw new RequiredError("licenseUuid", "Required parameter requestParameters.licenseUuid was null or undefined when calling enterpriseLicensePartialUpdate.");
      }
      const queryParameters = {};
      const headerParameters = {};
      headerParameters["Content-Type"] = "application/json";
      if (this.configuration && this.configuration.accessToken) {
        const token = this.configuration.accessToken;
        const tokenString = yield token("authentik", []);
        if (tokenString) {
          headerParameters["Authorization"] = `Bearer ${tokenString}`;
        }
      }
      const response = yield this.request({
        path: `/enterprise/license/{license_uuid}/`.replace(`{${"license_uuid"}}`, encodeURIComponent(String(requestParameters.licenseUuid))),
        method: "PATCH",
        headers: headerParameters,
        query: queryParameters,
        body: PatchedLicenseRequestToJSON(requestParameters.patchedLicenseRequest)
      }, initOverrides);
      return new JSONApiResponse(response, (jsonValue) => LicenseFromJSON(jsonValue));
    });
  }
  /**
   * License Viewset
   */
  enterpriseLicensePartialUpdate(requestParameters, initOverrides) {
    return __awaiter3(this, void 0, void 0, function* () {
      const response = yield this.enterpriseLicensePartialUpdateRaw(requestParameters, initOverrides);
      return yield response.value();
    });
  }
  /**
   * License Viewset
   */
  enterpriseLicenseRetrieveRaw(requestParameters, initOverrides) {
    return __awaiter3(this, void 0, void 0, function* () {
      if (requestParameters.licenseUuid === null || requestParameters.licenseUuid === void 0) {
        throw new RequiredError("licenseUuid", "Required parameter requestParameters.licenseUuid was null or undefined when calling enterpriseLicenseRetrieve.");
      }
      const queryParameters = {};
      const headerParameters = {};
      if (this.configuration && this.configuration.accessToken) {
        const token = this.configuration.accessToken;
        const tokenString = yield token("authentik", []);
        if (tokenString) {
          headerParameters["Authorization"] = `Bearer ${tokenString}`;
        }
      }
      const response = yield this.request({
        path: `/enterprise/license/{license_uuid}/`.replace(`{${"license_uuid"}}`, encodeURIComponent(String(requestParameters.licenseUuid))),
        method: "GET",
        headers: headerParameters,
        query: queryParameters
      }, initOverrides);
      return new JSONApiResponse(response, (jsonValue) => LicenseFromJSON(jsonValue));
    });
  }
  /**
   * License Viewset
   */
  enterpriseLicenseRetrieve(requestParameters, initOverrides) {
    return __awaiter3(this, void 0, void 0, function* () {
      const response = yield this.enterpriseLicenseRetrieveRaw(requestParameters, initOverrides);
      return yield response.value();
    });
  }
  /**
   * Get the total license status
   */
  enterpriseLicenseSummaryRetrieveRaw(initOverrides) {
    return __awaiter3(this, void 0, void 0, function* () {
      const queryParameters = {};
      const headerParameters = {};
      if (this.configuration && this.configuration.accessToken) {
        const token = this.configuration.accessToken;
        const tokenString = yield token("authentik", []);
        if (tokenString) {
          headerParameters["Authorization"] = `Bearer ${tokenString}`;
        }
      }
      const response = yield this.request({
        path: `/enterprise/license/summary/`,
        method: "GET",
        headers: headerParameters,
        query: queryParameters
      }, initOverrides);
      return new JSONApiResponse(response, (jsonValue) => LicenseSummaryFromJSON(jsonValue));
    });
  }
  /**
   * Get the total license status
   */
  enterpriseLicenseSummaryRetrieve(initOverrides) {
    return __awaiter3(this, void 0, void 0, function* () {
      const response = yield this.enterpriseLicenseSummaryRetrieveRaw(initOverrides);
      return yield response.value();
    });
  }
  /**
   * License Viewset
   */
  enterpriseLicenseUpdateRaw(requestParameters, initOverrides) {
    return __awaiter3(this, void 0, void 0, function* () {
      if (requestParameters.licenseUuid === null || requestParameters.licenseUuid === void 0) {
        throw new RequiredError("licenseUuid", "Required parameter requestParameters.licenseUuid was null or undefined when calling enterpriseLicenseUpdate.");
      }
      if (requestParameters.licenseRequest === null || requestParameters.licenseRequest === void 0) {
        throw new RequiredError("licenseRequest", "Required parameter requestParameters.licenseRequest was null or undefined when calling enterpriseLicenseUpdate.");
      }
      const queryParameters = {};
      const headerParameters = {};
      headerParameters["Content-Type"] = "application/json";
      if (this.configuration && this.configuration.accessToken) {
        const token = this.configuration.accessToken;
        const tokenString = yield token("authentik", []);
        if (tokenString) {
          headerParameters["Authorization"] = `Bearer ${tokenString}`;
        }
      }
      const response = yield this.request({
        path: `/enterprise/license/{license_uuid}/`.replace(`{${"license_uuid"}}`, encodeURIComponent(String(requestParameters.licenseUuid))),
        method: "PUT",
        headers: headerParameters,
        query: queryParameters,
        body: LicenseRequestToJSON(requestParameters.licenseRequest)
      }, initOverrides);
      return new JSONApiResponse(response, (jsonValue) => LicenseFromJSON(jsonValue));
    });
  }
  /**
   * License Viewset
   */
  enterpriseLicenseUpdate(requestParameters, initOverrides) {
    return __awaiter3(this, void 0, void 0, function* () {
      const response = yield this.enterpriseLicenseUpdateRaw(requestParameters, initOverrides);
      return yield response.value();
    });
  }
  /**
   * Get a list of all objects that use this object
   */
  enterpriseLicenseUsedByListRaw(requestParameters, initOverrides) {
    return __awaiter3(this, void 0, void 0, function* () {
      if (requestParameters.licenseUuid === null || requestParameters.licenseUuid === void 0) {
        throw new RequiredError("licenseUuid", "Required parameter requestParameters.licenseUuid was null or undefined when calling enterpriseLicenseUsedByList.");
      }
      const queryParameters = {};
      const headerParameters = {};
      if (this.configuration && this.configuration.accessToken) {
        const token = this.configuration.accessToken;
        const tokenString = yield token("authentik", []);
        if (tokenString) {
          headerParameters["Authorization"] = `Bearer ${tokenString}`;
        }
      }
      const response = yield this.request({
        path: `/enterprise/license/{license_uuid}/used_by/`.replace(`{${"license_uuid"}}`, encodeURIComponent(String(requestParameters.licenseUuid))),
        method: "GET",
        headers: headerParameters,
        query: queryParameters
      }, initOverrides);
      return new JSONApiResponse(response, (jsonValue) => jsonValue.map(UsedByFromJSON));
    });
  }
  /**
   * Get a list of all objects that use this object
   */
  enterpriseLicenseUsedByList(requestParameters, initOverrides) {
    return __awaiter3(this, void 0, void 0, function* () {
      const response = yield this.enterpriseLicenseUsedByListRaw(requestParameters, initOverrides);
      return yield response.value();
    });
  }
};

// node_modules/@goauthentik/api/dist/esm/apis/RootApi.js
var __awaiter4 = function(thisArg, _arguments, P, generator) {
  function adopt(value) {
    return value instanceof P ? value : new P(function(resolve) {
      resolve(value);
    });
  }
  return new (P || (P = Promise))(function(resolve, reject) {
    function fulfilled(value) {
      try {
        step(generator.next(value));
      } catch (e4) {
        reject(e4);
      }
    }
    function rejected(value) {
      try {
        step(generator["throw"](value));
      } catch (e4) {
        reject(e4);
      }
    }
    function step(result) {
      result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected);
    }
    step((generator = generator.apply(thisArg, _arguments || [])).next());
  });
};
var RootApi = class extends BaseAPI {
  /**
   * Retrieve public configuration options
   */
  rootConfigRetrieveRaw(initOverrides) {
    return __awaiter4(this, void 0, void 0, function* () {
      const queryParameters = {};
      const headerParameters = {};
      if (this.configuration && this.configuration.accessToken) {
        const token = this.configuration.accessToken;
        const tokenString = yield token("authentik", []);
        if (tokenString) {
          headerParameters["Authorization"] = `Bearer ${tokenString}`;
        }
      }
      const response = yield this.request({
        path: `/root/config/`,
        method: "GET",
        headers: headerParameters,
        query: queryParameters
      }, initOverrides);
      return new JSONApiResponse(response, (jsonValue) => ConfigFromJSON(jsonValue));
    });
  }
  /**
   * Retrieve public configuration options
   */
  rootConfigRetrieve(initOverrides) {
    return __awaiter4(this, void 0, void 0, function* () {
      const response = yield this.rootConfigRetrieveRaw(initOverrides);
      return yield response.value();
    });
  }
};

// src/common/errors.ts
var SentryIgnoredError = class extends Error {
};

// src/common/utils.ts
function getCookie(name) {
  let cookieValue = "";
  if (document.cookie && document.cookie !== "") {
    const cookies = document.cookie.split(";");
    for (let i3 = 0; i3 < cookies.length; i3++) {
      const cookie = cookies[i3].trim();
      if (cookie.substring(0, name.length + 1) === name + "=") {
        cookieValue = decodeURIComponent(cookie.substring(name.length + 1));
        break;
      }
    }
  }
  return cookieValue;
}
function first(...args) {
  for (let index = 0; index < args.length; index++) {
    const element = args[index];
    if (element !== void 0 && element !== null) {
      return element;
    }
  }
  throw new SentryIgnoredError(`No compatible arg given: ${args}`);
}
var ascii_lowercase = "abcdefghijklmnopqrstuvwxyz";
var ascii_uppercase = "ABCDEFGHIJKLMNOPQRSTUVWXYZ";
var ascii_letters = ascii_lowercase + ascii_uppercase;
var digits = "0123456789";
var hexdigits = digits + "abcdefABCDEF";
var isCSSResult = (v) => v instanceof n && v.styleSheet !== void 0;
var _adaptCSS = (sheet) => typeof sheet === "string" ? i([sheet], []).styleSheet : isCSSResult(sheet) ? sheet.styleSheet : sheet;
function adaptCSS(sheet) {
  return Array.isArray(sheet) ? sheet.map(_adaptCSS) : _adaptCSS(sheet);
}
var _timeUnits = /* @__PURE__ */ new Map([
  ["year", 24 * 60 * 60 * 1e3 * 365],
  ["month", 24 * 60 * 60 * 1e3 * 365 / 12],
  ["day", 24 * 60 * 60 * 1e3],
  ["hour", 60 * 60 * 1e3],
  ["minute", 60 * 1e3],
  ["second", 1e3]
]);

// src/common/api/middleware.ts
var CSRFHeaderName = "X-authentik-CSRF";
var LoggingMiddleware = class {
  constructor(brand) {
    this.brand = brand;
  }
  post(context) {
    let msg2 = `authentik/api[${this.brand.matchedDomain}]: `;
    msg2 += `%c${context.response.status}%c ${context.init.method} ${context.url}`;
    let style = "";
    if (context.response.status >= 400) {
      style = "color: red; font-weight: bold;";
    }
    console.debug(msg2, style, "");
    return Promise.resolve(context.response);
  }
};
var CSRFMiddleware = class {
  pre(context) {
    context.init.headers[CSRFHeaderName] = getCookie("authentik_csrf");
    return Promise.resolve(context);
  }
};
var EventMiddleware = class {
  post(context) {
    const request = {
      method: (context.init.method || "GET").toUpperCase(),
      path: context.url,
      status: context.response.status
    };
    window.dispatchEvent(
      new CustomEvent(EVENT_REQUEST_POST, {
        bubbles: true,
        composed: true,
        detail: request
      })
    );
    return Promise.resolve(context.response);
  }
};

// src/common/global.ts
function globalAK() {
  const ak = window.authentik;
  if (ak && !ak._converted) {
    ak._converted = true;
    ak.brand = CurrentBrandFromJSON(ak.brand);
    ak.config = ConfigFromJSON(ak.config);
  }
  if (!ak) {
    return {
      config: ConfigFromJSON({
        capabilities: []
      }),
      brand: CurrentBrandFromJSON({
        ui_footer_links: []
      }),
      versionFamily: "",
      versionSubdomain: "",
      build: ""
    };
  }
  return ak;
}

// src/common/api/config.ts
var globalConfigPromise = Promise.resolve(globalAK().config);
var globalBrandPromise = Promise.resolve(globalAK().brand);
function getMetaContent(key) {
  const metaEl = document.querySelector(`meta[name=${key}]`);
  if (!metaEl)
    return "";
  return metaEl.content;
}
var DEFAULT_CONFIG = new Configuration({
  basePath: window.location.origin + "/api/v3",
  headers: {
    "sentry-trace": getMetaContent("sentry-trace")
  },
  middleware: [
    new CSRFMiddleware(),
    new EventMiddleware(),
    new LoggingMiddleware(globalAK().brand)
  ]
});
console.debug(`authentik(early): version ${VERSION}, apiBase ${DEFAULT_CONFIG.basePath}`);

// src/common/users.ts
var globalMePromise;
function me() {
  if (!globalMePromise) {
    globalMePromise = new CoreApi(DEFAULT_CONFIG).coreUsersMeRetrieve().then((user) => {
      if (!user.user.settings || !("locale" in user.user.settings)) {
        return user;
      }
      const locale = user.user.settings.locale;
      if (locale && locale !== "") {
        console.debug(
          `authentik/locale: Activating user's configured locale '${locale}'`
        );
        window.dispatchEvent(
          new CustomEvent(EVENT_LOCALE_REQUEST, {
            composed: true,
            bubbles: true,
            detail: { locale }
          })
        );
      }
      return user;
    }).catch((ex) => {
      const defaultUser = {
        user: {
          pk: -1,
          isSuperuser: false,
          isActive: true,
          groups: [],
          avatar: "",
          uid: "",
          username: "",
          name: "",
          settings: {},
          systemPermissions: []
        }
      };
      if (ex.response?.status === 401 || ex.response?.status === 403) {
        const relativeUrl = window.location.toString().substring(window.location.origin.length);
        window.location.assign(
          `/flows/-/default/authentication/?next=${encodeURIComponent(relativeUrl)}`
        );
      }
      return defaultUser;
    });
  }
  return globalMePromise;
}

// src/common/sentry.ts
function currentInterface() {
  const pathMatches = window.location.pathname.match(/.+if\/(\w+)\//);
  let currentInterface2 = "unknown";
  if (pathMatches && pathMatches.length >= 2) {
    currentInterface2 = pathMatches[1];
  }
  return currentInterface2.toLowerCase();
}

// src/common/ui/config.ts
var DefaultUIConfig = class {
  constructor() {
    this.enabledFeatures = {
      apiDrawer: true,
      notificationDrawer: true,
      settings: true,
      applicationEdit: true,
      search: true
    };
    this.layout = {
      type: "row" /* row */
    };
    this.navbar = {
      userDisplay: "username" /* username */
    };
    this.theme = {
      base: UiThemeEnum.Automatic,
      background: "",
      cardBackground: ""
    };
    this.pagination = {
      perPage: 20
    };
    this.locale = "";
    this.defaults = {
      userPath: "users"
    };
    if (currentInterface() === "user") {
      this.enabledFeatures.apiDrawer = false;
    }
  }
};
var globalUiConfig;
function getConfigForUser(user) {
  const settings = user.settings;
  let config2 = new DefaultUIConfig();
  if (!settings) {
    return config2;
  }
  config2 = Object.assign(new DefaultUIConfig(), settings);
  return config2;
}
function uiConfig() {
  if (!globalUiConfig) {
    globalUiConfig = me().then((user) => {
      return getConfigForUser(user.user);
    });
  }
  return globalUiConfig;
}

// src/elements/decorators/bound.ts
function bound(target, key, descriptor) {
  if (typeof descriptor?.value !== "function") {
    throw new Error("Only methods can be @bound.");
  }
  return {
    configurable: true,
    get() {
      const method = descriptor.value.bind(this);
      Object.defineProperty(this, key, { value: method, configurable: true, writable: true });
      return method;
    }
  };
}

// src/elements/controllers/ModalOrchestrationController.ts
var modalIsLive = (modal) => modal.isConnected && modal.checkVisibility();
var ModalOrchestrationController = class {
  constructor(host) {
    this.knownModals = [];
    this.host = host;
    host.addController(this);
  }
  hostConnected() {
    window.addEventListener("keyup", this.handleKeyup);
    window.addEventListener("ak-modal-show", this.addModal);
    window.addEventListener("ak-modal-hide", this.closeModal);
  }
  hostDisconnected() {
    window.removeEventListener("keyup", this.handleKeyup);
    window.removeEventListener("ak-modal-show", this.addModal);
    window.removeEventListener("ak-modal-hide", this.closeModal);
  }
  addModal(e4) {
    this.knownModals = [...this.knownModals, e4.modal];
  }
  scheduleCleanup(modal) {
    setTimeout(() => {
      this.knownModals = this.knownModals.filter((m) => modalIsLive(m) && modal !== m);
    }, 0);
  }
  closeModal(e4) {
    const modal = e4.modal;
    if (!modalIsLive(modal)) {
      return;
    }
    if (modal.closeModal() !== false) {
      this.scheduleCleanup(modal);
    }
  }
  removeTopmostModal() {
    let checking = true;
    while (checking) {
      const modal = this.knownModals.pop();
      if (!modal) {
        break;
      }
      if (!modalIsLive(modal)) {
        continue;
      }
      if (modal.closeModal() !== false) {
        this.scheduleCleanup(modal);
      }
      checking = false;
      break;
    }
  }
  handleKeyup(e4) {
    if (e4.key === "Escape" || e4.key === "Esc") {
      this.removeTopmostModal();
    }
  }
};
__decorateClass([
  bound
], ModalOrchestrationController.prototype, "addModal", 1);
__decorateClass([
  bound
], ModalOrchestrationController.prototype, "closeModal", 1);
__decorateClass([
  bound
], ModalOrchestrationController.prototype, "handleKeyup", 1);

// src/elements/utils/ensureCSSStyleSheet.ts
var supportsAdoptingStyleSheets = window.ShadowRoot && (window.ShadyCSS === void 0 || window.ShadyCSS.nativeShadow) && "adoptedStyleSheets" in Document.prototype && "replace" in CSSStyleSheet.prototype;
function stringToStylesheet(css2) {
  if (supportsAdoptingStyleSheets) {
    const sheet2 = r(css2).styleSheet;
    if (sheet2 === void 0) {
      throw new Error(
        `CSS processing error: undefined stylesheet from string.  Source: ${css2}`
      );
    }
    return sheet2;
  }
  const sheet = new CSSStyleSheet();
  sheet.replaceSync(css2);
  return sheet;
}
function cssResultToStylesheet(css2) {
  const sheet = css2.styleSheet;
  return sheet ? sheet : stringToStylesheet(css2.toString());
}
var ensureCSSStyleSheet = (css2) => css2 instanceof n ? cssResultToStylesheet(css2) : typeof css2 === "string" ? stringToStylesheet(css2) : css2;

// node_modules/@lit/reactive-element/decorators/custom-element.js
var t = (t3) => (e4, o3) => {
  void 0 !== o3 ? o3.addInitializer(() => {
    customElements.define(t3, e4);
  }) : customElements.define(t3, e4);
};

// node_modules/@lit/reactive-element/decorators/property.js
var o = { attribute: true, type: String, converter: u, reflect: false, hasChanged: f };
var r2 = (t3 = o, e4, r4) => {
  const { kind: n4, metadata: i3 } = r4;
  let s5 = globalThis.litPropertyMetadata.get(i3);
  if (void 0 === s5 && globalThis.litPropertyMetadata.set(i3, s5 = /* @__PURE__ */ new Map()), s5.set(r4.name, t3), "accessor" === n4) {
    const { name: o3 } = r4;
    return { set(r5) {
      const n5 = e4.get.call(this);
      e4.set.call(this, r5), this.requestUpdate(o3, n5, t3);
    }, init(e5) {
      return void 0 !== e5 && this.P(o3, void 0, t3), e5;
    } };
  }
  if ("setter" === n4) {
    const { name: o3 } = r4;
    return function(r5) {
      const n5 = this[o3];
      e4.call(this, r5), this.requestUpdate(o3, n5, t3);
    };
  }
  throw Error("Unsupported decorator location: " + n4);
};
function n2(t3) {
  return (e4, o3) => "object" == typeof o3 ? r2(t3, e4, o3) : ((t4, e5, o4) => {
    const r4 = e5.hasOwnProperty(o4);
    return e5.constructor.createProperty(o4, r4 ? { ...t4, wrapped: true } : t4), r4 ? Object.getOwnPropertyDescriptor(e5, o4) : void 0;
  })(t3, e4, o3);
}

// node_modules/@lit/reactive-element/decorators/state.js
function r3(r4) {
  return n2({ ...r4, state: true, attribute: false });
}

// node_modules/@patternfly/patternfly/patternfly-base.css
var patternfly_base_default = '.pf-t-light {\n  --pf-global--Color--100: var(--pf-global--Color--dark-100);\n  --pf-global--Color--200: var(--pf-global--Color--dark-200);\n  --pf-global--BorderColor--100: var(--pf-global--BorderColor--dark-100);\n  --pf-global--primary-color--100: var(--pf-global--primary-color--dark-100);\n  --pf-global--link--Color: var(--pf-global--link--Color--dark);\n  --pf-global--link--Color--hover: var(--pf-global--link--Color--dark--hover);\n  --pf-global--BackgroundColor--100: var(--pf-global--BackgroundColor--light-100);\n}\n\n.pf-t-dark {\n  --pf-global--Color--100: var(--pf-global--Color--light-100);\n  --pf-global--Color--200: var(--pf-global--Color--light-200);\n  --pf-global--BorderColor--100: var(--pf-global--BorderColor--light-100);\n  --pf-global--primary-color--100: var(--pf-global--primary-color--light-100);\n  --pf-global--link--Color: var(--pf-global--link--Color--light);\n  --pf-global--link--Color--hover: var(--pf-global--link--Color--light);\n  --pf-global--BackgroundColor--100: var(--pf-global--BackgroundColor--dark-100);\n}\n.pf-t-dark .pf-c-card {\n  --pf-c-card--BackgroundColor: var(--pf-global--BackgroundColor--dark-transparent-200);\n}\n.pf-t-dark .pf-c-button {\n  --pf-c-button--m-primary--Color: var(--pf-global--primary-color--dark-100);\n  --pf-c-button--m-primary--hover--Color: var(--pf-global--primary-color--dark-100);\n  --pf-c-button--m-primary--focus--Color: var(--pf-global--primary-color--dark-100);\n  --pf-c-button--m-primary--active--Color: var(--pf-global--primary-color--dark-100);\n  --pf-c-button--m-primary--BackgroundColor: var(--pf-global--BackgroundColor--light-100);\n  --pf-c-button--m-primary--hover--BackgroundColor: var(--pf-global--BackgroundColor--light-300);\n  --pf-c-button--m-primary--focus--BackgroundColor: var(--pf-global--BackgroundColor--light-300);\n  --pf-c-button--m-primary--active--BackgroundColor: var(--pf-global--BackgroundColor--light-300);\n  --pf-c-button--m-secondary--Color: var(--pf-global--Color--light-100);\n  --pf-c-button--m-secondary--hover--Color: var(--pf-global--Color--light-100);\n  --pf-c-button--m-secondary--focus--Color: var(--pf-global--Color--light-100);\n  --pf-c-button--m-secondary--active--Color: var(--pf-global--Color--light-100);\n  --pf-c-button--m-secondary--BorderColor: var(--pf-global--Color--light-100);\n  --pf-c-button--m-secondary--hover--BorderColor: var(--pf-global--Color--light-100);\n  --pf-c-button--m-secondary--focus--BorderColor: var(--pf-global--Color--light-100);\n  --pf-c-button--m-secondary--active--BorderColor: var(--pf-global--Color--light-100);\n}\n\n:root {\n  --pf-global--palette--black-100: #fafafa;\n  --pf-global--palette--black-150: #f5f5f5;\n  --pf-global--palette--black-200: #f0f0f0;\n  --pf-global--palette--black-300: #d2d2d2;\n  --pf-global--palette--black-400: #b8bbbe;\n  --pf-global--palette--black-500: #8a8d90;\n  --pf-global--palette--black-600: #6a6e73;\n  --pf-global--palette--black-700: #4f5255;\n  --pf-global--palette--black-800: #3c3f42;\n  --pf-global--palette--black-850: #212427;\n  --pf-global--palette--black-900: #151515;\n  --pf-global--palette--black-1000: #030303;\n  --pf-global--palette--blue-50: #e7f1fa;\n  --pf-global--palette--blue-100: #bee1f4;\n  --pf-global--palette--blue-200: #73bcf7;\n  --pf-global--palette--blue-300: #2b9af3;\n  --pf-global--palette--blue-400: #06c;\n  --pf-global--palette--blue-500: #004080;\n  --pf-global--palette--blue-600: #002952;\n  --pf-global--palette--blue-700: #001223;\n  --pf-global--palette--cyan-50: #f2f9f9;\n  --pf-global--palette--cyan-100: #a2d9d9;\n  --pf-global--palette--cyan-200: #73c5c5;\n  --pf-global--palette--cyan-300: #009596;\n  --pf-global--palette--cyan-400: #005f60;\n  --pf-global--palette--cyan-500: #003737;\n  --pf-global--palette--cyan-600: #002323;\n  --pf-global--palette--cyan-700: #000f0f;\n  --pf-global--palette--gold-50: #fdf7e7;\n  --pf-global--palette--gold-100: #f9e0a2;\n  --pf-global--palette--gold-200: #f6d173;\n  --pf-global--palette--gold-300: #f4c145;\n  --pf-global--palette--gold-400: #f0ab00;\n  --pf-global--palette--gold-500: #c58c00;\n  --pf-global--palette--gold-600: #795600;\n  --pf-global--palette--gold-700: #3d2c00;\n  --pf-global--palette--green-50: #f3faf2;\n  --pf-global--palette--green-100: #bde5b8;\n  --pf-global--palette--green-200: #95d58e;\n  --pf-global--palette--green-300: #6ec664;\n  --pf-global--palette--green-400: #5ba352;\n  --pf-global--palette--green-500: #3e8635;\n  --pf-global--palette--green-600: #1e4f18;\n  --pf-global--palette--green-700: #0f280d;\n  --pf-global--palette--light-blue-100: #beedf9;\n  --pf-global--palette--light-blue-200: #7cdbf3;\n  --pf-global--palette--light-blue-300: #35caed;\n  --pf-global--palette--light-blue-400: #00b9e4;\n  --pf-global--palette--light-blue-500: #008bad;\n  --pf-global--palette--light-blue-600: #005c73;\n  --pf-global--palette--light-blue-700: #002d39;\n  --pf-global--palette--light-green-100: #e4f5bc;\n  --pf-global--palette--light-green-200: #c8eb79;\n  --pf-global--palette--light-green-300: #ace12e;\n  --pf-global--palette--light-green-400: #92d400;\n  --pf-global--palette--light-green-500: #6ca100;\n  --pf-global--palette--light-green-600: #486b00;\n  --pf-global--palette--light-green-700: #253600;\n  --pf-global--palette--orange-50: #fff6ec;\n  --pf-global--palette--orange-100: #f4b678;\n  --pf-global--palette--orange-200: #ef9234;\n  --pf-global--palette--orange-300: #ec7a08;\n  --pf-global--palette--orange-400: #c46100;\n  --pf-global--palette--orange-500: #8f4700;\n  --pf-global--palette--orange-600: #773d00;\n  --pf-global--palette--orange-700: #3b1f00;\n  --pf-global--palette--purple-50: #f2f0fc;\n  --pf-global--palette--purple-100: #cbc1ff;\n  --pf-global--palette--purple-200: #b2a3ff;\n  --pf-global--palette--purple-300: #a18fff;\n  --pf-global--palette--purple-400: #8476d1;\n  --pf-global--palette--purple-500: #6753ac;\n  --pf-global--palette--purple-600: #40199a;\n  --pf-global--palette--purple-700: #1f0066;\n  --pf-global--palette--red-50: #faeae8;\n  --pf-global--palette--red-100: #c9190b;\n  --pf-global--palette--red-200: #a30000;\n  --pf-global--palette--red-300: #7d1007;\n  --pf-global--palette--red-400: #470000;\n  --pf-global--palette--red-500: #2c0000;\n  --pf-global--palette--white: #fff;\n  --pf-global--BackgroundColor--100: #fff;\n  --pf-global--BackgroundColor--150: #fafafa;\n  --pf-global--BackgroundColor--200: #f0f0f0;\n  --pf-global--BackgroundColor--light-100: #fff;\n  --pf-global--BackgroundColor--light-200: #fafafa;\n  --pf-global--BackgroundColor--light-300: #f0f0f0;\n  --pf-global--BackgroundColor--dark-100: #151515;\n  --pf-global--BackgroundColor--dark-200: #3c3f42;\n  --pf-global--BackgroundColor--dark-300: #212427;\n  --pf-global--BackgroundColor--dark-400: #4f5255;\n  --pf-global--BackgroundColor--dark-transparent-100: rgba(3, 3, 3, 0.62);\n  --pf-global--BackgroundColor--dark-transparent-200: rgba(3, 3, 3, 0.32);\n  --pf-global--Color--100: #151515;\n  --pf-global--Color--200: #6a6e73;\n  --pf-global--Color--300: #3c3f42;\n  --pf-global--Color--400: #8a8d90;\n  --pf-global--Color--light-100: #fff;\n  --pf-global--Color--light-200: #f0f0f0;\n  --pf-global--Color--light-300: #d2d2d2;\n  --pf-global--Color--dark-100: #151515;\n  --pf-global--Color--dark-200: #6a6e73;\n  --pf-global--active-color--100: #06c;\n  --pf-global--active-color--200: #bee1f4;\n  --pf-global--active-color--300: #2b9af3;\n  --pf-global--active-color--400: #73bcf7;\n  --pf-global--disabled-color--100: #6a6e73;\n  --pf-global--disabled-color--200: #d2d2d2;\n  --pf-global--disabled-color--300: #f0f0f0;\n  --pf-global--primary-color--100: #06c;\n  --pf-global--primary-color--200: #004080;\n  --pf-global--primary-color--light-100: #73bcf7;\n  --pf-global--primary-color--dark-100: #06c;\n  --pf-global--secondary-color--100: #6a6e73;\n  --pf-global--default-color--100: #73c5c5;\n  --pf-global--default-color--200: #009596;\n  --pf-global--default-color--300: #003737;\n  --pf-global--success-color--100: #3e8635;\n  --pf-global--success-color--200: #1e4f18;\n  --pf-global--info-color--100: #2b9af3;\n  --pf-global--info-color--200: #002952;\n  --pf-global--warning-color--100: #f0ab00;\n  --pf-global--warning-color--200: #795600;\n  --pf-global--danger-color--100: #c9190b;\n  --pf-global--danger-color--200: #a30000;\n  --pf-global--danger-color--300: #470000;\n  --pf-global--BoxShadow--sm: 0 0.0625rem 0.125rem 0 rgba(3, 3, 3, 0.12), 0 0 0.125rem 0 rgba(3, 3, 3, 0.06);\n  --pf-global--BoxShadow--sm-top: 0 -0.125rem 0.25rem -0.0625rem rgba(3, 3, 3, 0.16);\n  --pf-global--BoxShadow--sm-right: 0.125rem 0 0.25rem -0.0625rem rgba(3, 3, 3, 0.16);\n  --pf-global--BoxShadow--sm-bottom: 0 0.125rem 0.25rem -0.0625rem rgba(3, 3, 3, 0.16);\n  --pf-global--BoxShadow--sm-left: -0.125rem 0 0.25rem -0.0625rem rgba(3, 3, 3, 0.16);\n  --pf-global--BoxShadow--md: 0 0.25rem 0.5rem 0rem rgba(3, 3, 3, 0.12), 0 0 0.25rem 0 rgba(3, 3, 3, 0.06);\n  --pf-global--BoxShadow--md-top: 0 -0.5rem 0.5rem -0.375rem rgba(3, 3, 3, 0.18);\n  --pf-global--BoxShadow--md-right: 0.5rem 0 0.5rem -0.375rem rgba(3, 3, 3, 0.18);\n  --pf-global--BoxShadow--md-bottom: 0 0.5rem 0.5rem -0.375rem rgba(3, 3, 3, 0.18);\n  --pf-global--BoxShadow--md-left: -0.5rem 0 0.5rem -0.375rem rgba(3, 3, 3, 0.18);\n  --pf-global--BoxShadow--lg: 0 0.5rem 1rem 0 rgba(3, 3, 3, 0.16), 0 0 0.375rem 0 rgba(3, 3, 3, 0.08);\n  --pf-global--BoxShadow--lg-top: 0 -0.75rem 0.75rem -0.5rem rgba(3, 3, 3, 0.18);\n  --pf-global--BoxShadow--lg-right: 0.75rem 0 0.75rem -0.5rem rgba(3, 3, 3, 0.18);\n  --pf-global--BoxShadow--lg-bottom: 0 0.75rem 0.75rem -0.5rem rgba(3, 3, 3, 0.18);\n  --pf-global--BoxShadow--lg-left: -0.75rem 0 0.75rem -0.5rem rgba(3, 3, 3, 0.18);\n  --pf-global--BoxShadow--xl: 0 1rem 2rem 0 rgba(3, 3, 3, 0.16), 0 0 0.5rem 0 rgba(3, 3, 3, 0.1);\n  --pf-global--BoxShadow--xl-top: 0 -1rem 1rem -0.5rem rgba(3, 3, 3, 0.2);\n  --pf-global--BoxShadow--xl-right: 1rem 0 1rem -0.5rem rgba(3, 3, 3, 0.2);\n  --pf-global--BoxShadow--xl-bottom: 0 1rem 1rem -0.5rem rgba(3, 3, 3, 0.2);\n  --pf-global--BoxShadow--xl-left: -1rem 0 1rem -0.5rem rgba(3, 3, 3, 0.2);\n  --pf-global--BoxShadow--inset: inset 0 0 0.625rem 0 rgba(3, 3, 3, 0.25);\n  --pf-global--font-path: "./assets/fonts";\n  --pf-global--fonticon-path: "./assets/pficon";\n  --pf-global--spacer--xs: 0.25rem;\n  --pf-global--spacer--sm: 0.5rem;\n  --pf-global--spacer--md: 1rem;\n  --pf-global--spacer--lg: 1.5rem;\n  --pf-global--spacer--xl: 2rem;\n  --pf-global--spacer--2xl: 3rem;\n  --pf-global--spacer--3xl: 4rem;\n  --pf-global--spacer--4xl: 5rem;\n  --pf-global--spacer--form-element: 0.375rem;\n  --pf-global--gutter: 1rem;\n  --pf-global--gutter--md: 1.5rem;\n  --pf-global--ZIndex--xs: 100;\n  --pf-global--ZIndex--sm: 200;\n  --pf-global--ZIndex--md: 300;\n  --pf-global--ZIndex--lg: 400;\n  --pf-global--ZIndex--xl: 500;\n  --pf-global--ZIndex--2xl: 600;\n  --pf-global--breakpoint--xs: 0;\n  --pf-global--breakpoint--sm: 576px;\n  --pf-global--breakpoint--md: 768px;\n  --pf-global--breakpoint--lg: 992px;\n  --pf-global--breakpoint--xl: 1200px;\n  --pf-global--breakpoint--2xl: 1450px;\n  --pf-global--height-breakpoint--sm: 0;\n  --pf-global--height-breakpoint--md: 40rem;\n  --pf-global--height-breakpoint--lg: 48rem;\n  --pf-global--height-breakpoint--xl: 60rem;\n  --pf-global--height-breakpoint--2xl: 80rem;\n  --pf-global--link--Color: #06c;\n  --pf-global--link--Color--hover: #004080;\n  --pf-global--link--Color--light: #2b9af3;\n  --pf-global--link--Color--light--hover: #73bcf7;\n  --pf-global--link--Color--dark: #06c;\n  --pf-global--link--Color--dark--hover: #004080;\n  --pf-global--link--Color--visited: #40199a;\n  --pf-global--link--TextDecoration: none;\n  --pf-global--link--TextDecoration--hover: underline;\n  --pf-global--BorderWidth--sm: 1px;\n  --pf-global--BorderWidth--md: 2px;\n  --pf-global--BorderWidth--lg: 3px;\n  --pf-global--BorderWidth--xl: 4px;\n  --pf-global--BorderColor--100: #d2d2d2;\n  --pf-global--BorderColor--200: #8a8d90;\n  --pf-global--BorderColor--300: #f0f0f0;\n  --pf-global--BorderColor--dark-100: #d2d2d2;\n  --pf-global--BorderColor--light-100: #b8bbbe;\n  --pf-global--BorderRadius--sm: 3px;\n  --pf-global--BorderRadius--lg: 30em;\n  --pf-global--icon--Color--light: #6a6e73;\n  --pf-global--icon--Color--dark: #151515;\n  --pf-global--icon--FontSize--sm: 0.625rem;\n  --pf-global--icon--FontSize--md: 1.125rem;\n  --pf-global--icon--FontSize--lg: 1.5rem;\n  --pf-global--icon--FontSize--xl: 3.375rem;\n  --pf-global--FontFamily--sans-serif: "RedHatText", "Overpass", overpass, helvetica, arial, sans-serif;\n  --pf-global--FontFamily--heading--sans-serif: "RedHatDisplay", "Overpass", overpass, helvetica, arial, sans-serif;\n  --pf-global--FontFamily--monospace: "Liberation Mono", consolas, "SFMono-Regular", menlo, monaco, "Courier New", monospace;\n  --pf-global--FontFamily--redhat-updated--sans-serif: "RedHatTextUpdated", "Overpass", overpass, helvetica, arial, sans-serif;\n  --pf-global--FontFamily--redhat-updated--heading--sans-serif: "RedHatDisplayUpdated", "Overpass", overpass, helvetica, arial, sans-serif;\n  --pf-global--FontFamily--redhat--monospace: "RedHatMono", "Liberation Mono", consolas, "SFMono-Regular", menlo, monaco, "Courier New", monospace;\n  --pf-global--FontFamily--redhatVF--sans-serif: "RedHatTextVF", "RedHatText", "Overpass", overpass, helvetica, arial, sans-serif;\n  --pf-global--FontFamily--redhatVF--heading--sans-serif: "RedHatDisplayVF", "RedHatDisplay", "Overpass", overpass, helvetica, arial, sans-serif;\n  --pf-global--FontFamily--redhatVF--monospace: "RedHatMonoVF", "RedHatMono", "Liberation Mono", consolas, "SFMono-Regular", menlo, monaco, "Courier New", monospace;\n  --pf-global--FontFamily--overpass--sans-serif: "overpass", overpass, "open sans", -apple-system, blinkmacsystemfont, "Segoe UI", roboto, "Helvetica Neue", arial, sans-serif, "Apple Color Emoji", "Segoe UI Emoji", "Segoe UI Symbol";\n  --pf-global--FontFamily--overpass--monospace: "overpass-mono", overpass-mono, "SFMono-Regular", menlo, monaco, consolas, "Liberation Mono", "Courier New", monospace;\n  --pf-global--FontSize--4xl: 2.25rem;\n  --pf-global--FontSize--3xl: 1.75rem;\n  --pf-global--FontSize--2xl: 1.5rem;\n  --pf-global--FontSize--xl: 1.25rem;\n  --pf-global--FontSize--lg: 1.125rem;\n  --pf-global--FontSize--md: 1rem;\n  --pf-global--FontSize--sm: 0.875rem;\n  --pf-global--FontSize--xs: 0.75rem;\n  --pf-global--FontWeight--light: 300;\n  --pf-global--FontWeight--normal: 400;\n  --pf-global--FontWeight--semi-bold: 700;\n  --pf-global--FontWeight--overpass--semi-bold: 500;\n  --pf-global--FontWeight--bold: 700;\n  --pf-global--FontWeight--overpass--bold: 600;\n  --pf-global--LineHeight--sm: 1.3;\n  --pf-global--LineHeight--md: 1.5;\n  --pf-global--ListStyle: disc outside;\n  --pf-global--Transition: all 250ms cubic-bezier(0.42, 0, 0.58, 1);\n  --pf-global--TimingFunction: cubic-bezier(0.645, 0.045, 0.355, 1);\n  --pf-global--TransitionDuration: 250ms;\n  --pf-global--arrow--width: 0.9375rem;\n  --pf-global--arrow--width-lg: 1.5625rem;\n  --pf-global--target-size--MinWidth: 44px;\n  --pf-global--target-size--MinHeight: 44px;\n}\n\n.pf-m-overpass-font {\n  --pf-global--FontFamily--sans-serif: var(--pf-global--FontFamily--overpass--sans-serif);\n  --pf-global--FontFamily--heading--sans-serif: var(--pf-global--FontFamily--sans-serif);\n  --pf-global--FontFamily--monospace: var(--pf-global--FontFamily--overpass--monospace);\n  --pf-global--FontWeight--semi-bold: var(--pf-global--FontWeight--overpass--semi-bold);\n  --pf-global--FontWeight--bold: var(--pf-global--FontWeight--overpass--bold);\n}\n\n.pf-m-redhat-updated-font {\n  --pf-global--FontFamily--sans-serif: var(--pf-global--FontFamily--redhat-updated--sans-serif);\n  --pf-global--FontFamily--heading--sans-serif: var(--pf-global--FontFamily--redhat-updated--heading--sans-serif);\n}\n\n.pf-m-redhatmono-font {\n  --pf-global--FontFamily--monospace: var(--pf-global--FontFamily--redhat--monospace);\n}\n\n.pf-m-redhatVF-font {\n  --pf-global--FontFamily--sans-serif: var(--pf-global--FontFamily--redhatVF--sans-serif);\n  --pf-global--FontFamily--heading--sans-serif: var(--pf-global--FontFamily--redhatVF--heading--sans-serif);\n  --pf-global--FontFamily--monospace: var(--pf-global--FontFamily--redhatVF--monospace);\n}\n\n:root:where(.pf-theme-dark) {\n  --pf-global--palette--black-50: #e0e0e0;\n  --pf-global--palette--black-100: #c6c7c8;\n  --pf-global--palette--black-200: #aaabac;\n  --pf-global--palette--black-300: #868789;\n  --pf-global--palette--black-400: #57585a;\n  --pf-global--palette--black-500: #444548;\n  --pf-global--palette--black-600: #36373a;\n  --pf-global--palette--black-700: #26292d;\n  --pf-global--palette--black-800: #1b1d21;\n  --pf-global--palette--black-900: #0f1214;\n  --pf-global--palette--red-9999: #fe5142;\n  --pf-global--palette--red-8888: #ff7468;\n  --pf-global--palette--blue-300: #1fa7f8;\n  --pf-global--BackgroundColor--100: #1b1d21;\n  --pf-global--BackgroundColor--150: #212427;\n  --pf-global--BackgroundColor--200: #0f1214;\n  --pf-global--BackgroundColor--300: #26292d;\n  --pf-global--BackgroundColor--400: #36373a;\n  --pf-global--BorderColor--100: #444548;\n  --pf-global--BorderColor--200: #444548;\n  --pf-global--BorderColor--300: #57585a;\n  --pf-global--BorderColor--400: #aaabac;\n  --pf-global--Color--100: #e0e0e0;\n  --pf-global--Color--200: #aaabac;\n  --pf-global--active-color--100: #1fa7f8;\n  --pf-global--primary-color--100: #1fa7f8;\n  --pf-global--primary-color--300: #06c;\n  --pf-global--success-color--100: #5ba352;\n  --pf-global--warning-color--100: #f0ab00;\n  --pf-global--warning-color--200: #f4c145;\n  --pf-global--danger-color--100: #fe5142;\n  --pf-global--danger-color--200: #ff7468;\n  --pf-global--link--Color: #1fa7f8;\n  --pf-global--link--Color--hover: #73bcf7;\n  --pf-global--link--Color--visited: #a18fff;\n  --pf-global--disabled-color--100: #57585a;\n  --pf-global--disabled-color--200: #444548;\n  --pf-global--disabled-color--300: #aaabac;\n  --pf-global--icon--Color--light: #aaabac;\n  --pf-global--icon--Color--dark: #aaabac;\n  --pf-global--Color--dark-100: #e0e0e0;\n  --pf-global--Color--dark-200: #aaabac;\n  --pf-global--Color--light-100: #e0e0e0;\n  --pf-global--Color--light-200: #aaabac;\n  --pf-global--Color--light-300: #3c3f42;\n  --pf-global--BorderColor--dark-100: #444548;\n  --pf-global--BorderColor--light-100: #444548;\n  --pf-global--primary-color--light-100: #1fa7f8;\n  --pf-global--primary-color--dark-100: #1fa7f8;\n  --pf-global--link--Color--light: #1fa7f8;\n  --pf-global--link--Color--light--hover: #73bcf7;\n  --pf-global--link--Color--dark: #1fa7f8;\n  --pf-global--link--Color--dark--hover: #73bcf7;\n  --pf-global--BackgroundColor--light-100: #1b1d21;\n  --pf-global--BackgroundColor--light-200: #0f1214;\n  --pf-global--BackgroundColor--light-300: #26292d;\n  --pf-global--BackgroundColor--dark-100: #1b1d21;\n  --pf-global--BackgroundColor--dark-200: #0f1214;\n  --pf-global--BackgroundColor--dark-300: #26292d;\n  --pf-global--BackgroundColor--dark-400: #36373a;\n  --pf-global--BoxShadow--sm: 0 0.0625rem 0.125rem 0 rgba(3, 3, 3, 0.48), 0 0 0.125rem 0 rgba(3, 3, 3, 0.24);\n  --pf-global--BoxShadow--sm-top: 0 -0.125rem 0.25rem -0.0625rem rgba(3, 3, 3, 0.64);\n  --pf-global--BoxShadow--sm-right: 0.125rem 0 0.25rem -0.0625rem rgba(3, 3, 3, 0.64);\n  --pf-global--BoxShadow--sm-bottom: 0 0.125rem 0.25rem -0.0625rem rgba(3, 3, 3, 0.64);\n  --pf-global--BoxShadow--sm-left: -0.125rem 0 0.25rem -0.0625rem rgba(3, 3, 3, 0.64);\n  --pf-global--BoxShadow--md: 0 0.25rem 0.5rem 0rem rgba(3, 3, 3, 0.48), 0 0 0.25rem 0 rgba(3, 3, 3, 0.24);\n  --pf-global--BoxShadow--md-top: 0 -0.5rem 0.5rem -0.375rem rgba(3, 3, 3, 0.72);\n  --pf-global--BoxShadow--md-right: 0.5rem 0 0.5rem -0.375rem rgba(3, 3, 3, 0.72);\n  --pf-global--BoxShadow--md-bottom: 0 0.5rem 0.5rem -0.375rem rgba(3, 3, 3, 0.72);\n  --pf-global--BoxShadow--md-left: -0.5rem 0 0.5rem -0.375rem rgba(3, 3, 3, 0.72);\n  --pf-global--BoxShadow--lg: 0 0.5rem 1rem 0 rgba(3, 3, 3, 0.64), 0 0 0.375rem 0 rgba(3, 3, 3, 0.32);\n  --pf-global--BoxShadow--lg-top: 0 -0.75rem 0.75rem -0.5rem rgba(3, 3, 3, 0.72);\n  --pf-global--BoxShadow--lg-right: 0.75rem 0 0.75rem -0.5rem rgba(3, 3, 3, 0.72);\n  --pf-global--BoxShadow--lg-bottom: 0 0.75rem 0.75rem -0.5rem rgba(3, 3, 3, 0.72);\n  --pf-global--BoxShadow--lg-left: -0.75rem 0 0.75rem -0.5rem rgba(3, 3, 3, 0.72);\n  --pf-global--BoxShadow--xl: 0 1rem 2rem 0 rgba(3, 3, 3, 0.64), 0 0 0.5rem 0 rgba(3, 3, 3, 0.4);\n  --pf-global--BoxShadow--xl-top: 0 -1rem 1rem -0.5rem rgba(3, 3, 3, 0.8);\n  --pf-global--BoxShadow--xl-right: 1rem 0 1rem -0.5rem rgba(3, 3, 3, 0.8);\n  --pf-global--BoxShadow--xl-bottom: 0 1rem 1rem -0.5rem rgba(3, 3, 3, 0.8);\n  --pf-global--BoxShadow--xl-left: -1rem 0 1rem -0.5rem rgba(3, 3, 3, 0.8);\n  --pf-global--BoxShadow--inset: inset 0 0 0.625rem 0 #030303;\n}\n\n@font-face {\n  font-family: "RedHatDisplay";\n  src: url("./assets/fonts/RedHatDisplay/RedHatDisplay-Regular.woff2") format("woff2"), url("./assets/fonts/RedHatDisplay/RedHatDisplay-Regular.woff") format("woff");\n  font-style: normal;\n  font-weight: 300;\n  text-rendering: optimizelegibility;\n}\n@font-face {\n  font-family: "RedHatDisplay";\n  src: url("./assets/fonts/RedHatDisplay/RedHatDisplay-Medium.woff2") format("woff2"), url("./assets/fonts/RedHatDisplay/RedHatDisplay-Medium.woff") format("woff");\n  font-style: normal;\n  font-weight: 400;\n  text-rendering: optimizelegibility;\n}\n@font-face {\n  font-family: "RedHatDisplay";\n  src: url("./assets/fonts/RedHatDisplay/RedHatDisplay-Bold.woff2") format("woff2"), url("./assets/fonts/RedHatDisplay/RedHatDisplay-Bold.woff") format("woff");\n  font-style: normal;\n  font-weight: 700;\n  text-rendering: optimizelegibility;\n}\n@font-face {\n  font-family: "RedHatText";\n  src: url("./assets/fonts/RedHatText/RedHatText-Regular.woff2") format("woff2"), url("./assets/fonts/RedHatText/RedHatText-Regular.woff") format("woff");\n  font-style: normal;\n  font-weight: 400;\n  text-rendering: optimizelegibility;\n}\n@font-face {\n  font-family: "RedHatText";\n  src: url("./assets/fonts/RedHatText/RedHatText-Medium.woff2") format("woff2"), url("./assets/fonts/RedHatText/RedHatText-Medium.woff") format("woff");\n  font-style: normal;\n  font-weight: 700;\n  text-rendering: optimizelegibility;\n}\n@font-face {\n  font-family: "RedHatDisplayUpdated";\n  src: url("./assets/fonts/RedHatFont-updated/RedHatDisplay/RedHatDisplay-updated-Regular.woff2") format("woff2");\n  font-style: normal;\n  font-weight: 300;\n  text-rendering: optimizelegibility;\n}\n@font-face {\n  font-family: "RedHatDisplayUpdated";\n  src: url("./assets/fonts/RedHatFont-updated/RedHatDisplay/RedHatDisplay-updated-Medium.woff2") format("woff2");\n  font-style: normal;\n  font-weight: 400;\n  text-rendering: optimizelegibility;\n}\n@font-face {\n  font-family: "RedHatDisplayUpdated";\n  src: url("./assets/fonts/RedHatFont-updated/RedHatDisplay/RedHatDisplay-updated-Bold.woff2") format("woff2");\n  font-style: normal;\n  font-weight: 700;\n  text-rendering: optimizelegibility;\n}\n@font-face {\n  font-family: "RedHatTextUpdated";\n  src: url("./assets/fonts/RedHatFont-updated/RedHatText/RedHatText-updated-Regular.woff2") format("woff2");\n  font-style: normal;\n  font-weight: 400;\n  text-rendering: optimizelegibility;\n}\n@font-face {\n  font-family: "RedHatTextUpdated";\n  src: url("./assets/fonts/RedHatFont-updated/RedHatText/RedHatText-updated-Medium.woff2") format("woff2");\n  font-style: normal;\n  font-weight: 700;\n  text-rendering: optimizelegibility;\n}\n@font-face {\n  font-family: "RedHatMono";\n  src: url("./assets/fonts/RedHatFont-updated/RedHatMono/RedHatMono-updated-Regular.woff2") format("woff2");\n  font-style: normal;\n  font-weight: 400;\n  font-display: fallback;\n}\n@font-face {\n  font-family: "RedHatDisplayVF";\n  src: url("./assets/fonts/RedHatFont-updated/modified/RedHatDisplayVFModified-updated.woff2") format("woff2-variations");\n  font-style: normal;\n  font-weight: 300 900;\n  font-display: fallback;\n}\n@font-face {\n  font-family: "RedHatDisplayVF";\n  src: url("./assets/fonts/RedHatFont-updated/modified/RedHatDisplayVF-updated-ItalicModified.woff2") format("woff2-variations");\n  font-style: italic;\n  font-weight: 300 900;\n  font-display: fallback;\n}\n@font-face {\n  font-family: "RedHatTextVF";\n  src: url("./assets/fonts/RedHatFont-updated/modified/RedHatTextVFModified-updated.woff2") format("woff2-variations");\n  font-style: normal;\n  font-weight: 400 500;\n  font-display: fallback;\n}\n@font-face {\n  font-family: "RedHatTextVF";\n  src: url("./assets/fonts/RedHatFont-updated/modified/RedHatTextVF-updated-ItalicModified.woff2") format("woff2-variations");\n  font-style: italic;\n  font-weight: 400 500;\n  font-display: fallback;\n}\n@font-face {\n  font-family: "RedHatMonoVF";\n  src: url("./assets/fonts/RedHatFont-updated/RedHatMono/RedHatMonoVF-updated.woff2") format("woff2-variations");\n  font-style: normal;\n  font-weight: 300 700;\n  font-display: fallback;\n}\n@font-face {\n  font-family: "RedHatMonoVF";\n  src: url("./assets/fonts/RedHatFont-updated/RedHatMono/RedHatMonoVF-updated-Italic.woff2") format("woff2-variations");\n  font-style: italic;\n  font-weight: 300 700;\n  font-display: fallback;\n}\n@font-face {\n  font-family: "overpass";\n  font-style: normal;\n  font-weight: 200;\n  src: url("./assets/fonts/overpass-webfont/overpass-thin.woff2") format("woff2"), url("./assets/fonts/overpass-webfont/overpass-thin.woff") format("woff");\n}\n@font-face {\n  font-family: "overpass";\n  font-style: italic;\n  font-weight: 200;\n  src: url("./assets/fonts/overpass-webfont/overpass-thin-italic.woff2") format("woff2"), url("./assets/fonts/overpass-webfont/overpass-thin-italic.woff") format("woff");\n}\n@font-face {\n  font-family: "overpass";\n  font-style: normal;\n  font-weight: 300;\n  src: url("./assets/fonts/overpass-webfont/overpass-extralight.woff2") format("woff2"), url("./assets/fonts/overpass-webfont/overpass-extralight.woff") format("woff");\n}\n@font-face {\n  font-family: "overpass";\n  font-style: italic;\n  font-weight: 300;\n  src: url("./assets/fonts/overpass-webfont/overpass-extralight-italic.woff2") format("woff2"), url("./assets/fonts/overpass-webfont/overpass-extralight-italic.woff") format("woff");\n}\n@font-face {\n  font-family: "overpass";\n  font-style: normal;\n  font-weight: 400;\n  src: url("./assets/fonts/overpass-webfont/overpass-light.woff2") format("woff2"), url("./assets/fonts/overpass-webfont/overpass-light.woff") format("woff");\n}\n@font-face {\n  font-family: "overpass";\n  font-style: italic;\n  font-weight: 400;\n  src: url("./assets/fonts/overpass-webfont/overpass-light-italic.woff2") format("woff2"), url("./assets/fonts/overpass-webfont/overpass-light-italic.woff") format("woff");\n}\n@font-face {\n  font-family: "overpass";\n  font-style: normal;\n  font-weight: 500;\n  src: url("./assets/fonts/overpass-webfont/overpass-regular.woff2") format("woff2"), url("./assets/fonts/overpass-webfont/overpass-regular.woff") format("woff");\n}\n@font-face {\n  font-family: "overpass";\n  font-style: italic;\n  font-weight: 500;\n  src: url("./assets/fonts/overpass-webfont/overpass-italic.woff2") format("woff2"), url("./assets/fonts/overpass-webfont/overpass-italic.woff") format("woff");\n}\n@font-face {\n  font-family: "overpass";\n  font-style: normal;\n  font-weight: 600;\n  src: url("./assets/fonts/overpass-webfont/overpass-semibold.woff2") format("woff2"), url("./assets/fonts/overpass-webfont/overpass-semibold.woff") format("woff");\n}\n@font-face {\n  font-family: "overpass";\n  font-style: italic;\n  font-weight: 600;\n  src: url("./assets/fonts/overpass-webfont/overpass-semibold-italic.woff2") format("woff2"), url("./assets/fonts/overpass-webfont/overpass-semibold-italic.woff") format("woff");\n}\n@font-face {\n  font-family: "overpass";\n  font-style: normal;\n  font-weight: 700;\n  src: url("./assets/fonts/overpass-webfont/overpass-bold.woff2") format("woff2"), url("./assets/fonts/overpass-webfont/overpass-bold.woff") format("woff");\n}\n@font-face {\n  font-family: "overpass";\n  font-style: italic;\n  font-weight: 700;\n  src: url("./assets/fonts/overpass-webfont/overpass-bold-italic.woff2") format("woff2"), url("./assets/fonts/overpass-webfont/overpass-bold-italic.woff") format("woff");\n}\n@font-face {\n  font-family: "overpass";\n  font-style: normal;\n  font-weight: 800;\n  src: url("./assets/fonts/overpass-webfont/overpass-extrabold.woff2") format("woff2"), url("./assets/fonts/overpass-webfont/overpass-extrabold.woff") format("woff");\n}\n@font-face {\n  font-family: "overpass";\n  font-style: italic;\n  font-weight: 800;\n  src: url("./assets/fonts/overpass-webfont/overpass-extrabold-italic.woff2") format("woff2"), url("./assets/fonts/overpass-webfont/overpass-extrabold-italic.woff") format("woff");\n}\n@font-face {\n  font-family: "overpass";\n  font-style: normal;\n  font-weight: 900;\n  src: url("./assets/fonts/overpass-webfont/overpass-heavy.woff2") format("woff2"), url("./assets/fonts/overpass-webfont/overpass-heavy.woff") format("woff");\n}\n@font-face {\n  font-family: "overpass";\n  font-style: italic;\n  font-weight: 900;\n  src: url("./assets/fonts/overpass-webfont/overpass-heavy-italic.woff2") format("woff2"), url("./assets/fonts/overpass-webfont/overpass-heavy-italic.woff") format("woff");\n}\n@font-face {\n  font-family: "overpass-mono";\n  font-style: normal;\n  font-weight: 300;\n  src: url("./assets/fonts/overpass-mono-webfont/overpass-mono-light.woff2") format("woff2"), url("./assets/fonts/overpass-mono-webfont/overpass-mono-light.woff") format("woff");\n}\n@font-face {\n  font-family: "overpass-mono";\n  font-style: normal;\n  font-weight: 400;\n  src: url("./assets/fonts/overpass-mono-webfont/overpass-mono-regular.woff2") format("woff2"), url("./assets/fonts/overpass-mono-webfont/overpass-mono-regular.woff") format("woff");\n}\n@font-face {\n  font-family: "overpass-mono";\n  font-style: normal;\n  font-weight: 500;\n  src: url("./assets/fonts/overpass-mono-webfont/overpass-mono-semibold.woff2") format("woff2"), url("./assets/fonts/overpass-mono-webfont/overpass-mono-semibold.woff") format("woff");\n}\n@font-face {\n  font-family: "overpass-mono";\n  font-style: normal;\n  font-weight: 600;\n  src: url("./assets/fonts/overpass-mono-webfont/overpass-mono-bold.woff2") format("woff2"), url("./assets/fonts/overpass-mono-webfont/overpass-mono-bold.woff") format("woff");\n}\n[class*=pf-c-], [class*=pf-c-]::before, [class*=pf-c-]::after {\n  padding: 0;\n  margin: 0;\n  background-color: transparent;\n}\n\nhtml {\n  font-size: var(--pf-global--root--FontSize, unset) !important;\n}\n\n.pf-screen-reader {\n  position: fixed;\n  top: 0;\n  left: 0;\n  overflow: hidden;\n  clip: rect(0, 0, 0, 0);\n  white-space: nowrap;\n  border: 0;\n}\n.pf-screen-reader.pf-m-full-size {\n  width: 100%;\n  height: 100%;\n}\n.pf-screen-reader.pf-m-absolute {\n  position: absolute;\n}\n\n.pf-m-tabular-nums {\n  font-variant-numeric: tabular-nums;\n}\n\nhtml,\nbody,\np,\nol,\nul,\nli,\ndl,\ndt,\ndd,\nblockquote,\nfigure,\nfieldset,\nlegend,\ntextarea,\npre,\niframe,\nhr,\nh1,\nh2,\nh3,\nh4,\nh5,\nh6 {\n  padding: 0;\n  margin: 0;\n}\n\nhtml,\nbody {\n  height: 100%;\n}\n\nh1,\nh2,\nh3,\nh4,\nh5,\nh6 {\n  font-size: 100%;\n  font-weight: var(--pf-global--FontWeight--normal);\n}\n\nul {\n  list-style: none;\n}\n\nbutton,\ninput,\noptgroup,\nselect,\ntextarea {\n  margin: 0;\n  font-family: inherit;\n  font-size: 100%;\n  line-height: var(--pf-global--LineHeight--md);\n  color: var(--pf-global--Color--100);\n}\n\nimg,\nembed,\niframe,\nobject,\naudio,\nvideo {\n  max-width: 100%;\n  height: auto;\n}\n\niframe {\n  border: 0;\n}\n\ntable {\n  border-spacing: 0;\n  border-collapse: collapse;\n}\n\ntd,\nth {\n  padding: 0;\n  text-align: left;\n}\n\ncode,\npre {\n  font-family: var(--pf-global--FontFamily--monospace);\n}\n\n*,\n*::before,\n*::after {\n  box-sizing: border-box;\n}\n\nhtml {\n  font-family: sans-serif;\n  line-height: 1.15;\n}\n\nbody {\n  font-family: var(--pf-global--FontFamily--sans-serif);\n  font-size: var(--pf-global--FontSize--md);\n  font-weight: var(--pf-global--FontWeight--normal);\n  line-height: var(--pf-global--LineHeight--md);\n  text-align: left;\n  background-color: var(--pf-global--BackgroundColor--100);\n}\n\na {\n  font-weight: var(--pf-global--link--FontWeight);\n  color: var(--pf-global--link--Color);\n  text-decoration: var(--pf-global--link--TextDecoration);\n}\na:hover {\n  --pf-global--link--Color: var(--pf-global--link--Color--hover);\n  --pf-global--link--TextDecoration: var(--pf-global--link--TextDecoration--hover);\n}\n\nbutton,\na {\n  cursor: pointer;\n}\n\n.pf-m-overpass-font a {\n  font-weight: var(--pf-global--FontWeight--semi-bold);\n}\n\n:root:where(.pf-theme-dark) {\n  color-scheme: dark;\n}\n\n.pf-t-dark.pf-m-transparent {\n  background-color: transparent;\n}\n.pf-t-dark.pf-m-transparent-100 {\n  background-color: rgba(3, 3, 3, 0.42);\n}\n.pf-t-dark.pf-m-transparent-200 {\n  background-color: rgba(3, 3, 3, 0.6);\n}\n.pf-t-dark.pf-m-opaque-100 {\n  background-color: #1b1d21;\n}\n.pf-t-dark.pf-m-opaque-200 {\n  background-color: #0f1214;\n}\n\n.pf-t-light.pf-m-transparent {\n  background-color: transparent;\n}\n.pf-t-light.pf-m-opaque-100 {\n  background-color: #fff;\n}\n.pf-t-light.pf-m-opaque-200 {\n  background-color: #c6c7c8;\n}\n.pf-t-light.pf-m-opaque-300 {\n  background-color: #aaabac;\n}\n\n* .fa,\n* .fas,\n* .far,\n* .fal,\n* .fab {\n  -moz-osx-font-smoothing: grayscale;\n  -webkit-font-smoothing: antialiased;\n  display: inline-block;\n  font-style: normal;\n  font-variant: normal;\n  text-rendering: auto;\n  line-height: 1;\n}\n* .fa-lg {\n  font-size: 1.3333333333em;\n  line-height: 0.75em;\n  vertical-align: -0.0667em;\n}\n* .fa-xs {\n  font-size: 0.75em;\n}\n* .fa-sm {\n  font-size: 0.875em;\n}\n* .fa-1x {\n  font-size: 1em;\n}\n* .fa-2x {\n  font-size: 2em;\n}\n* .fa-3x {\n  font-size: 3em;\n}\n* .fa-4x {\n  font-size: 4em;\n}\n* .fa-5x {\n  font-size: 5em;\n}\n* .fa-6x {\n  font-size: 6em;\n}\n* .fa-7x {\n  font-size: 7em;\n}\n* .fa-8x {\n  font-size: 8em;\n}\n* .fa-9x {\n  font-size: 9em;\n}\n* .fa-10x {\n  font-size: 10em;\n}\n* .fa-fw {\n  text-align: center;\n  width: 1.25em;\n}\n* .fa-ul {\n  list-style-type: none;\n  margin-left: 2.5em;\n  padding-left: 0;\n}\n* .fa-ul > li {\n  position: relative;\n}\n* .fa-li {\n  left: -2em;\n  position: absolute;\n  text-align: center;\n  width: 2em;\n  line-height: inherit;\n}\n* .fa-border {\n  border: solid 0.08em #eee;\n  border-radius: 0.1em;\n  padding: 0.2em 0.25em 0.15em;\n}\n* .fa-pull-left {\n  float: left;\n}\n* .fa-pull-right {\n  float: right;\n}\n* .fa.fa-pull-left,\n* .fas.fa-pull-left,\n* .far.fa-pull-left,\n* .fal.fa-pull-left,\n* .fab.fa-pull-left {\n  margin-right: 0.3em;\n}\n* .fa.fa-pull-right,\n* .fas.fa-pull-right,\n* .far.fa-pull-right,\n* .fal.fa-pull-right,\n* .fab.fa-pull-right {\n  margin-left: 0.3em;\n}\n* .fa-spin {\n  animation: fa-spin 2s infinite linear;\n}\n* .fa-pulse {\n  animation: fa-spin 1s infinite steps(8);\n}\n@keyframes fa-spin {\n  0% {\n    transform: rotate(0deg);\n  }\n  100% {\n    transform: rotate(360deg);\n  }\n}\n* .fa-rotate-90 {\n  -ms-filter: "progid:DXImageTransform.Microsoft.BasicImage(rotation=1)";\n  transform: rotate(90deg);\n}\n* .fa-rotate-180 {\n  -ms-filter: "progid:DXImageTransform.Microsoft.BasicImage(rotation=2)";\n  transform: rotate(180deg);\n}\n* .fa-rotate-270 {\n  -ms-filter: "progid:DXImageTransform.Microsoft.BasicImage(rotation=3)";\n  transform: rotate(270deg);\n}\n* .fa-flip-horizontal {\n  -ms-filter: "progid:DXImageTransform.Microsoft.BasicImage(rotation=0, mirror=1)";\n  transform: scale(-1, 1);\n}\n* .fa-flip-vertical {\n  -ms-filter: "progid:DXImageTransform.Microsoft.BasicImage(rotation=2, mirror=1)";\n  transform: scale(1, -1);\n}\n* .fa-flip-horizontal.fa-flip-vertical {\n  -ms-filter: "progid:DXImageTransform.Microsoft.BasicImage(rotation=2, mirror=1)";\n  transform: scale(-1, -1);\n}\n* :root .fa-rotate-90,\n* :root .fa-rotate-180,\n* :root .fa-rotate-270,\n* :root .fa-flip-horizontal,\n* :root .fa-flip-vertical {\n  filter: none;\n}\n* .fa-stack {\n  display: inline-block;\n  height: 2em;\n  line-height: 2em;\n  position: relative;\n  vertical-align: middle;\n  width: 2.5em;\n}\n* .fa-stack-1x,\n* .fa-stack-2x {\n  left: 0;\n  position: absolute;\n  text-align: center;\n  width: 100%;\n}\n* .fa-stack-1x {\n  line-height: inherit;\n}\n* .fa-stack-2x {\n  font-size: 2em;\n}\n* .fa-inverse {\n  color: #fff;\n}\n* .fa-500px:before {\n  content: "\\f26e";\n}\n* .fa-accessible-icon:before {\n  content: "\\f368";\n}\n* .fa-accusoft:before {\n  content: "\\f369";\n}\n* .fa-acquisitions-incorporated:before {\n  content: "\\f6af";\n}\n* .fa-ad:before {\n  content: "\\f641";\n}\n* .fa-address-book:before {\n  content: "\\f2b9";\n}\n* .fa-address-card:before {\n  content: "\\f2bb";\n}\n* .fa-adjust:before {\n  content: "\\f042";\n}\n* .fa-adn:before {\n  content: "\\f170";\n}\n* .fa-adobe:before {\n  content: "\\f778";\n}\n* .fa-adversal:before {\n  content: "\\f36a";\n}\n* .fa-affiliatetheme:before {\n  content: "\\f36b";\n}\n* .fa-air-freshener:before {\n  content: "\\f5d0";\n}\n* .fa-algolia:before {\n  content: "\\f36c";\n}\n* .fa-align-center:before {\n  content: "\\f037";\n}\n* .fa-align-justify:before {\n  content: "\\f039";\n}\n* .fa-align-left:before {\n  content: "\\f036";\n}\n* .fa-align-right:before {\n  content: "\\f038";\n}\n* .fa-alipay:before {\n  content: "\\f642";\n}\n* .fa-allergies:before {\n  content: "\\f461";\n}\n* .fa-amazon:before {\n  content: "\\f270";\n}\n* .fa-amazon-pay:before {\n  content: "\\f42c";\n}\n* .fa-ambulance:before {\n  content: "\\f0f9";\n}\n* .fa-american-sign-language-interpreting:before {\n  content: "\\f2a3";\n}\n* .fa-amilia:before {\n  content: "\\f36d";\n}\n* .fa-anchor:before {\n  content: "\\f13d";\n}\n* .fa-android:before {\n  content: "\\f17b";\n}\n* .fa-angellist:before {\n  content: "\\f209";\n}\n* .fa-angle-double-down:before {\n  content: "\\f103";\n}\n* .fa-angle-double-left:before {\n  content: "\\f100";\n}\n* .fa-angle-double-right:before {\n  content: "\\f101";\n}\n* .fa-angle-double-up:before {\n  content: "\\f102";\n}\n* .fa-angle-down:before {\n  content: "\\f107";\n}\n* .fa-angle-left:before {\n  content: "\\f104";\n}\n* .fa-angle-right:before {\n  content: "\\f105";\n}\n* .fa-angle-up:before {\n  content: "\\f106";\n}\n* .fa-angry:before {\n  content: "\\f556";\n}\n* .fa-angrycreative:before {\n  content: "\\f36e";\n}\n* .fa-angular:before {\n  content: "\\f420";\n}\n* .fa-ankh:before {\n  content: "\\f644";\n}\n* .fa-app-store:before {\n  content: "\\f36f";\n}\n* .fa-app-store-ios:before {\n  content: "\\f370";\n}\n* .fa-apper:before {\n  content: "\\f371";\n}\n* .fa-apple:before {\n  content: "\\f179";\n}\n* .fa-apple-alt:before {\n  content: "\\f5d1";\n}\n* .fa-apple-pay:before {\n  content: "\\f415";\n}\n* .fa-archive:before {\n  content: "\\f187";\n}\n* .fa-archway:before {\n  content: "\\f557";\n}\n* .fa-arrow-alt-circle-down:before {\n  content: "\\f358";\n}\n* .fa-arrow-alt-circle-left:before {\n  content: "\\f359";\n}\n* .fa-arrow-alt-circle-right:before {\n  content: "\\f35a";\n}\n* .fa-arrow-alt-circle-up:before {\n  content: "\\f35b";\n}\n* .fa-arrow-circle-down:before {\n  content: "\\f0ab";\n}\n* .fa-arrow-circle-left:before {\n  content: "\\f0a8";\n}\n* .fa-arrow-circle-right:before {\n  content: "\\f0a9";\n}\n* .fa-arrow-circle-up:before {\n  content: "\\f0aa";\n}\n* .fa-arrow-down:before {\n  content: "\\f063";\n}\n* .fa-arrow-left:before {\n  content: "\\f060";\n}\n* .fa-arrow-right:before {\n  content: "\\f061";\n}\n* .fa-arrow-up:before {\n  content: "\\f062";\n}\n* .fa-arrows-alt:before {\n  content: "\\f0b2";\n}\n* .fa-arrows-alt-h:before {\n  content: "\\f337";\n}\n* .fa-arrows-alt-v:before {\n  content: "\\f338";\n}\n* .fa-artstation:before {\n  content: "\\f77a";\n}\n* .fa-assistive-listening-systems:before {\n  content: "\\f2a2";\n}\n* .fa-asterisk:before {\n  content: "\\f069";\n}\n* .fa-asymmetrik:before {\n  content: "\\f372";\n}\n* .fa-at:before {\n  content: "\\f1fa";\n}\n* .fa-atlas:before {\n  content: "\\f558";\n}\n* .fa-atlassian:before {\n  content: "\\f77b";\n}\n* .fa-atom:before {\n  content: "\\f5d2";\n}\n* .fa-audible:before {\n  content: "\\f373";\n}\n* .fa-audio-description:before {\n  content: "\\f29e";\n}\n* .fa-autoprefixer:before {\n  content: "\\f41c";\n}\n* .fa-avianex:before {\n  content: "\\f374";\n}\n* .fa-aviato:before {\n  content: "\\f421";\n}\n* .fa-award:before {\n  content: "\\f559";\n}\n* .fa-aws:before {\n  content: "\\f375";\n}\n* .fa-baby:before {\n  content: "\\f77c";\n}\n* .fa-baby-carriage:before {\n  content: "\\f77d";\n}\n* .fa-backspace:before {\n  content: "\\f55a";\n}\n* .fa-backward:before {\n  content: "\\f04a";\n}\n* .fa-balance-scale:before {\n  content: "\\f24e";\n}\n* .fa-ban:before {\n  content: "\\f05e";\n}\n* .fa-band-aid:before {\n  content: "\\f462";\n}\n* .fa-bandcamp:before {\n  content: "\\f2d5";\n}\n* .fa-barcode:before {\n  content: "\\f02a";\n}\n* .fa-bars:before {\n  content: "\\f0c9";\n}\n* .fa-baseball-ball:before {\n  content: "\\f433";\n}\n* .fa-basketball-ball:before {\n  content: "\\f434";\n}\n* .fa-bath:before {\n  content: "\\f2cd";\n}\n* .fa-battery-empty:before {\n  content: "\\f244";\n}\n* .fa-battery-full:before {\n  content: "\\f240";\n}\n* .fa-battery-half:before {\n  content: "\\f242";\n}\n* .fa-battery-quarter:before {\n  content: "\\f243";\n}\n* .fa-battery-three-quarters:before {\n  content: "\\f241";\n}\n* .fa-bed:before {\n  content: "\\f236";\n}\n* .fa-beer:before {\n  content: "\\f0fc";\n}\n* .fa-behance:before {\n  content: "\\f1b4";\n}\n* .fa-behance-square:before {\n  content: "\\f1b5";\n}\n* .fa-bell:before {\n  content: "\\f0f3";\n}\n* .fa-bell-slash:before {\n  content: "\\f1f6";\n}\n* .fa-bezier-curve:before {\n  content: "\\f55b";\n}\n* .fa-bible:before {\n  content: "\\f647";\n}\n* .fa-bicycle:before {\n  content: "\\f206";\n}\n* .fa-bimobject:before {\n  content: "\\f378";\n}\n* .fa-binoculars:before {\n  content: "\\f1e5";\n}\n* .fa-biohazard:before {\n  content: "\\f780";\n}\n* .fa-birthday-cake:before {\n  content: "\\f1fd";\n}\n* .fa-bitbucket:before {\n  content: "\\f171";\n}\n* .fa-bitcoin:before {\n  content: "\\f379";\n}\n* .fa-bity:before {\n  content: "\\f37a";\n}\n* .fa-black-tie:before {\n  content: "\\f27e";\n}\n* .fa-blackberry:before {\n  content: "\\f37b";\n}\n* .fa-blender:before {\n  content: "\\f517";\n}\n* .fa-blender-phone:before {\n  content: "\\f6b6";\n}\n* .fa-blind:before {\n  content: "\\f29d";\n}\n* .fa-blog:before {\n  content: "\\f781";\n}\n* .fa-blogger:before {\n  content: "\\f37c";\n}\n* .fa-blogger-b:before {\n  content: "\\f37d";\n}\n* .fa-bluetooth:before {\n  content: "\\f293";\n}\n* .fa-bluetooth-b:before {\n  content: "\\f294";\n}\n* .fa-bold:before {\n  content: "\\f032";\n}\n* .fa-bolt:before {\n  content: "\\f0e7";\n}\n* .fa-bomb:before {\n  content: "\\f1e2";\n}\n* .fa-bone:before {\n  content: "\\f5d7";\n}\n* .fa-bong:before {\n  content: "\\f55c";\n}\n* .fa-book:before {\n  content: "\\f02d";\n}\n* .fa-book-dead:before {\n  content: "\\f6b7";\n}\n* .fa-book-open:before {\n  content: "\\f518";\n}\n* .fa-book-reader:before {\n  content: "\\f5da";\n}\n* .fa-bookmark:before {\n  content: "\\f02e";\n}\n* .fa-bowling-ball:before {\n  content: "\\f436";\n}\n* .fa-box:before {\n  content: "\\f466";\n}\n* .fa-box-open:before {\n  content: "\\f49e";\n}\n* .fa-boxes:before {\n  content: "\\f468";\n}\n* .fa-braille:before {\n  content: "\\f2a1";\n}\n* .fa-brain:before {\n  content: "\\f5dc";\n}\n* .fa-briefcase:before {\n  content: "\\f0b1";\n}\n* .fa-briefcase-medical:before {\n  content: "\\f469";\n}\n* .fa-broadcast-tower:before {\n  content: "\\f519";\n}\n* .fa-broom:before {\n  content: "\\f51a";\n}\n* .fa-brush:before {\n  content: "\\f55d";\n}\n* .fa-btc:before {\n  content: "\\f15a";\n}\n* .fa-bug:before {\n  content: "\\f188";\n}\n* .fa-building:before {\n  content: "\\f1ad";\n}\n* .fa-bullhorn:before {\n  content: "\\f0a1";\n}\n* .fa-bullseye:before {\n  content: "\\f140";\n}\n* .fa-burn:before {\n  content: "\\f46a";\n}\n* .fa-buromobelexperte:before {\n  content: "\\f37f";\n}\n* .fa-bus:before {\n  content: "\\f207";\n}\n* .fa-bus-alt:before {\n  content: "\\f55e";\n}\n* .fa-business-time:before {\n  content: "\\f64a";\n}\n* .fa-buysellads:before {\n  content: "\\f20d";\n}\n* .fa-calculator:before {\n  content: "\\f1ec";\n}\n* .fa-calendar:before {\n  content: "\\f133";\n}\n* .fa-calendar-alt:before {\n  content: "\\f073";\n}\n* .fa-calendar-check:before {\n  content: "\\f274";\n}\n* .fa-calendar-day:before {\n  content: "\\f783";\n}\n* .fa-calendar-minus:before {\n  content: "\\f272";\n}\n* .fa-calendar-plus:before {\n  content: "\\f271";\n}\n* .fa-calendar-times:before {\n  content: "\\f273";\n}\n* .fa-calendar-week:before {\n  content: "\\f784";\n}\n* .fa-camera:before {\n  content: "\\f030";\n}\n* .fa-camera-retro:before {\n  content: "\\f083";\n}\n* .fa-campground:before {\n  content: "\\f6bb";\n}\n* .fa-canadian-maple-leaf:before {\n  content: "\\f785";\n}\n* .fa-candy-cane:before {\n  content: "\\f786";\n}\n* .fa-cannabis:before {\n  content: "\\f55f";\n}\n* .fa-capsules:before {\n  content: "\\f46b";\n}\n* .fa-car:before {\n  content: "\\f1b9";\n}\n* .fa-car-alt:before {\n  content: "\\f5de";\n}\n* .fa-car-battery:before {\n  content: "\\f5df";\n}\n* .fa-car-crash:before {\n  content: "\\f5e1";\n}\n* .fa-car-side:before {\n  content: "\\f5e4";\n}\n* .fa-caret-down:before {\n  content: "\\f0d7";\n}\n* .fa-caret-left:before {\n  content: "\\f0d9";\n}\n* .fa-caret-right:before {\n  content: "\\f0da";\n}\n* .fa-caret-square-down:before {\n  content: "\\f150";\n}\n* .fa-caret-square-left:before {\n  content: "\\f191";\n}\n* .fa-caret-square-right:before {\n  content: "\\f152";\n}\n* .fa-caret-square-up:before {\n  content: "\\f151";\n}\n* .fa-caret-up:before {\n  content: "\\f0d8";\n}\n* .fa-carrot:before {\n  content: "\\f787";\n}\n* .fa-cart-arrow-down:before {\n  content: "\\f218";\n}\n* .fa-cart-plus:before {\n  content: "\\f217";\n}\n* .fa-cash-register:before {\n  content: "\\f788";\n}\n* .fa-cat:before {\n  content: "\\f6be";\n}\n* .fa-cc-amazon-pay:before {\n  content: "\\f42d";\n}\n* .fa-cc-amex:before {\n  content: "\\f1f3";\n}\n* .fa-cc-apple-pay:before {\n  content: "\\f416";\n}\n* .fa-cc-diners-club:before {\n  content: "\\f24c";\n}\n* .fa-cc-discover:before {\n  content: "\\f1f2";\n}\n* .fa-cc-jcb:before {\n  content: "\\f24b";\n}\n* .fa-cc-mastercard:before {\n  content: "\\f1f1";\n}\n* .fa-cc-paypal:before {\n  content: "\\f1f4";\n}\n* .fa-cc-stripe:before {\n  content: "\\f1f5";\n}\n* .fa-cc-visa:before {\n  content: "\\f1f0";\n}\n* .fa-centercode:before {\n  content: "\\f380";\n}\n* .fa-centos:before {\n  content: "\\f789";\n}\n* .fa-certificate:before {\n  content: "\\f0a3";\n}\n* .fa-chair:before {\n  content: "\\f6c0";\n}\n* .fa-chalkboard:before {\n  content: "\\f51b";\n}\n* .fa-chalkboard-teacher:before {\n  content: "\\f51c";\n}\n* .fa-charging-station:before {\n  content: "\\f5e7";\n}\n* .fa-chart-area:before {\n  content: "\\f1fe";\n}\n* .fa-chart-bar:before {\n  content: "\\f080";\n}\n* .fa-chart-line:before {\n  content: "\\f201";\n}\n* .fa-chart-pie:before {\n  content: "\\f200";\n}\n* .fa-check:before {\n  content: "\\f00c";\n}\n* .fa-check-circle:before {\n  content: "\\f058";\n}\n* .fa-check-double:before {\n  content: "\\f560";\n}\n* .fa-check-square:before {\n  content: "\\f14a";\n}\n* .fa-chess:before {\n  content: "\\f439";\n}\n* .fa-chess-bishop:before {\n  content: "\\f43a";\n}\n* .fa-chess-board:before {\n  content: "\\f43c";\n}\n* .fa-chess-king:before {\n  content: "\\f43f";\n}\n* .fa-chess-knight:before {\n  content: "\\f441";\n}\n* .fa-chess-pawn:before {\n  content: "\\f443";\n}\n* .fa-chess-queen:before {\n  content: "\\f445";\n}\n* .fa-chess-rook:before {\n  content: "\\f447";\n}\n* .fa-chevron-circle-down:before {\n  content: "\\f13a";\n}\n* .fa-chevron-circle-left:before {\n  content: "\\f137";\n}\n* .fa-chevron-circle-right:before {\n  content: "\\f138";\n}\n* .fa-chevron-circle-up:before {\n  content: "\\f139";\n}\n* .fa-chevron-down:before {\n  content: "\\f078";\n}\n* .fa-chevron-left:before {\n  content: "\\f053";\n}\n* .fa-chevron-right:before {\n  content: "\\f054";\n}\n* .fa-chevron-up:before {\n  content: "\\f077";\n}\n* .fa-child:before {\n  content: "\\f1ae";\n}\n* .fa-chrome:before {\n  content: "\\f268";\n}\n* .fa-church:before {\n  content: "\\f51d";\n}\n* .fa-circle:before {\n  content: "\\f111";\n}\n* .fa-circle-notch:before {\n  content: "\\f1ce";\n}\n* .fa-city:before {\n  content: "\\f64f";\n}\n* .fa-clipboard:before {\n  content: "\\f328";\n}\n* .fa-clipboard-check:before {\n  content: "\\f46c";\n}\n* .fa-clipboard-list:before {\n  content: "\\f46d";\n}\n* .fa-clock:before {\n  content: "\\f017";\n}\n* .fa-clone:before {\n  content: "\\f24d";\n}\n* .fa-closed-captioning:before {\n  content: "\\f20a";\n}\n* .fa-cloud:before {\n  content: "\\f0c2";\n}\n* .fa-cloud-download-alt:before {\n  content: "\\f381";\n}\n* .fa-cloud-meatball:before {\n  content: "\\f73b";\n}\n* .fa-cloud-moon:before {\n  content: "\\f6c3";\n}\n* .fa-cloud-moon-rain:before {\n  content: "\\f73c";\n}\n* .fa-cloud-rain:before {\n  content: "\\f73d";\n}\n* .fa-cloud-showers-heavy:before {\n  content: "\\f740";\n}\n* .fa-cloud-sun:before {\n  content: "\\f6c4";\n}\n* .fa-cloud-sun-rain:before {\n  content: "\\f743";\n}\n* .fa-cloud-upload-alt:before {\n  content: "\\f382";\n}\n* .fa-cloudscale:before {\n  content: "\\f383";\n}\n* .fa-cloudsmith:before {\n  content: "\\f384";\n}\n* .fa-cloudversify:before {\n  content: "\\f385";\n}\n* .fa-cocktail:before {\n  content: "\\f561";\n}\n* .fa-code:before {\n  content: "\\f121";\n}\n* .fa-code-branch:before {\n  content: "\\f126";\n}\n* .fa-codepen:before {\n  content: "\\f1cb";\n}\n* .fa-codiepie:before {\n  content: "\\f284";\n}\n* .fa-coffee:before {\n  content: "\\f0f4";\n}\n* .fa-cog:before {\n  content: "\\f013";\n}\n* .fa-cogs:before {\n  content: "\\f085";\n}\n* .fa-coins:before {\n  content: "\\f51e";\n}\n* .fa-columns:before {\n  content: "\\f0db";\n}\n* .fa-comment:before {\n  content: "\\f075";\n}\n* .fa-comment-alt:before {\n  content: "\\f27a";\n}\n* .fa-comment-dollar:before {\n  content: "\\f651";\n}\n* .fa-comment-dots:before {\n  content: "\\f4ad";\n}\n* .fa-comment-slash:before {\n  content: "\\f4b3";\n}\n* .fa-comments:before {\n  content: "\\f086";\n}\n* .fa-comments-dollar:before {\n  content: "\\f653";\n}\n* .fa-compact-disc:before {\n  content: "\\f51f";\n}\n* .fa-compass:before {\n  content: "\\f14e";\n}\n* .fa-compress:before {\n  content: "\\f066";\n}\n* .fa-compress-arrows-alt:before {\n  content: "\\f78c";\n}\n* .fa-concierge-bell:before {\n  content: "\\f562";\n}\n* .fa-confluence:before {\n  content: "\\f78d";\n}\n* .fa-connectdevelop:before {\n  content: "\\f20e";\n}\n* .fa-contao:before {\n  content: "\\f26d";\n}\n* .fa-cookie:before {\n  content: "\\f563";\n}\n* .fa-cookie-bite:before {\n  content: "\\f564";\n}\n* .fa-copy:before {\n  content: "\\f0c5";\n}\n* .fa-copyright:before {\n  content: "\\f1f9";\n}\n* .fa-couch:before {\n  content: "\\f4b8";\n}\n* .fa-cpanel:before {\n  content: "\\f388";\n}\n* .fa-creative-commons:before {\n  content: "\\f25e";\n}\n* .fa-creative-commons-by:before {\n  content: "\\f4e7";\n}\n* .fa-creative-commons-nc:before {\n  content: "\\f4e8";\n}\n* .fa-creative-commons-nc-eu:before {\n  content: "\\f4e9";\n}\n* .fa-creative-commons-nc-jp:before {\n  content: "\\f4ea";\n}\n* .fa-creative-commons-nd:before {\n  content: "\\f4eb";\n}\n* .fa-creative-commons-pd:before {\n  content: "\\f4ec";\n}\n* .fa-creative-commons-pd-alt:before {\n  content: "\\f4ed";\n}\n* .fa-creative-commons-remix:before {\n  content: "\\f4ee";\n}\n* .fa-creative-commons-sa:before {\n  content: "\\f4ef";\n}\n* .fa-creative-commons-sampling:before {\n  content: "\\f4f0";\n}\n* .fa-creative-commons-sampling-plus:before {\n  content: "\\f4f1";\n}\n* .fa-creative-commons-share:before {\n  content: "\\f4f2";\n}\n* .fa-creative-commons-zero:before {\n  content: "\\f4f3";\n}\n* .fa-credit-card:before {\n  content: "\\f09d";\n}\n* .fa-critical-role:before {\n  content: "\\f6c9";\n}\n* .fa-crop:before {\n  content: "\\f125";\n}\n* .fa-crop-alt:before {\n  content: "\\f565";\n}\n* .fa-cross:before {\n  content: "\\f654";\n}\n* .fa-crosshairs:before {\n  content: "\\f05b";\n}\n* .fa-crow:before {\n  content: "\\f520";\n}\n* .fa-crown:before {\n  content: "\\f521";\n}\n* .fa-css3:before {\n  content: "\\f13c";\n}\n* .fa-css3-alt:before {\n  content: "\\f38b";\n}\n* .fa-cube:before {\n  content: "\\f1b2";\n}\n* .fa-cubes:before {\n  content: "\\f1b3";\n}\n* .fa-cut:before {\n  content: "\\f0c4";\n}\n* .fa-cuttlefish:before {\n  content: "\\f38c";\n}\n* .fa-d-and-d:before {\n  content: "\\f38d";\n}\n* .fa-d-and-d-beyond:before {\n  content: "\\f6ca";\n}\n* .fa-dashcube:before {\n  content: "\\f210";\n}\n* .fa-database:before {\n  content: "\\f1c0";\n}\n* .fa-deaf:before {\n  content: "\\f2a4";\n}\n* .fa-delicious:before {\n  content: "\\f1a5";\n}\n* .fa-democrat:before {\n  content: "\\f747";\n}\n* .fa-deploydog:before {\n  content: "\\f38e";\n}\n* .fa-deskpro:before {\n  content: "\\f38f";\n}\n* .fa-desktop:before {\n  content: "\\f108";\n}\n* .fa-dev:before {\n  content: "\\f6cc";\n}\n* .fa-deviantart:before {\n  content: "\\f1bd";\n}\n* .fa-dharmachakra:before {\n  content: "\\f655";\n}\n* .fa-dhl:before {\n  content: "\\f790";\n}\n* .fa-diagnoses:before {\n  content: "\\f470";\n}\n* .fa-diaspora:before {\n  content: "\\f791";\n}\n* .fa-dice:before {\n  content: "\\f522";\n}\n* .fa-dice-d20:before {\n  content: "\\f6cf";\n}\n* .fa-dice-d6:before {\n  content: "\\f6d1";\n}\n* .fa-dice-five:before {\n  content: "\\f523";\n}\n* .fa-dice-four:before {\n  content: "\\f524";\n}\n* .fa-dice-one:before {\n  content: "\\f525";\n}\n* .fa-dice-six:before {\n  content: "\\f526";\n}\n* .fa-dice-three:before {\n  content: "\\f527";\n}\n* .fa-dice-two:before {\n  content: "\\f528";\n}\n* .fa-digg:before {\n  content: "\\f1a6";\n}\n* .fa-digital-ocean:before {\n  content: "\\f391";\n}\n* .fa-digital-tachograph:before {\n  content: "\\f566";\n}\n* .fa-directions:before {\n  content: "\\f5eb";\n}\n* .fa-discord:before {\n  content: "\\f392";\n}\n* .fa-discourse:before {\n  content: "\\f393";\n}\n* .fa-divide:before {\n  content: "\\f529";\n}\n* .fa-dizzy:before {\n  content: "\\f567";\n}\n* .fa-dna:before {\n  content: "\\f471";\n}\n* .fa-dochub:before {\n  content: "\\f394";\n}\n* .fa-docker:before {\n  content: "\\f395";\n}\n* .fa-dog:before {\n  content: "\\f6d3";\n}\n* .fa-dollar-sign:before {\n  content: "\\f155";\n}\n* .fa-dolly:before {\n  content: "\\f472";\n}\n* .fa-dolly-flatbed:before {\n  content: "\\f474";\n}\n* .fa-donate:before {\n  content: "\\f4b9";\n}\n* .fa-door-closed:before {\n  content: "\\f52a";\n}\n* .fa-door-open:before {\n  content: "\\f52b";\n}\n* .fa-dot-circle:before {\n  content: "\\f192";\n}\n* .fa-dove:before {\n  content: "\\f4ba";\n}\n* .fa-download:before {\n  content: "\\f019";\n}\n* .fa-draft2digital:before {\n  content: "\\f396";\n}\n* .fa-drafting-compass:before {\n  content: "\\f568";\n}\n* .fa-dragon:before {\n  content: "\\f6d5";\n}\n* .fa-draw-polygon:before {\n  content: "\\f5ee";\n}\n* .fa-dribbble:before {\n  content: "\\f17d";\n}\n* .fa-dribbble-square:before {\n  content: "\\f397";\n}\n* .fa-dropbox:before {\n  content: "\\f16b";\n}\n* .fa-drum:before {\n  content: "\\f569";\n}\n* .fa-drum-steelpan:before {\n  content: "\\f56a";\n}\n* .fa-drumstick-bite:before {\n  content: "\\f6d7";\n}\n* .fa-drupal:before {\n  content: "\\f1a9";\n}\n* .fa-dumbbell:before {\n  content: "\\f44b";\n}\n* .fa-dumpster:before {\n  content: "\\f793";\n}\n* .fa-dumpster-fire:before {\n  content: "\\f794";\n}\n* .fa-dungeon:before {\n  content: "\\f6d9";\n}\n* .fa-dyalog:before {\n  content: "\\f399";\n}\n* .fa-earlybirds:before {\n  content: "\\f39a";\n}\n* .fa-ebay:before {\n  content: "\\f4f4";\n}\n* .fa-edge:before {\n  content: "\\f282";\n}\n* .fa-edit:before {\n  content: "\\f044";\n}\n* .fa-eject:before {\n  content: "\\f052";\n}\n* .fa-elementor:before {\n  content: "\\f430";\n}\n* .fa-ellipsis-h:before {\n  content: "\\f141";\n}\n* .fa-ellipsis-v:before {\n  content: "\\f142";\n}\n* .fa-ello:before {\n  content: "\\f5f1";\n}\n* .fa-ember:before {\n  content: "\\f423";\n}\n* .fa-empire:before {\n  content: "\\f1d1";\n}\n* .fa-envelope:before {\n  content: "\\f0e0";\n}\n* .fa-envelope-open:before {\n  content: "\\f2b6";\n}\n* .fa-envelope-open-text:before {\n  content: "\\f658";\n}\n* .fa-envelope-square:before {\n  content: "\\f199";\n}\n* .fa-envira:before {\n  content: "\\f299";\n}\n* .fa-equals:before {\n  content: "\\f52c";\n}\n* .fa-eraser:before {\n  content: "\\f12d";\n}\n* .fa-erlang:before {\n  content: "\\f39d";\n}\n* .fa-ethereum:before {\n  content: "\\f42e";\n}\n* .fa-ethernet:before {\n  content: "\\f796";\n}\n* .fa-etsy:before {\n  content: "\\f2d7";\n}\n* .fa-euro-sign:before {\n  content: "\\f153";\n}\n* .fa-exchange-alt:before {\n  content: "\\f362";\n}\n* .fa-exclamation:before {\n  content: "\\f12a";\n}\n* .fa-exclamation-circle:before {\n  content: "\\f06a";\n}\n* .fa-exclamation-triangle:before {\n  content: "\\f071";\n}\n* .fa-expand:before {\n  content: "\\f065";\n}\n* .fa-expand-arrows-alt:before {\n  content: "\\f31e";\n}\n* .fa-expeditedssl:before {\n  content: "\\f23e";\n}\n* .fa-external-link-alt:before {\n  content: "\\f35d";\n}\n* .fa-external-link-square-alt:before {\n  content: "\\f360";\n}\n* .fa-eye:before {\n  content: "\\f06e";\n}\n* .fa-eye-dropper:before {\n  content: "\\f1fb";\n}\n* .fa-eye-slash:before {\n  content: "\\f070";\n}\n* .fa-facebook:before {\n  content: "\\f09a";\n}\n* .fa-facebook-f:before {\n  content: "\\f39e";\n}\n* .fa-facebook-messenger:before {\n  content: "\\f39f";\n}\n* .fa-facebook-square:before {\n  content: "\\f082";\n}\n* .fa-fantasy-flight-games:before {\n  content: "\\f6dc";\n}\n* .fa-fast-backward:before {\n  content: "\\f049";\n}\n* .fa-fast-forward:before {\n  content: "\\f050";\n}\n* .fa-fax:before {\n  content: "\\f1ac";\n}\n* .fa-feather:before {\n  content: "\\f52d";\n}\n* .fa-feather-alt:before {\n  content: "\\f56b";\n}\n* .fa-fedex:before {\n  content: "\\f797";\n}\n* .fa-fedora:before {\n  content: "\\f798";\n}\n* .fa-female:before {\n  content: "\\f182";\n}\n* .fa-fighter-jet:before {\n  content: "\\f0fb";\n}\n* .fa-figma:before {\n  content: "\\f799";\n}\n* .fa-file:before {\n  content: "\\f15b";\n}\n* .fa-file-alt:before {\n  content: "\\f15c";\n}\n* .fa-file-archive:before {\n  content: "\\f1c6";\n}\n* .fa-file-audio:before {\n  content: "\\f1c7";\n}\n* .fa-file-code:before {\n  content: "\\f1c9";\n}\n* .fa-file-contract:before {\n  content: "\\f56c";\n}\n* .fa-file-csv:before {\n  content: "\\f6dd";\n}\n* .fa-file-download:before {\n  content: "\\f56d";\n}\n* .fa-file-excel:before {\n  content: "\\f1c3";\n}\n* .fa-file-export:before {\n  content: "\\f56e";\n}\n* .fa-file-image:before {\n  content: "\\f1c5";\n}\n* .fa-file-import:before {\n  content: "\\f56f";\n}\n* .fa-file-invoice:before {\n  content: "\\f570";\n}\n* .fa-file-invoice-dollar:before {\n  content: "\\f571";\n}\n* .fa-file-medical:before {\n  content: "\\f477";\n}\n* .fa-file-medical-alt:before {\n  content: "\\f478";\n}\n* .fa-file-pdf:before {\n  content: "\\f1c1";\n}\n* .fa-file-powerpoint:before {\n  content: "\\f1c4";\n}\n* .fa-file-prescription:before {\n  content: "\\f572";\n}\n* .fa-file-signature:before {\n  content: "\\f573";\n}\n* .fa-file-upload:before {\n  content: "\\f574";\n}\n* .fa-file-video:before {\n  content: "\\f1c8";\n}\n* .fa-file-word:before {\n  content: "\\f1c2";\n}\n* .fa-fill:before {\n  content: "\\f575";\n}\n* .fa-fill-drip:before {\n  content: "\\f576";\n}\n* .fa-film:before {\n  content: "\\f008";\n}\n* .fa-filter:before {\n  content: "\\f0b0";\n}\n* .fa-fingerprint:before {\n  content: "\\f577";\n}\n* .fa-fire:before {\n  content: "\\f06d";\n}\n* .fa-fire-alt:before {\n  content: "\\f7e4";\n}\n* .fa-fire-extinguisher:before {\n  content: "\\f134";\n}\n* .fa-firefox:before {\n  content: "\\f269";\n}\n* .fa-first-aid:before {\n  content: "\\f479";\n}\n* .fa-first-order:before {\n  content: "\\f2b0";\n}\n* .fa-first-order-alt:before {\n  content: "\\f50a";\n}\n* .fa-firstdraft:before {\n  content: "\\f3a1";\n}\n* .fa-fish:before {\n  content: "\\f578";\n}\n* .fa-fist-raised:before {\n  content: "\\f6de";\n}\n* .fa-flag:before {\n  content: "\\f024";\n}\n* .fa-flag-checkered:before {\n  content: "\\f11e";\n}\n* .fa-flag-usa:before {\n  content: "\\f74d";\n}\n* .fa-flask:before {\n  content: "\\f0c3";\n}\n* .fa-flickr:before {\n  content: "\\f16e";\n}\n* .fa-flipboard:before {\n  content: "\\f44d";\n}\n* .fa-flushed:before {\n  content: "\\f579";\n}\n* .fa-fly:before {\n  content: "\\f417";\n}\n* .fa-folder:before {\n  content: "\\f07b";\n}\n* .fa-folder-minus:before {\n  content: "\\f65d";\n}\n* .fa-folder-open:before {\n  content: "\\f07c";\n}\n* .fa-folder-plus:before {\n  content: "\\f65e";\n}\n* .fa-font:before {\n  content: "\\f031";\n}\n* .fa-font-awesome:before {\n  content: "\\f2b4";\n}\n* .fa-font-awesome-alt:before {\n  content: "\\f35c";\n}\n* .fa-font-awesome-flag:before {\n  content: "\\f425";\n}\n* .fa-font-awesome-logo-full:before {\n  content: "\\f4e6";\n}\n* .fa-fonticons:before {\n  content: "\\f280";\n}\n* .fa-fonticons-fi:before {\n  content: "\\f3a2";\n}\n* .fa-football-ball:before {\n  content: "\\f44e";\n}\n* .fa-fort-awesome:before {\n  content: "\\f286";\n}\n* .fa-fort-awesome-alt:before {\n  content: "\\f3a3";\n}\n* .fa-forumbee:before {\n  content: "\\f211";\n}\n* .fa-forward:before {\n  content: "\\f04e";\n}\n* .fa-foursquare:before {\n  content: "\\f180";\n}\n* .fa-free-code-camp:before {\n  content: "\\f2c5";\n}\n* .fa-freebsd:before {\n  content: "\\f3a4";\n}\n* .fa-frog:before {\n  content: "\\f52e";\n}\n* .fa-frown:before {\n  content: "\\f119";\n}\n* .fa-frown-open:before {\n  content: "\\f57a";\n}\n* .fa-fulcrum:before {\n  content: "\\f50b";\n}\n* .fa-funnel-dollar:before {\n  content: "\\f662";\n}\n* .fa-futbol:before {\n  content: "\\f1e3";\n}\n* .fa-galactic-republic:before {\n  content: "\\f50c";\n}\n* .fa-galactic-senate:before {\n  content: "\\f50d";\n}\n* .fa-gamepad:before {\n  content: "\\f11b";\n}\n* .fa-gas-pump:before {\n  content: "\\f52f";\n}\n* .fa-gavel:before {\n  content: "\\f0e3";\n}\n* .fa-gem:before {\n  content: "\\f3a5";\n}\n* .fa-genderless:before {\n  content: "\\f22d";\n}\n* .fa-get-pocket:before {\n  content: "\\f265";\n}\n* .fa-gg:before {\n  content: "\\f260";\n}\n* .fa-gg-circle:before {\n  content: "\\f261";\n}\n* .fa-ghost:before {\n  content: "\\f6e2";\n}\n* .fa-gift:before {\n  content: "\\f06b";\n}\n* .fa-gifts:before {\n  content: "\\f79c";\n}\n* .fa-git:before {\n  content: "\\f1d3";\n}\n* .fa-git-square:before {\n  content: "\\f1d2";\n}\n* .fa-github:before {\n  content: "\\f09b";\n}\n* .fa-github-alt:before {\n  content: "\\f113";\n}\n* .fa-github-square:before {\n  content: "\\f092";\n}\n* .fa-gitkraken:before {\n  content: "\\f3a6";\n}\n* .fa-gitlab:before {\n  content: "\\f296";\n}\n* .fa-gitter:before {\n  content: "\\f426";\n}\n* .fa-glass-cheers:before {\n  content: "\\f79f";\n}\n* .fa-glass-martini:before {\n  content: "\\f000";\n}\n* .fa-glass-martini-alt:before {\n  content: "\\f57b";\n}\n* .fa-glass-whiskey:before {\n  content: "\\f7a0";\n}\n* .fa-glasses:before {\n  content: "\\f530";\n}\n* .fa-glide:before {\n  content: "\\f2a5";\n}\n* .fa-glide-g:before {\n  content: "\\f2a6";\n}\n* .fa-globe:before {\n  content: "\\f0ac";\n}\n* .fa-globe-africa:before {\n  content: "\\f57c";\n}\n* .fa-globe-americas:before {\n  content: "\\f57d";\n}\n* .fa-globe-asia:before {\n  content: "\\f57e";\n}\n* .fa-globe-europe:before {\n  content: "\\f7a2";\n}\n* .fa-gofore:before {\n  content: "\\f3a7";\n}\n* .fa-golf-ball:before {\n  content: "\\f450";\n}\n* .fa-goodreads:before {\n  content: "\\f3a8";\n}\n* .fa-goodreads-g:before {\n  content: "\\f3a9";\n}\n* .fa-google:before {\n  content: "\\f1a0";\n}\n* .fa-google-drive:before {\n  content: "\\f3aa";\n}\n* .fa-google-play:before {\n  content: "\\f3ab";\n}\n* .fa-google-plus:before {\n  content: "\\f2b3";\n}\n* .fa-google-plus-g:before {\n  content: "\\f0d5";\n}\n* .fa-google-plus-square:before {\n  content: "\\f0d4";\n}\n* .fa-google-wallet:before {\n  content: "\\f1ee";\n}\n* .fa-gopuram:before {\n  content: "\\f664";\n}\n* .fa-graduation-cap:before {\n  content: "\\f19d";\n}\n* .fa-gratipay:before {\n  content: "\\f184";\n}\n* .fa-grav:before {\n  content: "\\f2d6";\n}\n* .fa-greater-than:before {\n  content: "\\f531";\n}\n* .fa-greater-than-equal:before {\n  content: "\\f532";\n}\n* .fa-grimace:before {\n  content: "\\f57f";\n}\n* .fa-grin:before {\n  content: "\\f580";\n}\n* .fa-grin-alt:before {\n  content: "\\f581";\n}\n* .fa-grin-beam:before {\n  content: "\\f582";\n}\n* .fa-grin-beam-sweat:before {\n  content: "\\f583";\n}\n* .fa-grin-hearts:before {\n  content: "\\f584";\n}\n* .fa-grin-squint:before {\n  content: "\\f585";\n}\n* .fa-grin-squint-tears:before {\n  content: "\\f586";\n}\n* .fa-grin-stars:before {\n  content: "\\f587";\n}\n* .fa-grin-tears:before {\n  content: "\\f588";\n}\n* .fa-grin-tongue:before {\n  content: "\\f589";\n}\n* .fa-grin-tongue-squint:before {\n  content: "\\f58a";\n}\n* .fa-grin-tongue-wink:before {\n  content: "\\f58b";\n}\n* .fa-grin-wink:before {\n  content: "\\f58c";\n}\n* .fa-grip-horizontal:before {\n  content: "\\f58d";\n}\n* .fa-grip-lines:before {\n  content: "\\f7a4";\n}\n* .fa-grip-lines-vertical:before {\n  content: "\\f7a5";\n}\n* .fa-grip-vertical:before {\n  content: "\\f58e";\n}\n* .fa-gripfire:before {\n  content: "\\f3ac";\n}\n* .fa-grunt:before {\n  content: "\\f3ad";\n}\n* .fa-guitar:before {\n  content: "\\f7a6";\n}\n* .fa-gulp:before {\n  content: "\\f3ae";\n}\n* .fa-h-square:before {\n  content: "\\f0fd";\n}\n* .fa-hacker-news:before {\n  content: "\\f1d4";\n}\n* .fa-hacker-news-square:before {\n  content: "\\f3af";\n}\n* .fa-hackerrank:before {\n  content: "\\f5f7";\n}\n* .fa-hammer:before {\n  content: "\\f6e3";\n}\n* .fa-hamsa:before {\n  content: "\\f665";\n}\n* .fa-hand-holding:before {\n  content: "\\f4bd";\n}\n* .fa-hand-holding-heart:before {\n  content: "\\f4be";\n}\n* .fa-hand-holding-usd:before {\n  content: "\\f4c0";\n}\n* .fa-hand-lizard:before {\n  content: "\\f258";\n}\n* .fa-hand-paper:before {\n  content: "\\f256";\n}\n* .fa-hand-peace:before {\n  content: "\\f25b";\n}\n* .fa-hand-point-down:before {\n  content: "\\f0a7";\n}\n* .fa-hand-point-left:before {\n  content: "\\f0a5";\n}\n* .fa-hand-point-right:before {\n  content: "\\f0a4";\n}\n* .fa-hand-point-up:before {\n  content: "\\f0a6";\n}\n* .fa-hand-pointer:before {\n  content: "\\f25a";\n}\n* .fa-hand-rock:before {\n  content: "\\f255";\n}\n* .fa-hand-scissors:before {\n  content: "\\f257";\n}\n* .fa-hand-spock:before {\n  content: "\\f259";\n}\n* .fa-hands:before {\n  content: "\\f4c2";\n}\n* .fa-hands-helping:before {\n  content: "\\f4c4";\n}\n* .fa-handshake:before {\n  content: "\\f2b5";\n}\n* .fa-hanukiah:before {\n  content: "\\f6e6";\n}\n* .fa-hashtag:before {\n  content: "\\f292";\n}\n* .fa-hat-wizard:before {\n  content: "\\f6e8";\n}\n* .fa-haykal:before {\n  content: "\\f666";\n}\n* .fa-hdd:before {\n  content: "\\f0a0";\n}\n* .fa-heading:before {\n  content: "\\f1dc";\n}\n* .fa-headphones:before {\n  content: "\\f025";\n}\n* .fa-headphones-alt:before {\n  content: "\\f58f";\n}\n* .fa-headset:before {\n  content: "\\f590";\n}\n* .fa-heart:before {\n  content: "\\f004";\n}\n* .fa-heart-broken:before {\n  content: "\\f7a9";\n}\n* .fa-heartbeat:before {\n  content: "\\f21e";\n}\n* .fa-helicopter:before {\n  content: "\\f533";\n}\n* .fa-highlighter:before {\n  content: "\\f591";\n}\n* .fa-hiking:before {\n  content: "\\f6ec";\n}\n* .fa-hippo:before {\n  content: "\\f6ed";\n}\n* .fa-hips:before {\n  content: "\\f452";\n}\n* .fa-hire-a-helper:before {\n  content: "\\f3b0";\n}\n* .fa-history:before {\n  content: "\\f1da";\n}\n* .fa-hockey-puck:before {\n  content: "\\f453";\n}\n* .fa-holly-berry:before {\n  content: "\\f7aa";\n}\n* .fa-home:before {\n  content: "\\f015";\n}\n* .fa-hooli:before {\n  content: "\\f427";\n}\n* .fa-hornbill:before {\n  content: "\\f592";\n}\n* .fa-horse:before {\n  content: "\\f6f0";\n}\n* .fa-horse-head:before {\n  content: "\\f7ab";\n}\n* .fa-hospital:before {\n  content: "\\f0f8";\n}\n* .fa-hospital-alt:before {\n  content: "\\f47d";\n}\n* .fa-hospital-symbol:before {\n  content: "\\f47e";\n}\n* .fa-hot-tub:before {\n  content: "\\f593";\n}\n* .fa-hotel:before {\n  content: "\\f594";\n}\n* .fa-hotjar:before {\n  content: "\\f3b1";\n}\n* .fa-hourglass:before {\n  content: "\\f254";\n}\n* .fa-hourglass-end:before {\n  content: "\\f253";\n}\n* .fa-hourglass-half:before {\n  content: "\\f252";\n}\n* .fa-hourglass-start:before {\n  content: "\\f251";\n}\n* .fa-house-damage:before {\n  content: "\\f6f1";\n}\n* .fa-houzz:before {\n  content: "\\f27c";\n}\n* .fa-hryvnia:before {\n  content: "\\f6f2";\n}\n* .fa-html5:before {\n  content: "\\f13b";\n}\n* .fa-hubspot:before {\n  content: "\\f3b2";\n}\n* .fa-i-cursor:before {\n  content: "\\f246";\n}\n* .fa-icicles:before {\n  content: "\\f7ad";\n}\n* .fa-id-badge:before {\n  content: "\\f2c1";\n}\n* .fa-id-card:before {\n  content: "\\f2c2";\n}\n* .fa-id-card-alt:before {\n  content: "\\f47f";\n}\n* .fa-igloo:before {\n  content: "\\f7ae";\n}\n* .fa-image:before {\n  content: "\\f03e";\n}\n* .fa-images:before {\n  content: "\\f302";\n}\n* .fa-imdb:before {\n  content: "\\f2d8";\n}\n* .fa-inbox:before {\n  content: "\\f01c";\n}\n* .fa-indent:before {\n  content: "\\f03c";\n}\n* .fa-industry:before {\n  content: "\\f275";\n}\n* .fa-infinity:before {\n  content: "\\f534";\n}\n* .fa-info:before {\n  content: "\\f129";\n}\n* .fa-info-circle:before {\n  content: "\\f05a";\n}\n* .fa-instagram:before {\n  content: "\\f16d";\n}\n* .fa-intercom:before {\n  content: "\\f7af";\n}\n* .fa-internet-explorer:before {\n  content: "\\f26b";\n}\n* .fa-invision:before {\n  content: "\\f7b0";\n}\n* .fa-ioxhost:before {\n  content: "\\f208";\n}\n* .fa-italic:before {\n  content: "\\f033";\n}\n* .fa-itunes:before {\n  content: "\\f3b4";\n}\n* .fa-itunes-note:before {\n  content: "\\f3b5";\n}\n* .fa-java:before {\n  content: "\\f4e4";\n}\n* .fa-jedi:before {\n  content: "\\f669";\n}\n* .fa-jedi-order:before {\n  content: "\\f50e";\n}\n* .fa-jenkins:before {\n  content: "\\f3b6";\n}\n* .fa-jira:before {\n  content: "\\f7b1";\n}\n* .fa-joget:before {\n  content: "\\f3b7";\n}\n* .fa-joint:before {\n  content: "\\f595";\n}\n* .fa-joomla:before {\n  content: "\\f1aa";\n}\n* .fa-journal-whills:before {\n  content: "\\f66a";\n}\n* .fa-js:before {\n  content: "\\f3b8";\n}\n* .fa-js-square:before {\n  content: "\\f3b9";\n}\n* .fa-jsfiddle:before {\n  content: "\\f1cc";\n}\n* .fa-kaaba:before {\n  content: "\\f66b";\n}\n* .fa-kaggle:before {\n  content: "\\f5fa";\n}\n* .fa-key:before {\n  content: "\\f084";\n}\n* .fa-keybase:before {\n  content: "\\f4f5";\n}\n* .fa-keyboard:before {\n  content: "\\f11c";\n}\n* .fa-keycdn:before {\n  content: "\\f3ba";\n}\n* .fa-khanda:before {\n  content: "\\f66d";\n}\n* .fa-kickstarter:before {\n  content: "\\f3bb";\n}\n* .fa-kickstarter-k:before {\n  content: "\\f3bc";\n}\n* .fa-kiss:before {\n  content: "\\f596";\n}\n* .fa-kiss-beam:before {\n  content: "\\f597";\n}\n* .fa-kiss-wink-heart:before {\n  content: "\\f598";\n}\n* .fa-kiwi-bird:before {\n  content: "\\f535";\n}\n* .fa-korvue:before {\n  content: "\\f42f";\n}\n* .fa-landmark:before {\n  content: "\\f66f";\n}\n* .fa-language:before {\n  content: "\\f1ab";\n}\n* .fa-laptop:before {\n  content: "\\f109";\n}\n* .fa-laptop-code:before {\n  content: "\\f5fc";\n}\n* .fa-laravel:before {\n  content: "\\f3bd";\n}\n* .fa-lastfm:before {\n  content: "\\f202";\n}\n* .fa-lastfm-square:before {\n  content: "\\f203";\n}\n* .fa-laugh:before {\n  content: "\\f599";\n}\n* .fa-laugh-beam:before {\n  content: "\\f59a";\n}\n* .fa-laugh-squint:before {\n  content: "\\f59b";\n}\n* .fa-laugh-wink:before {\n  content: "\\f59c";\n}\n* .fa-layer-group:before {\n  content: "\\f5fd";\n}\n* .fa-leaf:before {\n  content: "\\f06c";\n}\n* .fa-leanpub:before {\n  content: "\\f212";\n}\n* .fa-lemon:before {\n  content: "\\f094";\n}\n* .fa-less:before {\n  content: "\\f41d";\n}\n* .fa-less-than:before {\n  content: "\\f536";\n}\n* .fa-less-than-equal:before {\n  content: "\\f537";\n}\n* .fa-level-down-alt:before {\n  content: "\\f3be";\n}\n* .fa-level-up-alt:before {\n  content: "\\f3bf";\n}\n* .fa-life-ring:before {\n  content: "\\f1cd";\n}\n* .fa-lightbulb:before {\n  content: "\\f0eb";\n}\n* .fa-line:before {\n  content: "\\f3c0";\n}\n* .fa-link:before {\n  content: "\\f0c1";\n}\n* .fa-linkedin:before {\n  content: "\\f08c";\n}\n* .fa-linkedin-in:before {\n  content: "\\f0e1";\n}\n* .fa-linode:before {\n  content: "\\f2b8";\n}\n* .fa-linux:before {\n  content: "\\f17c";\n}\n* .fa-lira-sign:before {\n  content: "\\f195";\n}\n* .fa-list:before {\n  content: "\\f03a";\n}\n* .fa-list-alt:before {\n  content: "\\f022";\n}\n* .fa-list-ol:before {\n  content: "\\f0cb";\n}\n* .fa-list-ul:before {\n  content: "\\f0ca";\n}\n* .fa-location-arrow:before {\n  content: "\\f124";\n}\n* .fa-lock:before {\n  content: "\\f023";\n}\n* .fa-lock-open:before {\n  content: "\\f3c1";\n}\n* .fa-long-arrow-alt-down:before {\n  content: "\\f309";\n}\n* .fa-long-arrow-alt-left:before {\n  content: "\\f30a";\n}\n* .fa-long-arrow-alt-right:before {\n  content: "\\f30b";\n}\n* .fa-long-arrow-alt-up:before {\n  content: "\\f30c";\n}\n* .fa-low-vision:before {\n  content: "\\f2a8";\n}\n* .fa-luggage-cart:before {\n  content: "\\f59d";\n}\n* .fa-lyft:before {\n  content: "\\f3c3";\n}\n* .fa-magento:before {\n  content: "\\f3c4";\n}\n* .fa-magic:before {\n  content: "\\f0d0";\n}\n* .fa-magnet:before {\n  content: "\\f076";\n}\n* .fa-mail-bulk:before {\n  content: "\\f674";\n}\n* .fa-mailchimp:before {\n  content: "\\f59e";\n}\n* .fa-male:before {\n  content: "\\f183";\n}\n* .fa-mandalorian:before {\n  content: "\\f50f";\n}\n* .fa-map:before {\n  content: "\\f279";\n}\n* .fa-map-marked:before {\n  content: "\\f59f";\n}\n* .fa-map-marked-alt:before {\n  content: "\\f5a0";\n}\n* .fa-map-marker:before {\n  content: "\\f041";\n}\n* .fa-map-marker-alt:before {\n  content: "\\f3c5";\n}\n* .fa-map-pin:before {\n  content: "\\f276";\n}\n* .fa-map-signs:before {\n  content: "\\f277";\n}\n* .fa-markdown:before {\n  content: "\\f60f";\n}\n* .fa-marker:before {\n  content: "\\f5a1";\n}\n* .fa-mars:before {\n  content: "\\f222";\n}\n* .fa-mars-double:before {\n  content: "\\f227";\n}\n* .fa-mars-stroke:before {\n  content: "\\f229";\n}\n* .fa-mars-stroke-h:before {\n  content: "\\f22b";\n}\n* .fa-mars-stroke-v:before {\n  content: "\\f22a";\n}\n* .fa-mask:before {\n  content: "\\f6fa";\n}\n* .fa-mastodon:before {\n  content: "\\f4f6";\n}\n* .fa-maxcdn:before {\n  content: "\\f136";\n}\n* .fa-medal:before {\n  content: "\\f5a2";\n}\n* .fa-medapps:before {\n  content: "\\f3c6";\n}\n* .fa-medium:before {\n  content: "\\f23a";\n}\n* .fa-medium-m:before {\n  content: "\\f3c7";\n}\n* .fa-medkit:before {\n  content: "\\f0fa";\n}\n* .fa-medrt:before {\n  content: "\\f3c8";\n}\n* .fa-meetup:before {\n  content: "\\f2e0";\n}\n* .fa-megaport:before {\n  content: "\\f5a3";\n}\n* .fa-meh:before {\n  content: "\\f11a";\n}\n* .fa-meh-blank:before {\n  content: "\\f5a4";\n}\n* .fa-meh-rolling-eyes:before {\n  content: "\\f5a5";\n}\n* .fa-memory:before {\n  content: "\\f538";\n}\n* .fa-mendeley:before {\n  content: "\\f7b3";\n}\n* .fa-menorah:before {\n  content: "\\f676";\n}\n* .fa-mercury:before {\n  content: "\\f223";\n}\n* .fa-meteor:before {\n  content: "\\f753";\n}\n* .fa-microchip:before {\n  content: "\\f2db";\n}\n* .fa-microphone:before {\n  content: "\\f130";\n}\n* .fa-microphone-alt:before {\n  content: "\\f3c9";\n}\n* .fa-microphone-alt-slash:before {\n  content: "\\f539";\n}\n* .fa-microphone-slash:before {\n  content: "\\f131";\n}\n* .fa-microscope:before {\n  content: "\\f610";\n}\n* .fa-microsoft:before {\n  content: "\\f3ca";\n}\n* .fa-minus:before {\n  content: "\\f068";\n}\n* .fa-minus-circle:before {\n  content: "\\f056";\n}\n* .fa-minus-square:before {\n  content: "\\f146";\n}\n* .fa-mitten:before {\n  content: "\\f7b5";\n}\n* .fa-mix:before {\n  content: "\\f3cb";\n}\n* .fa-mixcloud:before {\n  content: "\\f289";\n}\n* .fa-mizuni:before {\n  content: "\\f3cc";\n}\n* .fa-mobile:before {\n  content: "\\f10b";\n}\n* .fa-mobile-alt:before {\n  content: "\\f3cd";\n}\n* .fa-modx:before {\n  content: "\\f285";\n}\n* .fa-monero:before {\n  content: "\\f3d0";\n}\n* .fa-money-bill:before {\n  content: "\\f0d6";\n}\n* .fa-money-bill-alt:before {\n  content: "\\f3d1";\n}\n* .fa-money-bill-wave:before {\n  content: "\\f53a";\n}\n* .fa-money-bill-wave-alt:before {\n  content: "\\f53b";\n}\n* .fa-money-check:before {\n  content: "\\f53c";\n}\n* .fa-money-check-alt:before {\n  content: "\\f53d";\n}\n* .fa-monument:before {\n  content: "\\f5a6";\n}\n* .fa-moon:before {\n  content: "\\f186";\n}\n* .fa-mortar-pestle:before {\n  content: "\\f5a7";\n}\n* .fa-mosque:before {\n  content: "\\f678";\n}\n* .fa-motorcycle:before {\n  content: "\\f21c";\n}\n* .fa-mountain:before {\n  content: "\\f6fc";\n}\n* .fa-mouse-pointer:before {\n  content: "\\f245";\n}\n* .fa-mug-hot:before {\n  content: "\\f7b6";\n}\n* .fa-music:before {\n  content: "\\f001";\n}\n* .fa-napster:before {\n  content: "\\f3d2";\n}\n* .fa-neos:before {\n  content: "\\f612";\n}\n* .fa-network-wired:before {\n  content: "\\f6ff";\n}\n* .fa-neuter:before {\n  content: "\\f22c";\n}\n* .fa-newspaper:before {\n  content: "\\f1ea";\n}\n* .fa-nimblr:before {\n  content: "\\f5a8";\n}\n* .fa-nintendo-switch:before {\n  content: "\\f418";\n}\n* .fa-node:before {\n  content: "\\f419";\n}\n* .fa-node-js:before {\n  content: "\\f3d3";\n}\n* .fa-not-equal:before {\n  content: "\\f53e";\n}\n* .fa-notes-medical:before {\n  content: "\\f481";\n}\n* .fa-npm:before {\n  content: "\\f3d4";\n}\n* .fa-ns8:before {\n  content: "\\f3d5";\n}\n* .fa-nutritionix:before {\n  content: "\\f3d6";\n}\n* .fa-object-group:before {\n  content: "\\f247";\n}\n* .fa-object-ungroup:before {\n  content: "\\f248";\n}\n* .fa-odnoklassniki:before {\n  content: "\\f263";\n}\n* .fa-odnoklassniki-square:before {\n  content: "\\f264";\n}\n* .fa-oil-can:before {\n  content: "\\f613";\n}\n* .fa-old-republic:before {\n  content: "\\f510";\n}\n* .fa-om:before {\n  content: "\\f679";\n}\n* .fa-opencart:before {\n  content: "\\f23d";\n}\n* .fa-openid:before {\n  content: "\\f19b";\n}\n* .fa-opera:before {\n  content: "\\f26a";\n}\n* .fa-optin-monster:before {\n  content: "\\f23c";\n}\n* .fa-osi:before {\n  content: "\\f41a";\n}\n* .fa-otter:before {\n  content: "\\f700";\n}\n* .fa-outdent:before {\n  content: "\\f03b";\n}\n* .fa-page4:before {\n  content: "\\f3d7";\n}\n* .fa-pagelines:before {\n  content: "\\f18c";\n}\n* .fa-paint-brush:before {\n  content: "\\f1fc";\n}\n* .fa-paint-roller:before {\n  content: "\\f5aa";\n}\n* .fa-palette:before {\n  content: "\\f53f";\n}\n* .fa-palfed:before {\n  content: "\\f3d8";\n}\n* .fa-pallet:before {\n  content: "\\f482";\n}\n* .fa-paper-plane:before {\n  content: "\\f1d8";\n}\n* .fa-paperclip:before {\n  content: "\\f0c6";\n}\n* .fa-parachute-box:before {\n  content: "\\f4cd";\n}\n* .fa-paragraph:before {\n  content: "\\f1dd";\n}\n* .fa-parking:before {\n  content: "\\f540";\n}\n* .fa-passport:before {\n  content: "\\f5ab";\n}\n* .fa-pastafarianism:before {\n  content: "\\f67b";\n}\n* .fa-paste:before {\n  content: "\\f0ea";\n}\n* .fa-patreon:before {\n  content: "\\f3d9";\n}\n* .fa-pause:before {\n  content: "\\f04c";\n}\n* .fa-pause-circle:before {\n  content: "\\f28b";\n}\n* .fa-paw:before {\n  content: "\\f1b0";\n}\n* .fa-paypal:before {\n  content: "\\f1ed";\n}\n* .fa-peace:before {\n  content: "\\f67c";\n}\n* .fa-pen:before {\n  content: "\\f304";\n}\n* .fa-pen-alt:before {\n  content: "\\f305";\n}\n* .fa-pen-fancy:before {\n  content: "\\f5ac";\n}\n* .fa-pen-nib:before {\n  content: "\\f5ad";\n}\n* .fa-pen-square:before {\n  content: "\\f14b";\n}\n* .fa-pencil-alt:before {\n  content: "\\f303";\n}\n* .fa-pencil-ruler:before {\n  content: "\\f5ae";\n}\n* .fa-penny-arcade:before {\n  content: "\\f704";\n}\n* .fa-people-carry:before {\n  content: "\\f4ce";\n}\n* .fa-percent:before {\n  content: "\\f295";\n}\n* .fa-percentage:before {\n  content: "\\f541";\n}\n* .fa-periscope:before {\n  content: "\\f3da";\n}\n* .fa-person-booth:before {\n  content: "\\f756";\n}\n* .fa-phabricator:before {\n  content: "\\f3db";\n}\n* .fa-phoenix-framework:before {\n  content: "\\f3dc";\n}\n* .fa-phoenix-squadron:before {\n  content: "\\f511";\n}\n* .fa-phone:before {\n  content: "\\f095";\n}\n* .fa-phone-slash:before {\n  content: "\\f3dd";\n}\n* .fa-phone-square:before {\n  content: "\\f098";\n}\n* .fa-phone-volume:before {\n  content: "\\f2a0";\n}\n* .fa-php:before {\n  content: "\\f457";\n}\n* .fa-pied-piper:before {\n  content: "\\f2ae";\n}\n* .fa-pied-piper-alt:before {\n  content: "\\f1a8";\n}\n* .fa-pied-piper-hat:before {\n  content: "\\f4e5";\n}\n* .fa-pied-piper-pp:before {\n  content: "\\f1a7";\n}\n* .fa-piggy-bank:before {\n  content: "\\f4d3";\n}\n* .fa-pills:before {\n  content: "\\f484";\n}\n* .fa-pinterest:before {\n  content: "\\f0d2";\n}\n* .fa-pinterest-p:before {\n  content: "\\f231";\n}\n* .fa-pinterest-square:before {\n  content: "\\f0d3";\n}\n* .fa-place-of-worship:before {\n  content: "\\f67f";\n}\n* .fa-plane:before {\n  content: "\\f072";\n}\n* .fa-plane-arrival:before {\n  content: "\\f5af";\n}\n* .fa-plane-departure:before {\n  content: "\\f5b0";\n}\n* .fa-play:before {\n  content: "\\f04b";\n}\n* .fa-play-circle:before {\n  content: "\\f144";\n}\n* .fa-playstation:before {\n  content: "\\f3df";\n}\n* .fa-plug:before {\n  content: "\\f1e6";\n}\n* .fa-plus:before {\n  content: "\\f067";\n}\n* .fa-plus-circle:before {\n  content: "\\f055";\n}\n* .fa-plus-square:before {\n  content: "\\f0fe";\n}\n* .fa-podcast:before {\n  content: "\\f2ce";\n}\n* .fa-poll:before {\n  content: "\\f681";\n}\n* .fa-poll-h:before {\n  content: "\\f682";\n}\n* .fa-poo:before {\n  content: "\\f2fe";\n}\n* .fa-poo-storm:before {\n  content: "\\f75a";\n}\n* .fa-poop:before {\n  content: "\\f619";\n}\n* .fa-portrait:before {\n  content: "\\f3e0";\n}\n* .fa-pound-sign:before {\n  content: "\\f154";\n}\n* .fa-power-off:before {\n  content: "\\f011";\n}\n* .fa-pray:before {\n  content: "\\f683";\n}\n* .fa-praying-hands:before {\n  content: "\\f684";\n}\n* .fa-prescription:before {\n  content: "\\f5b1";\n}\n* .fa-prescription-bottle:before {\n  content: "\\f485";\n}\n* .fa-prescription-bottle-alt:before {\n  content: "\\f486";\n}\n* .fa-print:before {\n  content: "\\f02f";\n}\n* .fa-procedures:before {\n  content: "\\f487";\n}\n* .fa-product-hunt:before {\n  content: "\\f288";\n}\n* .fa-project-diagram:before {\n  content: "\\f542";\n}\n* .fa-pushed:before {\n  content: "\\f3e1";\n}\n* .fa-puzzle-piece:before {\n  content: "\\f12e";\n}\n* .fa-python:before {\n  content: "\\f3e2";\n}\n* .fa-qq:before {\n  content: "\\f1d6";\n}\n* .fa-qrcode:before {\n  content: "\\f029";\n}\n* .fa-question:before {\n  content: "\\f128";\n}\n* .fa-question-circle:before {\n  content: "\\f059";\n}\n* .fa-quidditch:before {\n  content: "\\f458";\n}\n* .fa-quinscape:before {\n  content: "\\f459";\n}\n* .fa-quora:before {\n  content: "\\f2c4";\n}\n* .fa-quote-left:before {\n  content: "\\f10d";\n}\n* .fa-quote-right:before {\n  content: "\\f10e";\n}\n* .fa-quran:before {\n  content: "\\f687";\n}\n* .fa-r-project:before {\n  content: "\\f4f7";\n}\n* .fa-radiation:before {\n  content: "\\f7b9";\n}\n* .fa-radiation-alt:before {\n  content: "\\f7ba";\n}\n* .fa-rainbow:before {\n  content: "\\f75b";\n}\n* .fa-random:before {\n  content: "\\f074";\n}\n* .fa-raspberry-pi:before {\n  content: "\\f7bb";\n}\n* .fa-ravelry:before {\n  content: "\\f2d9";\n}\n* .fa-react:before {\n  content: "\\f41b";\n}\n* .fa-reacteurope:before {\n  content: "\\f75d";\n}\n* .fa-readme:before {\n  content: "\\f4d5";\n}\n* .fa-rebel:before {\n  content: "\\f1d0";\n}\n* .fa-receipt:before {\n  content: "\\f543";\n}\n* .fa-recycle:before {\n  content: "\\f1b8";\n}\n* .fa-red-river:before {\n  content: "\\f3e3";\n}\n* .fa-reddit:before {\n  content: "\\f1a1";\n}\n* .fa-reddit-alien:before {\n  content: "\\f281";\n}\n* .fa-reddit-square:before {\n  content: "\\f1a2";\n}\n* .fa-redhat:before {\n  content: "\\f7bc";\n}\n* .fa-redo:before {\n  content: "\\f01e";\n}\n* .fa-redo-alt:before {\n  content: "\\f2f9";\n}\n* .fa-registered:before {\n  content: "\\f25d";\n}\n* .fa-renren:before {\n  content: "\\f18b";\n}\n* .fa-reply:before {\n  content: "\\f3e5";\n}\n* .fa-reply-all:before {\n  content: "\\f122";\n}\n* .fa-replyd:before {\n  content: "\\f3e6";\n}\n* .fa-republican:before {\n  content: "\\f75e";\n}\n* .fa-researchgate:before {\n  content: "\\f4f8";\n}\n* .fa-resolving:before {\n  content: "\\f3e7";\n}\n* .fa-restroom:before {\n  content: "\\f7bd";\n}\n* .fa-retweet:before {\n  content: "\\f079";\n}\n* .fa-rev:before {\n  content: "\\f5b2";\n}\n* .fa-ribbon:before {\n  content: "\\f4d6";\n}\n* .fa-ring:before {\n  content: "\\f70b";\n}\n* .fa-road:before {\n  content: "\\f018";\n}\n* .fa-robot:before {\n  content: "\\f544";\n}\n* .fa-rocket:before {\n  content: "\\f135";\n}\n* .fa-rocketchat:before {\n  content: "\\f3e8";\n}\n* .fa-rockrms:before {\n  content: "\\f3e9";\n}\n* .fa-route:before {\n  content: "\\f4d7";\n}\n* .fa-rss:before {\n  content: "\\f09e";\n}\n* .fa-rss-square:before {\n  content: "\\f143";\n}\n* .fa-ruble-sign:before {\n  content: "\\f158";\n}\n* .fa-ruler:before {\n  content: "\\f545";\n}\n* .fa-ruler-combined:before {\n  content: "\\f546";\n}\n* .fa-ruler-horizontal:before {\n  content: "\\f547";\n}\n* .fa-ruler-vertical:before {\n  content: "\\f548";\n}\n* .fa-running:before {\n  content: "\\f70c";\n}\n* .fa-rupee-sign:before {\n  content: "\\f156";\n}\n* .fa-sad-cry:before {\n  content: "\\f5b3";\n}\n* .fa-sad-tear:before {\n  content: "\\f5b4";\n}\n* .fa-safari:before {\n  content: "\\f267";\n}\n* .fa-sass:before {\n  content: "\\f41e";\n}\n* .fa-satellite:before {\n  content: "\\f7bf";\n}\n* .fa-satellite-dish:before {\n  content: "\\f7c0";\n}\n* .fa-save:before {\n  content: "\\f0c7";\n}\n* .fa-schlix:before {\n  content: "\\f3ea";\n}\n* .fa-school:before {\n  content: "\\f549";\n}\n* .fa-screwdriver:before {\n  content: "\\f54a";\n}\n* .fa-scribd:before {\n  content: "\\f28a";\n}\n* .fa-scroll:before {\n  content: "\\f70e";\n}\n* .fa-sd-card:before {\n  content: "\\f7c2";\n}\n* .fa-search:before {\n  content: "\\f002";\n}\n* .fa-search-dollar:before {\n  content: "\\f688";\n}\n* .fa-search-location:before {\n  content: "\\f689";\n}\n* .fa-search-minus:before {\n  content: "\\f010";\n}\n* .fa-search-plus:before {\n  content: "\\f00e";\n}\n* .fa-searchengin:before {\n  content: "\\f3eb";\n}\n* .fa-seedling:before {\n  content: "\\f4d8";\n}\n* .fa-sellcast:before {\n  content: "\\f2da";\n}\n* .fa-sellsy:before {\n  content: "\\f213";\n}\n* .fa-server:before {\n  content: "\\f233";\n}\n* .fa-servicestack:before {\n  content: "\\f3ec";\n}\n* .fa-shapes:before {\n  content: "\\f61f";\n}\n* .fa-share:before {\n  content: "\\f064";\n}\n* .fa-share-alt:before {\n  content: "\\f1e0";\n}\n* .fa-share-alt-square:before {\n  content: "\\f1e1";\n}\n* .fa-share-square:before {\n  content: "\\f14d";\n}\n* .fa-shekel-sign:before {\n  content: "\\f20b";\n}\n* .fa-shield-alt:before {\n  content: "\\f3ed";\n}\n* .fa-ship:before {\n  content: "\\f21a";\n}\n* .fa-shipping-fast:before {\n  content: "\\f48b";\n}\n* .fa-shirtsinbulk:before {\n  content: "\\f214";\n}\n* .fa-shoe-prints:before {\n  content: "\\f54b";\n}\n* .fa-shopping-bag:before {\n  content: "\\f290";\n}\n* .fa-shopping-basket:before {\n  content: "\\f291";\n}\n* .fa-shopping-cart:before {\n  content: "\\f07a";\n}\n* .fa-shopware:before {\n  content: "\\f5b5";\n}\n* .fa-shower:before {\n  content: "\\f2cc";\n}\n* .fa-shuttle-van:before {\n  content: "\\f5b6";\n}\n* .fa-sign:before {\n  content: "\\f4d9";\n}\n* .fa-sign-in-alt:before {\n  content: "\\f2f6";\n}\n* .fa-sign-language:before {\n  content: "\\f2a7";\n}\n* .fa-sign-out-alt:before {\n  content: "\\f2f5";\n}\n* .fa-signal:before {\n  content: "\\f012";\n}\n* .fa-signature:before {\n  content: "\\f5b7";\n}\n* .fa-sim-card:before {\n  content: "\\f7c4";\n}\n* .fa-simplybuilt:before {\n  content: "\\f215";\n}\n* .fa-sistrix:before {\n  content: "\\f3ee";\n}\n* .fa-sitemap:before {\n  content: "\\f0e8";\n}\n* .fa-sith:before {\n  content: "\\f512";\n}\n* .fa-skating:before {\n  content: "\\f7c5";\n}\n* .fa-sketch:before {\n  content: "\\f7c6";\n}\n* .fa-skiing:before {\n  content: "\\f7c9";\n}\n* .fa-skiing-nordic:before {\n  content: "\\f7ca";\n}\n* .fa-skull:before {\n  content: "\\f54c";\n}\n* .fa-skull-crossbones:before {\n  content: "\\f714";\n}\n* .fa-skyatlas:before {\n  content: "\\f216";\n}\n* .fa-skype:before {\n  content: "\\f17e";\n}\n* .fa-slack:before {\n  content: "\\f198";\n}\n* .fa-slack-hash:before {\n  content: "\\f3ef";\n}\n* .fa-slash:before {\n  content: "\\f715";\n}\n* .fa-sleigh:before {\n  content: "\\f7cc";\n}\n* .fa-sliders-h:before {\n  content: "\\f1de";\n}\n* .fa-slideshare:before {\n  content: "\\f1e7";\n}\n* .fa-smile:before {\n  content: "\\f118";\n}\n* .fa-smile-beam:before {\n  content: "\\f5b8";\n}\n* .fa-smile-wink:before {\n  content: "\\f4da";\n}\n* .fa-smog:before {\n  content: "\\f75f";\n}\n* .fa-smoking:before {\n  content: "\\f48d";\n}\n* .fa-smoking-ban:before {\n  content: "\\f54d";\n}\n* .fa-sms:before {\n  content: "\\f7cd";\n}\n* .fa-snapchat:before {\n  content: "\\f2ab";\n}\n* .fa-snapchat-ghost:before {\n  content: "\\f2ac";\n}\n* .fa-snapchat-square:before {\n  content: "\\f2ad";\n}\n* .fa-snowboarding:before {\n  content: "\\f7ce";\n}\n* .fa-snowflake:before {\n  content: "\\f2dc";\n}\n* .fa-snowman:before {\n  content: "\\f7d0";\n}\n* .fa-snowplow:before {\n  content: "\\f7d2";\n}\n* .fa-socks:before {\n  content: "\\f696";\n}\n* .fa-solar-panel:before {\n  content: "\\f5ba";\n}\n* .fa-sort:before {\n  content: "\\f0dc";\n}\n* .fa-sort-alpha-down:before {\n  content: "\\f15d";\n}\n* .fa-sort-alpha-up:before {\n  content: "\\f15e";\n}\n* .fa-sort-amount-down:before {\n  content: "\\f160";\n}\n* .fa-sort-amount-up:before {\n  content: "\\f161";\n}\n* .fa-sort-down:before {\n  content: "\\f0dd";\n}\n* .fa-sort-numeric-down:before {\n  content: "\\f162";\n}\n* .fa-sort-numeric-up:before {\n  content: "\\f163";\n}\n* .fa-sort-up:before {\n  content: "\\f0de";\n}\n* .fa-soundcloud:before {\n  content: "\\f1be";\n}\n* .fa-sourcetree:before {\n  content: "\\f7d3";\n}\n* .fa-spa:before {\n  content: "\\f5bb";\n}\n* .fa-space-shuttle:before {\n  content: "\\f197";\n}\n* .fa-speakap:before {\n  content: "\\f3f3";\n}\n* .fa-spider:before {\n  content: "\\f717";\n}\n* .fa-spinner:before {\n  content: "\\f110";\n}\n* .fa-splotch:before {\n  content: "\\f5bc";\n}\n* .fa-spotify:before {\n  content: "\\f1bc";\n}\n* .fa-spray-can:before {\n  content: "\\f5bd";\n}\n* .fa-square:before {\n  content: "\\f0c8";\n}\n* .fa-square-full:before {\n  content: "\\f45c";\n}\n* .fa-square-root-alt:before {\n  content: "\\f698";\n}\n* .fa-squarespace:before {\n  content: "\\f5be";\n}\n* .fa-stack-exchange:before {\n  content: "\\f18d";\n}\n* .fa-stack-overflow:before {\n  content: "\\f16c";\n}\n* .fa-stamp:before {\n  content: "\\f5bf";\n}\n* .fa-star:before {\n  content: "\\f005";\n}\n* .fa-star-and-crescent:before {\n  content: "\\f699";\n}\n* .fa-star-half:before {\n  content: "\\f089";\n}\n* .fa-star-half-alt:before {\n  content: "\\f5c0";\n}\n* .fa-star-of-david:before {\n  content: "\\f69a";\n}\n* .fa-star-of-life:before {\n  content: "\\f621";\n}\n* .fa-staylinked:before {\n  content: "\\f3f5";\n}\n* .fa-steam:before {\n  content: "\\f1b6";\n}\n* .fa-steam-square:before {\n  content: "\\f1b7";\n}\n* .fa-steam-symbol:before {\n  content: "\\f3f6";\n}\n* .fa-step-backward:before {\n  content: "\\f048";\n}\n* .fa-step-forward:before {\n  content: "\\f051";\n}\n* .fa-stethoscope:before {\n  content: "\\f0f1";\n}\n* .fa-sticker-mule:before {\n  content: "\\f3f7";\n}\n* .fa-sticky-note:before {\n  content: "\\f249";\n}\n* .fa-stop:before {\n  content: "\\f04d";\n}\n* .fa-stop-circle:before {\n  content: "\\f28d";\n}\n* .fa-stopwatch:before {\n  content: "\\f2f2";\n}\n* .fa-store:before {\n  content: "\\f54e";\n}\n* .fa-store-alt:before {\n  content: "\\f54f";\n}\n* .fa-strava:before {\n  content: "\\f428";\n}\n* .fa-stream:before {\n  content: "\\f550";\n}\n* .fa-street-view:before {\n  content: "\\f21d";\n}\n* .fa-strikethrough:before {\n  content: "\\f0cc";\n}\n* .fa-stripe:before {\n  content: "\\f429";\n}\n* .fa-stripe-s:before {\n  content: "\\f42a";\n}\n* .fa-stroopwafel:before {\n  content: "\\f551";\n}\n* .fa-studiovinari:before {\n  content: "\\f3f8";\n}\n* .fa-stumbleupon:before {\n  content: "\\f1a4";\n}\n* .fa-stumbleupon-circle:before {\n  content: "\\f1a3";\n}\n* .fa-subscript:before {\n  content: "\\f12c";\n}\n* .fa-subway:before {\n  content: "\\f239";\n}\n* .fa-suitcase:before {\n  content: "\\f0f2";\n}\n* .fa-suitcase-rolling:before {\n  content: "\\f5c1";\n}\n* .fa-sun:before {\n  content: "\\f185";\n}\n* .fa-superpowers:before {\n  content: "\\f2dd";\n}\n* .fa-superscript:before {\n  content: "\\f12b";\n}\n* .fa-supple:before {\n  content: "\\f3f9";\n}\n* .fa-surprise:before {\n  content: "\\f5c2";\n}\n* .fa-suse:before {\n  content: "\\f7d6";\n}\n* .fa-swatchbook:before {\n  content: "\\f5c3";\n}\n* .fa-swimmer:before {\n  content: "\\f5c4";\n}\n* .fa-swimming-pool:before {\n  content: "\\f5c5";\n}\n* .fa-synagogue:before {\n  content: "\\f69b";\n}\n* .fa-sync:before {\n  content: "\\f021";\n}\n* .fa-sync-alt:before {\n  content: "\\f2f1";\n}\n* .fa-syringe:before {\n  content: "\\f48e";\n}\n* .fa-table:before {\n  content: "\\f0ce";\n}\n* .fa-table-tennis:before {\n  content: "\\f45d";\n}\n* .fa-tablet:before {\n  content: "\\f10a";\n}\n* .fa-tablet-alt:before {\n  content: "\\f3fa";\n}\n* .fa-tablets:before {\n  content: "\\f490";\n}\n* .fa-tachometer-alt:before {\n  content: "\\f3fd";\n}\n* .fa-tag:before {\n  content: "\\f02b";\n}\n* .fa-tags:before {\n  content: "\\f02c";\n}\n* .fa-tape:before {\n  content: "\\f4db";\n}\n* .fa-tasks:before {\n  content: "\\f0ae";\n}\n* .fa-taxi:before {\n  content: "\\f1ba";\n}\n* .fa-teamspeak:before {\n  content: "\\f4f9";\n}\n* .fa-teeth:before {\n  content: "\\f62e";\n}\n* .fa-teeth-open:before {\n  content: "\\f62f";\n}\n* .fa-telegram:before {\n  content: "\\f2c6";\n}\n* .fa-telegram-plane:before {\n  content: "\\f3fe";\n}\n* .fa-temperature-high:before {\n  content: "\\f769";\n}\n* .fa-temperature-low:before {\n  content: "\\f76b";\n}\n* .fa-tencent-weibo:before {\n  content: "\\f1d5";\n}\n* .fa-tenge:before {\n  content: "\\f7d7";\n}\n* .fa-terminal:before {\n  content: "\\f120";\n}\n* .fa-text-height:before {\n  content: "\\f034";\n}\n* .fa-text-width:before {\n  content: "\\f035";\n}\n* .fa-th:before {\n  content: "\\f00a";\n}\n* .fa-th-large:before {\n  content: "\\f009";\n}\n* .fa-th-list:before {\n  content: "\\f00b";\n}\n* .fa-the-red-yeti:before {\n  content: "\\f69d";\n}\n* .fa-theater-masks:before {\n  content: "\\f630";\n}\n* .fa-themeco:before {\n  content: "\\f5c6";\n}\n* .fa-themeisle:before {\n  content: "\\f2b2";\n}\n* .fa-thermometer:before {\n  content: "\\f491";\n}\n* .fa-thermometer-empty:before {\n  content: "\\f2cb";\n}\n* .fa-thermometer-full:before {\n  content: "\\f2c7";\n}\n* .fa-thermometer-half:before {\n  content: "\\f2c9";\n}\n* .fa-thermometer-quarter:before {\n  content: "\\f2ca";\n}\n* .fa-thermometer-three-quarters:before {\n  content: "\\f2c8";\n}\n* .fa-think-peaks:before {\n  content: "\\f731";\n}\n* .fa-thumbs-down:before {\n  content: "\\f165";\n}\n* .fa-thumbs-up:before {\n  content: "\\f164";\n}\n* .fa-thumbtack:before {\n  content: "\\f08d";\n}\n* .fa-ticket-alt:before {\n  content: "\\f3ff";\n}\n* .fa-times:before {\n  content: "\\f00d";\n}\n* .fa-times-circle:before {\n  content: "\\f057";\n}\n* .fa-tint:before {\n  content: "\\f043";\n}\n* .fa-tint-slash:before {\n  content: "\\f5c7";\n}\n* .fa-tired:before {\n  content: "\\f5c8";\n}\n* .fa-toggle-off:before {\n  content: "\\f204";\n}\n* .fa-toggle-on:before {\n  content: "\\f205";\n}\n* .fa-toilet:before {\n  content: "\\f7d8";\n}\n* .fa-toilet-paper:before {\n  content: "\\f71e";\n}\n* .fa-toolbox:before {\n  content: "\\f552";\n}\n* .fa-tools:before {\n  content: "\\f7d9";\n}\n* .fa-tooth:before {\n  content: "\\f5c9";\n}\n* .fa-torah:before {\n  content: "\\f6a0";\n}\n* .fa-torii-gate:before {\n  content: "\\f6a1";\n}\n* .fa-tractor:before {\n  content: "\\f722";\n}\n* .fa-trade-federation:before {\n  content: "\\f513";\n}\n* .fa-trademark:before {\n  content: "\\f25c";\n}\n* .fa-traffic-light:before {\n  content: "\\f637";\n}\n* .fa-train:before {\n  content: "\\f238";\n}\n* .fa-tram:before {\n  content: "\\f7da";\n}\n* .fa-transgender:before {\n  content: "\\f224";\n}\n* .fa-transgender-alt:before {\n  content: "\\f225";\n}\n* .fa-trash:before {\n  content: "\\f1f8";\n}\n* .fa-trash-alt:before {\n  content: "\\f2ed";\n}\n* .fa-tree:before {\n  content: "\\f1bb";\n}\n* .fa-trello:before {\n  content: "\\f181";\n}\n* .fa-tripadvisor:before {\n  content: "\\f262";\n}\n* .fa-trophy:before {\n  content: "\\f091";\n}\n* .fa-truck:before {\n  content: "\\f0d1";\n}\n* .fa-truck-loading:before {\n  content: "\\f4de";\n}\n* .fa-truck-monster:before {\n  content: "\\f63b";\n}\n* .fa-truck-moving:before {\n  content: "\\f4df";\n}\n* .fa-truck-pickup:before {\n  content: "\\f63c";\n}\n* .fa-tshirt:before {\n  content: "\\f553";\n}\n* .fa-tty:before {\n  content: "\\f1e4";\n}\n* .fa-tumblr:before {\n  content: "\\f173";\n}\n* .fa-tumblr-square:before {\n  content: "\\f174";\n}\n* .fa-tv:before {\n  content: "\\f26c";\n}\n* .fa-twitch:before {\n  content: "\\f1e8";\n}\n* .fa-twitter:before {\n  content: "\\f099";\n}\n* .fa-twitter-square:before {\n  content: "\\f081";\n}\n* .fa-typo3:before {\n  content: "\\f42b";\n}\n* .fa-uber:before {\n  content: "\\f402";\n}\n* .fa-ubuntu:before {\n  content: "\\f7df";\n}\n* .fa-uikit:before {\n  content: "\\f403";\n}\n* .fa-umbrella:before {\n  content: "\\f0e9";\n}\n* .fa-umbrella-beach:before {\n  content: "\\f5ca";\n}\n* .fa-underline:before {\n  content: "\\f0cd";\n}\n* .fa-undo:before {\n  content: "\\f0e2";\n}\n* .fa-undo-alt:before {\n  content: "\\f2ea";\n}\n* .fa-uniregistry:before {\n  content: "\\f404";\n}\n* .fa-universal-access:before {\n  content: "\\f29a";\n}\n* .fa-university:before {\n  content: "\\f19c";\n}\n* .fa-unlink:before {\n  content: "\\f127";\n}\n* .fa-unlock:before {\n  content: "\\f09c";\n}\n* .fa-unlock-alt:before {\n  content: "\\f13e";\n}\n* .fa-untappd:before {\n  content: "\\f405";\n}\n* .fa-upload:before {\n  content: "\\f093";\n}\n* .fa-ups:before {\n  content: "\\f7e0";\n}\n* .fa-usb:before {\n  content: "\\f287";\n}\n* .fa-user:before {\n  content: "\\f007";\n}\n* .fa-user-alt:before {\n  content: "\\f406";\n}\n* .fa-user-alt-slash:before {\n  content: "\\f4fa";\n}\n* .fa-user-astronaut:before {\n  content: "\\f4fb";\n}\n* .fa-user-check:before {\n  content: "\\f4fc";\n}\n* .fa-user-circle:before {\n  content: "\\f2bd";\n}\n* .fa-user-clock:before {\n  content: "\\f4fd";\n}\n* .fa-user-cog:before {\n  content: "\\f4fe";\n}\n* .fa-user-edit:before {\n  content: "\\f4ff";\n}\n* .fa-user-friends:before {\n  content: "\\f500";\n}\n* .fa-user-graduate:before {\n  content: "\\f501";\n}\n* .fa-user-injured:before {\n  content: "\\f728";\n}\n* .fa-user-lock:before {\n  content: "\\f502";\n}\n* .fa-user-md:before {\n  content: "\\f0f0";\n}\n* .fa-user-minus:before {\n  content: "\\f503";\n}\n* .fa-user-ninja:before {\n  content: "\\f504";\n}\n* .fa-user-plus:before {\n  content: "\\f234";\n}\n* .fa-user-secret:before {\n  content: "\\f21b";\n}\n* .fa-user-shield:before {\n  content: "\\f505";\n}\n* .fa-user-slash:before {\n  content: "\\f506";\n}\n* .fa-user-tag:before {\n  content: "\\f507";\n}\n* .fa-user-tie:before {\n  content: "\\f508";\n}\n* .fa-user-times:before {\n  content: "\\f235";\n}\n* .fa-users:before {\n  content: "\\f0c0";\n}\n* .fa-users-cog:before {\n  content: "\\f509";\n}\n* .fa-usps:before {\n  content: "\\f7e1";\n}\n* .fa-ussunnah:before {\n  content: "\\f407";\n}\n* .fa-utensil-spoon:before {\n  content: "\\f2e5";\n}\n* .fa-utensils:before {\n  content: "\\f2e7";\n}\n* .fa-vaadin:before {\n  content: "\\f408";\n}\n* .fa-vector-square:before {\n  content: "\\f5cb";\n}\n* .fa-venus:before {\n  content: "\\f221";\n}\n* .fa-venus-double:before {\n  content: "\\f226";\n}\n* .fa-venus-mars:before {\n  content: "\\f228";\n}\n* .fa-viacoin:before {\n  content: "\\f237";\n}\n* .fa-viadeo:before {\n  content: "\\f2a9";\n}\n* .fa-viadeo-square:before {\n  content: "\\f2aa";\n}\n* .fa-vial:before {\n  content: "\\f492";\n}\n* .fa-vials:before {\n  content: "\\f493";\n}\n* .fa-viber:before {\n  content: "\\f409";\n}\n* .fa-video:before {\n  content: "\\f03d";\n}\n* .fa-video-slash:before {\n  content: "\\f4e2";\n}\n* .fa-vihara:before {\n  content: "\\f6a7";\n}\n* .fa-vimeo:before {\n  content: "\\f40a";\n}\n* .fa-vimeo-square:before {\n  content: "\\f194";\n}\n* .fa-vimeo-v:before {\n  content: "\\f27d";\n}\n* .fa-vine:before {\n  content: "\\f1ca";\n}\n* .fa-vk:before {\n  content: "\\f189";\n}\n* .fa-vnv:before {\n  content: "\\f40b";\n}\n* .fa-volleyball-ball:before {\n  content: "\\f45f";\n}\n* .fa-volume-down:before {\n  content: "\\f027";\n}\n* .fa-volume-mute:before {\n  content: "\\f6a9";\n}\n* .fa-volume-off:before {\n  content: "\\f026";\n}\n* .fa-volume-up:before {\n  content: "\\f028";\n}\n* .fa-vote-yea:before {\n  content: "\\f772";\n}\n* .fa-vr-cardboard:before {\n  content: "\\f729";\n}\n* .fa-vuejs:before {\n  content: "\\f41f";\n}\n* .fa-walking:before {\n  content: "\\f554";\n}\n* .fa-wallet:before {\n  content: "\\f555";\n}\n* .fa-warehouse:before {\n  content: "\\f494";\n}\n* .fa-water:before {\n  content: "\\f773";\n}\n* .fa-weebly:before {\n  content: "\\f5cc";\n}\n* .fa-weibo:before {\n  content: "\\f18a";\n}\n* .fa-weight:before {\n  content: "\\f496";\n}\n* .fa-weight-hanging:before {\n  content: "\\f5cd";\n}\n* .fa-weixin:before {\n  content: "\\f1d7";\n}\n* .fa-whatsapp:before {\n  content: "\\f232";\n}\n* .fa-whatsapp-square:before {\n  content: "\\f40c";\n}\n* .fa-wheelchair:before {\n  content: "\\f193";\n}\n* .fa-whmcs:before {\n  content: "\\f40d";\n}\n* .fa-wifi:before {\n  content: "\\f1eb";\n}\n* .fa-wikipedia-w:before {\n  content: "\\f266";\n}\n* .fa-wind:before {\n  content: "\\f72e";\n}\n* .fa-window-close:before {\n  content: "\\f410";\n}\n* .fa-window-maximize:before {\n  content: "\\f2d0";\n}\n* .fa-window-minimize:before {\n  content: "\\f2d1";\n}\n* .fa-window-restore:before {\n  content: "\\f2d2";\n}\n* .fa-windows:before {\n  content: "\\f17a";\n}\n* .fa-wine-bottle:before {\n  content: "\\f72f";\n}\n* .fa-wine-glass:before {\n  content: "\\f4e3";\n}\n* .fa-wine-glass-alt:before {\n  content: "\\f5ce";\n}\n* .fa-wix:before {\n  content: "\\f5cf";\n}\n* .fa-wizards-of-the-coast:before {\n  content: "\\f730";\n}\n* .fa-wolf-pack-battalion:before {\n  content: "\\f514";\n}\n* .fa-won-sign:before {\n  content: "\\f159";\n}\n* .fa-wordpress:before {\n  content: "\\f19a";\n}\n* .fa-wordpress-simple:before {\n  content: "\\f411";\n}\n* .fa-wpbeginner:before {\n  content: "\\f297";\n}\n* .fa-wpexplorer:before {\n  content: "\\f2de";\n}\n* .fa-wpforms:before {\n  content: "\\f298";\n}\n* .fa-wpressr:before {\n  content: "\\f3e4";\n}\n* .fa-wrench:before {\n  content: "\\f0ad";\n}\n* .fa-x-ray:before {\n  content: "\\f497";\n}\n* .fa-xbox:before {\n  content: "\\f412";\n}\n* .fa-xing:before {\n  content: "\\f168";\n}\n* .fa-xing-square:before {\n  content: "\\f169";\n}\n* .fa-y-combinator:before {\n  content: "\\f23b";\n}\n* .fa-yahoo:before {\n  content: "\\f19e";\n}\n* .fa-yandex:before {\n  content: "\\f413";\n}\n* .fa-yandex-international:before {\n  content: "\\f414";\n}\n* .fa-yarn:before {\n  content: "\\f7e3";\n}\n* .fa-yelp:before {\n  content: "\\f1e9";\n}\n* .fa-yen-sign:before {\n  content: "\\f157";\n}\n* .fa-yin-yang:before {\n  content: "\\f6ad";\n}\n* .fa-yoast:before {\n  content: "\\f2b1";\n}\n* .fa-youtube:before {\n  content: "\\f167";\n}\n* .fa-youtube-square:before {\n  content: "\\f431";\n}\n* .fa-zhihu:before {\n  content: "\\f63f";\n}\n* .sr-only {\n  border: 0;\n  clip: rect(0, 0, 0, 0);\n  height: 1px;\n  margin: -1px;\n  overflow: hidden;\n  padding: 0;\n  position: absolute;\n  width: 1px;\n}\n* .sr-only-focusable:active, * .sr-only-focusable:focus {\n  clip: auto;\n  height: auto;\n  margin: 0;\n  overflow: visible;\n  position: static;\n  width: auto;\n}\n\n@font-face {\n  font-family: "Font Awesome 5 Free";\n  font-style: normal;\n  font-weight: 900;\n  src: url("./assets/fonts/webfonts/fa-solid-900.woff2") format("woff2"), url("./assets/fonts/webfonts/fa-solid-900.woff") format("woff");\n}\n.fa,\n.fas {\n  font-family: "Font Awesome 5 Free";\n  font-weight: 900;\n}\n\n@font-face {\n  font-family: "pficon";\n  src: url("./assets/pficon/pficon.woff2") format("woff2"), url("./assets/pficon/pficon.woff") format("woff");\n}\n.pf-icon-zone:before, .pf-icon-warning-triangle:before, .pf-icon-volume:before, .pf-icon-virtual-machine:before, .pf-icon-users:before, .pf-icon-user:before, .pf-icon-unplugged:before, .pf-icon-unlocked:before, .pf-icon-unknown:before, .pf-icon-trend-up:before, .pf-icon-trend-down:before, .pf-icon-topology:before, .pf-icon-thumb-tack:before, .pf-icon-tenant:before, .pf-icon-task:before, .pf-icon-storage-domain:before, .pf-icon-spinner2:before, .pf-icon-spinner:before, .pf-icon-services:before, .pf-icon-service:before, .pf-icon-service-catalog:before, .pf-icon-server:before, .pf-icon-server-group:before, .pf-icon-security:before, .pf-icon-screen:before, .pf-icon-save:before, .pf-icon-running:before, .pf-icon-resources-full:before, .pf-icon-resources-empty:before, .pf-icon-resources-almost-full:before, .pf-icon-resources-almost-empty:before, .pf-icon-resource-pool:before, .pf-icon-repository:before, .pf-icon-replicator:before, .pf-icon-remove2:before, .pf-icon-registry:before, .pf-icon-regions:before, .pf-icon-rebooting:before, .pf-icon-rebalance:before, .pf-icon-project:before, .pf-icon-process-automation:before, .pf-icon-private:before, .pf-icon-print:before, .pf-icon-port:before, .pf-icon-plugged:before, .pf-icon-pficon-vcenter:before, .pf-icon-pficon-template:before, .pf-icon-pficon-sort-common-desc:before, .pf-icon-pficon-sort-common-asc:before, .pf-icon-pficon-satellite:before, .pf-icon-pficon-network-range:before, .pf-icon-pficon-history:before, .pf-icon-pficon-dragdrop:before, .pf-icon-pending:before, .pf-icon-paused:before, .pf-icon-panel-open:before, .pf-icon-panel-close:before, .pf-icon-package:before, .pf-icon-os-image:before, .pf-icon-orders:before, .pf-icon-optimize:before, .pf-icon-openstack:before, .pf-icon-openshift:before, .pf-icon-open-drawer-right:before, .pf-icon-on:before, .pf-icon-on-running:before, .pf-icon-ok:before, .pf-icon-off:before, .pf-icon-not-started:before, .pf-icon-new-process:before, .pf-icon-network:before, .pf-icon-namespaces:before, .pf-icon-monitoring:before, .pf-icon-module:before, .pf-icon-migration:before, .pf-icon-middleware:before, .pf-icon-messages:before, .pf-icon-memory:before, .pf-icon-maintenance:before, .pf-icon-locked:before, .pf-icon-key:before, .pf-icon-integration:before, .pf-icon-infrastructure:before, .pf-icon-info:before, .pf-icon-in-progress:before, .pf-icon-import:before, .pf-icon-home:before, .pf-icon-history:before, .pf-icon-help:before, .pf-icon-globe-route:before, .pf-icon-folder-open:before, .pf-icon-folder-close:before, .pf-icon-flavor:before, .pf-icon-filter:before, .pf-icon-export:before, .pf-icon-error-circle-o:before, .pf-icon-equalizer:before, .pf-icon-enterprise:before, .pf-icon-enhancement:before, .pf-icon-edit:before, .pf-icon-domain:before, .pf-icon-disconnected:before, .pf-icon-degraded:before, .pf-icon-data-source:before, .pf-icon-data-sink:before, .pf-icon-data-processor:before, .pf-icon-critical-risk:before, .pf-icon-cpu:before, .pf-icon-container-node:before, .pf-icon-connected:before, .pf-icon-cluster:before, .pf-icon-cloud-tenant:before, .pf-icon-cloud-security:before, .pf-icon-close:before, .pf-icon-chat:before, .pf-icon-catalog:before, .pf-icon-bundle:before, .pf-icon-builder-image:before, .pf-icon-build:before, .pf-icon-blueprint:before, .pf-icon-bell:before, .pf-icon-automation:before, .pf-icon-attention-bell:before, .pf-icon-asleep:before, .pf-icon-arrow:before, .pf-icon-applications:before, .pf-icon-ansible-tower:before, .pf-icon-add-circle-o:before {\n  font-family: "pficon";\n  -webkit-font-smoothing: antialiased;\n  -moz-osx-font-smoothing: grayscale;\n  font-style: normal;\n  font-variant: normal;\n  font-weight: normal;\n  text-decoration: none;\n  text-transform: none;\n}\n\n.pf-icon-add-circle-o:before {\n  content: "\\e61b";\n}\n\n.pf-icon-ansible-tower:before {\n  content: "\\e950";\n}\n\n.pf-icon-applications:before {\n  content: "\\e936";\n}\n\n.pf-icon-arrow:before {\n  content: "\\e929";\n}\n\n.pf-icon-asleep:before {\n  content: "\\e92e";\n}\n\n.pf-icon-attention-bell:before {\n  content: "\\e951";\n}\n\n.pf-icon-automation:before {\n  content: "\\e937";\n}\n\n.pf-icon-bell:before {\n  content: "\\e952";\n}\n\n.pf-icon-blueprint:before {\n  content: "\\e915";\n}\n\n.pf-icon-build:before {\n  content: "\\e902";\n}\n\n.pf-icon-builder-image:before {\n  content: "\\e800";\n}\n\n.pf-icon-bundle:before {\n  content: "\\e918";\n}\n\n.pf-icon-catalog:before {\n  content: "\\e953";\n}\n\n.pf-icon-chat:before {\n  content: "\\e954";\n}\n\n.pf-icon-close:before {\n  content: "\\e60b";\n}\n\n.pf-icon-cloud-security:before {\n  content: "\\e903";\n}\n\n.pf-icon-cloud-tenant:before {\n  content: "\\e904";\n}\n\n.pf-icon-cluster:before {\n  content: "\\e620";\n}\n\n.pf-icon-connected:before {\n  content: "\\e938";\n}\n\n.pf-icon-container-node:before {\n  content: "\\e621";\n}\n\n.pf-icon-cpu:before {\n  content: "\\e927";\n}\n\n.pf-icon-critical-risk:before {\n  content: "\\e976";\n}\n\n.pf-icon-data-processor:before {\n  content: "\\e97b";\n}\n\n.pf-icon-data-sink:before {\n  content: "\\e978";\n}\n\n.pf-icon-data-source:before {\n  content: "\\e979";\n}\n\n.pf-icon-degraded:before {\n  content: "\\e91b";\n}\n\n.pf-icon-disconnected:before {\n  content: "\\e955";\n}\n\n.pf-icon-domain:before {\n  content: "\\e919";\n}\n\n.pf-icon-edit:before {\n  content: "\\e60a";\n}\n\n.pf-icon-enhancement:before {\n  content: "\\e93a";\n}\n\n.pf-icon-enterprise:before {\n  content: "\\e906";\n}\n\n.pf-icon-equalizer:before {\n  content: "\\e956";\n}\n\n.pf-icon-error-circle-o:before {\n  content: "\\e926";\n}\n\n.pf-icon-export:before {\n  content: "\\e616";\n}\n\n.pf-icon-filter:before {\n  content: "\\e943";\n}\n\n.pf-icon-flavor:before {\n  content: "\\e957";\n}\n\n.pf-icon-folder-close:before {\n  content: "\\e607";\n}\n\n.pf-icon-folder-open:before {\n  content: "\\e606";\n}\n\n.pf-icon-globe-route:before {\n  content: "\\e958";\n}\n\n.pf-icon-help:before {\n  content: "\\e605";\n}\n\n.pf-icon-history:before {\n  content: "\\e617";\n}\n\n.pf-icon-home:before {\n  content: "\\e618";\n}\n\n.pf-icon-import:before {\n  content: "\\e615";\n}\n\n.pf-icon-in-progress:before {\n  content: "\\e933";\n}\n\n.pf-icon-info:before {\n  content: "\\e92b";\n}\n\n.pf-icon-infrastructure:before {\n  content: "\\e93d";\n}\n\n.pf-icon-integration:before {\n  content: "\\e948";\n}\n\n.pf-icon-key:before {\n  content: "\\e924";\n}\n\n.pf-icon-locked:before {\n  content: "\\e923";\n}\n\n.pf-icon-maintenance:before {\n  content: "\\e932";\n}\n\n.pf-icon-memory:before {\n  content: "\\e908";\n}\n\n.pf-icon-messages:before {\n  content: "\\e603";\n}\n\n.pf-icon-middleware:before {\n  content: "\\e917";\n}\n\n.pf-icon-migration:before {\n  content: "\\e931";\n}\n\n.pf-icon-module:before {\n  content: "\\e959";\n}\n\n.pf-icon-monitoring:before {\n  content: "\\e95a";\n}\n\n.pf-icon-namespaces:before {\n  content: "\\e95b";\n}\n\n.pf-icon-network:before {\n  content: "\\e909";\n}\n\n.pf-icon-new-process:before {\n  content: "\\e95c";\n}\n\n.pf-icon-not-started:before {\n  content: "\\e95d";\n}\n\n.pf-icon-off:before {\n  content: "\\e92d";\n}\n\n.pf-icon-ok:before {\n  content: "\\e602";\n}\n\n.pf-icon-on-running:before {\n  content: "\\e925";\n}\n\n.pf-icon-on:before {\n  content: "\\e92c";\n}\n\n.pf-icon-open-drawer-right:before {\n  content: "\\e977";\n}\n\n.pf-icon-openshift:before {\n  content: "\\e95e";\n}\n\n.pf-icon-openstack:before {\n  content: "\\e95f";\n}\n\n.pf-icon-optimize:before {\n  content: "\\e93e";\n}\n\n.pf-icon-orders:before {\n  content: "\\e93f";\n}\n\n.pf-icon-os-image:before {\n  content: "\\e960";\n}\n\n.pf-icon-package:before {\n  content: "\\e961";\n}\n\n.pf-icon-panel-close:before {\n  content: "\\e962";\n}\n\n.pf-icon-panel-open:before {\n  content: "\\e963";\n}\n\n.pf-icon-paused:before {\n  content: "\\e92f";\n}\n\n.pf-icon-pending:before {\n  content: "\\e964";\n}\n\n.pf-icon-pficon-dragdrop:before {\n  content: "\\e965";\n}\n\n.pf-icon-pficon-history:before {\n  content: "\\e966";\n}\n\n.pf-icon-pficon-network-range:before {\n  content: "\\e967";\n}\n\n.pf-icon-pficon-satellite:before {\n  content: "\\e968";\n}\n\n.pf-icon-pficon-sort-common-asc:before {\n  content: "\\e94e";\n}\n\n.pf-icon-pficon-sort-common-desc:before {\n  content: "\\e94f";\n}\n\n.pf-icon-pficon-template:before {\n  content: "\\e94c";\n}\n\n.pf-icon-pficon-vcenter:before {\n  content: "\\e969";\n}\n\n.pf-icon-plugged:before {\n  content: "\\e96a";\n}\n\n.pf-icon-port:before {\n  content: "\\e96b";\n}\n\n.pf-icon-print:before {\n  content: "\\e612";\n}\n\n.pf-icon-private:before {\n  content: "\\e914";\n}\n\n.pf-icon-process-automation:before {\n  content: "\\e949";\n}\n\n.pf-icon-project:before {\n  content: "\\e96c";\n}\n\n.pf-icon-rebalance:before {\n  content: "\\e91c";\n}\n\n.pf-icon-rebooting:before {\n  content: "\\e96d";\n}\n\n.pf-icon-regions:before {\n  content: "\\e90a";\n}\n\n.pf-icon-registry:before {\n  content: "\\e623";\n}\n\n.pf-icon-remove2:before {\n  content: "\\e96e";\n}\n\n.pf-icon-replicator:before {\n  content: "\\e624";\n}\n\n.pf-icon-repository:before {\n  content: "\\e90b";\n}\n\n.pf-icon-resource-pool:before {\n  content: "\\e90c";\n}\n\n.pf-icon-resources-almost-empty:before {\n  content: "\\e91d";\n}\n\n.pf-icon-resources-almost-full:before {\n  content: "\\e912";\n}\n\n.pf-icon-resources-empty:before {\n  content: "\\e96f";\n}\n\n.pf-icon-resources-full:before {\n  content: "\\e913";\n}\n\n.pf-icon-running:before {\n  content: "\\e970";\n}\n\n.pf-icon-save:before {\n  content: "\\e601";\n}\n\n.pf-icon-screen:before {\n  content: "\\e971";\n}\n\n.pf-icon-security:before {\n  content: "\\e946";\n}\n\n.pf-icon-server-group:before {\n  content: "\\e91a";\n}\n\n.pf-icon-server:before {\n  content: "\\e90d";\n}\n\n.pf-icon-service-catalog:before {\n  content: "\\e972";\n}\n\n.pf-icon-service:before {\n  content: "\\e61e";\n}\n\n.pf-icon-services:before {\n  content: "\\e947";\n}\n\n.pf-icon-spinner:before {\n  content: "\\e973";\n}\n\n.pf-icon-spinner2:before {\n  content: "\\e613";\n}\n\n.pf-icon-storage-domain:before {\n  content: "\\e90e";\n}\n\n.pf-icon-task:before {\n  content: "\\e974";\n}\n\n.pf-icon-tenant:before {\n  content: "\\e916";\n}\n\n.pf-icon-thumb-tack:before {\n  content: "\\e920";\n}\n\n.pf-icon-topology:before {\n  content: "\\e608";\n}\n\n.pf-icon-trend-down:before {\n  content: "\\e900";\n}\n\n.pf-icon-trend-up:before {\n  content: "\\e901";\n}\n\n.pf-icon-unknown:before {\n  content: "\\e935";\n}\n\n.pf-icon-unlocked:before {\n  content: "\\e922";\n}\n\n.pf-icon-unplugged:before {\n  content: "\\e942";\n}\n\n.pf-icon-user:before {\n  content: "\\e91e";\n}\n\n.pf-icon-users:before {\n  content: "\\e91f";\n}\n\n.pf-icon-virtual-machine:before {\n  content: "\\e90f";\n}\n\n.pf-icon-volume:before {\n  content: "\\e910";\n}\n\n.pf-icon-warning-triangle:before {\n  content: "\\e975";\n}\n\n.pf-icon-zone:before {\n  content: "\\e911";\n}';

// src/common/styles/authentik.css
var authentik_default = ":root {\n    --ak-accent: #fd4b2d;\n\n    --ak-dark-foreground: #fafafa;\n    --ak-dark-foreground-darker: #bebebe;\n    --ak-dark-foreground-link: #5a5cb9;\n    --ak-dark-background: #18191a;\n    --ak-dark-background-darker: #000000;\n    --ak-dark-background-light: #1c1e21;\n    --ak-dark-background-light-ish: #212427;\n    --ak-dark-background-lighter: #2b2e33;\n\n    /* PatternFly likes to override global variables for some reason */\n    --ak-global--Color--100: var(--pf-global--Color--100);\n\n    /* Minimum width after which the sidebar becomes automatic */\n    --ak-sidebar--minimum-auto-width: 80rem;\n}\n\n::-webkit-scrollbar {\n    width: 5px;\n    height: 5px;\n    background-color: transparent;\n}\n::-webkit-scrollbar-thumb {\n    background-color: var(--ak-accent);\n}\n::-webkit-scrollbar-track {\n    background-color: transparent;\n}\n::-webkit-scrollbar-corner {\n    background-color: transparent;\n}\n\nhtml {\n    --pf-c-nav__link--PaddingTop: 0.5rem;\n    --pf-c-nav__link--PaddingRight: 0.5rem;\n    --pf-c-nav__link--PaddingBottom: 0.5rem;\n    --pf-c-nav__link--PaddingLeft: 0.5rem;\n}\n\nhtml > form > input {\n    position: absolute;\n    top: -2000px;\n    left: -2000px;\n}\n\n.pf-icon {\n    display: inline-block;\n    font-style: normal;\n    font-variant: normal;\n    text-rendering: auto;\n    line-height: 1;\n    vertical-align: middle;\n}\n\n.pf-c-page__header {\n    z-index: 0;\n    background-color: var(--ak-dark-background-light);\n    box-shadow: var(--pf-global--BoxShadow--lg-bottom);\n}\n\n/*****************************\n* Login adjustments\n*****************************/\n/* Ensure card is displayed on small screens */\n.pf-c-login__main {\n    display: block;\n    position: relative;\n    width: 100%;\n}\n.ak-login-container {\n    height: calc(100vh - var(--pf-global--spacer--lg) - var(--pf-global--spacer--lg));\n    width: 35rem;\n    display: flex;\n    flex-direction: column;\n    justify-content: space-evenly;\n}\n.pf-c-login__header {\n    flex-grow: 1;\n}\n.pf-c-login__footer {\n    flex-grow: 2;\n    display: flex;\n    justify-content: end;\n    flex-direction: column;\n}\n.pf-c-login__footer ul.pf-c-list.pf-m-inline {\n    justify-content: center;\n    padding: 2rem 0;\n}\n/*****************************\n* End Login adjustments\n*****************************/\n\n.pf-c-content h1 {\n    display: flex;\n    align-items: flex-start;\n}\n.pf-c-content h1 i {\n    font-style: normal;\n}\n.pf-c-content h1 :first-child {\n    margin-right: var(--pf-global--spacer--sm);\n}\n\n/* ensure background on non-flow pages match */\n.pf-c-background-image::before {\n    background-image: var(--ak-flow-background);\n    background-position: center;\n}\n\n.pf-m-success {\n    color: var(--pf-global--success-color--100) !important;\n}\n.pf-m-warning {\n    color: var(--pf-global--warning-color--100);\n}\n.pf-m-danger {\n    color: var(--pf-global--danger-color--100);\n}\n\n.pf-c-description-list__description .pf-c-button {\n    margin-right: 6px;\n    margin-bottom: 6px;\n}\n\n/* Flow-card adjustments for static pages */\n.pf-c-brand {\n    padding-top: calc(\n        var(--pf-c-login__main-footer-links--PaddingTop) +\n            var(--pf-c-login__main-footer-links--PaddingBottom) +\n            var(--pf-c-login__main-body--PaddingBottom)\n    );\n    max-height: 9rem;\n}\n\n.ak-brand {\n    display: flex;\n    justify-content: center;\n    width: 100%;\n}\n.ak-brand img {\n    padding: 0 2rem;\n    max-height: inherit;\n}\n\n@media (min-height: 60rem) {\n    .pf-c-login.stacked .pf-c-login__main {\n        margin-top: 13rem;\n    }\n}\n\n.pf-c-data-list {\n    padding-inline-start: 0;\n}\n";

// src/common/styles/theme-dark.css
var theme_dark_default = ':root {\n    --pf-global--Color--100: var(--ak-dark-foreground) !important;\n    --ak-global--Color--100: var(--ak-dark-foreground) !important;\n    --pf-c-page__main-section--m-light--BackgroundColor: var(--ak-dark-background-darker);\n    --pf-global--link--Color: var(--ak-dark-foreground-link) !important;\n}\nbody {\n    background-color: var(--ak-dark-background) !important;\n}\n.pf-c-radio {\n    --pf-c-radio__label--Color: var(--ak-dark-foreground);\n}\n/* Global page background colour */\n.pf-c-page {\n    --pf-c-page--BackgroundColor: var(--ak-dark-background);\n}\n.pf-c-drawer__content {\n    --pf-c-drawer__content--BackgroundColor: var(--ak-dark-background);\n}\n.pf-c-title {\n    color: var(--ak-dark-foreground);\n}\n.pf-u-mb-xl {\n    color: var(--ak-dark-foreground);\n}\n/* Header sections */\n.pf-c-page__main-section {\n    --pf-c-page__main-section--BackgroundColor: var(--ak-dark-background);\n}\n.sidebar-trigger,\n.notification-trigger {\n    background-color: transparent !important;\n}\n.pf-c-page__main-section.pf-m-light {\n    background-color: transparent;\n}\n.pf-c-content {\n    color: var(--ak-dark-foreground);\n}\n/* Card */\n.pf-c-card {\n    --pf-c-card--BackgroundColor: var(--ak-dark-background-light);\n    color: var(--ak-dark-foreground);\n}\n.pf-c-card__title,\n.pf-c-card__body {\n    color: var(--ak-dark-foreground);\n}\n.pf-c-toolbar {\n    --pf-c-toolbar--BackgroundColor: var(--ak-dark-background-light);\n}\n.pf-c-pagination.pf-m-bottom {\n    background-color: var(--ak-dark-background-light);\n}\n/* table */\n.pf-c-table {\n    --pf-c-table--BackgroundColor: var(--ak-dark-background-light);\n    --pf-c-table--BorderColor: var(--ak-dark-background-lighter);\n    --pf-c-table--cell--Color: var(--ak-dark-foreground);\n    --pf-c-table--tr--m-hoverable--hover--BackgroundColor: var(--ak-dark-background-light-ish);\n    --pf-c-table--tr--m-hoverable--active--BackgroundColor: var(--ak-dark-background-lighter);\n}\n.pf-c-table__text {\n    color: var(--ak-dark-foreground);\n}\n.pf-c-table__sort:not(.pf-m-selected) .pf-c-table__button .pf-c-table__text {\n    color: var(--ak-dark-foreground) !important;\n}\n.pf-c-table__sort-indicator i {\n    color: var(--ak-dark-foreground) !important;\n}\n.pf-c-table__expandable-row.pf-m-expanded {\n    --pf-c-table__expandable-row--m-expanded--BorderBottomColor: var(--ak-dark-background-lighter);\n}\n/* tabs */\n.pf-c-tabs {\n    background-color: transparent;\n}\n.pf-c-tabs.pf-m-box.pf-m-vertical .pf-c-tabs__list::before {\n    border-color: transparent;\n}\n.pf-c-tabs.pf-m-box .pf-c-tabs__item.pf-m-current:first-child .pf-c-tabs__link::before {\n    border-color: transparent;\n}\n.pf-c-tabs__link::before {\n    border-color: transparent;\n}\n.pf-c-tabs__item.pf-m-current {\n    --pf-c-tabs__link--after--BorderColor: var(--ak-accent);\n}\n.pf-c-tabs__link {\n    --pf-c-tabs__link--Color: var(--ak-dark-foreground);\n}\n.pf-c-tabs.pf-m-vertical .pf-c-tabs__link {\n    background-color: transparent;\n}\n/* table, on mobile */\n@media screen and (max-width: 1200px) {\n    .pf-m-grid-xl.pf-c-table tbody:first-of-type {\n        border-top-color: var(--ak-dark-background);\n    }\n    .pf-m-grid-xl.pf-c-table tr:not(.pf-c-table__expandable-row) {\n        border-bottom-color: var(--ak-dark-background);\n    }\n}\n/* class for pagination text */\n.pf-c-options-menu__toggle {\n    color: var(--ak-dark-foreground);\n}\n/* table icon used for expanding rows */\n.pf-c-table__toggle-icon {\n    color: var(--ak-dark-foreground);\n}\n/* expandable elements */\n.pf-c-expandable-section__toggle-text {\n    color: var(--ak-dark-foreground);\n}\n.pf-c-expandable-section__toggle-icon {\n    color: var(--ak-dark-foreground);\n}\n.pf-c-expandable-section.pf-m-display-lg {\n    background-color: var(--ak-dark-background-light-ish);\n}\n/* header for form group */\n.pf-c-form__field-group-header-title-text {\n    color: var(--ak-dark-foreground);\n}\n.pf-c-form__field-group {\n    border-bottom: 0;\n}\n/* inputs */\noptgroup,\noption {\n    color: var(--ak-dark-foreground);\n}\nselect[multiple] optgroup:checked,\nselect[multiple] option:checked {\n    color: var(--ak-dark-background);\n}\n.pf-c-input-group {\n    --pf-c-input-group--BackgroundColor: transparent;\n}\n.pf-c-form-control {\n    --pf-c-form-control--BorderTopColor: transparent !important;\n    --pf-c-form-control--BorderRightColor: transparent !important;\n    --pf-c-form-control--BorderLeftColor: transparent !important;\n    --pf-global--BackgroundColor--100: var(--ak-dark-background-light) !important;\n    --pf-c-form-control--BackgroundColor: var(--ak-dark-background-light);\n    --pf-c-form-control--Color: var(--ak-dark-foreground) !important;\n}\n.pf-c-form-control:disabled {\n    background-color: var(--ak-dark-background-light);\n}\n.pf-c-form-control[readonly] {\n    background-color: var(--ak-dark-background-light);\n}\n.pf-c-switch__input:checked ~ .pf-c-switch__label {\n    --pf-c-switch__input--checked__label--Color: var(--ak-dark-foreground);\n}\ninput[type="datetime-local"]::-webkit-calendar-picker-indicator,\ninput[type="date"]::-webkit-calendar-picker-indicator {\n    filter: invert(1);\n}\n/* select toggle */\n.pf-c-select__toggle::before {\n    --pf-c-select__toggle--before--BorderTopColor: var(--ak-dark-background-lighter);\n    --pf-c-select__toggle--before--BorderRightColor: var(--ak-dark-background-lighter);\n    --pf-c-select__toggle--before--BorderLeftColor: var(--ak-dark-background-lighter);\n}\n.pf-c-select__toggle.pf-m-typeahead {\n    --pf-c-select__toggle--BackgroundColor: var(--ak-dark-background-light);\n}\n.pf-c-select__menu {\n    --pf-c-select__menu--BackgroundColor: var(--ak-dark-background-light-ish);\n    color: var(--ak-dark-foreground);\n}\n.pf-c-select__menu-item {\n    color: var(--ak-dark-foreground);\n}\n.pf-c-select__menu-wrapper:hover,\n.pf-c-select__menu-item:hover {\n    --pf-c-select__menu-item--hover--BackgroundColor: var(--ak-dark-background-lighter);\n}\n.pf-c-select__menu-wrapper:focus-within,\n.pf-c-select__menu-wrapper.pf-m-focus,\n.pf-c-select__menu-item:focus,\n.pf-c-select__menu-item.pf-m-focus {\n    --pf-c-select__menu-item--focus--BackgroundColor: var(--ak-dark-background-light-ish);\n}\n.pf-c-button:disabled {\n    color: var(--ak-dark-background-lighter);\n}\n.pf-c-button.pf-m-plain:hover {\n    color: var(--ak-dark-foreground);\n}\n.pf-c-button.pf-m-control {\n    --pf-c-button--after--BorderColor: var(--ak-dark-background-lighter)\n        var(--ak-dark-background-lighter) var(--pf-c-button--m-control--after--BorderBottomColor)\n        var(--ak-dark-background-lighter);\n    background-color: var(--ak-dark-background-light);\n    color: var(--ak-dark-foreground);\n}\n.pf-m-tertiary,\n.pf-c-button.pf-m-tertiary {\n    --pf-c-button--after--BorderColor: var(--ak-dark-foreground-darker);\n    color: var(--ak-dark-foreground-darker);\n}\n.pf-m-tertiary:hover,\n.pf-c-button.pf-m-tertiary:hover {\n    --pf-c-button--after--BorderColor: var(--ak-dark-background-lighter);\n}\n.pf-c-form__label-text {\n    color: var(--ak-dark-foreground);\n}\n.pf-c-check__label {\n    color: var(--ak-dark-foreground);\n}\n.pf-c-dropdown__toggle::before {\n    border-color: transparent;\n}\n.pf-c-dropdown__menu {\n    --pf-c-dropdown__menu--BackgroundColor: var(--ak-dark-background);\n}\n.pf-c-dropdown__menu-item {\n    --pf-c-dropdown__menu-item--BackgroundColor: var(--ak-dark-background);\n    --pf-c-dropdown__menu-item--Color: var(--ak-dark-foreground);\n}\n.pf-c-dropdown__menu-item:hover,\n.pf-c-dropdown__menu-item:focus {\n    --pf-c-dropdown__menu-item--BackgroundColor: var(--ak-dark-background-light-ish);\n    --pf-c-dropdown__menu-item--Color: var(--ak-dark-foreground);\n}\n.pf-c-toggle-group__button {\n    color: var(--ak-dark-foreground) !important;\n}\n.pf-c-toggle-group__button:not(.pf-m-selected) {\n    background-color: var(--ak-dark-background-light) !important;\n}\n.pf-c-toggle-group__button.pf-m-selected {\n    color: var(--ak-dark-foreground) !important;\n    background-color: var(--pf-global--primary-color--100) !important;\n}\n/* inputs help text */\n.pf-c-form__helper-text:not(.pf-m-error) {\n    color: var(--ak-dark-foreground);\n}\n/* modal */\n.pf-c-modal-box,\n.pf-c-modal-box__header,\n.pf-c-modal-box__footer,\n.pf-c-modal-box__body {\n    background-color: var(--ak-dark-background);\n}\n/* sidebar */\n.pf-c-nav {\n    background-color: var(--ak-dark-background-light);\n}\n/* flows */\n.pf-c-login__main {\n    --pf-c-login__main--BackgroundColor: var(--ak-dark-background);\n}\n.pf-c-login__main-body,\n.pf-c-login__main-header,\n.pf-c-login__main-header-desc {\n    color: var(--ak-dark-foreground);\n}\n.pf-c-login__main-footer-links-item img,\n.pf-c-login__main-footer-links-item .fas {\n    filter: invert(1);\n}\n.pf-c-login__main-footer-band {\n    --pf-c-login__main-footer-band--BackgroundColor: var(--ak-dark-background-lighter);\n    color: var(--ak-dark-foreground);\n}\n.form-control-static {\n    color: var(--ak-dark-foreground);\n}\n/* notifications */\n.pf-c-drawer__panel {\n    background-color: var(--ak-dark-background);\n}\n.pf-c-notification-drawer {\n    --pf-c-notification-drawer--BackgroundColor: var(--ak-dark-background);\n}\n.pf-c-notification-drawer__header {\n    background-color: var(--ak-dark-background-lighter);\n    color: var(--ak-dark-foreground);\n}\n.pf-c-notification-drawer__list-item {\n    background-color: var(--ak-dark-background-light-ish);\n    color: var(--ak-dark-foreground);\n    --pf-c-notification-drawer__list-item--BorderBottomColor: var(\n        --ak-dark-background-lighter\n    ) !important;\n}\n/* data list */\n.pf-c-data-list {\n    padding-inline-start: 0;\n    border-top-color: var(--ak-dark-background-lighter);\n}\n.pf-c-data-list__item {\n    --pf-c-data-list__item--BackgroundColor: transparent;\n    --pf-c-data-list__item--BorderBottomColor: var(--ak-dark-background-lighter);\n    color: var(--ak-dark-foreground);\n}\n/* wizards */\n.pf-c-wizard__nav {\n    --pf-c-wizard__nav--BackgroundColor: var(--ak-dark-background-lighter);\n    --pf-c-wizard__nav--lg--BorderRightColor: transparent;\n}\n.pf-c-wizard__main {\n    background-color: var(--ak-dark-background-light-ish);\n}\n.pf-c-wizard__footer {\n    --pf-c-wizard__footer--BackgroundColor: var(--ak-dark-background-light-ish);\n}\n.pf-c-wizard__toggle-num,\n.pf-c-wizard__nav-link::before {\n    --pf-c-wizard__nav-link--before--BackgroundColor: transparent;\n}\n/* tree view */\n.pf-c-tree-view__node {\n    --pf-c-tree-view__node--Color: var(--ak-dark-foreground);\n}\n.pf-c-tree-view__node-toggle {\n    --pf-c-tree-view__node-toggle--Color: var(--ak-dark-foreground);\n}\n.pf-c-tree-view__node:focus {\n    --pf-c-tree-view__node--focus--BackgroundColor: var(--ak-dark-background-light-ish);\n}\n.pf-c-tree-view__content:hover,\n.pf-c-tree-view__content:focus-within {\n    --pf-c-tree-view__node--hover--BackgroundColor: var(--ak-dark-background-light-ish);\n}\n/* stepper */\n.pf-c-progress-stepper__step-title {\n    --pf-c-progress-stepper__step-title--Color: var(--ak-dark-foreground);\n}\n';

// src/elements/Base.ts
var rootInterface = () => document.body.querySelector("[data-ak-interface-root]") ?? void 0;
var css;
function fetchCustomCSS() {
  if (!css) {
    css = Promise.all(
      Array.of(...document.head.querySelectorAll("link[data-inject]")).map(
        (link) => {
          return fetch(link.href).then((res) => {
            return res.text();
          }).finally(() => {
            return "";
          });
        }
      )
    );
  }
  return css;
}
var QUERY_MEDIA_COLOR_LIGHT = "(prefers-color-scheme: light)";
var AKElement = class extends s {
  get activeTheme() {
    return this._activeTheme;
  }
  constructor() {
    super();
  }
  setInitialStyles(root) {
    const styleRoot = "ShadyDOM" in window ? document : root;
    styleRoot.adoptedStyleSheets = adaptCSS([
      ...styleRoot.adoptedStyleSheets,
      ensureCSSStyleSheet(authentik_default)
    ]);
    this._initTheme(styleRoot);
    this._initCustomCSS(styleRoot);
  }
  createRenderRoot() {
    this.fixElementStyles();
    const root = super.createRenderRoot();
    this.setInitialStyles(root);
    return root;
  }
  async getTheme() {
    return rootInterface()?.getTheme() || UiThemeEnum.Automatic;
  }
  fixElementStyles() {
    this.constructor.elementStyles = this.constructor.elementStyles.map(ensureCSSStyleSheet);
  }
  async _initTheme(root) {
    this._activateTheme(
      root,
      window.matchMedia(QUERY_MEDIA_COLOR_LIGHT).matches ? UiThemeEnum.Light : UiThemeEnum.Dark
    );
    this._applyTheme(root, await this.getTheme());
  }
  async _initCustomCSS(root) {
    const sheets = await fetchCustomCSS();
    sheets.map((css2) => {
      if (css2 === "") {
        return;
      }
      new CSSStyleSheet().replace(css2).then((sheet) => {
        root.adoptedStyleSheets = [...root.adoptedStyleSheets, sheet];
      });
    });
  }
  _applyTheme(root, theme) {
    if (!theme) {
      theme = UiThemeEnum.Automatic;
    }
    if (theme === UiThemeEnum.Automatic) {
      if (!this._mediaMatcher) {
        this._mediaMatcher = window.matchMedia(QUERY_MEDIA_COLOR_LIGHT);
        this._mediaMatcherHandler = (ev) => {
          const theme2 = ev?.matches || this._mediaMatcher?.matches ? UiThemeEnum.Light : UiThemeEnum.Dark;
          this._activateTheme(root, theme2);
        };
        this._mediaMatcher.addEventListener("change", this._mediaMatcherHandler);
      }
      return;
    } else if (this._mediaMatcher && this._mediaMatcherHandler) {
      this._mediaMatcher.removeEventListener("change", this._mediaMatcherHandler);
      this._mediaMatcher = void 0;
    }
    this._activateTheme(root, theme);
  }
  static themeToStylesheet(theme) {
    if (theme === UiThemeEnum.Dark) {
      return theme_dark_default;
    }
    return void 0;
  }
  _activateTheme(root, theme) {
    if (theme === this._activeTheme) {
      return;
    }
    this.dispatchEvent(
      new CustomEvent(EVENT_THEME_CHANGE, {
        bubbles: true,
        composed: true,
        detail: theme
      })
    );
    this.setAttribute("theme", theme);
    const stylesheet = AKElement.themeToStylesheet(theme);
    const oldStylesheet = AKElement.themeToStylesheet(this._activeTheme);
    if (stylesheet) {
      root.adoptedStyleSheets = [...root.adoptedStyleSheets, ensureCSSStyleSheet(stylesheet)];
    }
    if (oldStylesheet) {
      root.adoptedStyleSheets = root.adoptedStyleSheets.filter((v) => v !== oldStylesheet);
    }
    this._activeTheme = theme;
    this.requestUpdate();
  }
};
AKElement = __decorateClass([
  localized()
], AKElement);

// node_modules/@lit/context/lib/context-request-event.js
var s2 = class extends Event {
  constructor(s5, t3, e4) {
    super("context-request", { bubbles: true, composed: true }), this.context = s5, this.callback = t3, this.subscribe = e4 ?? false;
  }
};

// node_modules/@lit/context/lib/create-context.js
function n3(n4) {
  return n4;
}

// node_modules/@lit/context/lib/controllers/context-consumer.js
var s3 = class {
  constructor(t3, s5, i3, h) {
    if (this.subscribe = false, this.provided = false, this.value = void 0, this.t = (t4, s6) => {
      this.unsubscribe && (this.unsubscribe !== s6 && (this.provided = false, this.unsubscribe()), this.subscribe || this.unsubscribe()), this.value = t4, this.host.requestUpdate(), this.provided && !this.subscribe || (this.provided = true, this.callback && this.callback(t4, s6)), this.unsubscribe = s6;
    }, this.host = t3, void 0 !== s5.context) {
      const t4 = s5;
      this.context = t4.context, this.callback = t4.callback, this.subscribe = t4.subscribe ?? false;
    } else
      this.context = s5, this.callback = i3, this.subscribe = h ?? false;
    this.host.addController(this);
  }
  hostConnected() {
    this.dispatchRequest();
  }
  hostDisconnected() {
    this.unsubscribe && (this.unsubscribe(), this.unsubscribe = void 0);
  }
  dispatchRequest() {
    this.host.dispatchEvent(new s2(this.context, this.t, this.subscribe));
  }
};

// node_modules/@lit/context/lib/value-notifier.js
var s4 = class {
  get value() {
    return this.o;
  }
  set value(s5) {
    this.setValue(s5);
  }
  setValue(s5, t3 = false) {
    const i3 = t3 || !Object.is(s5, this.o);
    this.o = s5, i3 && this.updateObservers();
  }
  constructor(s5) {
    this.subscriptions = /* @__PURE__ */ new Map(), this.updateObservers = () => {
      for (const [s6, { disposer: t3 }] of this.subscriptions)
        s6(this.o, t3);
    }, void 0 !== s5 && (this.value = s5);
  }
  addCallback(s5, t3, i3) {
    if (!i3)
      return void s5(this.value);
    this.subscriptions.has(s5) || this.subscriptions.set(s5, { disposer: () => {
      this.subscriptions.delete(s5);
    }, consumerHost: t3 });
    const { disposer: h } = this.subscriptions.get(s5);
    s5(this.value, h);
  }
  clearCallbacks() {
    this.subscriptions.clear();
  }
};

// node_modules/@lit/context/lib/controllers/context-provider.js
var e2 = class extends Event {
  constructor(t3) {
    super("context-provider", { bubbles: true, composed: true }), this.context = t3;
  }
};
var i2 = class extends s4 {
  constructor(s5, e4, i3) {
    super(void 0 !== e4.context ? e4.initialValue : i3), this.onContextRequest = (t3) => {
      const s6 = t3.composedPath()[0];
      t3.context === this.context && s6 !== this.host && (t3.stopPropagation(), this.addCallback(t3.callback, s6, t3.subscribe));
    }, this.onProviderRequest = (s6) => {
      const e5 = s6.composedPath()[0];
      if (s6.context !== this.context || e5 === this.host)
        return;
      const i4 = /* @__PURE__ */ new Set();
      for (const [s7, { consumerHost: e6 }] of this.subscriptions)
        i4.has(s7) || (i4.add(s7), e6.dispatchEvent(new s2(this.context, s7, true)));
      s6.stopPropagation();
    }, this.host = s5, void 0 !== e4.context ? this.context = e4.context : this.context = e4, this.attachListeners(), this.host.addController?.(this);
  }
  attachListeners() {
    this.host.addEventListener("context-request", this.onContextRequest), this.host.addEventListener("context-provider", this.onProviderRequest);
  }
  hostConnected() {
    this.host.dispatchEvent(new e2(this.context));
  }
};

// node_modules/@lit/context/lib/decorators/consume.js
function c({ context: c2, subscribe: e4 }) {
  return (o3, n4) => {
    "object" == typeof n4 ? n4.addInitializer(function() {
      new s3(this, { context: c2, callback: (t3) => {
        this[n4.name] = t3;
      }, subscribe: e4 });
    }) : o3.constructor.addInitializer((o4) => {
      new s3(o4, { context: c2, callback: (t3) => {
        o4[n4] = t3;
      }, subscribe: e4 });
    });
  };
}

// src/elements/AuthentikContexts.ts
var authentikConfigContext = n3(Symbol("authentik-config-context"));
var authentikUserContext = n3(Symbol("authentik-user-context"));
var authentikEnterpriseContext = n3(
  Symbol("authentik-enterprise-context")
);
var authentikBrandContext = n3(Symbol("authentik-brand-context"));

// src/elements/Interface/BrandContextController.ts
var BrandContextController = class {
  constructor(host) {
    this.host = host;
    this.context = new i2(this.host, {
      context: authentikBrandContext,
      initialValue: void 0
    });
    this.fetch = this.fetch.bind(this);
    this.fetch();
  }
  fetch() {
    new CoreApi(DEFAULT_CONFIG).coreBrandsCurrentRetrieve().then((brand) => {
      this.context.setValue(brand);
      this.host.brand = brand;
    });
  }
  hostConnected() {
    window.addEventListener(EVENT_REFRESH, this.fetch);
  }
  hostDisconnected() {
    window.removeEventListener(EVENT_REFRESH, this.fetch);
  }
  hostUpdate() {
    if (this.host.brand !== this.context.value) {
      this.context.setValue(this.host.brand);
    }
  }
};

// src/elements/Interface/ConfigContextController.ts
var ConfigContextController = class {
  constructor(host) {
    this.host = host;
    this.context = new i2(this.host, {
      context: authentikConfigContext,
      initialValue: void 0
    });
    this.context.setValue(globalAK().config);
    this.host.config = globalAK().config;
    this.fetch = this.fetch.bind(this);
    this.fetch();
  }
  fetch() {
    new RootApi(DEFAULT_CONFIG).rootConfigRetrieve().then((config2) => {
      this.context.setValue(config2);
      this.host.config = config2;
    });
  }
  hostConnected() {
    window.addEventListener(EVENT_REFRESH, this.fetch);
  }
  hostDisconnected() {
    window.removeEventListener(EVENT_REFRESH, this.fetch);
  }
  hostUpdate() {
    if (this.host.config !== this.context.value) {
      this.context.setValue(this.host.config);
    }
  }
};

// src/elements/Interface/EnterpriseContextController.ts
var EnterpriseContextController = class {
  constructor(host) {
    this.host = host;
    this.context = new i2(this.host, {
      context: authentikEnterpriseContext,
      initialValue: void 0
    });
    this.fetch = this.fetch.bind(this);
    this.fetch();
  }
  fetch() {
    new EnterpriseApi(DEFAULT_CONFIG).enterpriseLicenseSummaryRetrieve().then((enterprise) => {
      this.context.setValue(enterprise);
      this.host.licenseSummary = enterprise;
    });
  }
  hostConnected() {
    window.addEventListener(EVENT_REFRESH_ENTERPRISE, this.fetch);
  }
  hostDisconnected() {
    window.removeEventListener(EVENT_REFRESH_ENTERPRISE, this.fetch);
  }
  hostUpdate() {
    if (this.host.licenseSummary !== this.context.value) {
      this.context.setValue(this.host.licenseSummary);
    }
  }
};

// src/elements/Interface/Interface.ts
var brandContext = Symbol("brandContext");
var configContext = Symbol("configContext");
var modalController = Symbol("modalController");
var Interface = class extends AKElement {
  static {
    brandContext, configContext, modalController;
  }
  constructor() {
    super();
    document.adoptedStyleSheets = [...document.adoptedStyleSheets, ensureCSSStyleSheet(patternfly_base_default)];
    this[brandContext] = new BrandContextController(this);
    this[configContext] = new ConfigContextController(this);
    this[modalController] = new ModalOrchestrationController(this);
    this.dataset.akInterfaceRoot = "true";
  }
  _activateTheme(root, theme) {
    super._activateTheme(root, theme);
    super._activateTheme(document, theme);
  }
  async getTheme() {
    if (!this.uiConfig) {
      this.uiConfig = await uiConfig();
    }
    return this.uiConfig.theme?.base || UiThemeEnum.Automatic;
  }
};
__decorateClass([
  r3()
], Interface.prototype, "uiConfig", 2);
__decorateClass([
  r3()
], Interface.prototype, "config", 2);
__decorateClass([
  r3()
], Interface.prototype, "brand", 2);
var enterpriseContext = Symbol("enterpriseContext");
var EnterpriseAwareInterface = class extends Interface {
  static {
    enterpriseContext;
  }
  constructor() {
    super();
    this[enterpriseContext] = new EnterpriseContextController(this);
  }
};
__decorateClass([
  r3()
], EnterpriseAwareInterface.prototype, "licenseSummary", 2);

// src/elements/utils/customEvents.ts
var customEvent = (name, details = {}) => new CustomEvent(name, {
  composed: true,
  bubbles: true,
  detail: details
});

// src/elements/Interface/brandProvider.ts
function WithBrandConfig(superclass, subscribe = true) {
  class WithBrandProvider extends superclass {
  }
  __decorateClass([
    c({ context: authentikBrandContext, subscribe })
  ], WithBrandProvider.prototype, "brand", 2);
  return WithBrandProvider;
}

// src/locale-codes.ts
var sourceLocale = `en`;
var targetLocales = [
  `de`,
  `en`,
  `es`,
  `fr`,
  `ko`,
  `nl`,
  `pl`,
  `pseudo-LOCALE`,
  `tr`,
  `zh_TW`,
  `zh-CN`,
  `zh-Hans`,
  `zh-Hant`
];

// src/elements/ak-locale-context/definitions.ts
var enLocale = en_exports;
var debug = [
  "pseudo-LOCALE",
  /^pseudo/i,
  () => msg("Pseudolocale (for testing)"),
  async () => await import("./pseudo-LOCALE-2OYMNGVV.js")
];
var LOCALE_TABLE = [
  ["en", /^en([_-]|$)/i, () => msg("English"), async () => await import("./en-LYUZUILX.js")],
  ["es", /^es([_-]|$)/i, () => msg("Spanish"), async () => await import("./es-GLWU5KTG.js")],
  ["de", /^de([_-]|$)/i, () => msg("German"), async () => await import("./de-M27O2EUG.js")],
  ["fr", /^fr([_-]|$)/i, () => msg("French"), async () => await import("./fr-54NT5AJE.js")],
  ["ko", /^ko([_-]|$)/i, () => msg("Korean"), async () => await import("./ko-QYDDQ5R5.js")],
  ["nl", /^nl([_-]|$)/i, () => msg("Dutch"), async () => await import("./nl-AIIMI5NZ.js")],
  ["pl", /^pl([_-]|$)/i, () => msg("Polish"), async () => await import("./pl-G46E5IEL.js")],
  ["tr", /^tr([_-]|$)/i, () => msg("Turkish"), async () => await import("./tr-SNKONRD7.js")],
  ["zh-Hant", /^zh[_-](HK|Hant)/i, () => msg("Chinese (traditional)"), async () => await import("./zh-Hant-6UJ5XWVG.js")],
  ["zh_TW", /^zh[_-]TW$/i, () => msg("Taiwanese Mandarin"), async () => await import("./zh_TW-HGIPLQBV.js")],
  ["zh-Hans", /^zh(\b|_)/i, () => msg("Chinese (simplified)"), async () => await import("./zh-Hans-AHOE27YH.js")],
  debug
];
var LOCALES = LOCALE_TABLE.map(([code, match, label, locale]) => ({
  code,
  match,
  label,
  locale
}));

// src/elements/ak-locale-context/helpers.ts
var DEFAULT_LOCALE = "en";
var TOMBSTONE = "\u26FC\u26FCtombstone\u26FC\u26FC";
var LOCALES2 = LOCALES.map(
  (locale) => locale.code === "en" ? { ...locale, locale: async () => enLocale } : locale
);
function getBestMatchLocale(locale) {
  return LOCALES2.find((l) => l.match.test(locale));
}
function findSupportedLocale(candidates) {
  const candidate = candidates.find((candidate2) => getBestMatchLocale(candidate2));
  return candidate ? getBestMatchLocale(candidate) : void 0;
}
function localeCodeFromUrl(param = "locale") {
  const url = new URL(window.location.href);
  return url.searchParams.get(param) || "";
}
var isLocaleCandidate = (v) => typeof v === "string" && v !== "" && v !== TOMBSTONE;
function autoDetectLanguage(userReq = TOMBSTONE, brandReq = TOMBSTONE) {
  const localeCandidates = [
    localeCodeFromUrl("locale"),
    userReq,
    window.navigator?.language ?? TOMBSTONE,
    brandReq,
    globalAK()?.locale ?? TOMBSTONE,
    DEFAULT_LOCALE
  ].filter(isLocaleCandidate);
  const firstSupportedLocale = findSupportedLocale(localeCandidates);
  if (!firstSupportedLocale) {
    console.debug(
      `authentik/locale: No locale found for '[${localeCandidates}.join(',')]', falling back to ${DEFAULT_LOCALE}`
    );
    return DEFAULT_LOCALE;
  }
  return firstSupportedLocale.code;
}

// src/elements/ak-locale-context/configureLocale.ts
var getLocale = void 0;
var setLocale = void 0;
function initializeLocalization() {
  if (getLocale && setLocale) {
    return [getLocale, setLocale];
  }
  ({ getLocale, setLocale } = configureLocalization({
    sourceLocale,
    targetLocales,
    loadLocale: async (locale) => {
      const localeDef = getBestMatchLocale(locale);
      if (!localeDef) {
        console.warn(`Unrecognized locale: ${localeDef}`);
        return Promise.reject("");
      }
      return localeDef.locale();
    }
  }));
  return [getLocale, setLocale];
}

// src/elements/ak-locale-context/ak-locale-context.ts
var LocaleContextBase = WithBrandConfig(s);
var LocaleContext = class extends LocaleContextBase {
  constructor(code = DEFAULT_LOCALE) {
    super();
    this.locale = DEFAULT_LOCALE;
    this.param = "locale";
    this.notifyApplication = this.notifyApplication.bind(this);
    this.updateLocaleHandler = this.updateLocaleHandler.bind(this);
    try {
      const [getLocale2, setLocale2] = initializeLocalization();
      this.getLocale = getLocale2;
      this.setLocale = setLocale2;
      this.setLocale(code).then(() => {
        window.setTimeout(this.notifyApplication, 0);
      });
    } catch (e4) {
      throw new Error(`Developer error: Must have only one locale context per session: ${e4}`);
    }
  }
  connectedCallback() {
    super.connectedCallback();
    this.updateLocale();
    window.addEventListener(EVENT_LOCALE_REQUEST, this.updateLocaleHandler);
  }
  disconnectedCallback() {
    window.removeEventListener(EVENT_LOCALE_REQUEST, this.updateLocaleHandler);
    super.disconnectedCallback();
  }
  updateLocaleHandler(ev) {
    console.debug("authentik/locale: Locale update request received.");
    this.updateLocale(ev.detail.locale);
  }
  updateLocale(requestedLocale = void 0) {
    const localeRequest = autoDetectLanguage(requestedLocale, this.brand?.defaultLocale);
    const locale = getBestMatchLocale(localeRequest);
    if (!locale) {
      console.warn(`authentik/locale: failed to find locale for code ${localeRequest}`);
      return;
    }
    locale.locale().then(() => {
      console.debug(`Setting Locale to ... ${locale.label()} (${locale.code})`);
      this.setLocale(locale.code).then(() => {
        window.setTimeout(this.notifyApplication, 0);
      });
    });
  }
  notifyApplication() {
    this.dispatchEvent(customEvent(EVENT_LOCALE_CHANGE));
  }
  render() {
    return x`<slot></slot>`;
  }
};
__decorateClass([
  n2({ attribute: true, type: String })
], LocaleContext.prototype, "locale", 2);
__decorateClass([
  n2({ attribute: true, type: String })
], LocaleContext.prototype, "param", 2);
LocaleContext = __decorateClass([
  t("ak-locale-context")
], LocaleContext);

// node_modules/@patternfly/patternfly/components/Button/button.css
var button_default = '.pf-c-button {\n  --pf-c-button--PaddingTop: var(--pf-global--spacer--form-element);\n  --pf-c-button--PaddingRight: var(--pf-global--spacer--md);\n  --pf-c-button--PaddingBottom: var(--pf-global--spacer--form-element);\n  --pf-c-button--PaddingLeft: var(--pf-global--spacer--md);\n  --pf-c-button--LineHeight: var(--pf-global--LineHeight--md);\n  --pf-c-button--FontWeight: var(--pf-global--FontWeight--normal);\n  --pf-c-button--FontSize: var(--pf-global--FontSize--md);\n  --pf-c-button--BackgroundColor: transparent;\n  --pf-c-button--BorderRadius: var(--pf-global--BorderRadius--sm);\n  --pf-c-button--after--BorderRadius: var(--pf-global--BorderRadius--sm);\n  --pf-c-button--after--BorderColor: transparent;\n  --pf-c-button--after--BorderWidth: var(--pf-global--BorderWidth--sm);\n  --pf-c-button--hover--after--BorderWidth: var(--pf-global--BorderWidth--md);\n  --pf-c-button--focus--after--BorderWidth: var(--pf-global--BorderWidth--md);\n  --pf-c-button--active--after--BorderWidth: var(--pf-global--BorderWidth--md);\n  --pf-c-button--disabled--Color: var(--pf-global--disabled-color--100);\n  --pf-c-button--disabled--BackgroundColor: var(--pf-global--disabled-color--200);\n  --pf-c-button--disabled--after--BorderColor: transparent;\n  --pf-c-button--m-primary--BackgroundColor: var(--pf-global--primary-color--100);\n  --pf-c-button--m-primary--Color: var(--pf-global--Color--light-100);\n  --pf-c-button--m-primary--hover--BackgroundColor: var(--pf-global--primary-color--200);\n  --pf-c-button--m-primary--hover--Color: var(--pf-global--Color--light-100);\n  --pf-c-button--m-primary--focus--BackgroundColor: var(--pf-global--primary-color--200);\n  --pf-c-button--m-primary--focus--Color: var(--pf-global--Color--light-100);\n  --pf-c-button--m-primary--active--BackgroundColor: var(--pf-global--primary-color--200);\n  --pf-c-button--m-primary--active--Color: var(--pf-global--Color--light-100);\n  --pf-c-button--m-secondary--BackgroundColor: transparent;\n  --pf-c-button--m-secondary--after--BorderColor: var(--pf-global--primary-color--100);\n  --pf-c-button--m-secondary--Color: var(--pf-global--primary-color--100);\n  --pf-c-button--m-secondary--hover--BackgroundColor: transparent;\n  --pf-c-button--m-secondary--hover--after--BorderColor: var(--pf-global--primary-color--100);\n  --pf-c-button--m-secondary--hover--Color: var(--pf-global--primary-color--100);\n  --pf-c-button--m-secondary--focus--BackgroundColor: transparent;\n  --pf-c-button--m-secondary--focus--after--BorderColor: var(--pf-global--primary-color--100);\n  --pf-c-button--m-secondary--focus--Color: var(--pf-global--primary-color--100);\n  --pf-c-button--m-secondary--active--BackgroundColor: transparent;\n  --pf-c-button--m-secondary--active--after--BorderColor: var(--pf-global--primary-color--100);\n  --pf-c-button--m-secondary--active--Color: var(--pf-global--primary-color--100);\n  --pf-c-button--m-secondary--m-danger--BackgroundColor: transparent;\n  --pf-c-button--m-secondary--m-danger--Color: var(--pf-global--danger-color--100);\n  --pf-c-button--m-secondary--m-danger--after--BorderColor: var(--pf-global--danger-color--100);\n  --pf-c-button--m-secondary--m-danger--hover--BackgroundColor: transparent;\n  --pf-c-button--m-secondary--m-danger--hover--Color: var(--pf-global--danger-color--200);\n  --pf-c-button--m-secondary--m-danger--hover--after--BorderColor: var(--pf-global--danger-color--100);\n  --pf-c-button--m-secondary--m-danger--focus--BackgroundColor: transparent;\n  --pf-c-button--m-secondary--m-danger--focus--Color: var(--pf-global--danger-color--200);\n  --pf-c-button--m-secondary--m-danger--focus--after--BorderColor: var(--pf-global--danger-color--100);\n  --pf-c-button--m-secondary--m-danger--active--BackgroundColor: transparent;\n  --pf-c-button--m-secondary--m-danger--active--Color: var(--pf-global--danger-color--200);\n  --pf-c-button--m-secondary--m-danger--active--after--BorderColor: var(--pf-global--danger-color--100);\n  --pf-c-button--m-tertiary--BackgroundColor: transparent;\n  --pf-c-button--m-tertiary--after--BorderColor: var(--pf-global--Color--100);\n  --pf-c-button--m-tertiary--Color: var(--pf-global--Color--100);\n  --pf-c-button--m-tertiary--hover--BackgroundColor: transparent;\n  --pf-c-button--m-tertiary--hover--after--BorderColor: var(--pf-global--Color--100);\n  --pf-c-button--m-tertiary--hover--Color: var(--pf-global--Color--100);\n  --pf-c-button--m-tertiary--focus--BackgroundColor: transparent;\n  --pf-c-button--m-tertiary--focus--after--BorderColor: var(--pf-global--Color--100);\n  --pf-c-button--m-tertiary--focus--Color: var(--pf-global--Color--100);\n  --pf-c-button--m-tertiary--active--BackgroundColor: transparent;\n  --pf-c-button--m-tertiary--active--after--BorderColor: var(--pf-global--Color--100);\n  --pf-c-button--m-tertiary--active--Color: var(--pf-global--Color--100);\n  --pf-c-button--m-warning--BackgroundColor: var(--pf-global--warning-color--100);\n  --pf-c-button--m-warning--Color: var(--pf-global--Color--dark-100);\n  --pf-c-button--m-warning--hover--BackgroundColor: var(--pf-global--palette--gold-500);\n  --pf-c-button--m-warning--hover--Color: var(--pf-global--Color--dark-100);\n  --pf-c-button--m-warning--focus--BackgroundColor: var(--pf-global--palette--gold-500);\n  --pf-c-button--m-warning--focus--Color: var(--pf-global--Color--dark-100);\n  --pf-c-button--m-warning--active--BackgroundColor: var(--pf-global--palette--gold-500);\n  --pf-c-button--m-warning--active--Color: var(--pf-global--Color--dark-100);\n  --pf-c-button--m-danger--BackgroundColor: var(--pf-global--danger-color--100);\n  --pf-c-button--m-danger--Color: var(--pf-global--Color--light-100);\n  --pf-c-button--m-danger--hover--BackgroundColor: var(--pf-global--danger-color--200);\n  --pf-c-button--m-danger--hover--Color: var(--pf-global--Color--light-100);\n  --pf-c-button--m-danger--focus--BackgroundColor: var(--pf-global--danger-color--200);\n  --pf-c-button--m-danger--focus--Color: var(--pf-global--Color--light-100);\n  --pf-c-button--m-danger--active--BackgroundColor: var(--pf-global--danger-color--200);\n  --pf-c-button--m-danger--active--Color: var(--pf-global--Color--light-100);\n  --pf-c-button--m-link--BackgroundColor: transparent;\n  --pf-c-button--m-link--Color: var(--pf-global--link--Color);\n  --pf-c-button--m-link--hover--BackgroundColor: transparent;\n  --pf-c-button--m-link--hover--Color: var(--pf-global--link--Color--hover);\n  --pf-c-button--m-link--focus--BackgroundColor: transparent;\n  --pf-c-button--m-link--focus--Color: var(--pf-global--link--Color--hover);\n  --pf-c-button--m-link--active--BackgroundColor: transparent;\n  --pf-c-button--m-link--active--Color: var(--pf-global--link--Color--hover);\n  --pf-c-button--m-link--disabled--BackgroundColor: transparent;\n  --pf-c-button--m-link--m-inline--FontSize: inherit;\n  --pf-c-button--m-link--m-inline--hover--TextDecoration: var(--pf-global--link--TextDecoration--hover);\n  --pf-c-button--m-link--m-inline--hover--Color: var(--pf-global--link--Color--hover);\n  --pf-c-button--m-link--m-inline--PaddingTop: 0;\n  --pf-c-button--m-link--m-inline--PaddingRight: 0;\n  --pf-c-button--m-link--m-inline--PaddingBottom: 0;\n  --pf-c-button--m-link--m-inline--PaddingLeft: 0;\n  --pf-c-button--m-link--m-inline__progress--Left: var(--pf-global--spacer--xs);\n  --pf-c-button--m-link--m-inline--m-in-progress--PaddingLeft: calc(var(--pf-c-button--m-link--m-inline__progress--Left) + 1rem + var(--pf-global--spacer--sm));\n  --pf-c-button--m-link--m-danger--BackgroundColor: transparent;\n  --pf-c-button--m-link--m-danger--Color: var(--pf-global--danger-color--100);\n  --pf-c-button--m-link--m-danger--hover--BackgroundColor: transparent;\n  --pf-c-button--m-link--m-danger--hover--Color: var(--pf-global--danger-color--200);\n  --pf-c-button--m-link--m-danger--focus--BackgroundColor: transparent;\n  --pf-c-button--m-link--m-danger--focus--Color: var(--pf-global--danger-color--200);\n  --pf-c-button--m-link--m-danger--active--BackgroundColor: transparent;\n  --pf-c-button--m-link--m-danger--active--Color: var(--pf-global--danger-color--200);\n  --pf-c-button--m-plain--BackgroundColor: transparent;\n  --pf-c-button--m-plain--Color: var(--pf-global--Color--200);\n  --pf-c-button--m-plain--hover--BackgroundColor: transparent;\n  --pf-c-button--m-plain--hover--Color: var(--pf-global--Color--100);\n  --pf-c-button--m-plain--focus--BackgroundColor: transparent;\n  --pf-c-button--m-plain--focus--Color: var(--pf-global--Color--100);\n  --pf-c-button--m-plain--active--BackgroundColor: transparent;\n  --pf-c-button--m-plain--active--Color: var(--pf-global--Color--100);\n  --pf-c-button--m-plain--disabled--Color: var(--pf-global--disabled-color--200);\n  --pf-c-button--m-plain--disabled--BackgroundColor: transparent;\n  --pf-c-button--m-control--BackgroundColor: var(--pf-global--BackgroundColor--100);\n  --pf-c-button--m-control--Color: var(--pf-global--Color--100);\n  --pf-c-button--m-control--BorderRadius: 0;\n  --pf-c-button--m-control--after--BorderWidth: var(--pf-global--BorderWidth--sm);\n  --pf-c-button--m-control--after--BorderTopColor: var(--pf-global--BorderColor--300);\n  --pf-c-button--m-control--after--BorderRightColor: var(--pf-global--BorderColor--300);\n  --pf-c-button--m-control--after--BorderBottomColor: var(--pf-global--BorderColor--200);\n  --pf-c-button--m-control--after--BorderLeftColor: var(--pf-global--BorderColor--300);\n  --pf-c-button--m-control--disabled--BackgroundColor: var(--pf-global--disabled-color--300);\n  --pf-c-button--m-control--hover--BackgroundColor: var(--pf-global--BackgroundColor--100);\n  --pf-c-button--m-control--hover--Color: var(--pf-global--Color--100);\n  --pf-c-button--m-control--hover--after--BorderBottomWidth: var(--pf-global--BorderWidth--md);\n  --pf-c-button--m-control--hover--after--BorderBottomColor: var(--pf-global--active-color--100);\n  --pf-c-button--m-control--active--BackgroundColor: var(--pf-global--BackgroundColor--100);\n  --pf-c-button--m-control--active--Color: var(--pf-global--Color--100);\n  --pf-c-button--m-control--active--after--BorderBottomWidth: var(--pf-global--BorderWidth--md);\n  --pf-c-button--m-control--active--after--BorderBottomColor: var(--pf-global--active-color--100);\n  --pf-c-button--m-control--focus--BackgroundColor: var(--pf-global--BackgroundColor--100);\n  --pf-c-button--m-control--focus--Color: var(--pf-global--Color--100);\n  --pf-c-button--m-control--focus--after--BorderBottomWidth: var(--pf-global--BorderWidth--md);\n  --pf-c-button--m-control--focus--after--BorderBottomColor: var(--pf-global--active-color--100);\n  --pf-c-button--m-control--m-expanded--BackgroundColor: var(--pf-global--BackgroundColor--100);\n  --pf-c-button--m-control--m-expanded--Color: var(--pf-global--Color--100);\n  --pf-c-button--m-control--m-expanded--after--BorderBottomWidth: var(--pf-global--BorderWidth--md);\n  --pf-c-button--m-control--m-expanded--after--BorderBottomColor: var(--pf-global--active-color--100);\n  --pf-c-button--m-small--FontSize: var(--pf-global--FontSize--sm);\n  --pf-c-button--m-display-lg--PaddingTop: var(--pf-global--spacer--md);\n  --pf-c-button--m-display-lg--PaddingRight: var(--pf-global--spacer--xl);\n  --pf-c-button--m-display-lg--PaddingBottom: var(--pf-global--spacer--md);\n  --pf-c-button--m-display-lg--PaddingLeft: var(--pf-global--spacer--xl);\n  --pf-c-button--m-display-lg--FontWeight: var(--pf-global--FontWeight--bold);\n  --pf-c-button--m-link--m-display-lg--FontSize: var(--pf-global--FontSize--lg);\n  --pf-c-button__icon--m-start--MarginRight: var(--pf-global--spacer--xs);\n  --pf-c-button__icon--m-end--MarginLeft: var(--pf-global--spacer--xs);\n  --pf-c-button__progress--width: calc(var(--pf-global--icon--FontSize--md) + var(--pf-global--spacer--sm));\n  --pf-c-button__progress--Opacity: 0;\n  --pf-c-button__progress--TranslateY: -50%;\n  --pf-c-button__progress--TranslateX: 0;\n  --pf-c-button__progress--Top: 50%;\n  --pf-c-button__progress--Left: var(--pf-global--spacer--md);\n  --pf-c-button--m-progress--TransitionProperty: padding;\n  --pf-c-button--m-progress--TransitionDuration: var(--pf-global--TransitionDuration);\n  --pf-c-button--m-progress--PaddingRight: calc(var(--pf-global--spacer--md) + var(--pf-c-button__progress--width) / 2);\n  --pf-c-button--m-progress--PaddingLeft: calc(var(--pf-global--spacer--md) + var(--pf-c-button__progress--width) / 2);\n  --pf-c-button--m-in-progress--PaddingRight: var(--pf-global--spacer--md);\n  --pf-c-button--m-in-progress--PaddingLeft: calc(var(--pf-global--spacer--md) + var(--pf-c-button__progress--width));\n  --pf-c-button--m-in-progress--m-plain--Color: var(--pf-global--primary-color--100);\n  --pf-c-button--m-in-progress--m-plain__progress--Left: 50%;\n  --pf-c-button--m-in-progress--m-plain__progress--TranslateX: -50%;\n  --pf-c-button__count--MarginLeft: var(--pf-global--spacer--sm);\n  --pf-c-button--disabled__c-badge--Color: var(--pf-global--Color--dark-100);\n  --pf-c-button--disabled__c-badge--BackgroundColor: var(--pf-global--BackgroundColor--200);\n  --pf-c-button--m-primary__c-badge--BorderColor: var(--pf-global--BorderColor--300);\n  --pf-c-button--m-primary__c-badge--BorderWidth: var(--pf-global--BorderWidth--sm);\n  position: relative;\n  display: inline-block;\n  padding: var(--pf-c-button--PaddingTop) var(--pf-c-button--PaddingRight) var(--pf-c-button--PaddingBottom) var(--pf-c-button--PaddingLeft);\n  font-size: var(--pf-c-button--FontSize);\n  font-weight: var(--pf-c-button--FontWeight);\n  line-height: var(--pf-c-button--LineHeight);\n  text-align: center;\n  white-space: nowrap;\n  user-select: none;\n  border: 0;\n  border-radius: var(--pf-c-button--BorderRadius);\n}\n.pf-c-button::after {\n  position: absolute;\n  top: 0;\n  right: 0;\n  bottom: 0;\n  left: 0;\n  pointer-events: none;\n  content: "";\n  border: var(--pf-c-button--after--BorderWidth) solid;\n  border-color: var(--pf-c-button--after--BorderColor);\n  border-radius: var(--pf-c-button--after--BorderRadius);\n}\n.pf-c-button:hover {\n  --pf-c-button--after--BorderWidth: var(--pf-c-button--hover--after--BorderWidth);\n  text-decoration: none;\n}\n.pf-c-button:focus {\n  --pf-c-button--after--BorderWidth: var(--pf-c-button--focus--after--BorderWidth);\n}\n.pf-c-button:active, .pf-c-button.pf-m-active {\n  --pf-c-button--after--BorderWidth: var(--pf-c-button--active--after--BorderWidth);\n}\n.pf-c-button.pf-m-block {\n  display: block;\n  width: 100%;\n}\n.pf-c-button.pf-m-small {\n  --pf-c-button--FontSize: var(--pf-c-button--m-small--FontSize);\n}\n.pf-c-button.pf-m-primary.pf-m-display-lg, .pf-c-button.pf-m-secondary.pf-m-display-lg, .pf-c-button.pf-m-tertiary.pf-m-display-lg, .pf-c-button.pf-m-link.pf-m-display-lg {\n  --pf-c-button--PaddingTop: var(--pf-c-button--m-display-lg--PaddingTop);\n  --pf-c-button--PaddingRight: var(--pf-c-button--m-display-lg--PaddingRight);\n  --pf-c-button--PaddingBottom: var(--pf-c-button--m-display-lg--PaddingBottom);\n  --pf-c-button--PaddingLeft: var(--pf-c-button--m-display-lg--PaddingLeft);\n  --pf-c-button--FontWeight: var(--pf-c-button--m-display-lg--FontWeight);\n}\n.pf-c-button.pf-m-primary {\n  color: var(--pf-c-button--m-primary--Color);\n  background-color: var(--pf-c-button--m-primary--BackgroundColor);\n}\n.pf-c-button.pf-m-primary:hover {\n  --pf-c-button--m-primary--Color: var(--pf-c-button--m-primary--hover--Color);\n  --pf-c-button--m-primary--BackgroundColor: var(--pf-c-button--m-primary--hover--BackgroundColor);\n}\n.pf-c-button.pf-m-primary:focus {\n  --pf-c-button--m-primary--Color: var(--pf-c-button--m-primary--focus--Color);\n  --pf-c-button--m-primary--BackgroundColor: var(--pf-c-button--m-primary--focus--BackgroundColor);\n}\n.pf-c-button.pf-m-primary:active, .pf-c-button.pf-m-primary.pf-m-active {\n  --pf-c-button--m-primary--Color: var(--pf-c-button--m-primary--active--Color);\n  --pf-c-button--m-primary--BackgroundColor: var(--pf-c-button--m-primary--active--BackgroundColor);\n}\n.pf-c-button.pf-m-primary .pf-c-badge.pf-m-unread {\n  border: var(--pf-c-button--m-primary__c-badge--BorderWidth) solid var(--pf-c-button--m-primary__c-badge--BorderColor);\n}\n.pf-c-button.pf-m-secondary {\n  --pf-c-button--after--BorderColor: var(--pf-c-button--m-secondary--after--BorderColor);\n  color: var(--pf-c-button--m-secondary--Color);\n  background-color: var(--pf-c-button--m-secondary--BackgroundColor);\n}\n.pf-c-button.pf-m-secondary:hover {\n  --pf-c-button--m-secondary--Color: var(--pf-c-button--m-secondary--hover--Color);\n  --pf-c-button--m-secondary--BackgroundColor: var(--pf-c-button--m-secondary--hover--BackgroundColor);\n  --pf-c-button--after--BorderColor: var(--pf-c-button--m-secondary--hover--after--BorderColor);\n}\n.pf-c-button.pf-m-secondary:focus {\n  --pf-c-button--m-secondary--Color: var(--pf-c-button--m-secondary--focus--Color);\n  --pf-c-button--m-secondary--BackgroundColor: var(--pf-c-button--m-secondary--focus--BackgroundColor);\n  --pf-c-button--after--BorderColor: var(--pf-c-button--m-secondary--focus--after--BorderColor);\n}\n.pf-c-button.pf-m-secondary.pf-m-active, .pf-c-button.pf-m-secondary:active {\n  --pf-c-button--m-secondary--Color: var(--pf-c-button--m-secondary--active--Color);\n  --pf-c-button--m-secondary--BackgroundColor: var(--pf-c-button--m-secondary--active--BackgroundColor);\n  --pf-c-button--after--BorderColor: var(--pf-c-button--m-secondary--active--after--BorderColor);\n}\n.pf-c-button.pf-m-tertiary {\n  --pf-c-button--after--BorderColor: var(--pf-c-button--m-tertiary--after--BorderColor);\n  color: var(--pf-c-button--m-tertiary--Color);\n  background-color: var(--pf-c-button--m-tertiary--BackgroundColor);\n}\n.pf-c-button.pf-m-tertiary:hover {\n  --pf-c-button--m-tertiary--Color: var(--pf-c-button--m-tertiary--hover--Color);\n  --pf-c-button--m-tertiary--BackgroundColor: var(--pf-c-button--m-tertiary--hover--BackgroundColor);\n  --pf-c-button--after--BorderColor: var(--pf-c-button--m-tertiary--hover--after--BorderColor);\n}\n.pf-c-button.pf-m-tertiary:focus {\n  --pf-c-button--m-tertiary--Color: var(--pf-c-button--m-tertiary--focus--Color);\n  --pf-c-button--m-tertiary--BackgroundColor: var(--pf-c-button--m-tertiary--focus--BackgroundColor);\n  --pf-c-button--after--BorderColor: var(--pf-c-button--m-tertiary--focus--after--BorderColor);\n}\n.pf-c-button.pf-m-tertiary:active, .pf-c-button.pf-m-tertiary.pf-m-active {\n  --pf-c-button--m-tertiary--Color: var(--pf-c-button--m-tertiary--active--Color);\n  --pf-c-button--m-tertiary--BackgroundColor: var(--pf-c-button--m-tertiary--active--BackgroundColor);\n  --pf-c-button--after--BorderColor: var(--pf-c-button--m-tertiary--active--after--BorderColor);\n}\n.pf-c-button.pf-m-link {\n  --pf-c-button--disabled--BackgroundColor: var(--pf-c-button--m-link--disabled--BackgroundColor);\n  color: var(--pf-c-button--m-link--Color);\n  background-color: var(--pf-c-button--m-link--BackgroundColor);\n}\n.pf-c-button.pf-m-link:not(.pf-m-inline):hover {\n  --pf-c-button--m-link--Color: var(--pf-c-button--m-link--hover--Color);\n  --pf-c-button--m-link--BackgroundColor: var(--pf-c-button--m-link--hover--BackgroundColor);\n}\n.pf-c-button.pf-m-link:not(.pf-m-inline):focus {\n  --pf-c-button--m-link--Color: var(--pf-c-button--m-link--focus--Color);\n  --pf-c-button--m-link--BackgroundColor: var(--pf-c-button--m-link--focus--BackgroundColor);\n}\n.pf-c-button.pf-m-link:not(.pf-m-inline):active, .pf-c-button.pf-m-link:not(.pf-m-inline).pf-m-active {\n  --pf-c-button--m-link--Color: var(--pf-c-button--m-link--active--Color);\n  --pf-c-button--m-link--BackgroundColor: var(--pf-c-button--m-link--active--BackgroundColor);\n}\n.pf-c-button.pf-m-link.pf-m-inline {\n  --pf-c-button--FontSize: var(--pf-c-button--m-link--m-inline--FontSize);\n  --pf-c-button__progress--Left: var(--pf-c-button--m-link--m-inline__progress--Left);\n  display: inline;\n  padding: var(--pf-c-button--m-link--m-inline--PaddingTop) var(--pf-c-button--m-link--m-inline--PaddingRight) var(--pf-c-button--m-link--m-inline--PaddingBottom) var(--pf-c-button--m-link--m-inline--PaddingLeft);\n  text-align: left;\n  white-space: normal;\n  cursor: pointer;\n}\n.pf-c-button.pf-m-link.pf-m-inline:hover {\n  --pf-c-button--m-link--Color: var(--pf-c-button--m-link--m-inline--hover--Color);\n  text-decoration: var(--pf-c-button--m-link--m-inline--hover--TextDecoration);\n}\n.pf-c-button.pf-m-link.pf-m-display-lg {\n  --pf-c-button--FontSize: var(--pf-c-button--m-link--m-display-lg--FontSize);\n}\n.pf-c-button.pf-m-danger {\n  color: var(--pf-c-button--m-danger--Color);\n  background-color: var(--pf-c-button--m-danger--BackgroundColor);\n}\n.pf-c-button.pf-m-danger:hover {\n  --pf-c-button--m-danger--Color: var(--pf-c-button--m-danger--hover--Color);\n  --pf-c-button--m-danger--BackgroundColor: var(--pf-c-button--m-danger--hover--BackgroundColor);\n}\n.pf-c-button.pf-m-danger:focus {\n  --pf-c-button--m-danger--Color: var(--pf-c-button--m-danger--focus--Color);\n  --pf-c-button--m-danger--BackgroundColor: var(--pf-c-button--m-danger--focus--BackgroundColor);\n}\n.pf-c-button.pf-m-danger:active, .pf-c-button.pf-m-danger.pf-m-active {\n  --pf-c-button--m-danger--Color: var(--pf-c-button--m-danger--active--Color);\n  --pf-c-button--m-danger--BackgroundColor: var(--pf-c-button--m-danger--active--BackgroundColor);\n}\n.pf-c-button.pf-m-danger.pf-m-secondary {\n  --pf-c-button--m-danger--Color: var(--pf-c-button--m-secondary--m-danger--Color);\n  --pf-c-button--m-danger--BackgroundColor: var(--pf-c-button--m-secondary--m-danger--BackgroundColor);\n  --pf-c-button--after--BorderColor: var(--pf-c-button--m-secondary--m-danger--after--BorderColor);\n}\n.pf-c-button.pf-m-danger.pf-m-secondary:hover {\n  --pf-c-button--m-secondary--m-danger--Color: var(--pf-c-button--m-secondary--m-danger--hover--Color);\n  --pf-c-button--m-secondary--m-danger--BackgroundColor: var(--pf-c-button--m-secondary--m-danger--hover--BackgroundColor);\n  --pf-c-button--after--BorderColor: var(--pf-c-button--m-secondary--m-danger--hover--after--BorderColor);\n}\n.pf-c-button.pf-m-danger.pf-m-secondary:focus {\n  --pf-c-button--m-secondary--m-danger--Color: var(--pf-c-button--m-secondary--m-danger--focus--Color);\n  --pf-c-button--m-secondary--m-danger--BackgroundColor: var(--pf-c-button--m-secondary--m-danger--focus--BackgroundColor);\n  --pf-c-button--after--BorderColor: var(--pf-c-button--m-secondary--m-danger--focus--after--BorderColor);\n}\n.pf-c-button.pf-m-danger.pf-m-secondary:active, .pf-c-button.pf-m-danger.pf-m-secondary.pf-m-active {\n  --pf-c-button--m-secondary--m-danger--Color: var(--pf-c-button--m-secondary--m-danger--active--Color);\n  --pf-c-button--m-secondary--m-danger--BackgroundColor: var(--pf-c-button--m-secondary--m-danger--active--BackgroundColor);\n  --pf-c-button--after--BorderColor: var(--pf-c-button--m-secondary--m-danger--active--after--BorderColor);\n}\n.pf-c-button.pf-m-danger.pf-m-link {\n  --pf-c-button--m-danger--Color: var(--pf-c-button--m-link--m-danger--Color);\n  --pf-c-button--m-danger--BackgroundColor: var(--pf-c-button--m-link--m-danger--BackgroundColor);\n}\n.pf-c-button.pf-m-danger.pf-m-link:hover {\n  --pf-c-button--m-link--m-danger--Color: var(--pf-c-button--m-link--m-danger--hover--Color);\n  --pf-c-button--m-link--m-danger--BackgroundColor: var(--pf-c-button--m-link--m-danger--hover--BackgroundColor);\n}\n.pf-c-button.pf-m-danger.pf-m-link:focus {\n  --pf-c-button--m-link--m-danger--Color: var(--pf-c-button--m-link--m-danger--focus--Color);\n  --pf-c-button--m-link--m-danger--BackgroundColor: var(--pf-c-button--m-link--m-danger--focus--BackgroundColor);\n}\n.pf-c-button.pf-m-danger.pf-m-link:active, .pf-c-button.pf-m-danger.pf-m-link.pf-m-active {\n  --pf-c-button--m-link--m-danger--Color: var(--pf-c-button--m-link--m-danger--active--Color);\n  --pf-c-button--m-link--m-danger--BackgroundColor: var(--pf-c-button--m-link--m-danger--active--BackgroundColor);\n}\n.pf-c-button.pf-m-warning {\n  color: var(--pf-c-button--m-warning--Color);\n  background-color: var(--pf-c-button--m-warning--BackgroundColor);\n}\n.pf-c-button.pf-m-warning:hover {\n  --pf-c-button--m-warning--Color: var(--pf-c-button--m-warning--hover--Color);\n  --pf-c-button--m-warning--BackgroundColor: var(--pf-c-button--m-warning--hover--BackgroundColor);\n}\n.pf-c-button.pf-m-warning:focus {\n  --pf-c-button--m-warning--Color: var(--pf-c-button--m-warning--focus--Color);\n  --pf-c-button--m-warning--BackgroundColor: var(--pf-c-button--m-warning--focus--BackgroundColor);\n}\n.pf-c-button.pf-m-warning:active, .pf-c-button.pf-m-warning.pf-m-active {\n  --pf-c-button--m-warning--Color: var(--pf-c-button--m-warning--active--Color);\n  --pf-c-button--m-warning--BackgroundColor: var(--pf-c-button--m-warning--active--BackgroundColor);\n}\n.pf-c-button.pf-m-control {\n  --pf-c-button--BorderRadius: var(--pf-c-button--m-control--BorderRadius);\n  --pf-c-button--disabled--BackgroundColor: var(--pf-c-button--m-control--disabled--BackgroundColor);\n  --pf-c-button--after--BorderWidth: var(--pf-c-button--m-control--after--BorderWidth);\n  --pf-c-button--after--BorderColor: var(--pf-c-button--m-control--after--BorderTopColor) var(--pf-c-button--m-control--after--BorderRightColor) var(--pf-c-button--m-control--after--BorderBottomColor) var(--pf-c-button--m-control--after--BorderLeftColor);\n  color: var(--pf-c-button--m-control--Color);\n  background-color: var(--pf-c-button--m-control--BackgroundColor);\n}\n.pf-c-button.pf-m-control::after {\n  border-radius: initial;\n}\n.pf-c-button.pf-m-control:hover {\n  --pf-c-button--m-control--Color: var(--pf-c-button--m-control--hover--Color);\n  --pf-c-button--m-control--BackgroundColor: var(--pf-c-button--m-control--hover--BackgroundColor);\n  --pf-c-button--m-control--after--BorderBottomColor: var(--pf-c-button--m-control--hover--after--BorderBottomColor);\n}\n.pf-c-button.pf-m-control:hover::after {\n  border-bottom-width: var(--pf-c-button--m-control--hover--after--BorderBottomWidth);\n}\n.pf-c-button.pf-m-control:active, .pf-c-button.pf-m-control.pf-m-active {\n  --pf-c-button--m-control--Color: var(--pf-c-button--m-control--active--Color);\n  --pf-c-button--m-control--BackgroundColor: var(--pf-c-button--m-control--active--BackgroundColor);\n  --pf-c-button--m-control--after--BorderBottomColor: var(--pf-c-button--m-control--active--after--BorderBottomColor);\n}\n.pf-c-button.pf-m-control:active::after, .pf-c-button.pf-m-control.pf-m-active::after {\n  border-bottom-width: var(--pf-c-button--m-control--active--after--BorderBottomWidth);\n}\n.pf-c-button.pf-m-control:focus {\n  --pf-c-button--m-control--Color: var(--pf-c-button--m-control--focus--Color);\n  --pf-c-button--m-control--BackgroundColor: var(--pf-c-button--m-control--focus--BackgroundColor);\n  --pf-c-button--m-control--after--BorderBottomColor: var(--pf-c-button--m-control--focus--after--BorderBottomColor);\n}\n.pf-c-button.pf-m-control:focus::after {\n  border-bottom-width: var(--pf-c-button--m-control--focus--after--BorderBottomWidth);\n}\n.pf-c-button.pf-m-control.pf-m-expanded {\n  --pf-c-button--m-control--Color: var(--pf-c-button--m-control--m-expanded--Color);\n  --pf-c-button--m-control--BackgroundColor: var(--pf-c-button--m-control--m-expanded--BackgroundColor);\n  --pf-c-button--m-control--after--BorderBottomColor: var(--pf-c-button--m-control--m-expanded--after--BorderBottomColor);\n}\n.pf-c-button.pf-m-control.pf-m-expanded::after {\n  border-bottom-width: var(--pf-c-button--m-control--m-expanded--after--BorderBottomWidth);\n}\n.pf-c-button.pf-m-plain {\n  --pf-c-button--disabled--Color: var(--pf-c-button--m-plain--disabled--Color);\n  --pf-c-button--disabled--BackgroundColor: var(--pf-c-button--m-plain--disabled--BackgroundColor);\n  color: var(--pf-c-button--m-plain--Color);\n  background-color: var(--pf-c-button--m-plain--BackgroundColor);\n}\n.pf-c-button.pf-m-plain:hover {\n  --pf-c-button--m-plain--Color: var(--pf-c-button--m-plain--hover--Color);\n  --pf-c-button--m-plain--BackgroundColor: var(--pf-c-button--m-plain--hover--BackgroundColor);\n}\n.pf-c-button.pf-m-plain:active, .pf-c-button.pf-m-plain.pf-m-active {\n  --pf-c-button--m-plain--Color: var(--pf-c-button--m-plain--active--Color);\n  --pf-c-button--m-plain--BackgroundColor: var(--pf-c-button--m-plain--active--BackgroundColor);\n}\n.pf-c-button.pf-m-plain:focus {\n  --pf-c-button--m-plain--Color: var(--pf-c-button--m-plain--focus--Color);\n  --pf-c-button--m-plain--BackgroundColor: var(--pf-c-button--m-plain--focus--BackgroundColor);\n}\n.pf-c-button:disabled, .pf-c-button.pf-m-disabled {\n  pointer-events: none;\n}\n.pf-c-button:disabled, .pf-c-button.pf-m-disabled, .pf-c-button.pf-m-aria-disabled {\n  color: var(--pf-c-button--disabled--Color);\n  background-color: var(--pf-c-button--disabled--BackgroundColor);\n}\n.pf-c-button:disabled::after, .pf-c-button.pf-m-disabled::after, .pf-c-button.pf-m-aria-disabled::after {\n  border-color: var(--pf-c-button--disabled--after--BorderColor);\n}\n.pf-c-button:disabled .pf-c-badge, .pf-c-button.pf-m-disabled .pf-c-badge, .pf-c-button.pf-m-aria-disabled .pf-c-badge {\n  --pf-c-badge--m-unread--Color: var(--pf-c-button--disabled__c-badge--Color);\n  --pf-c-badge--m-unread--BackgroundColor: var(--pf-c-button--disabled__c-badge--BackgroundColor);\n  --pf-c-button--m-primary__c-badge--BorderWidth: 0;\n}\n.pf-c-button.pf-m-aria-disabled {\n  --pf-c-button--after--BorderWidth: 0;\n  --pf-c-button--m-link--m-inline--hover--TextDecoration: none;\n  cursor: default;\n}\n.pf-c-button.pf-m-progress {\n  --pf-c-button--PaddingRight: var(--pf-c-button--m-progress--PaddingRight);\n  --pf-c-button--PaddingLeft: var(--pf-c-button--m-progress--PaddingLeft);\n  transition: var(--pf-c-button--m-progress--TransitionProperty) var(--pf-c-button--m-progress--TransitionDuration);\n}\n.pf-c-button.pf-m-in-progress {\n  --pf-c-button--m-link--m-inline--PaddingLeft: var(--pf-c-button--m-link--m-inline--m-in-progress--PaddingLeft);\n}\n.pf-c-button.pf-m-in-progress:not(.pf-m-plain) {\n  --pf-c-button--PaddingRight: var(--pf-c-button--m-in-progress--PaddingRight);\n  --pf-c-button--PaddingLeft: var(--pf-c-button--m-in-progress--PaddingLeft);\n}\n.pf-c-button.pf-m-in-progress.pf-m-plain {\n  --pf-c-button--m-plain--Color: var(--pf-c-button--m-in-progress--m-plain--Color);\n  --pf-c-button__progress--Left: var(--pf-c-button--m-in-progress--m-plain__progress--Left);\n  --pf-c-button__progress--TranslateX: var(--pf-c-button--m-in-progress--m-plain__progress--TranslateX);\n}\n.pf-c-button.pf-m-in-progress.pf-m-plain > :not(.pf-c-button__progress) {\n  opacity: 0;\n}\n\n.pf-c-button__icon.pf-m-start {\n  margin-right: var(--pf-c-button__icon--m-start--MarginRight);\n}\n.pf-c-button__icon.pf-m-end {\n  margin-left: var(--pf-c-button__icon--m-end--MarginLeft);\n}\n\n.pf-c-button__progress {\n  position: absolute;\n  top: var(--pf-c-button__progress--Top);\n  left: var(--pf-c-button__progress--Left);\n  line-height: 1;\n  transform: translate(var(--pf-c-button__progress--TranslateX), var(--pf-c-button__progress--TranslateY));\n}\n.pf-c-button__progress .pf-c-spinner {\n  --pf-c-spinner--Color: currentcolor;\n}\n\n.pf-c-button__count {\n  display: inline-flex;\n  align-items: center;\n  margin-left: var(--pf-c-button__count--MarginLeft);\n}\n\n.pf-m-overpass-font .pf-c-button {\n  --pf-c-button--FontWeight: var(--pf-global--FontWeight--semi-bold);\n}\n\n:where(.pf-theme-dark) .pf-c-button {\n  --pf-c-button--disabled--Color: var(--pf-global--disabled-color--300);\n  --pf-c-button--m-primary--BackgroundColor: var(--pf-global--primary-color--300);\n  --pf-c-button--m-tertiary--after--BorderColor: var(--pf-global--BorderColor--100);\n  --pf-c-button--m-tertiary--Color: var(--pf-global--palette--black-100);\n  --pf-c-button--m-tertiary--hover--after--BorderColor: var(--pf-global--BorderColor--100);\n  --pf-c-button--m-tertiary--hover--Color: var(--pf-global--palette--black-100);\n  --pf-c-button--m-tertiary--focus--after--BorderColor: var(--pf-global--BorderColor--100);\n  --pf-c-button--m-tertiary--focus--Color: var(--pf-global--palette--black-100);\n  --pf-c-button--m-tertiary--active--after--BorderColor: var(--pf-global--BorderColor--100);\n  --pf-c-button--m-tertiary--active--Color: var(--pf-global--palette--black-100);\n  --pf-c-button--m-warning--Color: var(--pf-global--palette--black-900);\n  --pf-c-button--m-warning--hover--Color: var(--pf-global--palette--black-900);\n  --pf-c-button--m-warning--focus--Color: var(--pf-global--palette--black-900);\n  --pf-c-button--m-warning--active--Color: var(--pf-global--palette--black-900);\n  --pf-c-button--m-warning--hover--BackgroundColor: var(--pf-global--warning-color--200);\n  --pf-c-button--m-warning--focus--BackgroundColor: var(--pf-global--warning-color--200);\n  --pf-c-button--m-warning--active--BackgroundColor: var(--pf-global--warning-color--200);\n  --pf-c-button--m-danger--Color: var(--pf-global--palette--black-900);\n  --pf-c-button--m-danger--hover--Color: var(--pf-global--palette--black-900);\n  --pf-c-button--m-danger--focus--Color: var(--pf-global--palette--black-900);\n  --pf-c-button--m-danger--active--Color: var(--pf-global--palette--black-900);\n  --pf-c-button--m-control--BackgroundColor: var(--pf-global--BackgroundColor--400);\n  --pf-c-button--m-control--hover--BackgroundColor: var(--pf-global--BackgroundColor--400);\n  --pf-c-button--m-control--active--BackgroundColor: var(--pf-global--BackgroundColor--400);\n  --pf-c-button--m-control--focus--BackgroundColor: var(--pf-global--BackgroundColor--400);\n  --pf-c-button--m-control--m-expanded--BackgroundColor: var(--pf-global--BackgroundColor--400);\n  --pf-c-button--m-control--after--BorderTopColor: transparent;\n  --pf-c-button--m-control--after--BorderRightColor: transparent;\n  --pf-c-button--m-control--after--BorderBottomColor: var(--pf-global--BorderColor--400);\n  --pf-c-button--m-control--after--BorderLeftColor: transparent;\n  --pf-c-button--m-control--hover--after--BorderBottomColor: var(--pf-global--primary-color--100);\n  --pf-c-button--m-control--active--after--BorderBottomColor: var(--pf-global--primary-color--100);\n  --pf-c-button--m-control--focus--after--BorderBottomColor: var(--pf-global--primary-color--100);\n  --pf-c-button--m-control--m-expanded--after--BorderBottomColor: var(--pf-global--primary-color--100);\n  --pf-c-button--m-control--disabled--BackgroundColor: var(--pf-global--disabled-color--200);\n  --pf-c-button--m-primary__c-badge--BorderColor: var(--pf-global--Color--100);\n}\n:where(.pf-theme-dark) .pf-c-button.pf-m-control:disabled::after {\n  border: 0;\n  border-bottom: var(--pf-global--BorderWidth--sm) solid var(--pf-global--palette--black-700);\n}';

// node_modules/@patternfly/patternfly/components/Page/page.css
var page_default = '.pf-c-page__sidebar.pf-m-light {\n  --pf-global--Color--100: var(--pf-global--Color--dark-100);\n  --pf-global--Color--200: var(--pf-global--Color--dark-200);\n  --pf-global--BorderColor--100: var(--pf-global--BorderColor--dark-100);\n  --pf-global--primary-color--100: var(--pf-global--primary-color--dark-100);\n  --pf-global--link--Color: var(--pf-global--link--Color--dark);\n  --pf-global--link--Color--hover: var(--pf-global--link--Color--dark--hover);\n  --pf-global--BackgroundColor--100: var(--pf-global--BackgroundColor--light-100);\n}\n\n.pf-c-page__main-section[class*=pf-m-dark-], .pf-c-page__sidebar-body.pf-m-menu .pf-c-context-selector, .pf-c-page__header {\n  --pf-global--Color--100: var(--pf-global--Color--light-100);\n  --pf-global--Color--200: var(--pf-global--Color--light-200);\n  --pf-global--BorderColor--100: var(--pf-global--BorderColor--light-100);\n  --pf-global--primary-color--100: var(--pf-global--primary-color--light-100);\n  --pf-global--link--Color: var(--pf-global--link--Color--light);\n  --pf-global--link--Color--hover: var(--pf-global--link--Color--light);\n  --pf-global--BackgroundColor--100: var(--pf-global--BackgroundColor--dark-100);\n}\n.pf-c-page__main-section[class*=pf-m-dark-] .pf-c-card, .pf-c-page__sidebar-body.pf-m-menu .pf-c-context-selector .pf-c-card, .pf-c-page__header .pf-c-card {\n  --pf-c-card--BackgroundColor: var(--pf-global--BackgroundColor--dark-transparent-200);\n}\n.pf-c-page__main-section[class*=pf-m-dark-] .pf-c-button, .pf-c-page__sidebar-body.pf-m-menu .pf-c-context-selector .pf-c-button, .pf-c-page__header .pf-c-button {\n  --pf-c-button--m-primary--Color: var(--pf-global--primary-color--dark-100);\n  --pf-c-button--m-primary--hover--Color: var(--pf-global--primary-color--dark-100);\n  --pf-c-button--m-primary--focus--Color: var(--pf-global--primary-color--dark-100);\n  --pf-c-button--m-primary--active--Color: var(--pf-global--primary-color--dark-100);\n  --pf-c-button--m-primary--BackgroundColor: var(--pf-global--BackgroundColor--light-100);\n  --pf-c-button--m-primary--hover--BackgroundColor: var(--pf-global--BackgroundColor--light-300);\n  --pf-c-button--m-primary--focus--BackgroundColor: var(--pf-global--BackgroundColor--light-300);\n  --pf-c-button--m-primary--active--BackgroundColor: var(--pf-global--BackgroundColor--light-300);\n  --pf-c-button--m-secondary--Color: var(--pf-global--Color--light-100);\n  --pf-c-button--m-secondary--hover--Color: var(--pf-global--Color--light-100);\n  --pf-c-button--m-secondary--focus--Color: var(--pf-global--Color--light-100);\n  --pf-c-button--m-secondary--active--Color: var(--pf-global--Color--light-100);\n  --pf-c-button--m-secondary--BorderColor: var(--pf-global--Color--light-100);\n  --pf-c-button--m-secondary--hover--BorderColor: var(--pf-global--Color--light-100);\n  --pf-c-button--m-secondary--focus--BorderColor: var(--pf-global--Color--light-100);\n  --pf-c-button--m-secondary--active--BorderColor: var(--pf-global--Color--light-100);\n}\n\n.pf-c-page__header-tools-item, .pf-c-page__header-tools-group {\n  --pf-hidden-visible--visible--Visibility: visible;\n  --pf-hidden-visible--hidden--Display: none;\n  --pf-hidden-visible--hidden--Visibility: hidden;\n  --pf-hidden-visible--Display: var(--pf-hidden-visible--visible--Display);\n  --pf-hidden-visible--Visibility: var(--pf-hidden-visible--visible--Visibility);\n  display: var(--pf-hidden-visible--Display);\n  visibility: var(--pf-hidden-visible--Visibility);\n}\n.pf-m-hidden.pf-c-page__header-tools-item, .pf-m-hidden.pf-c-page__header-tools-group {\n  --pf-hidden-visible--Display: var(--pf-hidden-visible--hidden--Display);\n  --pf-hidden-visible--Visibility: var(--pf-hidden-visible--hidden--Visibility);\n}\n@media screen and (min-width: 576px) {\n  .pf-m-hidden-on-sm.pf-c-page__header-tools-item, .pf-m-hidden-on-sm.pf-c-page__header-tools-group {\n    --pf-hidden-visible--Display: var(--pf-hidden-visible--hidden--Display);\n    --pf-hidden-visible--Visibility: var(--pf-hidden-visible--hidden--Visibility);\n  }\n  .pf-m-visible-on-sm.pf-c-page__header-tools-item, .pf-m-visible-on-sm.pf-c-page__header-tools-group {\n    --pf-hidden-visible--Display: var(--pf-hidden-visible--visible--Display);\n    --pf-hidden-visible--Visibility: var(--pf-hidden-visible--visible--Visibility);\n  }\n}\n@media screen and (min-width: 768px) {\n  .pf-m-hidden-on-md.pf-c-page__header-tools-item, .pf-m-hidden-on-md.pf-c-page__header-tools-group {\n    --pf-hidden-visible--Display: var(--pf-hidden-visible--hidden--Display);\n    --pf-hidden-visible--Visibility: var(--pf-hidden-visible--hidden--Visibility);\n  }\n  .pf-m-visible-on-md.pf-c-page__header-tools-item, .pf-m-visible-on-md.pf-c-page__header-tools-group {\n    --pf-hidden-visible--Display: var(--pf-hidden-visible--visible--Display);\n    --pf-hidden-visible--Visibility: var(--pf-hidden-visible--visible--Visibility);\n  }\n}\n@media screen and (min-width: 992px) {\n  .pf-m-hidden-on-lg.pf-c-page__header-tools-item, .pf-m-hidden-on-lg.pf-c-page__header-tools-group {\n    --pf-hidden-visible--Display: var(--pf-hidden-visible--hidden--Display);\n    --pf-hidden-visible--Visibility: var(--pf-hidden-visible--hidden--Visibility);\n  }\n  .pf-m-visible-on-lg.pf-c-page__header-tools-item, .pf-m-visible-on-lg.pf-c-page__header-tools-group {\n    --pf-hidden-visible--Display: var(--pf-hidden-visible--visible--Display);\n    --pf-hidden-visible--Visibility: var(--pf-hidden-visible--visible--Visibility);\n  }\n}\n@media screen and (min-width: 1200px) {\n  .pf-m-hidden-on-xl.pf-c-page__header-tools-item, .pf-m-hidden-on-xl.pf-c-page__header-tools-group {\n    --pf-hidden-visible--Display: var(--pf-hidden-visible--hidden--Display);\n    --pf-hidden-visible--Visibility: var(--pf-hidden-visible--hidden--Visibility);\n  }\n  .pf-m-visible-on-xl.pf-c-page__header-tools-item, .pf-m-visible-on-xl.pf-c-page__header-tools-group {\n    --pf-hidden-visible--Display: var(--pf-hidden-visible--visible--Display);\n    --pf-hidden-visible--Visibility: var(--pf-hidden-visible--visible--Visibility);\n  }\n}\n@media screen and (min-width: 1450px) {\n  .pf-m-hidden-on-2xl.pf-c-page__header-tools-item, .pf-m-hidden-on-2xl.pf-c-page__header-tools-group {\n    --pf-hidden-visible--Display: var(--pf-hidden-visible--hidden--Display);\n    --pf-hidden-visible--Visibility: var(--pf-hidden-visible--hidden--Visibility);\n  }\n  .pf-m-visible-on-2xl.pf-c-page__header-tools-item, .pf-m-visible-on-2xl.pf-c-page__header-tools-group {\n    --pf-hidden-visible--Display: var(--pf-hidden-visible--visible--Display);\n    --pf-hidden-visible--Visibility: var(--pf-hidden-visible--visible--Visibility);\n  }\n}\n\n.pf-c-page {\n  --pf-c-page--BackgroundColor: var(--pf-global--BackgroundColor--light-300);\n  --pf-c-page__header--BackgroundColor: var(--pf-global--BackgroundColor--dark-100);\n  --pf-c-page__header--ZIndex: var(--pf-global--ZIndex--md);\n  --pf-c-page__header--MinHeight: 4.75rem;\n  --pf-c-page__header-brand--PaddingLeft: var(--pf-global--spacer--md);\n  --pf-c-page__header-brand--xl--PaddingRight: var(--pf-global--spacer--xl);\n  --pf-c-page__header-brand--xl--PaddingLeft: var(--pf-global--spacer--lg);\n  --pf-c-page__header-sidebar-toggle__c-button--PaddingTop: var(--pf-global--spacer--sm);\n  --pf-c-page__header-sidebar-toggle__c-button--PaddingRight: var(--pf-global--spacer--sm);\n  --pf-c-page__header-sidebar-toggle__c-button--PaddingBottom: var(--pf-global--spacer--sm);\n  --pf-c-page__header-sidebar-toggle__c-button--PaddingLeft: var(--pf-global--spacer--sm);\n  --pf-c-page__header-sidebar-toggle__c-button--MarginRight: var(--pf-global--spacer--md);\n  --pf-c-page__header-sidebar-toggle__c-button--MarginLeft: calc(var(--pf-c-page__header-sidebar-toggle__c-button--PaddingLeft) * -1);\n  --pf-c-page__header-sidebar-toggle__c-button--FontSize: var(--pf-global--FontSize--2xl);\n  --pf-c-page__header-brand-link--c-brand--MaxHeight: 3.75rem;\n  --pf-c-page__header-nav--BackgroundColor: var(--pf-global--BackgroundColor--dark-300);\n  --pf-c-page__header-nav--xl--BackgroundColor: transparent;\n  --pf-c-page__header-nav--xl--PaddingRight: var(--pf-global--spacer--xl);\n  --pf-c-page__header-nav--xl--PaddingLeft: var(--pf-global--spacer--xl);\n  --pf-c-page__header-tools--MarginRight: var(--pf-global--spacer--md);\n  --pf-c-page__header-tools--xl--MarginRight: var(--pf-global--spacer--lg);\n  --pf-c-page__header-tools--c-avatar--MarginLeft: var(--pf-global--spacer--md);\n  --pf-c-page__header-tools-group--MarginLeft: var(--pf-global--spacer--xl);\n  --pf-c-page__header-tools-group--Display: flex;\n  --pf-c-page__header-tools-item--Display: block;\n  --pf-c-page__header-tools-item--c-notification-badge--hover--BackgroundColor: var(--pf-global--BackgroundColor--dark-200);\n  --pf-c-page__header-tools--c-button--notification-badge--m-unread--after--BackgroundColor: var(--pf-global--primary-color--200);\n  --pf-c-page__header-tools--c-button--notification-badge--m-attention--after--BackgroundColor: var(--pf-global--danger-color--200);\n  --pf-c-page__header-tools--c-button--m-selected--notification-badge--m-unread--after--BackgroundColor: var(--pf-global--primary-color--200);\n  --pf-c-page__header-tools--c-button--m-selected--notification-badge--m-attention--after--BackgroundColor: var(--pf-global--danger-color--200);\n  --pf-c-page__header-tools--c-button--m-selected--before--Width: auto;\n  --pf-c-page__header-tools--c-button--m-selected--before--Height: auto;\n  --pf-c-page__header-tools--c-button--m-selected--before--BackgroundColor: var(--pf-global--BackgroundColor--dark-200);\n  --pf-c-page__header-tools--c-button--m-selected--before--BorderRadius: var(--pf-global--BorderRadius--sm);\n  --pf-c-page__header-tools--c-button--m-selected--c-notification-badge--m-unread--after--BorderColor: transparent;\n  --pf-c-page__sidebar--ZIndex: var(--pf-global--ZIndex--sm);\n  --pf-c-page__sidebar--Width: 18.125rem;\n  --pf-c-page__sidebar--BackgroundColor: var(--pf-global--BackgroundColor--dark-300);\n  --pf-c-page__sidebar--m-light--BackgroundColor: var(--pf-global--BackgroundColor--light-100);\n  --pf-c-page__sidebar--m-light--BorderRightWidth: var(--pf-global--BorderWidth--sm);\n  --pf-c-page__sidebar--m-light--BorderRightColor: var(--pf-global--BorderColor--100);\n  --pf-c-page__sidebar--BoxShadow: var(--pf-global--BoxShadow--lg-right);\n  --pf-c-page__sidebar--Transition: var(--pf-global--Transition);\n  --pf-c-page__sidebar--TranslateX: -100%;\n  --pf-c-page__sidebar--TranslateZ: 0;\n  --pf-c-page__sidebar--m-expanded--TranslateX: 0;\n  --pf-c-page__sidebar--xl--TranslateX: 0;\n  --pf-c-page__sidebar-body--PaddingTop: var(--pf-global--spacer--sm);\n  --pf-c-page__sidebar-body--PaddingBottom: var(--pf-global--spacer--md);\n  --pf-c-page__sidebar-body--m-menu--PaddingTop: 0;\n  --pf-c-page__sidebar-body--m-menu--PaddingBottom: 0;\n  --pf-c-page__sidebar-body--m-menu--BorderTopColor: var(--pf-global--BackgroundColor--dark-200);\n  --pf-c-page__sidebar-body--m-menu--BorderTopWidth: var(--pf-global--BorderWidth--sm);\n  --pf-c-page__sidebar-body--m-menu--c-context-selector--BorderBottomColor: var(--pf-global--BackgroundColor--dark-200);\n  --pf-c-page__main--ZIndex: var(--pf-global--ZIndex--xs);\n  --pf-c-page__main-section--PaddingTop: var(--pf-global--spacer--md);\n  --pf-c-page__main-section--PaddingRight: var(--pf-global--spacer--md);\n  --pf-c-page__main-section--PaddingBottom: var(--pf-global--spacer--md);\n  --pf-c-page__main-section--PaddingLeft: var(--pf-global--spacer--md);\n  --pf-c-page__main-section--xl--PaddingTop: var(--pf-global--spacer--lg);\n  --pf-c-page__main-section--xl--PaddingRight: var(--pf-global--spacer--lg);\n  --pf-c-page__main-section--xl--PaddingBottom: var(--pf-global--spacer--lg);\n  --pf-c-page__main-section--xl--PaddingLeft: var(--pf-global--spacer--lg);\n  --pf-c-page__main-breadcrumb--main-section--PaddingTop: var(--pf-global--spacer--md);\n  --pf-c-page__main-section--BackgroundColor: var(--pf-global--BackgroundColor--light-300);\n  --pf-c-page__main-section--m-light--BackgroundColor: var(--pf-global--BackgroundColor--light-100);\n  --pf-c-page__main-section--m-light-100--BackgroundColor: var(--pf-global--BackgroundColor--150);\n  --pf-c-page__main-section--m-dark-100--BackgroundColor: var(--pf-global--BackgroundColor--dark-transparent-100);\n  --pf-c-page__main-section--m-dark-200--BackgroundColor: var(--pf-global--BackgroundColor--dark-transparent-200);\n  --pf-c-page__main-breadcrumb--page__main-tabs--PaddingTop: var(--pf-global--spacer--md);\n  --pf-c-page__main-nav--page__main-tabs--PaddingTop: var(--pf-global--spacer--md);\n  --pf-c-page--section--m-limit-width--MaxWidth: calc(125rem - var(--pf-c-page__sidebar--Width));\n  --pf-c-page--section--m-sticky-top--ZIndex: var(--pf-global--ZIndex--md);\n  --pf-c-page--section--m-sticky-top--BoxShadow: var(--pf-global--BoxShadow--sm-bottom);\n  --pf-c-page--section--m-sticky-bottom--ZIndex: var(--pf-global--ZIndex--md);\n  --pf-c-page--section--m-sticky-bottom--BoxShadow: var(--pf-global--BoxShadow--sm-top);\n  --pf-c-page--section--m-shadow-bottom--BoxShadow: var(--pf-global--BoxShadow--sm-bottom);\n  --pf-c-page--section--m-shadow-bottom--ZIndex: var(--pf-global--ZIndex--xs);\n  --pf-c-page--section--m-shadow-top--BoxShadow: var(--pf-global--BoxShadow--sm-top);\n  --pf-c-page--section--m-shadow-top--ZIndex: var(--pf-global--ZIndex--xs);\n  --pf-c-page__main-nav--BackgroundColor: var(--pf-global--BackgroundColor--light-100);\n  --pf-c-page__main-nav--PaddingTop: var(--pf-global--spacer--md);\n  --pf-c-page__main-nav--PaddingRight: 0;\n  --pf-c-page__main-nav--PaddingLeft: 0;\n  --pf-c-page__main-nav--m-sticky-top--PaddingBottom: var(--pf-global--spacer--md);\n  --pf-c-page__main-nav--xl--PaddingRight: var(--pf-global--spacer--sm);\n  --pf-c-page__main-nav--xl--PaddingLeft: var(--pf-global--spacer--sm);\n  --pf-c-page__main-subnav--BackgroundColor: var(--pf-global--BackgroundColor--dark-300);\n  --pf-c-page__main-subnav--BorderTopWidth: var(--pf-global--BorderWidth--sm);\n  --pf-c-page__main-subnav--BorderTopColor: var(--pf-global--palette--black-800);\n  --pf-c-page__main-subnav--BorderLeftWidth: 0;\n  --pf-c-page__main-subnav--BorderLeftColor: var(--pf-global--palette--black-800);\n  --pf-c-page__sidebar--main__main-subnav--BorderLeftWidth: var(--pf-global--BorderWidth--sm);\n  --pf-c-page__sidebar--m-collapsed--main__main-subnav--BorderLeftWidth: 0;\n  --pf-c-page__main-breadcrumb--BackgroundColor: var(--pf-global--BackgroundColor--light-100);\n  --pf-c-page__main-breadcrumb--PaddingTop: var(--pf-global--spacer--md);\n  --pf-c-page__main-breadcrumb--PaddingRight: var(--pf-global--spacer--md);\n  --pf-c-page__main-breadcrumb--PaddingBottom: 0;\n  --pf-c-page__main-breadcrumb--PaddingLeft: var(--pf-global--spacer--md);\n  --pf-c-page__main-breadcrumb--m-sticky-top--PaddingBottom: var(--pf-global--spacer--md);\n  --pf-c-page__main-breadcrumb--xl--PaddingRight: var(--pf-global--spacer--lg);\n  --pf-c-page__main-breadcrumb--xl--PaddingLeft: var(--pf-global--spacer--lg);\n  --pf-c-page__main-tabs--PaddingTop: 0;\n  --pf-c-page__main-tabs--PaddingRight: 0;\n  --pf-c-page__main-tabs--PaddingBottom: 0;\n  --pf-c-page__main-tabs--PaddingLeft: 0;\n  --pf-c-page__main-tabs--BackgroundColor: var(--pf-global--BackgroundColor--light-100);\n  --pf-c-page__main-wizard--BackgroundColor: var(--pf-global--BackgroundColor--light-100);\n  --pf-c-page__main-wizard--BorderTopColor: var(--pf-global--BorderColor--100);\n  --pf-c-page__main-wizard--BorderTopWidth: var(--pf-global--BorderWidth--sm);\n  --pf-c-page__main-wizard--m-light-200--BackgroundColor: var(--pf-global--BackgroundColor--200);\n  display: grid;\n  height: 100%;\n  grid-template-columns: 1fr;\n  grid-template-rows: max-content 1fr;\n  grid-template-areas: "header" "main";\n  background-color: var(--pf-c-page--BackgroundColor);\n}\n@media (min-width: 1200px) {\n  .pf-c-page {\n    --pf-c-page__header-brand--PaddingLeft: var(--pf-c-page__header-brand--xl--PaddingLeft);\n  }\n}\n@media screen and (min-width: 1200px) {\n  .pf-c-page {\n    --pf-c-page__header-nav--BackgroundColor: var(--pf-c-page__header-nav--xl--BackgroundColor);\n    --pf-c-page__header-nav--PaddingRight: var(--pf-c-page__header-nav--xl--PaddingRight);\n    --pf-c-page__header-nav--PaddingLeft: var(--pf-c-page__header-nav--xl--PaddingLeft);\n  }\n}\n@media screen and (min-width: 1200px) {\n  .pf-c-page {\n    --pf-c-page__header-tools--MarginRight: var(--pf-c-page__header-tools--xl--MarginRight);\n  }\n}\n@media screen and (min-width: 1200px) {\n  .pf-c-page {\n    --pf-c-page__sidebar--TranslateX: var(--pf-c-page__sidebar--xl--TranslateX);\n  }\n}\n@media screen and (min-width: 1200px) {\n  .pf-c-page {\n    --pf-c-page__main-section--PaddingTop: var(--pf-c-page__main-section--xl--PaddingTop);\n    --pf-c-page__main-section--PaddingRight: var(--pf-c-page__main-section--xl--PaddingRight);\n    --pf-c-page__main-section--PaddingBottom: var(--pf-c-page__main-section--xl--PaddingBottom);\n    --pf-c-page__main-section--PaddingLeft: var(--pf-c-page__main-section--xl--PaddingLeft);\n  }\n}\n@media screen and (min-width: 1200px) {\n  .pf-c-page {\n    --pf-c-page__main-nav--PaddingRight: var(--pf-c-page__main-nav--xl--PaddingRight);\n    --pf-c-page__main-nav--PaddingLeft: var(--pf-c-page__main-nav--xl--PaddingLeft);\n  }\n}\n@media screen and (min-width: 1200px) {\n  .pf-c-page {\n    --pf-c-page__main-breadcrumb--PaddingRight: var(--pf-c-page__main-breadcrumb--xl--PaddingRight);\n    --pf-c-page__main-breadcrumb--PaddingLeft: var(--pf-c-page__main-breadcrumb--xl--PaddingLeft);\n  }\n}\n@media (min-width: 1200px) {\n  .pf-c-page {\n    grid-template-columns: max-content 1fr;\n    grid-template-areas: "header header" "nav main";\n  }\n}\n.pf-c-page.pf-m-full-height {\n  height: 100vh;\n  height: 100dvh;\n  max-height: 100%;\n}\n\n.pf-c-page__header,\n.pf-c-page > .pf-c-masthead {\n  grid-area: header;\n  z-index: var(--pf-c-page__header--ZIndex);\n}\n\n.pf-c-page__header {\n  color: var(--pf-global--Color--100);\n  grid-template-columns: auto auto;\n  display: grid;\n  align-items: center;\n  min-width: 0;\n  min-height: var(--pf-c-page__header--MinHeight);\n  background-color: var(--pf-c-page__header--BackgroundColor);\n}\n.pf-c-page__header > * {\n  display: flex;\n  align-items: center;\n}\n@media screen and (min-width: 992px) {\n  .pf-c-page__header {\n    grid-template-columns: auto 1fr auto;\n  }\n}\n.pf-c-page__header .pf-c-masthead {\n  grid-column: span 2;\n  align-self: stretch;\n}\n\n.pf-c-page__header-brand {\n  grid-column: 1/2;\n  padding-left: var(--pf-c-page__header-brand--PaddingLeft);\n}\n@media (min-width: 1200px) {\n  .pf-c-page__header-brand {\n    padding-right: var(--pf-c-page__header-brand--xl--PaddingRight);\n  }\n}\n\n.pf-c-page__header-brand-link {\n  display: flex;\n  flex: 1;\n  align-items: center;\n}\n.pf-c-page__header-brand-link .pf-c-brand {\n  max-height: var(--pf-c-page__header-brand-link--c-brand--MaxHeight);\n}\n\n.pf-c-page__header-brand-toggle .pf-c-button {\n  padding: var(--pf-c-page__header-sidebar-toggle__c-button--PaddingTop) var(--pf-c-page__header-sidebar-toggle__c-button--PaddingRight) var(--pf-c-page__header-sidebar-toggle__c-button--PaddingBottom) var(--pf-c-page__header-sidebar-toggle__c-button--PaddingLeft);\n  margin-right: var(--pf-c-page__header-sidebar-toggle__c-button--MarginRight);\n  margin-left: var(--pf-c-page__header-sidebar-toggle__c-button--MarginLeft);\n  font-size: var(--pf-c-page__header-sidebar-toggle__c-button--FontSize);\n  line-height: 1;\n}\n\n.pf-c-page__header-nav {\n  align-self: stretch;\n  min-width: 0;\n  padding-right: var(--pf-c-page__header-nav--PaddingRight);\n  padding-left: var(--pf-c-page__header-nav--PaddingLeft);\n  background-color: var(--pf-c-page__header-nav--BackgroundColor);\n  grid-column: 1/-1;\n  grid-row: 2/3;\n}\n@media screen and (min-width: 1200px) {\n  .pf-c-page__header-nav {\n    grid-column: 2/3;\n    grid-row: 1/2;\n  }\n}\n.pf-c-page__header-nav .pf-c-nav {\n  align-self: stretch;\n}\n\n.pf-c-page__header-tools {\n  grid-column: 2/3;\n  margin-right: var(--pf-c-page__header-tools--MarginRight);\n  margin-left: auto;\n}\n.pf-c-page__header-tools .pf-c-avatar {\n  margin-left: var(--pf-c-page__header-tools--c-avatar--MarginLeft);\n}\n@media screen and (min-width: 992px) {\n  .pf-c-page__header-tools {\n    grid-column: 3/4;\n  }\n}\n\n.pf-c-page__header-tools-group {\n  --pf-hidden-visible--visible--Display: var(--pf-c-page__header-tools-group--Display);\n  align-items: center;\n}\n.pf-c-page__header-tools-group + .pf-c-page__header-tools-group {\n  margin-left: var(--pf-c-page__header-tools-group--MarginLeft);\n}\n\n.pf-c-page__header-tools-item {\n  --pf-hidden-visible--visible--Display: var(--pf-c-page__header-tools-item--Display);\n}\n.pf-c-page__header-tools-item .pf-c-notification-badge.pf-m-read:hover {\n  --pf-c-notification-badge--after--BackgroundColor: var(--pf-c-page__header-tools-item--c-notification-badge--hover--BackgroundColor);\n}\n.pf-c-page__header-tools-item.pf-m-selected .pf-c-button {\n  background-color: var(--pf-c-page__header-tools--c-button--m-selected--before--BackgroundColor);\n  border-radius: var(--pf-c-page__header-tools--c-button--m-selected--before--BorderRadius);\n}\n.pf-c-page__header-tools-item.pf-m-selected .pf-c-button::before {\n  position: absolute;\n  top: 0;\n  right: 0;\n  bottom: 0;\n  left: 0;\n  width: var(--pf-c-page__header-tools--c-button--m-selected--before--Width);\n  height: var(--pf-c-page__header-tools--c-button--m-selected--before--Height);\n  content: "";\n}\n.pf-c-page__header-tools-item.pf-m-selected .pf-c-button .pf-c-notification-badge.pf-m-unread {\n  --pf-c-notification-badge--after--BackgroundColor: var(--pf-c-page__header-tools--c-button--m-selected--notification-badge--m-unread--after--BackgroundColor);\n}\n.pf-c-page__header-tools-item.pf-m-selected .pf-c-button .pf-c-notification-badge.pf-m-unread::after {\n  border-color: var(--pf-c-page__header-tools--c-button--m-selected--c-notification-badge--m-unread--after--BorderColor);\n}\n.pf-c-page__header-tools-item.pf-m-selected .pf-c-button .pf-c-notification-badge.pf-m-attention {\n  --pf-c-notification-badge--after--BackgroundColor: var(--pf-global--danger-color--200);\n}\n.pf-c-page__header-tools-item .pf-c-button:focus .pf-c-notification-badge.pf-m-unread {\n  --pf-c-notification-badge--after--BackgroundColor: var(--pf-c-page__header-tools--c-button--notification-badge--m-unread--after--BackgroundColor);\n}\n.pf-c-page__header-tools-item .pf-c-button:focus .pf-c-notification-badge.pf-m-attention {\n  --pf-c-notification-badge--after--BackgroundColor: var(--pf-c-page__header-tools--c-button--notification-badge--m-attention--after--BackgroundColor);\n}\n\n.pf-c-page__sidebar {\n  grid-area: nav;\n  grid-row-start: 2;\n  grid-column-start: 1;\n  z-index: var(--pf-c-page__sidebar--ZIndex);\n  width: var(--pf-c-page__sidebar--Width);\n  overflow-x: hidden;\n  overflow-y: auto;\n  -webkit-overflow-scrolling: touch;\n  background-color: var(--pf-c-page__sidebar--BackgroundColor);\n  transition: var(--pf-c-page__sidebar--Transition);\n  transform: translateX(var(--pf-c-page__sidebar--TranslateX)) translateZ(var(--pf-c-page__sidebar--TranslateZ));\n}\n.pf-c-page__sidebar.pf-m-expanded {\n  --pf-c-page__sidebar--TranslateX: var(--pf-c-page__sidebar--m-expanded--TranslateX);\n  box-shadow: var(--pf-c-page__sidebar--BoxShadow);\n}\n@media screen and (min-width: 1200px) {\n  .pf-c-page__sidebar.pf-m-expanded {\n    --pf-c-page__sidebar--BoxShadow: none;\n  }\n}\n.pf-c-page__sidebar.pf-m-collapsed {\n  max-width: 0;\n  overflow: hidden;\n}\n.pf-c-page__sidebar.pf-m-light {\n  color: var(--pf-global--Color--100);\n  --pf-c-page__sidebar--BackgroundColor: var(--pf-c-page__sidebar--m-light--BackgroundColor);\n  border-right: var(--pf-c-page__sidebar--m-light--BorderRightWidth) solid var(--pf-c-page__sidebar--m-light--BorderRightColor);\n}\n\n.pf-c-page__sidebar-body {\n  padding-top: var(--pf-c-page__sidebar-body--PaddingTop);\n  padding-bottom: var(--pf-c-page__sidebar-body--PaddingBottom);\n}\n.pf-c-page__sidebar-body.pf-m-menu {\n  --pf-c-page__sidebar-body--PaddingTop: var(--pf-c-page__sidebar-body--m-menu--PaddingTop);\n  --pf-c-page__sidebar-body--PaddingBottom: var(--pf-c-page__sidebar-body--m-menu--PaddingBottom);\n  background-color: var(--pf-global--palette--black-900);\n  border-top: var(--pf-c-page__sidebar-body--m-menu--BorderTopWidth) solid var(--pf-c-page__sidebar-body--m-menu--BorderTopColor);\n}\n.pf-c-page__sidebar-body.pf-m-menu + .pf-c-page__sidebar-body.pf-m-menu {\n  --pf-c-page__sidebar-body--m-menu--BorderTopWidth: 0;\n}\n.pf-c-page__sidebar-body.pf-m-menu .pf-c-context-selector {\n  --pf-c-context-selector__toggle--BorderTopColor: transparent;\n  --pf-c-context-selector__toggle--BorderRightColor: transparent;\n  --pf-c-context-selector__toggle--BorderBottomColor: var(--pf-c-page__sidebar-body--m-menu--c-context-selector--BorderBottomColor);\n  --pf-c-context-selector__toggle--BorderLeftColor: transparent;\n  --pf-c-context-selector__menu--Top: 100%;\n  color: var(--pf-global--Color--100);\n  width: 100%;\n}\n\n.pf-c-page__main-nav.pf-m-limit-width,\n.pf-c-page__main-breadcrumb.pf-m-limit-width,\n.pf-c-page__main-tabs.pf-m-limit-width,\n.pf-c-page__main-section.pf-m-limit-width,\n.pf-c-page__main-wizard.pf-m-limit-width {\n  display: flex;\n  flex-direction: column;\n  padding: 0;\n}\n.pf-c-page__main-nav.pf-m-limit-width > .pf-c-page__main-body,\n.pf-c-page__main-breadcrumb.pf-m-limit-width > .pf-c-page__main-body,\n.pf-c-page__main-tabs.pf-m-limit-width > .pf-c-page__main-body,\n.pf-c-page__main-section.pf-m-limit-width > .pf-c-page__main-body,\n.pf-c-page__main-wizard.pf-m-limit-width > .pf-c-page__main-body {\n  flex: 1;\n  max-width: var(--pf-c-page--section--m-limit-width--MaxWidth);\n}\n.pf-c-page__main-nav.pf-m-limit-width.pf-m-align-center,\n.pf-c-page__main-breadcrumb.pf-m-limit-width.pf-m-align-center,\n.pf-c-page__main-tabs.pf-m-limit-width.pf-m-align-center,\n.pf-c-page__main-section.pf-m-limit-width.pf-m-align-center,\n.pf-c-page__main-wizard.pf-m-limit-width.pf-m-align-center {\n  align-items: center;\n}\n.pf-c-page__main-nav.pf-m-limit-width.pf-m-align-center > .pf-c-page__main-body,\n.pf-c-page__main-breadcrumb.pf-m-limit-width.pf-m-align-center > .pf-c-page__main-body,\n.pf-c-page__main-tabs.pf-m-limit-width.pf-m-align-center > .pf-c-page__main-body,\n.pf-c-page__main-section.pf-m-limit-width.pf-m-align-center > .pf-c-page__main-body,\n.pf-c-page__main-wizard.pf-m-limit-width.pf-m-align-center > .pf-c-page__main-body {\n  width: 100%;\n}\n\n.pf-c-page__main-nav,\n.pf-c-page__main-breadcrumb,\n.pf-c-page__main-tabs,\n.pf-c-page__main-section,\n.pf-c-page__main-wizard,\n.pf-c-page__main-group,\n.pf-c-page__main-subnav {\n  flex-shrink: 0;\n}\n.pf-c-page__main-nav.pf-m-overflow-scroll,\n.pf-c-page__main-breadcrumb.pf-m-overflow-scroll,\n.pf-c-page__main-tabs.pf-m-overflow-scroll,\n.pf-c-page__main-section.pf-m-overflow-scroll,\n.pf-c-page__main-wizard.pf-m-overflow-scroll,\n.pf-c-page__main-group.pf-m-overflow-scroll,\n.pf-c-page__main-subnav.pf-m-overflow-scroll {\n  position: relative;\n  flex-shrink: 1;\n  overflow: auto;\n}\n.pf-c-page__main-nav.pf-m-shadow-bottom,\n.pf-c-page__main-breadcrumb.pf-m-shadow-bottom,\n.pf-c-page__main-tabs.pf-m-shadow-bottom,\n.pf-c-page__main-section.pf-m-shadow-bottom,\n.pf-c-page__main-wizard.pf-m-shadow-bottom,\n.pf-c-page__main-group.pf-m-shadow-bottom,\n.pf-c-page__main-subnav.pf-m-shadow-bottom {\n  z-index: var(--pf-c-page--section--m-shadow-bottom--ZIndex);\n  box-shadow: var(--pf-c-page--section--m-shadow-bottom--BoxShadow);\n}\n.pf-c-page__main-nav.pf-m-shadow-top,\n.pf-c-page__main-breadcrumb.pf-m-shadow-top,\n.pf-c-page__main-tabs.pf-m-shadow-top,\n.pf-c-page__main-section.pf-m-shadow-top,\n.pf-c-page__main-wizard.pf-m-shadow-top,\n.pf-c-page__main-group.pf-m-shadow-top,\n.pf-c-page__main-subnav.pf-m-shadow-top {\n  z-index: var(--pf-c-page--section--m-shadow-top--ZIndex);\n  box-shadow: var(--pf-c-page--section--m-shadow-top--BoxShadow);\n}\n.pf-c-page__main-nav.pf-m-sticky-top,\n.pf-c-page__main-breadcrumb.pf-m-sticky-top,\n.pf-c-page__main-tabs.pf-m-sticky-top,\n.pf-c-page__main-section.pf-m-sticky-top,\n.pf-c-page__main-wizard.pf-m-sticky-top,\n.pf-c-page__main-group.pf-m-sticky-top,\n.pf-c-page__main-subnav.pf-m-sticky-top {\n  position: sticky;\n  top: 0;\n  z-index: var(--pf-c-page--section--m-sticky-top--ZIndex);\n  box-shadow: var(--pf-c-page--section--m-sticky-top--BoxShadow);\n}\n.pf-c-page__main-nav.pf-m-sticky-bottom,\n.pf-c-page__main-breadcrumb.pf-m-sticky-bottom,\n.pf-c-page__main-tabs.pf-m-sticky-bottom,\n.pf-c-page__main-section.pf-m-sticky-bottom,\n.pf-c-page__main-wizard.pf-m-sticky-bottom,\n.pf-c-page__main-group.pf-m-sticky-bottom,\n.pf-c-page__main-subnav.pf-m-sticky-bottom {\n  position: sticky;\n  bottom: 0;\n  z-index: var(--pf-c-page--section--m-sticky-bottom--ZIndex);\n  box-shadow: var(--pf-c-page--section--m-sticky-bottom--BoxShadow);\n}\n@media (min-height: 0) {\n  .pf-c-page__main-nav.pf-m-sticky-top-on-sm-height,\n.pf-c-page__main-breadcrumb.pf-m-sticky-top-on-sm-height,\n.pf-c-page__main-tabs.pf-m-sticky-top-on-sm-height,\n.pf-c-page__main-section.pf-m-sticky-top-on-sm-height,\n.pf-c-page__main-wizard.pf-m-sticky-top-on-sm-height,\n.pf-c-page__main-group.pf-m-sticky-top-on-sm-height,\n.pf-c-page__main-subnav.pf-m-sticky-top-on-sm-height {\n    position: sticky;\n    top: 0;\n    z-index: var(--pf-c-page--section--m-sticky-top--ZIndex);\n    box-shadow: var(--pf-c-page--section--m-sticky-top--BoxShadow);\n  }\n  .pf-c-page__main-nav.pf-m-sticky-bottom-on-sm-height,\n.pf-c-page__main-breadcrumb.pf-m-sticky-bottom-on-sm-height,\n.pf-c-page__main-tabs.pf-m-sticky-bottom-on-sm-height,\n.pf-c-page__main-section.pf-m-sticky-bottom-on-sm-height,\n.pf-c-page__main-wizard.pf-m-sticky-bottom-on-sm-height,\n.pf-c-page__main-group.pf-m-sticky-bottom-on-sm-height,\n.pf-c-page__main-subnav.pf-m-sticky-bottom-on-sm-height {\n    position: sticky;\n    bottom: 0;\n    z-index: var(--pf-c-page--section--m-sticky-bottom--ZIndex);\n    box-shadow: var(--pf-c-page--section--m-sticky-bottom--BoxShadow);\n  }\n}\n@media (min-height: 40rem) {\n  .pf-c-page__main-nav.pf-m-sticky-top-on-md-height,\n.pf-c-page__main-breadcrumb.pf-m-sticky-top-on-md-height,\n.pf-c-page__main-tabs.pf-m-sticky-top-on-md-height,\n.pf-c-page__main-section.pf-m-sticky-top-on-md-height,\n.pf-c-page__main-wizard.pf-m-sticky-top-on-md-height,\n.pf-c-page__main-group.pf-m-sticky-top-on-md-height,\n.pf-c-page__main-subnav.pf-m-sticky-top-on-md-height {\n    position: sticky;\n    top: 0;\n    z-index: var(--pf-c-page--section--m-sticky-top--ZIndex);\n    box-shadow: var(--pf-c-page--section--m-sticky-top--BoxShadow);\n  }\n  .pf-c-page__main-nav.pf-m-sticky-bottom-on-md-height,\n.pf-c-page__main-breadcrumb.pf-m-sticky-bottom-on-md-height,\n.pf-c-page__main-tabs.pf-m-sticky-bottom-on-md-height,\n.pf-c-page__main-section.pf-m-sticky-bottom-on-md-height,\n.pf-c-page__main-wizard.pf-m-sticky-bottom-on-md-height,\n.pf-c-page__main-group.pf-m-sticky-bottom-on-md-height,\n.pf-c-page__main-subnav.pf-m-sticky-bottom-on-md-height {\n    position: sticky;\n    bottom: 0;\n    z-index: var(--pf-c-page--section--m-sticky-bottom--ZIndex);\n    box-shadow: var(--pf-c-page--section--m-sticky-bottom--BoxShadow);\n  }\n}\n@media (min-height: 48rem) {\n  .pf-c-page__main-nav.pf-m-sticky-top-on-lg-height,\n.pf-c-page__main-breadcrumb.pf-m-sticky-top-on-lg-height,\n.pf-c-page__main-tabs.pf-m-sticky-top-on-lg-height,\n.pf-c-page__main-section.pf-m-sticky-top-on-lg-height,\n.pf-c-page__main-wizard.pf-m-sticky-top-on-lg-height,\n.pf-c-page__main-group.pf-m-sticky-top-on-lg-height,\n.pf-c-page__main-subnav.pf-m-sticky-top-on-lg-height {\n    position: sticky;\n    top: 0;\n    z-index: var(--pf-c-page--section--m-sticky-top--ZIndex);\n    box-shadow: var(--pf-c-page--section--m-sticky-top--BoxShadow);\n  }\n  .pf-c-page__main-nav.pf-m-sticky-bottom-on-lg-height,\n.pf-c-page__main-breadcrumb.pf-m-sticky-bottom-on-lg-height,\n.pf-c-page__main-tabs.pf-m-sticky-bottom-on-lg-height,\n.pf-c-page__main-section.pf-m-sticky-bottom-on-lg-height,\n.pf-c-page__main-wizard.pf-m-sticky-bottom-on-lg-height,\n.pf-c-page__main-group.pf-m-sticky-bottom-on-lg-height,\n.pf-c-page__main-subnav.pf-m-sticky-bottom-on-lg-height {\n    position: sticky;\n    bottom: 0;\n    z-index: var(--pf-c-page--section--m-sticky-bottom--ZIndex);\n    box-shadow: var(--pf-c-page--section--m-sticky-bottom--BoxShadow);\n  }\n}\n@media (min-height: 60rem) {\n  .pf-c-page__main-nav.pf-m-sticky-top-on-xl-height,\n.pf-c-page__main-breadcrumb.pf-m-sticky-top-on-xl-height,\n.pf-c-page__main-tabs.pf-m-sticky-top-on-xl-height,\n.pf-c-page__main-section.pf-m-sticky-top-on-xl-height,\n.pf-c-page__main-wizard.pf-m-sticky-top-on-xl-height,\n.pf-c-page__main-group.pf-m-sticky-top-on-xl-height,\n.pf-c-page__main-subnav.pf-m-sticky-top-on-xl-height {\n    position: sticky;\n    top: 0;\n    z-index: var(--pf-c-page--section--m-sticky-top--ZIndex);\n    box-shadow: var(--pf-c-page--section--m-sticky-top--BoxShadow);\n  }\n  .pf-c-page__main-nav.pf-m-sticky-bottom-on-xl-height,\n.pf-c-page__main-breadcrumb.pf-m-sticky-bottom-on-xl-height,\n.pf-c-page__main-tabs.pf-m-sticky-bottom-on-xl-height,\n.pf-c-page__main-section.pf-m-sticky-bottom-on-xl-height,\n.pf-c-page__main-wizard.pf-m-sticky-bottom-on-xl-height,\n.pf-c-page__main-group.pf-m-sticky-bottom-on-xl-height,\n.pf-c-page__main-subnav.pf-m-sticky-bottom-on-xl-height {\n    position: sticky;\n    bottom: 0;\n    z-index: var(--pf-c-page--section--m-sticky-bottom--ZIndex);\n    box-shadow: var(--pf-c-page--section--m-sticky-bottom--BoxShadow);\n  }\n}\n@media (min-height: 80rem) {\n  .pf-c-page__main-nav.pf-m-sticky-top-on-2xl-height,\n.pf-c-page__main-breadcrumb.pf-m-sticky-top-on-2xl-height,\n.pf-c-page__main-tabs.pf-m-sticky-top-on-2xl-height,\n.pf-c-page__main-section.pf-m-sticky-top-on-2xl-height,\n.pf-c-page__main-wizard.pf-m-sticky-top-on-2xl-height,\n.pf-c-page__main-group.pf-m-sticky-top-on-2xl-height,\n.pf-c-page__main-subnav.pf-m-sticky-top-on-2xl-height {\n    position: sticky;\n    top: 0;\n    z-index: var(--pf-c-page--section--m-sticky-top--ZIndex);\n    box-shadow: var(--pf-c-page--section--m-sticky-top--BoxShadow);\n  }\n  .pf-c-page__main-nav.pf-m-sticky-bottom-on-2xl-height,\n.pf-c-page__main-breadcrumb.pf-m-sticky-bottom-on-2xl-height,\n.pf-c-page__main-tabs.pf-m-sticky-bottom-on-2xl-height,\n.pf-c-page__main-section.pf-m-sticky-bottom-on-2xl-height,\n.pf-c-page__main-wizard.pf-m-sticky-bottom-on-2xl-height,\n.pf-c-page__main-group.pf-m-sticky-bottom-on-2xl-height,\n.pf-c-page__main-subnav.pf-m-sticky-bottom-on-2xl-height {\n    position: sticky;\n    bottom: 0;\n    z-index: var(--pf-c-page--section--m-sticky-bottom--ZIndex);\n    box-shadow: var(--pf-c-page--section--m-sticky-bottom--BoxShadow);\n  }\n}\n\n.pf-c-page__main,\n.pf-c-page__drawer {\n  grid-area: main;\n  z-index: var(--pf-c-page__main--ZIndex);\n  overflow-x: hidden;\n  overflow-y: auto;\n  -webkit-overflow-scrolling: touch;\n}\n.pf-c-page__main:focus,\n.pf-c-page__drawer:focus {\n  outline: 0;\n}\n\n.pf-c-page__main,\n.pf-c-page__main-drawer,\n.pf-c-page__main-group {\n  display: flex;\n  flex-direction: column;\n}\n\n.pf-c-page__main-nav {\n  padding-top: var(--pf-c-page__main-nav--PaddingTop);\n  padding-right: var(--pf-c-page__main-nav--PaddingRight);\n  padding-left: var(--pf-c-page__main-nav--PaddingLeft);\n  background-color: var(--pf-c-page__main-nav--BackgroundColor);\n}\n.pf-c-page__main-nav.pf-m-sticky-top, .pf-c-page__main-group.pf-m-sticky-top .pf-c-page__main-nav:last-child {\n  padding-bottom: var(--pf-c-page__main-nav--m-sticky-top--PaddingBottom);\n}\n@media (min-height: 0) {\n  .pf-c-page__main-nav.pf-m-sticky-top-on-sm-height, .pf-c-page__main-group.pf-m-sticky-top-on-sm-height .pf-c-page__main-nav:last-child {\n    padding-bottom: var(--pf-c-page__main-nav--m-sticky-top--PaddingBottom);\n  }\n}\n@media (min-height: 40rem) {\n  .pf-c-page__main-nav.pf-m-sticky-top-on-md-height, .pf-c-page__main-group.pf-m-sticky-top-on-md-height .pf-c-page__main-nav:last-child {\n    padding-bottom: var(--pf-c-page__main-nav--m-sticky-top--PaddingBottom);\n  }\n}\n@media (min-height: 48rem) {\n  .pf-c-page__main-nav.pf-m-sticky-top-on-lg-height, .pf-c-page__main-group.pf-m-sticky-top-on-lg-height .pf-c-page__main-nav:last-child {\n    padding-bottom: var(--pf-c-page__main-nav--m-sticky-top--PaddingBottom);\n  }\n}\n@media (min-height: 60rem) {\n  .pf-c-page__main-nav.pf-m-sticky-top-on-xl-height, .pf-c-page__main-group.pf-m-sticky-top-on-xl-height .pf-c-page__main-nav:last-child {\n    padding-bottom: var(--pf-c-page__main-nav--m-sticky-top--PaddingBottom);\n  }\n}\n@media (min-height: 80rem) {\n  .pf-c-page__main-nav.pf-m-sticky-top-on-2xl-height, .pf-c-page__main-group.pf-m-sticky-top-on-2xl-height .pf-c-page__main-nav:last-child {\n    padding-bottom: var(--pf-c-page__main-nav--m-sticky-top--PaddingBottom);\n  }\n}\n\n.pf-c-page__main-subnav {\n  background-color: var(--pf-c-page__main-subnav--BackgroundColor);\n  border-top: var(--pf-c-page__main-subnav--BorderTopWidth) solid var(--pf-c-page__main-subnav--BorderTopColor);\n  border-left: var(--pf-c-page__main-subnav--BorderLeftWidth) solid var(--pf-c-page__main-subnav--BorderLeftColor);\n}\n@media screen and (min-width: 1200px) {\n  .pf-c-page__sidebar ~ .pf-c-page__main {\n    --pf-c-page__main-subnav--BorderLeftWidth: var(--pf-c-page__sidebar--main__main-subnav--BorderLeftWidth);\n  }\n}\n.pf-c-page__sidebar.pf-m-collapsed ~ .pf-c-page__main {\n  --pf-c-page__main-subnav--BorderLeftWidth: var(--pf-c-page__sidebar--m-collapsed--main__main-subnav--BorderLeftWidth);\n}\n\n.pf-c-page__main-breadcrumb {\n  padding: var(--pf-c-page__main-breadcrumb--PaddingTop) var(--pf-c-page__main-breadcrumb--PaddingRight) var(--pf-c-page__main-breadcrumb--PaddingBottom) var(--pf-c-page__main-breadcrumb--PaddingLeft);\n  background-color: var(--pf-c-page__main-breadcrumb--BackgroundColor);\n}\n.pf-c-page__main-breadcrumb + .pf-c-page__main-section {\n  --pf-c-page__main-section--PaddingTop: var(--pf-c-page__main-breadcrumb--main-section--PaddingTop);\n}\n.pf-c-page__main-breadcrumb.pf-m-sticky-top, .pf-c-page__main-group.pf-m-sticky-top .pf-c-page__main-breadcrumb:last-child {\n  --pf-c-page__main-breadcrumb--PaddingBottom: var(--pf-c-page__main-breadcrumb--m-sticky-top--PaddingBottom);\n}\n@media (min-height: 0) {\n  .pf-c-page__main-breadcrumb.pf-m-sticky-top-on-sm-height, .pf-c-page__main-group.pf-m-sticky-top-on-sm-height .pf-c-page__main-breadcrumb:last-child {\n    --pf-c-page__main-breadcrumb--PaddingBottom: var(--pf-c-page__main-breadcrumb--m-sticky-top--PaddingBottom);\n  }\n}\n@media (min-height: 40rem) {\n  .pf-c-page__main-breadcrumb.pf-m-sticky-top-on-md-height, .pf-c-page__main-group.pf-m-sticky-top-on-md-height .pf-c-page__main-breadcrumb:last-child {\n    --pf-c-page__main-breadcrumb--PaddingBottom: var(--pf-c-page__main-breadcrumb--m-sticky-top--PaddingBottom);\n  }\n}\n@media (min-height: 48rem) {\n  .pf-c-page__main-breadcrumb.pf-m-sticky-top-on-lg-height, .pf-c-page__main-group.pf-m-sticky-top-on-lg-height .pf-c-page__main-breadcrumb:last-child {\n    --pf-c-page__main-breadcrumb--PaddingBottom: var(--pf-c-page__main-breadcrumb--m-sticky-top--PaddingBottom);\n  }\n}\n@media (min-height: 60rem) {\n  .pf-c-page__main-breadcrumb.pf-m-sticky-top-on-xl-height, .pf-c-page__main-group.pf-m-sticky-top-on-xl-height .pf-c-page__main-breadcrumb:last-child {\n    --pf-c-page__main-breadcrumb--PaddingBottom: var(--pf-c-page__main-breadcrumb--m-sticky-top--PaddingBottom);\n  }\n}\n@media (min-height: 80rem) {\n  .pf-c-page__main-breadcrumb.pf-m-sticky-top-on-2xl-height, .pf-c-page__main-group.pf-m-sticky-top-on-2xl-height .pf-c-page__main-breadcrumb:last-child {\n    --pf-c-page__main-breadcrumb--PaddingBottom: var(--pf-c-page__main-breadcrumb--m-sticky-top--PaddingBottom);\n  }\n}\n\n.pf-c-page__main-tabs {\n  padding: var(--pf-c-page__main-tabs--PaddingTop) var(--pf-c-page__main-tabs--PaddingRight) var(--pf-c-page__main-tabs--PaddingBottom) var(--pf-c-page__main-tabs--PaddingLeft);\n  background-color: var(--pf-c-page__main-tabs--BackgroundColor);\n}\n.pf-c-page__main-nav + .pf-c-page__main-tabs {\n  --pf-c-page__main-tabs--PaddingTop: var(--pf-c-page__main-nav--page__main-tabs--PaddingTop);\n}\n.pf-c-page__main-breadcrumb + .pf-c-page__main-tabs {\n  --pf-c-page__main-tabs--PaddingTop: var(--pf-c-page__main-breadcrumb--page__main-tabs--PaddingTop);\n}\n\n.pf-c-page__main-section:last-child, .pf-c-page__main-section:only-child, .pf-c-page__main-section.pf-m-fill,\n.pf-c-page__main-group:last-child,\n.pf-c-page__main-group:only-child,\n.pf-c-page__main-group.pf-m-fill,\n.pf-c-page__main-wizard:last-child,\n.pf-c-page__main-wizard:only-child,\n.pf-c-page__main-wizard.pf-m-fill {\n  flex-grow: 1;\n}\n.pf-c-page__main-section.pf-m-no-fill,\n.pf-c-page__main-group.pf-m-no-fill,\n.pf-c-page__main-wizard.pf-m-no-fill {\n  flex-grow: 0;\n}\n\n.pf-c-page__main-section {\n  padding: var(--pf-c-page__main-section--PaddingTop) var(--pf-c-page__main-section--PaddingRight) var(--pf-c-page__main-section--PaddingBottom) var(--pf-c-page__main-section--PaddingLeft);\n  background-color: var(--pf-c-page__main-section--BackgroundColor);\n}\n.pf-c-page__main-section.pf-m-light {\n  --pf-c-page__main-section--BackgroundColor: var(--pf-c-page__main-section--m-light--BackgroundColor);\n}\n.pf-c-page__main-section.pf-m-light-100 {\n  --pf-c-page__main-section--BackgroundColor: var(--pf-c-page__main-section--m-light-100--BackgroundColor);\n}\n.pf-c-page__main-section[class*=pf-m-dark-] {\n  color: var(--pf-global--Color--100);\n}\n.pf-c-page__main-section.pf-m-dark-100 {\n  --pf-c-page__main-section--BackgroundColor: var(--pf-c-page__main-section--m-dark-100--BackgroundColor);\n}\n.pf-c-page__main-section.pf-m-dark-200 {\n  --pf-c-page__main-section--BackgroundColor: var(--pf-c-page__main-section--m-dark-200--BackgroundColor);\n}\n.pf-c-page__main-section.pf-m-padding {\n  padding: var(--pf-c-page__main-section--PaddingTop) var(--pf-c-page__main-section--PaddingRight) var(--pf-c-page__main-section--PaddingBottom) var(--pf-c-page__main-section--PaddingLeft);\n}\n.pf-c-page__main-section.pf-m-padding.pf-m-limit-width {\n  padding: 0;\n}\n.pf-c-page__main-section.pf-m-padding.pf-m-limit-width .pf-c-page__main-body {\n  padding: var(--pf-c-page__main-section--PaddingTop) var(--pf-c-page__main-section--PaddingRight) var(--pf-c-page__main-section--PaddingBottom) var(--pf-c-page__main-section--PaddingLeft);\n}\n.pf-c-page__main-section.pf-m-no-padding, .pf-c-page__main-section.pf-m-no-padding.pf-m-limit-width .pf-c-page__main-body {\n  padding: 0;\n}\n@media (min-width: 576px) {\n  .pf-c-page__main-section.pf-m-padding-on-sm {\n    padding: var(--pf-c-page__main-section--PaddingTop) var(--pf-c-page__main-section--PaddingRight) var(--pf-c-page__main-section--PaddingBottom) var(--pf-c-page__main-section--PaddingLeft);\n  }\n  .pf-c-page__main-section.pf-m-padding-on-sm.pf-m-limit-width {\n    padding: 0;\n  }\n  .pf-c-page__main-section.pf-m-padding-on-sm.pf-m-limit-width .pf-c-page__main-body {\n    padding: var(--pf-c-page__main-section--PaddingTop) var(--pf-c-page__main-section--PaddingRight) var(--pf-c-page__main-section--PaddingBottom) var(--pf-c-page__main-section--PaddingLeft);\n  }\n  .pf-c-page__main-section.pf-m-no-padding-on-sm, .pf-c-page__main-section.pf-m-no-padding-on-sm.pf-m-limit-width .pf-c-page__main-body {\n    padding: 0;\n  }\n}\n@media (min-width: 768px) {\n  .pf-c-page__main-section.pf-m-padding-on-md {\n    padding: var(--pf-c-page__main-section--PaddingTop) var(--pf-c-page__main-section--PaddingRight) var(--pf-c-page__main-section--PaddingBottom) var(--pf-c-page__main-section--PaddingLeft);\n  }\n  .pf-c-page__main-section.pf-m-padding-on-md.pf-m-limit-width {\n    padding: 0;\n  }\n  .pf-c-page__main-section.pf-m-padding-on-md.pf-m-limit-width .pf-c-page__main-body {\n    padding: var(--pf-c-page__main-section--PaddingTop) var(--pf-c-page__main-section--PaddingRight) var(--pf-c-page__main-section--PaddingBottom) var(--pf-c-page__main-section--PaddingLeft);\n  }\n  .pf-c-page__main-section.pf-m-no-padding-on-md, .pf-c-page__main-section.pf-m-no-padding-on-md.pf-m-limit-width .pf-c-page__main-body {\n    padding: 0;\n  }\n}\n@media (min-width: 992px) {\n  .pf-c-page__main-section.pf-m-padding-on-lg {\n    padding: var(--pf-c-page__main-section--PaddingTop) var(--pf-c-page__main-section--PaddingRight) var(--pf-c-page__main-section--PaddingBottom) var(--pf-c-page__main-section--PaddingLeft);\n  }\n  .pf-c-page__main-section.pf-m-padding-on-lg.pf-m-limit-width {\n    padding: 0;\n  }\n  .pf-c-page__main-section.pf-m-padding-on-lg.pf-m-limit-width .pf-c-page__main-body {\n    padding: var(--pf-c-page__main-section--PaddingTop) var(--pf-c-page__main-section--PaddingRight) var(--pf-c-page__main-section--PaddingBottom) var(--pf-c-page__main-section--PaddingLeft);\n  }\n  .pf-c-page__main-section.pf-m-no-padding-on-lg, .pf-c-page__main-section.pf-m-no-padding-on-lg.pf-m-limit-width .pf-c-page__main-body {\n    padding: 0;\n  }\n}\n@media (min-width: 1200px) {\n  .pf-c-page__main-section.pf-m-padding-on-xl {\n    padding: var(--pf-c-page__main-section--PaddingTop) var(--pf-c-page__main-section--PaddingRight) var(--pf-c-page__main-section--PaddingBottom) var(--pf-c-page__main-section--PaddingLeft);\n  }\n  .pf-c-page__main-section.pf-m-padding-on-xl.pf-m-limit-width {\n    padding: 0;\n  }\n  .pf-c-page__main-section.pf-m-padding-on-xl.pf-m-limit-width .pf-c-page__main-body {\n    padding: var(--pf-c-page__main-section--PaddingTop) var(--pf-c-page__main-section--PaddingRight) var(--pf-c-page__main-section--PaddingBottom) var(--pf-c-page__main-section--PaddingLeft);\n  }\n  .pf-c-page__main-section.pf-m-no-padding-on-xl, .pf-c-page__main-section.pf-m-no-padding-on-xl.pf-m-limit-width .pf-c-page__main-body {\n    padding: 0;\n  }\n}\n@media (min-width: 1450px) {\n  .pf-c-page__main-section.pf-m-padding-on-2xl {\n    padding: var(--pf-c-page__main-section--PaddingTop) var(--pf-c-page__main-section--PaddingRight) var(--pf-c-page__main-section--PaddingBottom) var(--pf-c-page__main-section--PaddingLeft);\n  }\n  .pf-c-page__main-section.pf-m-padding-on-2xl.pf-m-limit-width {\n    padding: 0;\n  }\n  .pf-c-page__main-section.pf-m-padding-on-2xl.pf-m-limit-width .pf-c-page__main-body {\n    padding: var(--pf-c-page__main-section--PaddingTop) var(--pf-c-page__main-section--PaddingRight) var(--pf-c-page__main-section--PaddingBottom) var(--pf-c-page__main-section--PaddingLeft);\n  }\n  .pf-c-page__main-section.pf-m-no-padding-on-2xl, .pf-c-page__main-section.pf-m-no-padding-on-2xl.pf-m-limit-width .pf-c-page__main-body {\n    padding: 0;\n  }\n}\n\n.pf-c-page__main-wizard {\n  flex: 1 1;\n  min-height: 0;\n  background-color: var(--pf-c-page__main-wizard--BackgroundColor);\n  border-top: var(--pf-c-page__main-wizard--BorderTopWidth) solid var(--pf-c-page__main-wizard--BorderTopColor);\n}\n.pf-c-page__main-wizard:first-child {\n  --pf-c-page__main-wizard--BorderTopWidth: 0;\n}\n.pf-c-page__main-wizard.pf-m-light-200 {\n  --pf-c-page__main-wizard--BackgroundColor: var(--pf-c-page__main-wizard--m-light-200--BackgroundColor);\n}\n\n.pf-c-page__main-wizard .pf-c-page__main-body {\n  min-height: 0;\n}\n\n.pf-c-page__main-group {\n  flex-shrink: 0;\n}\n\n.pf-c-page__main-nav .pf-c-page__main-body {\n  padding-top: var(--pf-c-page__main-nav--PaddingTop);\n  padding-right: var(--pf-c-page__main-nav--PaddingRight);\n  padding-left: var(--pf-c-page__main-nav--PaddingLeft);\n}\n.pf-c-page__main-breadcrumb .pf-c-page__main-body {\n  padding: var(--pf-c-page__main-breadcrumb--PaddingTop) var(--pf-c-page__main-breadcrumb--PaddingRight) var(--pf-c-page__main-breadcrumb--PaddingBottom) var(--pf-c-page__main-breadcrumb--PaddingLeft);\n}\n.pf-c-page__main-section .pf-c-page__main-body {\n  padding: var(--pf-c-page__main-section--PaddingTop) var(--pf-c-page__main-section--PaddingRight) var(--pf-c-page__main-section--PaddingBottom) var(--pf-c-page__main-section--PaddingLeft);\n}\n.pf-c-page__main-tabs .pf-c-page__main-body {\n  padding: var(--pf-c-page__main-tabs--PaddingTop) var(--pf-c-page__main-tabs--PaddingRight) var(--pf-c-page__main-tabs--PaddingBottom) var(--pf-c-page__main-tabs--PaddingLeft);\n}\n\n.pf-c-page__drawer {\n  grid-area: main;\n}\n.pf-c-page__drawer > .pf-c-drawer {\n  flex: 1 0 auto;\n}\n\n:where(.pf-theme-dark) .pf-c-page__sidebar-body.pf-m-menu .pf-c-context-selector,\n:where(.pf-theme-dark) .pf-c-page__main-section[class*=pf-m-dark-],\n:where(.pf-theme-dark) .pf-c-page__header {\n  --pf-global--Color--100: #e0e0e0;\n  --pf-global--Color--200: #aaabac;\n  --pf-global--BorderColor--100: #444548;\n  --pf-global--primary-color--100: #1fa7f8;\n  --pf-global--link--Color: #1fa7f8;\n  --pf-global--link--Color--hover: #73bcf7;\n  --pf-global--BackgroundColor--100: #1b1d21;\n}\n:where(.pf-theme-dark) .pf-c-page__sidebar-body.pf-m-menu .pf-c-context-selector .pf-c-card,\n:where(.pf-theme-dark) .pf-c-page__main-section[class*=pf-m-dark-] .pf-c-card,\n:where(.pf-theme-dark) .pf-c-page__header .pf-c-card {\n  --pf-c-card--BackgroundColor: var(--pf-global--BackgroundColor--100);\n}\n:where(.pf-theme-dark) .pf-c-page__sidebar-body.pf-m-menu .pf-c-context-selector .pf-c-button,\n:where(.pf-theme-dark) .pf-c-page__main-section[class*=pf-m-dark-] .pf-c-button,\n:where(.pf-theme-dark) .pf-c-page__header .pf-c-button {\n  --pf-c-button--m-primary--Color: var(--pf-global--Color--light-100);\n  --pf-c-button--m-primary--hover--Color: var(--pf-global--Color--light-100);\n  --pf-c-button--m-primary--focus--Color: var(--pf-global--Color--light-100);\n  --pf-c-button--m-primary--active--Color: var(--pf-global--Color--light-100);\n  --pf-c-button--m-primary--BackgroundColor: var(--pf-global--primary-color--300);\n  --pf-c-button--m-primary--hover--BackgroundColor: var(--pf-global--primary-color--200);\n  --pf-c-button--m-primary--focus--BackgroundColor: var(--pf-global--primary-color--200);\n  --pf-c-button--m-primary--active--BackgroundColor: var(--pf-global--primary-color--200);\n  --pf-c-button--m-secondary--Color: var(--pf-global--primary-color--100);\n  --pf-c-button--m-secondary--hover--Color: var(--pf-global--primary-color--100);\n  --pf-c-button--m-secondary--focus--Color: var(--pf-global--primary-color--100);\n  --pf-c-button--m-secondary--active--Color: var(--pf-global--primary-color--100);\n}\n\n:where(.pf-theme-dark) .pf-c-page {\n  --pf-c-page__main-section--BackgroundColor: var(--pf-global--BackgroundColor--200);\n  --pf-c-page__header-tools--c-button--m-selected--before--BackgroundColor: var(--pf-global--BackgroundColor--300);\n  --pf-c-page__sidebar--BackgroundColor: var(--pf-global--BackgroundColor--100);\n  --pf-c-page__header--BackgroundColor: var(--pf-global--palette--black-1000);\n}\n:where(.pf-theme-dark) .pf-c-page__header-tools-item.pf-m-selected .pf-c-button {\n  color: var(--pf-global--Color--100);\n}\n:where(.pf-theme-dark) .pf-c-page__header-tools-item.pf-m-selected .pf-c-button .pf-c-notification-badge:hover::before {\n  background-color: var(--pf-c-page__header-tools--c-button--m-selected--before--BackgroundColor);\n}\n:where(.pf-theme-dark) .pf-c-page__sidebar {\n  border-right: var(--pf-global--BorderWidth--sm) solid var(--pf-global--BorderColor--100);\n}\n:where(.pf-theme-dark) .pf-c-page__main-nav.pf-m-sticky-top, :where(.pf-theme-dark) .pf-c-page__main-nav.pf-m-sticky-bottom {\n  --pf-c-page__main-nav--BackgroundColor: var(--pf-global--BackgroundColor--300);\n}\n:where(.pf-theme-dark) .pf-c-page__main-breadcrumb.pf-m-sticky-top, :where(.pf-theme-dark) .pf-c-page__main-breadcrumb.pf-m-sticky-bottom {\n  --pf-c-page__main-breadcrumb--BackgroundColor: var(--pf-global--BackgroundColor--300);\n}\n:where(.pf-theme-dark) .pf-c-page__main-group.pf-m-sticky-top, :where(.pf-theme-dark) .pf-c-page__main-group.pf-m-sticky-bottom {\n  --pf-c-page__main-section--m-light--BackgroundColor: var(--pf-global--BackgroundColor--300);\n  --pf-c-page__main-section--BackgroundColor: var(--pf-global--BackgroundColor--300);\n  --pf-c-page__main-breadcrumb--BackgroundColor: var(--pf-global--BackgroundColor--300);\n  --pf-c-page__main-nav--BackgroundColor: var(--pf-global--BackgroundColor--300);\n}\n:where(.pf-theme-dark) .pf-c-page__main-section.pf-m-sticky-top, :where(.pf-theme-dark) .pf-c-page__main-section.pf-m-sticky-bottom {\n  --pf-c-page__main-section--BackgroundColor: var(--pf-global--BackgroundColor--300);\n}\n:where(.pf-theme-dark) .pf-c-page__sidebar-body.pf-m-menu .pf-c-context-selector,\n:where(.pf-theme-dark) .pf-c-page__main-section[class*=pf-m-dark-],\n:where(.pf-theme-dark) .pf-c-page__header {\n  color: var(--pf-global--Color--100);\n}';

// src/elements/sidebar/SidebarBrand.ts
var MIN_WIDTH = 1200;
var DefaultBrand = {
  brandingLogo: "/static/dist/assets/icons/icon_left_brand.svg",
  brandingFavicon: "/static/dist/assets/icons/icon.png",
  brandingTitle: "authentik",
  uiFooterLinks: [],
  uiTheme: UiThemeEnum.Automatic,
  matchedDomain: "",
  defaultLocale: ""
};
var SidebarBrand = class extends WithBrandConfig(AKElement) {
  static get styles() {
    return [
      patternfly_base_default,
      patternfly_base_default,
      page_default,
      button_default,
      i`
                :host {
                    display: flex;
                    flex-direction: row;
                    align-items: center;
                    height: 114px;
                    min-height: 114px;
                }
                .pf-c-brand img {
                    padding: 0 0.5rem;
                    height: 42px;
                }
                button.pf-c-button.sidebar-trigger {
                    background-color: transparent;
                    border-radius: 0px;
                    height: 100%;
                    color: var(--ak-dark-foreground);
                }
            `
    ];
  }
  constructor() {
    super();
    window.addEventListener("resize", () => {
      this.requestUpdate();
    });
  }
  render() {
    return x` ${window.innerWidth <= MIN_WIDTH ? x`
                      <button
                          class="sidebar-trigger pf-c-button"
                          @click=${() => {
      this.dispatchEvent(
        new CustomEvent(EVENT_SIDEBAR_TOGGLE, {
          bubbles: true,
          composed: true
        })
      );
    }}
                      >
                          <i class="fas fa-bars"></i>
                      </button>
                  ` : x``}
            <a href="#/" class="pf-c-page__header-brand-link">
                <div class="pf-c-brand ak-brand">
                    <img
                        src=${this.brand?.brandingLogo ?? DefaultBrand.brandingLogo}
                        alt="authentik Logo"
                        loading="lazy"
                    />
                </div>
            </a>`;
  }
};
SidebarBrand = __decorateClass([
  t("ak-sidebar-brand")
], SidebarBrand);

// node_modules/rapidoc/dist/rapidoc-min.js
(() => {
  var e4, t3, r4 = { 656: (e5, t4, r5) => {
    "use strict";
    const n5 = window, o4 = n5.ShadowRoot && (void 0 === n5.ShadyCSS || n5.ShadyCSS.nativeShadow) && "adoptedStyleSheets" in Document.prototype && "replace" in CSSStyleSheet.prototype, a = Symbol(), i3 = /* @__PURE__ */ new WeakMap();
    class s5 {
      constructor(e6, t5, r6) {
        if (this._$cssResult$ = true, r6 !== a)
          throw Error("CSSResult is not constructable. Use `unsafeCSS` or `css` instead.");
        this.cssText = e6, this.t = t5;
      }
      get styleSheet() {
        let e6 = this.o;
        const t5 = this.t;
        if (o4 && void 0 === e6) {
          const r6 = void 0 !== t5 && 1 === t5.length;
          r6 && (e6 = i3.get(t5)), void 0 === e6 && ((this.o = e6 = new CSSStyleSheet()).replaceSync(this.cssText), r6 && i3.set(t5, e6));
        }
        return e6;
      }
      toString() {
        return this.cssText;
      }
    }
    const l = (e6) => new s5("string" == typeof e6 ? e6 : e6 + "", void 0, a), c2 = (e6, ...t5) => {
      const r6 = 1 === e6.length ? e6[0] : t5.reduce((t6, r7, n6) => t6 + ((e7) => {
        if (true === e7._$cssResult$)
          return e7.cssText;
        if ("number" == typeof e7)
          return e7;
        throw Error("Value passed to 'css' function must be a 'css' function result: " + e7 + ". Use 'unsafeCSS' to pass non-literal values, but take care to ensure page security.");
      })(r7) + e6[n6 + 1], e6[0]);
      return new s5(r6, e6, a);
    }, p = o4 ? (e6) => e6 : (e6) => e6 instanceof CSSStyleSheet ? ((e7) => {
      let t5 = "";
      for (const r6 of e7.cssRules)
        t5 += r6.cssText;
      return l(t5);
    })(e6) : e6;
    var d;
    const u2 = window, h = u2.trustedTypes, f2 = h ? h.emptyScript : "", m = u2.reactiveElementPolyfillSupport, y = { toAttribute(e6, t5) {
      switch (t5) {
        case Boolean:
          e6 = e6 ? f2 : null;
          break;
        case Object:
        case Array:
          e6 = null == e6 ? e6 : JSON.stringify(e6);
      }
      return e6;
    }, fromAttribute(e6, t5) {
      let r6 = e6;
      switch (t5) {
        case Boolean:
          r6 = null !== e6;
          break;
        case Number:
          r6 = null === e6 ? null : Number(e6);
          break;
        case Object:
        case Array:
          try {
            r6 = JSON.parse(e6);
          } catch (e7) {
            r6 = null;
          }
      }
      return r6;
    } }, g = (e6, t5) => t5 !== e6 && (t5 == t5 || e6 == e6), v = { attribute: true, type: String, converter: y, reflect: false, hasChanged: g };
    class b extends HTMLElement {
      constructor() {
        super(), this._$Ei = /* @__PURE__ */ new Map(), this.isUpdatePending = false, this.hasUpdated = false, this._$El = null, this.u();
      }
      static addInitializer(e6) {
        var t5;
        this.finalize(), (null !== (t5 = this.h) && void 0 !== t5 ? t5 : this.h = []).push(e6);
      }
      static get observedAttributes() {
        this.finalize();
        const e6 = [];
        return this.elementProperties.forEach((t5, r6) => {
          const n6 = this._$Ep(r6, t5);
          void 0 !== n6 && (this._$Ev.set(n6, r6), e6.push(n6));
        }), e6;
      }
      static createProperty(e6, t5 = v) {
        if (t5.state && (t5.attribute = false), this.finalize(), this.elementProperties.set(e6, t5), !t5.noAccessor && !this.prototype.hasOwnProperty(e6)) {
          const r6 = "symbol" == typeof e6 ? Symbol() : "__" + e6, n6 = this.getPropertyDescriptor(e6, r6, t5);
          void 0 !== n6 && Object.defineProperty(this.prototype, e6, n6);
        }
      }
      static getPropertyDescriptor(e6, t5, r6) {
        return { get() {
          return this[t5];
        }, set(n6) {
          const o5 = this[e6];
          this[t5] = n6, this.requestUpdate(e6, o5, r6);
        }, configurable: true, enumerable: true };
      }
      static getPropertyOptions(e6) {
        return this.elementProperties.get(e6) || v;
      }
      static finalize() {
        if (this.hasOwnProperty("finalized"))
          return false;
        this.finalized = true;
        const e6 = Object.getPrototypeOf(this);
        if (e6.finalize(), void 0 !== e6.h && (this.h = [...e6.h]), this.elementProperties = new Map(e6.elementProperties), this._$Ev = /* @__PURE__ */ new Map(), this.hasOwnProperty("properties")) {
          const e7 = this.properties, t5 = [...Object.getOwnPropertyNames(e7), ...Object.getOwnPropertySymbols(e7)];
          for (const r6 of t5)
            this.createProperty(r6, e7[r6]);
        }
        return this.elementStyles = this.finalizeStyles(this.styles), true;
      }
      static finalizeStyles(e6) {
        const t5 = [];
        if (Array.isArray(e6)) {
          const r6 = new Set(e6.flat(1 / 0).reverse());
          for (const e7 of r6)
            t5.unshift(p(e7));
        } else
          void 0 !== e6 && t5.push(p(e6));
        return t5;
      }
      static _$Ep(e6, t5) {
        const r6 = t5.attribute;
        return false === r6 ? void 0 : "string" == typeof r6 ? r6 : "string" == typeof e6 ? e6.toLowerCase() : void 0;
      }
      u() {
        var e6;
        this._$E_ = new Promise((e7) => this.enableUpdating = e7), this._$AL = /* @__PURE__ */ new Map(), this._$Eg(), this.requestUpdate(), null === (e6 = this.constructor.h) || void 0 === e6 || e6.forEach((e7) => e7(this));
      }
      addController(e6) {
        var t5, r6;
        (null !== (t5 = this._$ES) && void 0 !== t5 ? t5 : this._$ES = []).push(e6), void 0 !== this.renderRoot && this.isConnected && (null === (r6 = e6.hostConnected) || void 0 === r6 || r6.call(e6));
      }
      removeController(e6) {
        var t5;
        null === (t5 = this._$ES) || void 0 === t5 || t5.splice(this._$ES.indexOf(e6) >>> 0, 1);
      }
      _$Eg() {
        this.constructor.elementProperties.forEach((e6, t5) => {
          this.hasOwnProperty(t5) && (this._$Ei.set(t5, this[t5]), delete this[t5]);
        });
      }
      createRenderRoot() {
        var e6;
        const t5 = null !== (e6 = this.shadowRoot) && void 0 !== e6 ? e6 : this.attachShadow(this.constructor.shadowRootOptions);
        return ((e7, t6) => {
          o4 ? e7.adoptedStyleSheets = t6.map((e8) => e8 instanceof CSSStyleSheet ? e8 : e8.styleSheet) : t6.forEach((t7) => {
            const r6 = document.createElement("style"), o5 = n5.litNonce;
            void 0 !== o5 && r6.setAttribute("nonce", o5), r6.textContent = t7.cssText, e7.appendChild(r6);
          });
        })(t5, this.constructor.elementStyles), t5;
      }
      connectedCallback() {
        var e6;
        void 0 === this.renderRoot && (this.renderRoot = this.createRenderRoot()), this.enableUpdating(true), null === (e6 = this._$ES) || void 0 === e6 || e6.forEach((e7) => {
          var t5;
          return null === (t5 = e7.hostConnected) || void 0 === t5 ? void 0 : t5.call(e7);
        });
      }
      enableUpdating(e6) {
      }
      disconnectedCallback() {
        var e6;
        null === (e6 = this._$ES) || void 0 === e6 || e6.forEach((e7) => {
          var t5;
          return null === (t5 = e7.hostDisconnected) || void 0 === t5 ? void 0 : t5.call(e7);
        });
      }
      attributeChangedCallback(e6, t5, r6) {
        this._$AK(e6, r6);
      }
      _$EO(e6, t5, r6 = v) {
        var n6;
        const o5 = this.constructor._$Ep(e6, r6);
        if (void 0 !== o5 && true === r6.reflect) {
          const a2 = (void 0 !== (null === (n6 = r6.converter) || void 0 === n6 ? void 0 : n6.toAttribute) ? r6.converter : y).toAttribute(t5, r6.type);
          this._$El = e6, null == a2 ? this.removeAttribute(o5) : this.setAttribute(o5, a2), this._$El = null;
        }
      }
      _$AK(e6, t5) {
        var r6;
        const n6 = this.constructor, o5 = n6._$Ev.get(e6);
        if (void 0 !== o5 && this._$El !== o5) {
          const e7 = n6.getPropertyOptions(o5), a2 = "function" == typeof e7.converter ? { fromAttribute: e7.converter } : void 0 !== (null === (r6 = e7.converter) || void 0 === r6 ? void 0 : r6.fromAttribute) ? e7.converter : y;
          this._$El = o5, this[o5] = a2.fromAttribute(t5, e7.type), this._$El = null;
        }
      }
      requestUpdate(e6, t5, r6) {
        let n6 = true;
        void 0 !== e6 && (((r6 = r6 || this.constructor.getPropertyOptions(e6)).hasChanged || g)(this[e6], t5) ? (this._$AL.has(e6) || this._$AL.set(e6, t5), true === r6.reflect && this._$El !== e6 && (void 0 === this._$EC && (this._$EC = /* @__PURE__ */ new Map()), this._$EC.set(e6, r6))) : n6 = false), !this.isUpdatePending && n6 && (this._$E_ = this._$Ej());
      }
      async _$Ej() {
        this.isUpdatePending = true;
        try {
          await this._$E_;
        } catch (e7) {
          Promise.reject(e7);
        }
        const e6 = this.scheduleUpdate();
        return null != e6 && await e6, !this.isUpdatePending;
      }
      scheduleUpdate() {
        return this.performUpdate();
      }
      performUpdate() {
        var e6;
        if (!this.isUpdatePending)
          return;
        this.hasUpdated, this._$Ei && (this._$Ei.forEach((e7, t6) => this[t6] = e7), this._$Ei = void 0);
        let t5 = false;
        const r6 = this._$AL;
        try {
          t5 = this.shouldUpdate(r6), t5 ? (this.willUpdate(r6), null === (e6 = this._$ES) || void 0 === e6 || e6.forEach((e7) => {
            var t6;
            return null === (t6 = e7.hostUpdate) || void 0 === t6 ? void 0 : t6.call(e7);
          }), this.update(r6)) : this._$Ek();
        } catch (e7) {
          throw t5 = false, this._$Ek(), e7;
        }
        t5 && this._$AE(r6);
      }
      willUpdate(e6) {
      }
      _$AE(e6) {
        var t5;
        null === (t5 = this._$ES) || void 0 === t5 || t5.forEach((e7) => {
          var t6;
          return null === (t6 = e7.hostUpdated) || void 0 === t6 ? void 0 : t6.call(e7);
        }), this.hasUpdated || (this.hasUpdated = true, this.firstUpdated(e6)), this.updated(e6);
      }
      _$Ek() {
        this._$AL = /* @__PURE__ */ new Map(), this.isUpdatePending = false;
      }
      get updateComplete() {
        return this.getUpdateComplete();
      }
      getUpdateComplete() {
        return this._$E_;
      }
      shouldUpdate(e6) {
        return true;
      }
      update(e6) {
        void 0 !== this._$EC && (this._$EC.forEach((e7, t5) => this._$EO(t5, this[t5], e7)), this._$EC = void 0), this._$Ek();
      }
      updated(e6) {
      }
      firstUpdated(e6) {
      }
    }
    var x2;
    b.finalized = true, b.elementProperties = /* @__PURE__ */ new Map(), b.elementStyles = [], b.shadowRootOptions = { mode: "open" }, null == m || m({ ReactiveElement: b }), (null !== (d = u2.reactiveElementVersions) && void 0 !== d ? d : u2.reactiveElementVersions = []).push("1.6.1");
    const w = window, $ = w.trustedTypes, k = $ ? $.createPolicy("lit-html", { createHTML: (e6) => e6 }) : void 0, S = `lit$${(Math.random() + "").slice(9)}$`, A = "?" + S, E = `<${A}>`, O = document, T2 = (e6 = "") => O.createComment(e6), C = (e6) => null === e6 || "object" != typeof e6 && "function" != typeof e6, j = Array.isArray, I = (e6) => j(e6) || "function" == typeof (null == e6 ? void 0 : e6[Symbol.iterator]), _ = /<(?:(!--|\/[^a-zA-Z])|(\/?[a-zA-Z][^>\s]*)|(\/?$))/g, P = /-->/g, R = />/g, L = RegExp(`>|[ 	
\f\r](?:([^\\s"'>=/]+)([ 	
\f\r]*=[ 	
\f\r]*(?:[^ 	
\f\r"'\`<>=]|("|')|))|$)`, "g"), F = /'/g, D = /"/g, B = /^(?:script|style|textarea|title)$/i, N = (e6) => (t5, ...r6) => ({ _$litType$: e6, strings: t5, values: r6 }), q = N(1), U = (N(2), Symbol.for("lit-noChange")), z = Symbol.for("lit-nothing"), M = /* @__PURE__ */ new WeakMap(), H = O.createTreeWalker(O, 129, null, false), W = (e6, t5) => {
      const r6 = e6.length - 1, n6 = [];
      let o5, a2 = 2 === t5 ? "<svg>" : "", i4 = _;
      for (let t6 = 0; t6 < r6; t6++) {
        const r7 = e6[t6];
        let s7, l2, c3 = -1, p2 = 0;
        for (; p2 < r7.length && (i4.lastIndex = p2, l2 = i4.exec(r7), null !== l2); )
          p2 = i4.lastIndex, i4 === _ ? "!--" === l2[1] ? i4 = P : void 0 !== l2[1] ? i4 = R : void 0 !== l2[2] ? (B.test(l2[2]) && (o5 = RegExp("</" + l2[2], "g")), i4 = L) : void 0 !== l2[3] && (i4 = L) : i4 === L ? ">" === l2[0] ? (i4 = null != o5 ? o5 : _, c3 = -1) : void 0 === l2[1] ? c3 = -2 : (c3 = i4.lastIndex - l2[2].length, s7 = l2[1], i4 = void 0 === l2[3] ? L : '"' === l2[3] ? D : F) : i4 === D || i4 === F ? i4 = L : i4 === P || i4 === R ? i4 = _ : (i4 = L, o5 = void 0);
        const d2 = i4 === L && e6[t6 + 1].startsWith("/>") ? " " : "";
        a2 += i4 === _ ? r7 + E : c3 >= 0 ? (n6.push(s7), r7.slice(0, c3) + "$lit$" + r7.slice(c3) + S + d2) : r7 + S + (-2 === c3 ? (n6.push(void 0), t6) : d2);
      }
      const s6 = a2 + (e6[r6] || "<?>") + (2 === t5 ? "</svg>" : "");
      if (!Array.isArray(e6) || !e6.hasOwnProperty("raw"))
        throw Error("invalid template strings array");
      return [void 0 !== k ? k.createHTML(s6) : s6, n6];
    };
    class V {
      constructor({ strings: e6, _$litType$: t5 }, r6) {
        let n6;
        this.parts = [];
        let o5 = 0, a2 = 0;
        const i4 = e6.length - 1, s6 = this.parts, [l2, c3] = W(e6, t5);
        if (this.el = V.createElement(l2, r6), H.currentNode = this.el.content, 2 === t5) {
          const e7 = this.el.content, t6 = e7.firstChild;
          t6.remove(), e7.append(...t6.childNodes);
        }
        for (; null !== (n6 = H.nextNode()) && s6.length < i4; ) {
          if (1 === n6.nodeType) {
            if (n6.hasAttributes()) {
              const e7 = [];
              for (const t6 of n6.getAttributeNames())
                if (t6.endsWith("$lit$") || t6.startsWith(S)) {
                  const r7 = c3[a2++];
                  if (e7.push(t6), void 0 !== r7) {
                    const e8 = n6.getAttribute(r7.toLowerCase() + "$lit$").split(S), t7 = /([.?@])?(.*)/.exec(r7);
                    s6.push({ type: 1, index: o5, name: t7[2], strings: e8, ctor: "." === t7[1] ? Z : "?" === t7[1] ? X : "@" === t7[1] ? ee : Y });
                  } else
                    s6.push({ type: 6, index: o5 });
                }
              for (const t6 of e7)
                n6.removeAttribute(t6);
            }
            if (B.test(n6.tagName)) {
              const e7 = n6.textContent.split(S), t6 = e7.length - 1;
              if (t6 > 0) {
                n6.textContent = $ ? $.emptyScript : "";
                for (let r7 = 0; r7 < t6; r7++)
                  n6.append(e7[r7], T2()), H.nextNode(), s6.push({ type: 2, index: ++o5 });
                n6.append(e7[t6], T2());
              }
            }
          } else if (8 === n6.nodeType)
            if (n6.data === A)
              s6.push({ type: 2, index: o5 });
            else {
              let e7 = -1;
              for (; -1 !== (e7 = n6.data.indexOf(S, e7 + 1)); )
                s6.push({ type: 7, index: o5 }), e7 += S.length - 1;
            }
          o5++;
        }
      }
      static createElement(e6, t5) {
        const r6 = O.createElement("template");
        return r6.innerHTML = e6, r6;
      }
    }
    function G(e6, t5, r6 = e6, n6) {
      var o5, a2, i4, s6;
      if (t5 === U)
        return t5;
      let l2 = void 0 !== n6 ? null === (o5 = r6._$Co) || void 0 === o5 ? void 0 : o5[n6] : r6._$Cl;
      const c3 = C(t5) ? void 0 : t5._$litDirective$;
      return (null == l2 ? void 0 : l2.constructor) !== c3 && (null === (a2 = null == l2 ? void 0 : l2._$AO) || void 0 === a2 || a2.call(l2, false), void 0 === c3 ? l2 = void 0 : (l2 = new c3(e6), l2._$AT(e6, r6, n6)), void 0 !== n6 ? (null !== (i4 = (s6 = r6)._$Co) && void 0 !== i4 ? i4 : s6._$Co = [])[n6] = l2 : r6._$Cl = l2), void 0 !== l2 && (t5 = G(e6, l2._$AS(e6, t5.values), l2, n6)), t5;
    }
    class K {
      constructor(e6, t5) {
        this.u = [], this._$AN = void 0, this._$AD = e6, this._$AM = t5;
      }
      get parentNode() {
        return this._$AM.parentNode;
      }
      get _$AU() {
        return this._$AM._$AU;
      }
      v(e6) {
        var t5;
        const { el: { content: r6 }, parts: n6 } = this._$AD, o5 = (null !== (t5 = null == e6 ? void 0 : e6.creationScope) && void 0 !== t5 ? t5 : O).importNode(r6, true);
        H.currentNode = o5;
        let a2 = H.nextNode(), i4 = 0, s6 = 0, l2 = n6[0];
        for (; void 0 !== l2; ) {
          if (i4 === l2.index) {
            let t6;
            2 === l2.type ? t6 = new J(a2, a2.nextSibling, this, e6) : 1 === l2.type ? t6 = new l2.ctor(a2, l2.name, l2.strings, this, e6) : 6 === l2.type && (t6 = new te(a2, this, e6)), this.u.push(t6), l2 = n6[++s6];
          }
          i4 !== (null == l2 ? void 0 : l2.index) && (a2 = H.nextNode(), i4++);
        }
        return o5;
      }
      p(e6) {
        let t5 = 0;
        for (const r6 of this.u)
          void 0 !== r6 && (void 0 !== r6.strings ? (r6._$AI(e6, r6, t5), t5 += r6.strings.length - 2) : r6._$AI(e6[t5])), t5++;
      }
    }
    class J {
      constructor(e6, t5, r6, n6) {
        var o5;
        this.type = 2, this._$AH = z, this._$AN = void 0, this._$AA = e6, this._$AB = t5, this._$AM = r6, this.options = n6, this._$Cm = null === (o5 = null == n6 ? void 0 : n6.isConnected) || void 0 === o5 || o5;
      }
      get _$AU() {
        var e6, t5;
        return null !== (t5 = null === (e6 = this._$AM) || void 0 === e6 ? void 0 : e6._$AU) && void 0 !== t5 ? t5 : this._$Cm;
      }
      get parentNode() {
        let e6 = this._$AA.parentNode;
        const t5 = this._$AM;
        return void 0 !== t5 && 11 === e6.nodeType && (e6 = t5.parentNode), e6;
      }
      get startNode() {
        return this._$AA;
      }
      get endNode() {
        return this._$AB;
      }
      _$AI(e6, t5 = this) {
        e6 = G(this, e6, t5), C(e6) ? e6 === z || null == e6 || "" === e6 ? (this._$AH !== z && this._$AR(), this._$AH = z) : e6 !== this._$AH && e6 !== U && this.g(e6) : void 0 !== e6._$litType$ ? this.$(e6) : void 0 !== e6.nodeType ? this.T(e6) : I(e6) ? this.k(e6) : this.g(e6);
      }
      O(e6, t5 = this._$AB) {
        return this._$AA.parentNode.insertBefore(e6, t5);
      }
      T(e6) {
        this._$AH !== e6 && (this._$AR(), this._$AH = this.O(e6));
      }
      g(e6) {
        this._$AH !== z && C(this._$AH) ? this._$AA.nextSibling.data = e6 : this.T(O.createTextNode(e6)), this._$AH = e6;
      }
      $(e6) {
        var t5;
        const { values: r6, _$litType$: n6 } = e6, o5 = "number" == typeof n6 ? this._$AC(e6) : (void 0 === n6.el && (n6.el = V.createElement(n6.h, this.options)), n6);
        if ((null === (t5 = this._$AH) || void 0 === t5 ? void 0 : t5._$AD) === o5)
          this._$AH.p(r6);
        else {
          const e7 = new K(o5, this), t6 = e7.v(this.options);
          e7.p(r6), this.T(t6), this._$AH = e7;
        }
      }
      _$AC(e6) {
        let t5 = M.get(e6.strings);
        return void 0 === t5 && M.set(e6.strings, t5 = new V(e6)), t5;
      }
      k(e6) {
        j(this._$AH) || (this._$AH = [], this._$AR());
        const t5 = this._$AH;
        let r6, n6 = 0;
        for (const o5 of e6)
          n6 === t5.length ? t5.push(r6 = new J(this.O(T2()), this.O(T2()), this, this.options)) : r6 = t5[n6], r6._$AI(o5), n6++;
        n6 < t5.length && (this._$AR(r6 && r6._$AB.nextSibling, n6), t5.length = n6);
      }
      _$AR(e6 = this._$AA.nextSibling, t5) {
        var r6;
        for (null === (r6 = this._$AP) || void 0 === r6 || r6.call(this, false, true, t5); e6 && e6 !== this._$AB; ) {
          const t6 = e6.nextSibling;
          e6.remove(), e6 = t6;
        }
      }
      setConnected(e6) {
        var t5;
        void 0 === this._$AM && (this._$Cm = e6, null === (t5 = this._$AP) || void 0 === t5 || t5.call(this, e6));
      }
    }
    class Y {
      constructor(e6, t5, r6, n6, o5) {
        this.type = 1, this._$AH = z, this._$AN = void 0, this.element = e6, this.name = t5, this._$AM = n6, this.options = o5, r6.length > 2 || "" !== r6[0] || "" !== r6[1] ? (this._$AH = Array(r6.length - 1).fill(new String()), this.strings = r6) : this._$AH = z;
      }
      get tagName() {
        return this.element.tagName;
      }
      get _$AU() {
        return this._$AM._$AU;
      }
      _$AI(e6, t5 = this, r6, n6) {
        const o5 = this.strings;
        let a2 = false;
        if (void 0 === o5)
          e6 = G(this, e6, t5, 0), a2 = !C(e6) || e6 !== this._$AH && e6 !== U, a2 && (this._$AH = e6);
        else {
          const n7 = e6;
          let i4, s6;
          for (e6 = o5[0], i4 = 0; i4 < o5.length - 1; i4++)
            s6 = G(this, n7[r6 + i4], t5, i4), s6 === U && (s6 = this._$AH[i4]), a2 || (a2 = !C(s6) || s6 !== this._$AH[i4]), s6 === z ? e6 = z : e6 !== z && (e6 += (null != s6 ? s6 : "") + o5[i4 + 1]), this._$AH[i4] = s6;
        }
        a2 && !n6 && this.j(e6);
      }
      j(e6) {
        e6 === z ? this.element.removeAttribute(this.name) : this.element.setAttribute(this.name, null != e6 ? e6 : "");
      }
    }
    class Z extends Y {
      constructor() {
        super(...arguments), this.type = 3;
      }
      j(e6) {
        this.element[this.name] = e6 === z ? void 0 : e6;
      }
    }
    const Q = $ ? $.emptyScript : "";
    class X extends Y {
      constructor() {
        super(...arguments), this.type = 4;
      }
      j(e6) {
        e6 && e6 !== z ? this.element.setAttribute(this.name, Q) : this.element.removeAttribute(this.name);
      }
    }
    class ee extends Y {
      constructor(e6, t5, r6, n6, o5) {
        super(e6, t5, r6, n6, o5), this.type = 5;
      }
      _$AI(e6, t5 = this) {
        var r6;
        if ((e6 = null !== (r6 = G(this, e6, t5, 0)) && void 0 !== r6 ? r6 : z) === U)
          return;
        const n6 = this._$AH, o5 = e6 === z && n6 !== z || e6.capture !== n6.capture || e6.once !== n6.once || e6.passive !== n6.passive, a2 = e6 !== z && (n6 === z || o5);
        o5 && this.element.removeEventListener(this.name, this, n6), a2 && this.element.addEventListener(this.name, this, e6), this._$AH = e6;
      }
      handleEvent(e6) {
        var t5, r6;
        "function" == typeof this._$AH ? this._$AH.call(null !== (r6 = null === (t5 = this.options) || void 0 === t5 ? void 0 : t5.host) && void 0 !== r6 ? r6 : this.element, e6) : this._$AH.handleEvent(e6);
      }
    }
    class te {
      constructor(e6, t5, r6) {
        this.element = e6, this.type = 6, this._$AN = void 0, this._$AM = t5, this.options = r6;
      }
      get _$AU() {
        return this._$AM._$AU;
      }
      _$AI(e6) {
        G(this, e6);
      }
    }
    const re = { P: "$lit$", A: S, M: A, C: 1, L: W, R: K, D: I, V: G, I: J, H: Y, N: X, U: ee, B: Z, F: te }, ne = w.litHtmlPolyfillSupport;
    null == ne || ne(V, J), (null !== (x2 = w.litHtmlVersions) && void 0 !== x2 ? x2 : w.litHtmlVersions = []).push("2.6.1");
    var oe, ae;
    class ie extends b {
      constructor() {
        super(...arguments), this.renderOptions = { host: this }, this._$Dt = void 0;
      }
      createRenderRoot() {
        var e6, t5;
        const r6 = super.createRenderRoot();
        return null !== (e6 = (t5 = this.renderOptions).renderBefore) && void 0 !== e6 || (t5.renderBefore = r6.firstChild), r6;
      }
      update(e6) {
        const t5 = this.render();
        this.hasUpdated || (this.renderOptions.isConnected = this.isConnected), super.update(e6), this._$Dt = ((e7, t6, r6) => {
          var n6, o5;
          const a2 = null !== (n6 = null == r6 ? void 0 : r6.renderBefore) && void 0 !== n6 ? n6 : t6;
          let i4 = a2._$litPart$;
          if (void 0 === i4) {
            const e8 = null !== (o5 = null == r6 ? void 0 : r6.renderBefore) && void 0 !== o5 ? o5 : null;
            a2._$litPart$ = i4 = new J(t6.insertBefore(T2(), e8), e8, void 0, null != r6 ? r6 : {});
          }
          return i4._$AI(e7), i4;
        })(t5, this.renderRoot, this.renderOptions);
      }
      connectedCallback() {
        var e6;
        super.connectedCallback(), null === (e6 = this._$Dt) || void 0 === e6 || e6.setConnected(true);
      }
      disconnectedCallback() {
        var e6;
        super.disconnectedCallback(), null === (e6 = this._$Dt) || void 0 === e6 || e6.setConnected(false);
      }
      render() {
        return U;
      }
    }
    ie.finalized = true, ie._$litElement$ = true, null === (oe = globalThis.litElementHydrateSupport) || void 0 === oe || oe.call(globalThis, { LitElement: ie });
    const se = globalThis.litElementPolyfillSupport;
    null == se || se({ LitElement: ie });
    function le() {
      return { async: false, baseUrl: null, breaks: false, extensions: null, gfm: true, headerIds: true, headerPrefix: "", highlight: null, langPrefix: "language-", mangle: true, pedantic: false, renderer: null, sanitize: false, sanitizer: null, silent: false, smartypants: false, tokenizer: null, walkTokens: null, xhtml: false };
    }
    (null !== (ae = globalThis.litElementVersions) && void 0 !== ae ? ae : globalThis.litElementVersions = []).push("3.2.0");
    let ce = { async: false, baseUrl: null, breaks: false, extensions: null, gfm: true, headerIds: true, headerPrefix: "", highlight: null, langPrefix: "language-", mangle: true, pedantic: false, renderer: null, sanitize: false, sanitizer: null, silent: false, smartypants: false, tokenizer: null, walkTokens: null, xhtml: false };
    const pe = /[&<>"']/, de = new RegExp(pe.source, "g"), ue = /[<>"']|&(?!(#\d{1,7}|#[Xx][a-fA-F0-9]{1,6}|\w+);)/, he = new RegExp(ue.source, "g"), fe = { "&": "&amp;", "<": "&lt;", ">": "&gt;", '"': "&quot;", "'": "&#39;" }, me2 = (e6) => fe[e6];
    function ye(e6, t5) {
      if (t5) {
        if (pe.test(e6))
          return e6.replace(de, me2);
      } else if (ue.test(e6))
        return e6.replace(he, me2);
      return e6;
    }
    const ge = /&(#(?:\d+)|(?:#x[0-9A-Fa-f]+)|(?:\w+));?/gi;
    function ve(e6) {
      return e6.replace(ge, (e7, t5) => "colon" === (t5 = t5.toLowerCase()) ? ":" : "#" === t5.charAt(0) ? "x" === t5.charAt(1) ? String.fromCharCode(parseInt(t5.substring(2), 16)) : String.fromCharCode(+t5.substring(1)) : "");
    }
    const be = /(^|[^\[])\^/g;
    function xe(e6, t5) {
      e6 = "string" == typeof e6 ? e6 : e6.source, t5 = t5 || "";
      const r6 = { replace: (t6, n6) => (n6 = (n6 = n6.source || n6).replace(be, "$1"), e6 = e6.replace(t6, n6), r6), getRegex: () => new RegExp(e6, t5) };
      return r6;
    }
    const we = /[^\w:]/g, $e = /^$|^[a-z][a-z0-9+.-]*:|^[?#]/i;
    function ke(e6, t5, r6) {
      if (e6) {
        let e7;
        try {
          e7 = decodeURIComponent(ve(r6)).replace(we, "").toLowerCase();
        } catch (e8) {
          return null;
        }
        if (0 === e7.indexOf("javascript:") || 0 === e7.indexOf("vbscript:") || 0 === e7.indexOf("data:"))
          return null;
      }
      t5 && !$e.test(r6) && (r6 = function(e7, t6) {
        Se[" " + e7] || (Ae.test(e7) ? Se[" " + e7] = e7 + "/" : Se[" " + e7] = Ie(e7, "/", true));
        const r7 = -1 === (e7 = Se[" " + e7]).indexOf(":");
        return "//" === t6.substring(0, 2) ? r7 ? t6 : e7.replace(Ee, "$1") + t6 : "/" === t6.charAt(0) ? r7 ? t6 : e7.replace(Oe, "$1") + t6 : e7 + t6;
      }(t5, r6));
      try {
        r6 = encodeURI(r6).replace(/%25/g, "%");
      } catch (e7) {
        return null;
      }
      return r6;
    }
    const Se = {}, Ae = /^[^:]+:\/*[^/]*$/, Ee = /^([^:]+:)[\s\S]*$/, Oe = /^([^:]+:\/*[^/]*)[\s\S]*$/;
    const Te = { exec: function() {
    } };
    function Ce(e6) {
      let t5, r6, n6 = 1;
      for (; n6 < arguments.length; n6++)
        for (r6 in t5 = arguments[n6], t5)
          Object.prototype.hasOwnProperty.call(t5, r6) && (e6[r6] = t5[r6]);
      return e6;
    }
    function je(e6, t5) {
      const r6 = e6.replace(/\|/g, (e7, t6, r7) => {
        let n7 = false, o5 = t6;
        for (; --o5 >= 0 && "\\" === r7[o5]; )
          n7 = !n7;
        return n7 ? "|" : " |";
      }).split(/ \|/);
      let n6 = 0;
      if (r6[0].trim() || r6.shift(), r6.length > 0 && !r6[r6.length - 1].trim() && r6.pop(), r6.length > t5)
        r6.splice(t5);
      else
        for (; r6.length < t5; )
          r6.push("");
      for (; n6 < r6.length; n6++)
        r6[n6] = r6[n6].trim().replace(/\\\|/g, "|");
      return r6;
    }
    function Ie(e6, t5, r6) {
      const n6 = e6.length;
      if (0 === n6)
        return "";
      let o5 = 0;
      for (; o5 < n6; ) {
        const a2 = e6.charAt(n6 - o5 - 1);
        if (a2 !== t5 || r6) {
          if (a2 === t5 || !r6)
            break;
          o5++;
        } else
          o5++;
      }
      return e6.slice(0, n6 - o5);
    }
    function _e(e6) {
      e6 && e6.sanitize && !e6.silent && console.warn("marked(): sanitize and sanitizer parameters are deprecated since version 0.7.0, should not be used and will be removed in the future. Read more here: https://marked.js.org/#/USING_ADVANCED.md#options");
    }
    function Pe(e6, t5) {
      if (t5 < 1)
        return "";
      let r6 = "";
      for (; t5 > 1; )
        1 & t5 && (r6 += e6), t5 >>= 1, e6 += e6;
      return r6 + e6;
    }
    function Re(e6, t5, r6, n6) {
      const o5 = t5.href, a2 = t5.title ? ye(t5.title) : null, i4 = e6[1].replace(/\\([\[\]])/g, "$1");
      if ("!" !== e6[0].charAt(0)) {
        n6.state.inLink = true;
        const e7 = { type: "link", raw: r6, href: o5, title: a2, text: i4, tokens: n6.inlineTokens(i4) };
        return n6.state.inLink = false, e7;
      }
      return { type: "image", raw: r6, href: o5, title: a2, text: ye(i4) };
    }
    class Le {
      constructor(e6) {
        this.options = e6 || ce;
      }
      space(e6) {
        const t5 = this.rules.block.newline.exec(e6);
        if (t5 && t5[0].length > 0)
          return { type: "space", raw: t5[0] };
      }
      code(e6) {
        const t5 = this.rules.block.code.exec(e6);
        if (t5) {
          const e7 = t5[0].replace(/^ {1,4}/gm, "");
          return { type: "code", raw: t5[0], codeBlockStyle: "indented", text: this.options.pedantic ? e7 : Ie(e7, "\n") };
        }
      }
      fences(e6) {
        const t5 = this.rules.block.fences.exec(e6);
        if (t5) {
          const e7 = t5[0], r6 = function(e8, t6) {
            const r7 = e8.match(/^(\s+)(?:```)/);
            if (null === r7)
              return t6;
            const n6 = r7[1];
            return t6.split("\n").map((e9) => {
              const t7 = e9.match(/^\s+/);
              if (null === t7)
                return e9;
              const [r8] = t7;
              return r8.length >= n6.length ? e9.slice(n6.length) : e9;
            }).join("\n");
          }(e7, t5[3] || "");
          return { type: "code", raw: e7, lang: t5[2] ? t5[2].trim().replace(this.rules.inline._escapes, "$1") : t5[2], text: r6 };
        }
      }
      heading(e6) {
        const t5 = this.rules.block.heading.exec(e6);
        if (t5) {
          let e7 = t5[2].trim();
          if (/#$/.test(e7)) {
            const t6 = Ie(e7, "#");
            this.options.pedantic ? e7 = t6.trim() : t6 && !/ $/.test(t6) || (e7 = t6.trim());
          }
          return { type: "heading", raw: t5[0], depth: t5[1].length, text: e7, tokens: this.lexer.inline(e7) };
        }
      }
      hr(e6) {
        const t5 = this.rules.block.hr.exec(e6);
        if (t5)
          return { type: "hr", raw: t5[0] };
      }
      blockquote(e6) {
        const t5 = this.rules.block.blockquote.exec(e6);
        if (t5) {
          const e7 = t5[0].replace(/^ *>[ \t]?/gm, ""), r6 = this.lexer.state.top;
          this.lexer.state.top = true;
          const n6 = this.lexer.blockTokens(e7);
          return this.lexer.state.top = r6, { type: "blockquote", raw: t5[0], tokens: n6, text: e7 };
        }
      }
      list(e6) {
        let t5 = this.rules.block.list.exec(e6);
        if (t5) {
          let r6, n6, o5, a2, i4, s6, l2, c3, p2, d2, u3, h2, f3 = t5[1].trim();
          const m2 = f3.length > 1, y2 = { type: "list", raw: "", ordered: m2, start: m2 ? +f3.slice(0, -1) : "", loose: false, items: [] };
          f3 = m2 ? `\\d{1,9}\\${f3.slice(-1)}` : `\\${f3}`, this.options.pedantic && (f3 = m2 ? f3 : "[*+-]");
          const g2 = new RegExp(`^( {0,3}${f3})((?:[	 ][^\\n]*)?(?:\\n|$))`);
          for (; e6 && (h2 = false, t5 = g2.exec(e6)) && !this.rules.block.hr.test(e6); ) {
            if (r6 = t5[0], e6 = e6.substring(r6.length), c3 = t5[2].split("\n", 1)[0].replace(/^\t+/, (e7) => " ".repeat(3 * e7.length)), p2 = e6.split("\n", 1)[0], this.options.pedantic ? (a2 = 2, u3 = c3.trimLeft()) : (a2 = t5[2].search(/[^ ]/), a2 = a2 > 4 ? 1 : a2, u3 = c3.slice(a2), a2 += t5[1].length), s6 = false, !c3 && /^ *$/.test(p2) && (r6 += p2 + "\n", e6 = e6.substring(p2.length + 1), h2 = true), !h2) {
              const t6 = new RegExp(`^ {0,${Math.min(3, a2 - 1)}}(?:[*+-]|\\d{1,9}[.)])((?:[ 	][^\\n]*)?(?:\\n|$))`), n7 = new RegExp(`^ {0,${Math.min(3, a2 - 1)}}((?:- *){3,}|(?:_ *){3,}|(?:\\* *){3,})(?:\\n+|$)`), o6 = new RegExp(`^ {0,${Math.min(3, a2 - 1)}}(?:\`\`\`|~~~)`), i5 = new RegExp(`^ {0,${Math.min(3, a2 - 1)}}#`);
              for (; e6 && (d2 = e6.split("\n", 1)[0], p2 = d2, this.options.pedantic && (p2 = p2.replace(/^ {1,4}(?=( {4})*[^ ])/g, "  ")), !o6.test(p2)) && !i5.test(p2) && !t6.test(p2) && !n7.test(e6); ) {
                if (p2.search(/[^ ]/) >= a2 || !p2.trim())
                  u3 += "\n" + p2.slice(a2);
                else {
                  if (s6)
                    break;
                  if (c3.search(/[^ ]/) >= 4)
                    break;
                  if (o6.test(c3))
                    break;
                  if (i5.test(c3))
                    break;
                  if (n7.test(c3))
                    break;
                  u3 += "\n" + p2;
                }
                s6 || p2.trim() || (s6 = true), r6 += d2 + "\n", e6 = e6.substring(d2.length + 1), c3 = p2.slice(a2);
              }
            }
            y2.loose || (l2 ? y2.loose = true : /\n *\n *$/.test(r6) && (l2 = true)), this.options.gfm && (n6 = /^\[[ xX]\] /.exec(u3), n6 && (o5 = "[ ] " !== n6[0], u3 = u3.replace(/^\[[ xX]\] +/, ""))), y2.items.push({ type: "list_item", raw: r6, task: !!n6, checked: o5, loose: false, text: u3 }), y2.raw += r6;
          }
          y2.items[y2.items.length - 1].raw = r6.trimRight(), y2.items[y2.items.length - 1].text = u3.trimRight(), y2.raw = y2.raw.trimRight();
          const v2 = y2.items.length;
          for (i4 = 0; i4 < v2; i4++)
            if (this.lexer.state.top = false, y2.items[i4].tokens = this.lexer.blockTokens(y2.items[i4].text, []), !y2.loose) {
              const e7 = y2.items[i4].tokens.filter((e8) => "space" === e8.type), t6 = e7.length > 0 && e7.some((e8) => /\n.*\n/.test(e8.raw));
              y2.loose = t6;
            }
          if (y2.loose)
            for (i4 = 0; i4 < v2; i4++)
              y2.items[i4].loose = true;
          return y2;
        }
      }
      html(e6) {
        const t5 = this.rules.block.html.exec(e6);
        if (t5) {
          const e7 = { type: "html", raw: t5[0], pre: !this.options.sanitizer && ("pre" === t5[1] || "script" === t5[1] || "style" === t5[1]), text: t5[0] };
          if (this.options.sanitize) {
            const r6 = this.options.sanitizer ? this.options.sanitizer(t5[0]) : ye(t5[0]);
            e7.type = "paragraph", e7.text = r6, e7.tokens = this.lexer.inline(r6);
          }
          return e7;
        }
      }
      def(e6) {
        const t5 = this.rules.block.def.exec(e6);
        if (t5) {
          const e7 = t5[1].toLowerCase().replace(/\s+/g, " "), r6 = t5[2] ? t5[2].replace(/^<(.*)>$/, "$1").replace(this.rules.inline._escapes, "$1") : "", n6 = t5[3] ? t5[3].substring(1, t5[3].length - 1).replace(this.rules.inline._escapes, "$1") : t5[3];
          return { type: "def", tag: e7, raw: t5[0], href: r6, title: n6 };
        }
      }
      table(e6) {
        const t5 = this.rules.block.table.exec(e6);
        if (t5) {
          const e7 = { type: "table", header: je(t5[1]).map((e8) => ({ text: e8 })), align: t5[2].replace(/^ *|\| *$/g, "").split(/ *\| */), rows: t5[3] && t5[3].trim() ? t5[3].replace(/\n[ \t]*$/, "").split("\n") : [] };
          if (e7.header.length === e7.align.length) {
            e7.raw = t5[0];
            let r6, n6, o5, a2, i4 = e7.align.length;
            for (r6 = 0; r6 < i4; r6++)
              /^ *-+: *$/.test(e7.align[r6]) ? e7.align[r6] = "right" : /^ *:-+: *$/.test(e7.align[r6]) ? e7.align[r6] = "center" : /^ *:-+ *$/.test(e7.align[r6]) ? e7.align[r6] = "left" : e7.align[r6] = null;
            for (i4 = e7.rows.length, r6 = 0; r6 < i4; r6++)
              e7.rows[r6] = je(e7.rows[r6], e7.header.length).map((e8) => ({ text: e8 }));
            for (i4 = e7.header.length, n6 = 0; n6 < i4; n6++)
              e7.header[n6].tokens = this.lexer.inline(e7.header[n6].text);
            for (i4 = e7.rows.length, n6 = 0; n6 < i4; n6++)
              for (a2 = e7.rows[n6], o5 = 0; o5 < a2.length; o5++)
                a2[o5].tokens = this.lexer.inline(a2[o5].text);
            return e7;
          }
        }
      }
      lheading(e6) {
        const t5 = this.rules.block.lheading.exec(e6);
        if (t5)
          return { type: "heading", raw: t5[0], depth: "=" === t5[2].charAt(0) ? 1 : 2, text: t5[1], tokens: this.lexer.inline(t5[1]) };
      }
      paragraph(e6) {
        const t5 = this.rules.block.paragraph.exec(e6);
        if (t5) {
          const e7 = "\n" === t5[1].charAt(t5[1].length - 1) ? t5[1].slice(0, -1) : t5[1];
          return { type: "paragraph", raw: t5[0], text: e7, tokens: this.lexer.inline(e7) };
        }
      }
      text(e6) {
        const t5 = this.rules.block.text.exec(e6);
        if (t5)
          return { type: "text", raw: t5[0], text: t5[0], tokens: this.lexer.inline(t5[0]) };
      }
      escape(e6) {
        const t5 = this.rules.inline.escape.exec(e6);
        if (t5)
          return { type: "escape", raw: t5[0], text: ye(t5[1]) };
      }
      tag(e6) {
        const t5 = this.rules.inline.tag.exec(e6);
        if (t5)
          return !this.lexer.state.inLink && /^<a /i.test(t5[0]) ? this.lexer.state.inLink = true : this.lexer.state.inLink && /^<\/a>/i.test(t5[0]) && (this.lexer.state.inLink = false), !this.lexer.state.inRawBlock && /^<(pre|code|kbd|script)(\s|>)/i.test(t5[0]) ? this.lexer.state.inRawBlock = true : this.lexer.state.inRawBlock && /^<\/(pre|code|kbd|script)(\s|>)/i.test(t5[0]) && (this.lexer.state.inRawBlock = false), { type: this.options.sanitize ? "text" : "html", raw: t5[0], inLink: this.lexer.state.inLink, inRawBlock: this.lexer.state.inRawBlock, text: this.options.sanitize ? this.options.sanitizer ? this.options.sanitizer(t5[0]) : ye(t5[0]) : t5[0] };
      }
      link(e6) {
        const t5 = this.rules.inline.link.exec(e6);
        if (t5) {
          const e7 = t5[2].trim();
          if (!this.options.pedantic && /^</.test(e7)) {
            if (!/>$/.test(e7))
              return;
            const t6 = Ie(e7.slice(0, -1), "\\");
            if ((e7.length - t6.length) % 2 == 0)
              return;
          } else {
            const e8 = function(e9, t6) {
              if (-1 === e9.indexOf(t6[1]))
                return -1;
              const r7 = e9.length;
              let n7 = 0, o5 = 0;
              for (; o5 < r7; o5++)
                if ("\\" === e9[o5])
                  o5++;
                else if (e9[o5] === t6[0])
                  n7++;
                else if (e9[o5] === t6[1] && (n7--, n7 < 0))
                  return o5;
              return -1;
            }(t5[2], "()");
            if (e8 > -1) {
              const r7 = (0 === t5[0].indexOf("!") ? 5 : 4) + t5[1].length + e8;
              t5[2] = t5[2].substring(0, e8), t5[0] = t5[0].substring(0, r7).trim(), t5[3] = "";
            }
          }
          let r6 = t5[2], n6 = "";
          if (this.options.pedantic) {
            const e8 = /^([^'"]*[^\s])\s+(['"])(.*)\2/.exec(r6);
            e8 && (r6 = e8[1], n6 = e8[3]);
          } else
            n6 = t5[3] ? t5[3].slice(1, -1) : "";
          return r6 = r6.trim(), /^</.test(r6) && (r6 = this.options.pedantic && !/>$/.test(e7) ? r6.slice(1) : r6.slice(1, -1)), Re(t5, { href: r6 ? r6.replace(this.rules.inline._escapes, "$1") : r6, title: n6 ? n6.replace(this.rules.inline._escapes, "$1") : n6 }, t5[0], this.lexer);
        }
      }
      reflink(e6, t5) {
        let r6;
        if ((r6 = this.rules.inline.reflink.exec(e6)) || (r6 = this.rules.inline.nolink.exec(e6))) {
          let e7 = (r6[2] || r6[1]).replace(/\s+/g, " ");
          if (e7 = t5[e7.toLowerCase()], !e7) {
            const e8 = r6[0].charAt(0);
            return { type: "text", raw: e8, text: e8 };
          }
          return Re(r6, e7, r6[0], this.lexer);
        }
      }
      emStrong(e6, t5, r6 = "") {
        let n6 = this.rules.inline.emStrong.lDelim.exec(e6);
        if (!n6)
          return;
        if (n6[3] && r6.match(/[\p{L}\p{N}]/u))
          return;
        const o5 = n6[1] || n6[2] || "";
        if (!o5 || o5 && ("" === r6 || this.rules.inline.punctuation.exec(r6))) {
          const r7 = n6[0].length - 1;
          let o6, a2, i4 = r7, s6 = 0;
          const l2 = "*" === n6[0][0] ? this.rules.inline.emStrong.rDelimAst : this.rules.inline.emStrong.rDelimUnd;
          for (l2.lastIndex = 0, t5 = t5.slice(-1 * e6.length + r7); null != (n6 = l2.exec(t5)); ) {
            if (o6 = n6[1] || n6[2] || n6[3] || n6[4] || n6[5] || n6[6], !o6)
              continue;
            if (a2 = o6.length, n6[3] || n6[4]) {
              i4 += a2;
              continue;
            }
            if ((n6[5] || n6[6]) && r7 % 3 && !((r7 + a2) % 3)) {
              s6 += a2;
              continue;
            }
            if (i4 -= a2, i4 > 0)
              continue;
            a2 = Math.min(a2, a2 + i4 + s6);
            const t6 = e6.slice(0, r7 + n6.index + (n6[0].length - o6.length) + a2);
            if (Math.min(r7, a2) % 2) {
              const e7 = t6.slice(1, -1);
              return { type: "em", raw: t6, text: e7, tokens: this.lexer.inlineTokens(e7) };
            }
            const l3 = t6.slice(2, -2);
            return { type: "strong", raw: t6, text: l3, tokens: this.lexer.inlineTokens(l3) };
          }
        }
      }
      codespan(e6) {
        const t5 = this.rules.inline.code.exec(e6);
        if (t5) {
          let e7 = t5[2].replace(/\n/g, " ");
          const r6 = /[^ ]/.test(e7), n6 = /^ /.test(e7) && / $/.test(e7);
          return r6 && n6 && (e7 = e7.substring(1, e7.length - 1)), e7 = ye(e7, true), { type: "codespan", raw: t5[0], text: e7 };
        }
      }
      br(e6) {
        const t5 = this.rules.inline.br.exec(e6);
        if (t5)
          return { type: "br", raw: t5[0] };
      }
      del(e6) {
        const t5 = this.rules.inline.del.exec(e6);
        if (t5)
          return { type: "del", raw: t5[0], text: t5[2], tokens: this.lexer.inlineTokens(t5[2]) };
      }
      autolink(e6, t5) {
        const r6 = this.rules.inline.autolink.exec(e6);
        if (r6) {
          let e7, n6;
          return "@" === r6[2] ? (e7 = ye(this.options.mangle ? t5(r6[1]) : r6[1]), n6 = "mailto:" + e7) : (e7 = ye(r6[1]), n6 = e7), { type: "link", raw: r6[0], text: e7, href: n6, tokens: [{ type: "text", raw: e7, text: e7 }] };
        }
      }
      url(e6, t5) {
        let r6;
        if (r6 = this.rules.inline.url.exec(e6)) {
          let e7, n6;
          if ("@" === r6[2])
            e7 = ye(this.options.mangle ? t5(r6[0]) : r6[0]), n6 = "mailto:" + e7;
          else {
            let t6;
            do {
              t6 = r6[0], r6[0] = this.rules.inline._backpedal.exec(r6[0])[0];
            } while (t6 !== r6[0]);
            e7 = ye(r6[0]), n6 = "www." === r6[1] ? "http://" + r6[0] : r6[0];
          }
          return { type: "link", raw: r6[0], text: e7, href: n6, tokens: [{ type: "text", raw: e7, text: e7 }] };
        }
      }
      inlineText(e6, t5) {
        const r6 = this.rules.inline.text.exec(e6);
        if (r6) {
          let e7;
          return e7 = this.lexer.state.inRawBlock ? this.options.sanitize ? this.options.sanitizer ? this.options.sanitizer(r6[0]) : ye(r6[0]) : r6[0] : ye(this.options.smartypants ? t5(r6[0]) : r6[0]), { type: "text", raw: r6[0], text: e7 };
        }
      }
    }
    const Fe = { newline: /^(?: *(?:\n|$))+/, code: /^( {4}[^\n]+(?:\n(?: *(?:\n|$))*)?)+/, fences: /^ {0,3}(`{3,}(?=[^`\n]*\n)|~{3,})([^\n]*)\n(?:|([\s\S]*?)\n)(?: {0,3}\1[~`]* *(?=\n|$)|$)/, hr: /^ {0,3}((?:-[\t ]*){3,}|(?:_[ \t]*){3,}|(?:\*[ \t]*){3,})(?:\n+|$)/, heading: /^ {0,3}(#{1,6})(?=\s|$)(.*)(?:\n+|$)/, blockquote: /^( {0,3}> ?(paragraph|[^\n]*)(?:\n|$))+/, list: /^( {0,3}bull)([ \t][^\n]+?)?(?:\n|$)/, html: "^ {0,3}(?:<(script|pre|style|textarea)[\\s>][\\s\\S]*?(?:</\\1>[^\\n]*\\n+|$)|comment[^\\n]*(\\n+|$)|<\\?[\\s\\S]*?(?:\\?>\\n*|$)|<![A-Z][\\s\\S]*?(?:>\\n*|$)|<!\\[CDATA\\[[\\s\\S]*?(?:\\]\\]>\\n*|$)|</?(tag)(?: +|\\n|/?>)[\\s\\S]*?(?:(?:\\n *)+\\n|$)|<(?!script|pre|style|textarea)([a-z][\\w-]*)(?:attribute)*? */?>(?=[ \\t]*(?:\\n|$))[\\s\\S]*?(?:(?:\\n *)+\\n|$)|</(?!script|pre|style|textarea)[a-z][\\w-]*\\s*>(?=[ \\t]*(?:\\n|$))[\\s\\S]*?(?:(?:\\n *)+\\n|$))", def: /^ {0,3}\[(label)\]: *(?:\n *)?([^<\s][^\s]*|<.*?>)(?:(?: +(?:\n *)?| *\n *)(title))? *(?:\n+|$)/, table: Te, lheading: /^((?:.|\n(?!\n))+?)\n {0,3}(=+|-+) *(?:\n+|$)/, _paragraph: /^([^\n]+(?:\n(?!hr|heading|lheading|blockquote|fences|list|html|table| +\n)[^\n]+)*)/, text: /^[^\n]+/, _label: /(?!\s*\])(?:\\.|[^\[\]\\])+/, _title: /(?:"(?:\\"?|[^"\\])*"|'[^'\n]*(?:\n[^'\n]+)*\n?'|\([^()]*\))/ };
    Fe.def = xe(Fe.def).replace("label", Fe._label).replace("title", Fe._title).getRegex(), Fe.bullet = /(?:[*+-]|\d{1,9}[.)])/, Fe.listItemStart = xe(/^( *)(bull) */).replace("bull", Fe.bullet).getRegex(), Fe.list = xe(Fe.list).replace(/bull/g, Fe.bullet).replace("hr", "\\n+(?=\\1?(?:(?:- *){3,}|(?:_ *){3,}|(?:\\* *){3,})(?:\\n+|$))").replace("def", "\\n+(?=" + Fe.def.source + ")").getRegex(), Fe._tag = "address|article|aside|base|basefont|blockquote|body|caption|center|col|colgroup|dd|details|dialog|dir|div|dl|dt|fieldset|figcaption|figure|footer|form|frame|frameset|h[1-6]|head|header|hr|html|iframe|legend|li|link|main|menu|menuitem|meta|nav|noframes|ol|optgroup|option|p|param|section|source|summary|table|tbody|td|tfoot|th|thead|title|tr|track|ul", Fe._comment = /<!--(?!-?>)[\s\S]*?(?:-->|$)/, Fe.html = xe(Fe.html, "i").replace("comment", Fe._comment).replace("tag", Fe._tag).replace("attribute", / +[a-zA-Z:_][\w.:-]*(?: *= *"[^"\n]*"| *= *'[^'\n]*'| *= *[^\s"'=<>`]+)?/).getRegex(), Fe.paragraph = xe(Fe._paragraph).replace("hr", Fe.hr).replace("heading", " {0,3}#{1,6} ").replace("|lheading", "").replace("|table", "").replace("blockquote", " {0,3}>").replace("fences", " {0,3}(?:`{3,}(?=[^`\\n]*\\n)|~{3,})[^\\n]*\\n").replace("list", " {0,3}(?:[*+-]|1[.)]) ").replace("html", "</?(?:tag)(?: +|\\n|/?>)|<(?:script|pre|style|textarea|!--)").replace("tag", Fe._tag).getRegex(), Fe.blockquote = xe(Fe.blockquote).replace("paragraph", Fe.paragraph).getRegex(), Fe.normal = Ce({}, Fe), Fe.gfm = Ce({}, Fe.normal, { table: "^ *([^\\n ].*\\|.*)\\n {0,3}(?:\\| *)?(:?-+:? *(?:\\| *:?-+:? *)*)(?:\\| *)?(?:\\n((?:(?! *\\n|hr|heading|blockquote|code|fences|list|html).*(?:\\n|$))*)\\n*|$)" }), Fe.gfm.table = xe(Fe.gfm.table).replace("hr", Fe.hr).replace("heading", " {0,3}#{1,6} ").replace("blockquote", " {0,3}>").replace("code", " {4}[^\\n]").replace("fences", " {0,3}(?:`{3,}(?=[^`\\n]*\\n)|~{3,})[^\\n]*\\n").replace("list", " {0,3}(?:[*+-]|1[.)]) ").replace("html", "</?(?:tag)(?: +|\\n|/?>)|<(?:script|pre|style|textarea|!--)").replace("tag", Fe._tag).getRegex(), Fe.gfm.paragraph = xe(Fe._paragraph).replace("hr", Fe.hr).replace("heading", " {0,3}#{1,6} ").replace("|lheading", "").replace("table", Fe.gfm.table).replace("blockquote", " {0,3}>").replace("fences", " {0,3}(?:`{3,}(?=[^`\\n]*\\n)|~{3,})[^\\n]*\\n").replace("list", " {0,3}(?:[*+-]|1[.)]) ").replace("html", "</?(?:tag)(?: +|\\n|/?>)|<(?:script|pre|style|textarea|!--)").replace("tag", Fe._tag).getRegex(), Fe.pedantic = Ce({}, Fe.normal, { html: xe(`^ *(?:comment *(?:\\n|\\s*$)|<(tag)[\\s\\S]+?</\\1> *(?:\\n{2,}|\\s*$)|<tag(?:"[^"]*"|'[^']*'|\\s[^'"/>\\s]*)*?/?> *(?:\\n{2,}|\\s*$))`).replace("comment", Fe._comment).replace(/tag/g, "(?!(?:a|em|strong|small|s|cite|q|dfn|abbr|data|time|code|var|samp|kbd|sub|sup|i|b|u|mark|ruby|rt|rp|bdi|bdo|span|br|wbr|ins|del|img)\\b)\\w+(?!:|[^\\w\\s@]*@)\\b").getRegex(), def: /^ *\[([^\]]+)\]: *<?([^\s>]+)>?(?: +(["(][^\n]+[")]))? *(?:\n+|$)/, heading: /^(#{1,6})(.*)(?:\n+|$)/, fences: Te, lheading: /^(.+?)\n {0,3}(=+|-+) *(?:\n+|$)/, paragraph: xe(Fe.normal._paragraph).replace("hr", Fe.hr).replace("heading", " *#{1,6} *[^\n]").replace("lheading", Fe.lheading).replace("blockquote", " {0,3}>").replace("|fences", "").replace("|list", "").replace("|html", "").getRegex() });
    const De = { escape: /^\\([!"#$%&'()*+,\-./:;<=>?@\[\]\\^_`{|}~])/, autolink: /^<(scheme:[^\s\x00-\x1f<>]*|email)>/, url: Te, tag: "^comment|^</[a-zA-Z][\\w:-]*\\s*>|^<[a-zA-Z][\\w-]*(?:attribute)*?\\s*/?>|^<\\?[\\s\\S]*?\\?>|^<![a-zA-Z]+\\s[\\s\\S]*?>|^<!\\[CDATA\\[[\\s\\S]*?\\]\\]>", link: /^!?\[(label)\]\(\s*(href)(?:\s+(title))?\s*\)/, reflink: /^!?\[(label)\]\[(ref)\]/, nolink: /^!?\[(ref)\](?:\[\])?/, reflinkSearch: "reflink|nolink(?!\\()", emStrong: { lDelim: /^(?:\*+(?:([punct_])|[^\s*]))|^_+(?:([punct*])|([^\s_]))/, rDelimAst: /^(?:[^_*\\]|\\.)*?\_\_(?:[^_*\\]|\\.)*?\*(?:[^_*\\]|\\.)*?(?=\_\_)|(?:[^*\\]|\\.)+(?=[^*])|[punct_](\*+)(?=[\s]|$)|(?:[^punct*_\s\\]|\\.)(\*+)(?=[punct_\s]|$)|[punct_\s](\*+)(?=[^punct*_\s])|[\s](\*+)(?=[punct_])|[punct_](\*+)(?=[punct_])|(?:[^punct*_\s\\]|\\.)(\*+)(?=[^punct*_\s])/, rDelimUnd: /^(?:[^_*\\]|\\.)*?\*\*(?:[^_*\\]|\\.)*?\_(?:[^_*\\]|\\.)*?(?=\*\*)|(?:[^_\\]|\\.)+(?=[^_])|[punct*](\_+)(?=[\s]|$)|(?:[^punct*_\s\\]|\\.)(\_+)(?=[punct*\s]|$)|[punct*\s](\_+)(?=[^punct*_\s])|[\s](\_+)(?=[punct*])|[punct*](\_+)(?=[punct*])/ }, code: /^(`+)([^`]|[^`][\s\S]*?[^`])\1(?!`)/, br: /^( {2,}|\\)\n(?!\s*$)/, del: Te, text: /^(`+|[^`])(?:(?= {2,}\n)|[\s\S]*?(?:(?=[\\<!\[`*_]|\b_|$)|[^ ](?= {2,}\n)))/, punctuation: /^([\spunctuation])/ };
    function Be(e6) {
      return e6.replace(/---/g, "\u2014").replace(/--/g, "\u2013").replace(/(^|[-\u2014/(\[{"\s])'/g, "$1\u2018").replace(/'/g, "\u2019").replace(/(^|[-\u2014/(\[{\u2018\s])"/g, "$1\u201C").replace(/"/g, "\u201D").replace(/\.{3}/g, "\u2026");
    }
    function Ne(e6) {
      let t5, r6, n6 = "";
      const o5 = e6.length;
      for (t5 = 0; t5 < o5; t5++)
        r6 = e6.charCodeAt(t5), Math.random() > 0.5 && (r6 = "x" + r6.toString(16)), n6 += "&#" + r6 + ";";
      return n6;
    }
    De._punctuation = "!\"#$%&'()+\\-.,/:;<=>?@\\[\\]`^{|}~", De.punctuation = xe(De.punctuation).replace(/punctuation/g, De._punctuation).getRegex(), De.blockSkip = /\[[^\]]*?\]\([^\)]*?\)|`[^`]*?`|<[^>]*?>/g, De.escapedEmSt = /(?:^|[^\\])(?:\\\\)*\\[*_]/g, De._comment = xe(Fe._comment).replace("(?:-->|$)", "-->").getRegex(), De.emStrong.lDelim = xe(De.emStrong.lDelim).replace(/punct/g, De._punctuation).getRegex(), De.emStrong.rDelimAst = xe(De.emStrong.rDelimAst, "g").replace(/punct/g, De._punctuation).getRegex(), De.emStrong.rDelimUnd = xe(De.emStrong.rDelimUnd, "g").replace(/punct/g, De._punctuation).getRegex(), De._escapes = /\\([!"#$%&'()*+,\-./:;<=>?@\[\]\\^_`{|}~])/g, De._scheme = /[a-zA-Z][a-zA-Z0-9+.-]{1,31}/, De._email = /[a-zA-Z0-9.!#$%&'*+/=?^_`{|}~-]+(@)[a-zA-Z0-9](?:[a-zA-Z0-9-]{0,61}[a-zA-Z0-9])?(?:\.[a-zA-Z0-9](?:[a-zA-Z0-9-]{0,61}[a-zA-Z0-9])?)+(?![-_])/, De.autolink = xe(De.autolink).replace("scheme", De._scheme).replace("email", De._email).getRegex(), De._attribute = /\s+[a-zA-Z:_][\w.:-]*(?:\s*=\s*"[^"]*"|\s*=\s*'[^']*'|\s*=\s*[^\s"'=<>`]+)?/, De.tag = xe(De.tag).replace("comment", De._comment).replace("attribute", De._attribute).getRegex(), De._label = /(?:\[(?:\\.|[^\[\]\\])*\]|\\.|`[^`]*`|[^\[\]\\`])*?/, De._href = /<(?:\\.|[^\n<>\\])+>|[^\s\x00-\x1f]*/, De._title = /"(?:\\"?|[^"\\])*"|'(?:\\'?|[^'\\])*'|\((?:\\\)?|[^)\\])*\)/, De.link = xe(De.link).replace("label", De._label).replace("href", De._href).replace("title", De._title).getRegex(), De.reflink = xe(De.reflink).replace("label", De._label).replace("ref", Fe._label).getRegex(), De.nolink = xe(De.nolink).replace("ref", Fe._label).getRegex(), De.reflinkSearch = xe(De.reflinkSearch, "g").replace("reflink", De.reflink).replace("nolink", De.nolink).getRegex(), De.normal = Ce({}, De), De.pedantic = Ce({}, De.normal, { strong: { start: /^__|\*\*/, middle: /^__(?=\S)([\s\S]*?\S)__(?!_)|^\*\*(?=\S)([\s\S]*?\S)\*\*(?!\*)/, endAst: /\*\*(?!\*)/g, endUnd: /__(?!_)/g }, em: { start: /^_|\*/, middle: /^()\*(?=\S)([\s\S]*?\S)\*(?!\*)|^_(?=\S)([\s\S]*?\S)_(?!_)/, endAst: /\*(?!\*)/g, endUnd: /_(?!_)/g }, link: xe(/^!?\[(label)\]\((.*?)\)/).replace("label", De._label).getRegex(), reflink: xe(/^!?\[(label)\]\s*\[([^\]]*)\]/).replace("label", De._label).getRegex() }), De.gfm = Ce({}, De.normal, { escape: xe(De.escape).replace("])", "~|])").getRegex(), _extended_email: /[A-Za-z0-9._+-]+(@)[a-zA-Z0-9-_]+(?:\.[a-zA-Z0-9-_]*[a-zA-Z0-9])+(?![-_])/, url: /^((?:ftp|https?):\/\/|www\.)(?:[a-zA-Z0-9\-]+\.?)+[^\s<]*|^email/, _backpedal: /(?:[^?!.,:;*_'"~()&]+|\([^)]*\)|&(?![a-zA-Z0-9]+;$)|[?!.,:;*_'"~)]+(?!$))+/, del: /^(~~?)(?=[^\s~])([\s\S]*?[^\s~])\1(?=[^~]|$)/, text: /^([`~]+|[^`~])(?:(?= {2,}\n)|(?=[a-zA-Z0-9.!#$%&'*+\/=?_`{\|}~-]+@)|[\s\S]*?(?:(?=[\\<!\[`*~_]|\b_|https?:\/\/|ftp:\/\/|www\.|$)|[^ ](?= {2,}\n)|[^a-zA-Z0-9.!#$%&'*+\/=?_`{\|}~-](?=[a-zA-Z0-9.!#$%&'*+\/=?_`{\|}~-]+@)))/ }), De.gfm.url = xe(De.gfm.url, "i").replace("email", De.gfm._extended_email).getRegex(), De.breaks = Ce({}, De.gfm, { br: xe(De.br).replace("{2,}", "*").getRegex(), text: xe(De.gfm.text).replace("\\b_", "\\b_| {2,}\\n").replace(/\{2,\}/g, "*").getRegex() });
    class qe {
      constructor(e6) {
        this.tokens = [], this.tokens.links = /* @__PURE__ */ Object.create(null), this.options = e6 || ce, this.options.tokenizer = this.options.tokenizer || new Le(), this.tokenizer = this.options.tokenizer, this.tokenizer.options = this.options, this.tokenizer.lexer = this, this.inlineQueue = [], this.state = { inLink: false, inRawBlock: false, top: true };
        const t5 = { block: Fe.normal, inline: De.normal };
        this.options.pedantic ? (t5.block = Fe.pedantic, t5.inline = De.pedantic) : this.options.gfm && (t5.block = Fe.gfm, this.options.breaks ? t5.inline = De.breaks : t5.inline = De.gfm), this.tokenizer.rules = t5;
      }
      static get rules() {
        return { block: Fe, inline: De };
      }
      static lex(e6, t5) {
        return new qe(t5).lex(e6);
      }
      static lexInline(e6, t5) {
        return new qe(t5).inlineTokens(e6);
      }
      lex(e6) {
        let t5;
        for (e6 = e6.replace(/\r\n|\r/g, "\n"), this.blockTokens(e6, this.tokens); t5 = this.inlineQueue.shift(); )
          this.inlineTokens(t5.src, t5.tokens);
        return this.tokens;
      }
      blockTokens(e6, t5 = []) {
        let r6, n6, o5, a2;
        for (e6 = this.options.pedantic ? e6.replace(/\t/g, "    ").replace(/^ +$/gm, "") : e6.replace(/^( *)(\t+)/gm, (e7, t6, r7) => t6 + "    ".repeat(r7.length)); e6; )
          if (!(this.options.extensions && this.options.extensions.block && this.options.extensions.block.some((n7) => !!(r6 = n7.call({ lexer: this }, e6, t5)) && (e6 = e6.substring(r6.raw.length), t5.push(r6), true))))
            if (r6 = this.tokenizer.space(e6))
              e6 = e6.substring(r6.raw.length), 1 === r6.raw.length && t5.length > 0 ? t5[t5.length - 1].raw += "\n" : t5.push(r6);
            else if (r6 = this.tokenizer.code(e6))
              e6 = e6.substring(r6.raw.length), n6 = t5[t5.length - 1], !n6 || "paragraph" !== n6.type && "text" !== n6.type ? t5.push(r6) : (n6.raw += "\n" + r6.raw, n6.text += "\n" + r6.text, this.inlineQueue[this.inlineQueue.length - 1].src = n6.text);
            else if (r6 = this.tokenizer.fences(e6))
              e6 = e6.substring(r6.raw.length), t5.push(r6);
            else if (r6 = this.tokenizer.heading(e6))
              e6 = e6.substring(r6.raw.length), t5.push(r6);
            else if (r6 = this.tokenizer.hr(e6))
              e6 = e6.substring(r6.raw.length), t5.push(r6);
            else if (r6 = this.tokenizer.blockquote(e6))
              e6 = e6.substring(r6.raw.length), t5.push(r6);
            else if (r6 = this.tokenizer.list(e6))
              e6 = e6.substring(r6.raw.length), t5.push(r6);
            else if (r6 = this.tokenizer.html(e6))
              e6 = e6.substring(r6.raw.length), t5.push(r6);
            else if (r6 = this.tokenizer.def(e6))
              e6 = e6.substring(r6.raw.length), n6 = t5[t5.length - 1], !n6 || "paragraph" !== n6.type && "text" !== n6.type ? this.tokens.links[r6.tag] || (this.tokens.links[r6.tag] = { href: r6.href, title: r6.title }) : (n6.raw += "\n" + r6.raw, n6.text += "\n" + r6.raw, this.inlineQueue[this.inlineQueue.length - 1].src = n6.text);
            else if (r6 = this.tokenizer.table(e6))
              e6 = e6.substring(r6.raw.length), t5.push(r6);
            else if (r6 = this.tokenizer.lheading(e6))
              e6 = e6.substring(r6.raw.length), t5.push(r6);
            else {
              if (o5 = e6, this.options.extensions && this.options.extensions.startBlock) {
                let t6 = 1 / 0;
                const r7 = e6.slice(1);
                let n7;
                this.options.extensions.startBlock.forEach(function(e7) {
                  n7 = e7.call({ lexer: this }, r7), "number" == typeof n7 && n7 >= 0 && (t6 = Math.min(t6, n7));
                }), t6 < 1 / 0 && t6 >= 0 && (o5 = e6.substring(0, t6 + 1));
              }
              if (this.state.top && (r6 = this.tokenizer.paragraph(o5)))
                n6 = t5[t5.length - 1], a2 && "paragraph" === n6.type ? (n6.raw += "\n" + r6.raw, n6.text += "\n" + r6.text, this.inlineQueue.pop(), this.inlineQueue[this.inlineQueue.length - 1].src = n6.text) : t5.push(r6), a2 = o5.length !== e6.length, e6 = e6.substring(r6.raw.length);
              else if (r6 = this.tokenizer.text(e6))
                e6 = e6.substring(r6.raw.length), n6 = t5[t5.length - 1], n6 && "text" === n6.type ? (n6.raw += "\n" + r6.raw, n6.text += "\n" + r6.text, this.inlineQueue.pop(), this.inlineQueue[this.inlineQueue.length - 1].src = n6.text) : t5.push(r6);
              else if (e6) {
                const t6 = "Infinite loop on byte: " + e6.charCodeAt(0);
                if (this.options.silent) {
                  console.error(t6);
                  break;
                }
                throw new Error(t6);
              }
            }
        return this.state.top = true, t5;
      }
      inline(e6, t5 = []) {
        return this.inlineQueue.push({ src: e6, tokens: t5 }), t5;
      }
      inlineTokens(e6, t5 = []) {
        let r6, n6, o5, a2, i4, s6, l2 = e6;
        if (this.tokens.links) {
          const e7 = Object.keys(this.tokens.links);
          if (e7.length > 0)
            for (; null != (a2 = this.tokenizer.rules.inline.reflinkSearch.exec(l2)); )
              e7.includes(a2[0].slice(a2[0].lastIndexOf("[") + 1, -1)) && (l2 = l2.slice(0, a2.index) + "[" + Pe("a", a2[0].length - 2) + "]" + l2.slice(this.tokenizer.rules.inline.reflinkSearch.lastIndex));
        }
        for (; null != (a2 = this.tokenizer.rules.inline.blockSkip.exec(l2)); )
          l2 = l2.slice(0, a2.index) + "[" + Pe("a", a2[0].length - 2) + "]" + l2.slice(this.tokenizer.rules.inline.blockSkip.lastIndex);
        for (; null != (a2 = this.tokenizer.rules.inline.escapedEmSt.exec(l2)); )
          l2 = l2.slice(0, a2.index + a2[0].length - 2) + "++" + l2.slice(this.tokenizer.rules.inline.escapedEmSt.lastIndex), this.tokenizer.rules.inline.escapedEmSt.lastIndex--;
        for (; e6; )
          if (i4 || (s6 = ""), i4 = false, !(this.options.extensions && this.options.extensions.inline && this.options.extensions.inline.some((n7) => !!(r6 = n7.call({ lexer: this }, e6, t5)) && (e6 = e6.substring(r6.raw.length), t5.push(r6), true))))
            if (r6 = this.tokenizer.escape(e6))
              e6 = e6.substring(r6.raw.length), t5.push(r6);
            else if (r6 = this.tokenizer.tag(e6))
              e6 = e6.substring(r6.raw.length), n6 = t5[t5.length - 1], n6 && "text" === r6.type && "text" === n6.type ? (n6.raw += r6.raw, n6.text += r6.text) : t5.push(r6);
            else if (r6 = this.tokenizer.link(e6))
              e6 = e6.substring(r6.raw.length), t5.push(r6);
            else if (r6 = this.tokenizer.reflink(e6, this.tokens.links))
              e6 = e6.substring(r6.raw.length), n6 = t5[t5.length - 1], n6 && "text" === r6.type && "text" === n6.type ? (n6.raw += r6.raw, n6.text += r6.text) : t5.push(r6);
            else if (r6 = this.tokenizer.emStrong(e6, l2, s6))
              e6 = e6.substring(r6.raw.length), t5.push(r6);
            else if (r6 = this.tokenizer.codespan(e6))
              e6 = e6.substring(r6.raw.length), t5.push(r6);
            else if (r6 = this.tokenizer.br(e6))
              e6 = e6.substring(r6.raw.length), t5.push(r6);
            else if (r6 = this.tokenizer.del(e6))
              e6 = e6.substring(r6.raw.length), t5.push(r6);
            else if (r6 = this.tokenizer.autolink(e6, Ne))
              e6 = e6.substring(r6.raw.length), t5.push(r6);
            else if (this.state.inLink || !(r6 = this.tokenizer.url(e6, Ne))) {
              if (o5 = e6, this.options.extensions && this.options.extensions.startInline) {
                let t6 = 1 / 0;
                const r7 = e6.slice(1);
                let n7;
                this.options.extensions.startInline.forEach(function(e7) {
                  n7 = e7.call({ lexer: this }, r7), "number" == typeof n7 && n7 >= 0 && (t6 = Math.min(t6, n7));
                }), t6 < 1 / 0 && t6 >= 0 && (o5 = e6.substring(0, t6 + 1));
              }
              if (r6 = this.tokenizer.inlineText(o5, Be))
                e6 = e6.substring(r6.raw.length), "_" !== r6.raw.slice(-1) && (s6 = r6.raw.slice(-1)), i4 = true, n6 = t5[t5.length - 1], n6 && "text" === n6.type ? (n6.raw += r6.raw, n6.text += r6.text) : t5.push(r6);
              else if (e6) {
                const t6 = "Infinite loop on byte: " + e6.charCodeAt(0);
                if (this.options.silent) {
                  console.error(t6);
                  break;
                }
                throw new Error(t6);
              }
            } else
              e6 = e6.substring(r6.raw.length), t5.push(r6);
        return t5;
      }
    }
    class Ue {
      constructor(e6) {
        this.options = e6 || ce;
      }
      code(e6, t5, r6) {
        const n6 = (t5 || "").match(/\S*/)[0];
        if (this.options.highlight) {
          const t6 = this.options.highlight(e6, n6);
          null != t6 && t6 !== e6 && (r6 = true, e6 = t6);
        }
        return e6 = e6.replace(/\n$/, "") + "\n", n6 ? '<pre><code class="' + this.options.langPrefix + ye(n6) + '">' + (r6 ? e6 : ye(e6, true)) + "</code></pre>\n" : "<pre><code>" + (r6 ? e6 : ye(e6, true)) + "</code></pre>\n";
      }
      blockquote(e6) {
        return `<blockquote>
${e6}</blockquote>
`;
      }
      html(e6) {
        return e6;
      }
      heading(e6, t5, r6, n6) {
        if (this.options.headerIds) {
          return `<h${t5} id="${this.options.headerPrefix + n6.slug(r6)}">${e6}</h${t5}>
`;
        }
        return `<h${t5}>${e6}</h${t5}>
`;
      }
      hr() {
        return this.options.xhtml ? "<hr/>\n" : "<hr>\n";
      }
      list(e6, t5, r6) {
        const n6 = t5 ? "ol" : "ul";
        return "<" + n6 + (t5 && 1 !== r6 ? ' start="' + r6 + '"' : "") + ">\n" + e6 + "</" + n6 + ">\n";
      }
      listitem(e6) {
        return `<li>${e6}</li>
`;
      }
      checkbox(e6) {
        return "<input " + (e6 ? 'checked="" ' : "") + 'disabled="" type="checkbox"' + (this.options.xhtml ? " /" : "") + "> ";
      }
      paragraph(e6) {
        return `<p>${e6}</p>
`;
      }
      table(e6, t5) {
        return t5 && (t5 = `<tbody>${t5}</tbody>`), "<table>\n<thead>\n" + e6 + "</thead>\n" + t5 + "</table>\n";
      }
      tablerow(e6) {
        return `<tr>
${e6}</tr>
`;
      }
      tablecell(e6, t5) {
        const r6 = t5.header ? "th" : "td";
        return (t5.align ? `<${r6} align="${t5.align}">` : `<${r6}>`) + e6 + `</${r6}>
`;
      }
      strong(e6) {
        return `<strong>${e6}</strong>`;
      }
      em(e6) {
        return `<em>${e6}</em>`;
      }
      codespan(e6) {
        return `<code>${e6}</code>`;
      }
      br() {
        return this.options.xhtml ? "<br/>" : "<br>";
      }
      del(e6) {
        return `<del>${e6}</del>`;
      }
      link(e6, t5, r6) {
        if (null === (e6 = ke(this.options.sanitize, this.options.baseUrl, e6)))
          return r6;
        let n6 = '<a href="' + e6 + '"';
        return t5 && (n6 += ' title="' + t5 + '"'), n6 += ">" + r6 + "</a>", n6;
      }
      image(e6, t5, r6) {
        if (null === (e6 = ke(this.options.sanitize, this.options.baseUrl, e6)))
          return r6;
        let n6 = `<img src="${e6}" alt="${r6}"`;
        return t5 && (n6 += ` title="${t5}"`), n6 += this.options.xhtml ? "/>" : ">", n6;
      }
      text(e6) {
        return e6;
      }
    }
    class ze {
      strong(e6) {
        return e6;
      }
      em(e6) {
        return e6;
      }
      codespan(e6) {
        return e6;
      }
      del(e6) {
        return e6;
      }
      html(e6) {
        return e6;
      }
      text(e6) {
        return e6;
      }
      link(e6, t5, r6) {
        return "" + r6;
      }
      image(e6, t5, r6) {
        return "" + r6;
      }
      br() {
        return "";
      }
    }
    class Me {
      constructor() {
        this.seen = {};
      }
      serialize(e6) {
        return e6.toLowerCase().trim().replace(/<[!\/a-z].*?>/gi, "").replace(/[\u2000-\u206F\u2E00-\u2E7F\\'!"#$%&()*+,./:;<=>?@[\]^`{|}~]/g, "").replace(/\s/g, "-");
      }
      getNextSafeSlug(e6, t5) {
        let r6 = e6, n6 = 0;
        if (this.seen.hasOwnProperty(r6)) {
          n6 = this.seen[e6];
          do {
            n6++, r6 = e6 + "-" + n6;
          } while (this.seen.hasOwnProperty(r6));
        }
        return t5 || (this.seen[e6] = n6, this.seen[r6] = 0), r6;
      }
      slug(e6, t5 = {}) {
        const r6 = this.serialize(e6);
        return this.getNextSafeSlug(r6, t5.dryrun);
      }
    }
    class He {
      constructor(e6) {
        this.options = e6 || ce, this.options.renderer = this.options.renderer || new Ue(), this.renderer = this.options.renderer, this.renderer.options = this.options, this.textRenderer = new ze(), this.slugger = new Me();
      }
      static parse(e6, t5) {
        return new He(t5).parse(e6);
      }
      static parseInline(e6, t5) {
        return new He(t5).parseInline(e6);
      }
      parse(e6, t5 = true) {
        let r6, n6, o5, a2, i4, s6, l2, c3, p2, d2, u3, h2, f3, m2, y2, g2, v2, b2, x3, w2 = "";
        const $2 = e6.length;
        for (r6 = 0; r6 < $2; r6++)
          if (d2 = e6[r6], this.options.extensions && this.options.extensions.renderers && this.options.extensions.renderers[d2.type] && (x3 = this.options.extensions.renderers[d2.type].call({ parser: this }, d2), false !== x3 || !["space", "hr", "heading", "code", "table", "blockquote", "list", "html", "paragraph", "text"].includes(d2.type)))
            w2 += x3 || "";
          else
            switch (d2.type) {
              case "space":
                continue;
              case "hr":
                w2 += this.renderer.hr();
                continue;
              case "heading":
                w2 += this.renderer.heading(this.parseInline(d2.tokens), d2.depth, ve(this.parseInline(d2.tokens, this.textRenderer)), this.slugger);
                continue;
              case "code":
                w2 += this.renderer.code(d2.text, d2.lang, d2.escaped);
                continue;
              case "table":
                for (c3 = "", l2 = "", a2 = d2.header.length, n6 = 0; n6 < a2; n6++)
                  l2 += this.renderer.tablecell(this.parseInline(d2.header[n6].tokens), { header: true, align: d2.align[n6] });
                for (c3 += this.renderer.tablerow(l2), p2 = "", a2 = d2.rows.length, n6 = 0; n6 < a2; n6++) {
                  for (s6 = d2.rows[n6], l2 = "", i4 = s6.length, o5 = 0; o5 < i4; o5++)
                    l2 += this.renderer.tablecell(this.parseInline(s6[o5].tokens), { header: false, align: d2.align[o5] });
                  p2 += this.renderer.tablerow(l2);
                }
                w2 += this.renderer.table(c3, p2);
                continue;
              case "blockquote":
                p2 = this.parse(d2.tokens), w2 += this.renderer.blockquote(p2);
                continue;
              case "list":
                for (u3 = d2.ordered, h2 = d2.start, f3 = d2.loose, a2 = d2.items.length, p2 = "", n6 = 0; n6 < a2; n6++)
                  y2 = d2.items[n6], g2 = y2.checked, v2 = y2.task, m2 = "", y2.task && (b2 = this.renderer.checkbox(g2), f3 ? y2.tokens.length > 0 && "paragraph" === y2.tokens[0].type ? (y2.tokens[0].text = b2 + " " + y2.tokens[0].text, y2.tokens[0].tokens && y2.tokens[0].tokens.length > 0 && "text" === y2.tokens[0].tokens[0].type && (y2.tokens[0].tokens[0].text = b2 + " " + y2.tokens[0].tokens[0].text)) : y2.tokens.unshift({ type: "text", text: b2 }) : m2 += b2), m2 += this.parse(y2.tokens, f3), p2 += this.renderer.listitem(m2, v2, g2);
                w2 += this.renderer.list(p2, u3, h2);
                continue;
              case "html":
                w2 += this.renderer.html(d2.text);
                continue;
              case "paragraph":
                w2 += this.renderer.paragraph(this.parseInline(d2.tokens));
                continue;
              case "text":
                for (p2 = d2.tokens ? this.parseInline(d2.tokens) : d2.text; r6 + 1 < $2 && "text" === e6[r6 + 1].type; )
                  d2 = e6[++r6], p2 += "\n" + (d2.tokens ? this.parseInline(d2.tokens) : d2.text);
                w2 += t5 ? this.renderer.paragraph(p2) : p2;
                continue;
              default: {
                const e7 = 'Token with "' + d2.type + '" type was not found.';
                if (this.options.silent)
                  return void console.error(e7);
                throw new Error(e7);
              }
            }
        return w2;
      }
      parseInline(e6, t5) {
        t5 = t5 || this.renderer;
        let r6, n6, o5, a2 = "";
        const i4 = e6.length;
        for (r6 = 0; r6 < i4; r6++)
          if (n6 = e6[r6], this.options.extensions && this.options.extensions.renderers && this.options.extensions.renderers[n6.type] && (o5 = this.options.extensions.renderers[n6.type].call({ parser: this }, n6), false !== o5 || !["escape", "html", "link", "image", "strong", "em", "codespan", "br", "del", "text"].includes(n6.type)))
            a2 += o5 || "";
          else
            switch (n6.type) {
              case "escape":
              case "text":
                a2 += t5.text(n6.text);
                break;
              case "html":
                a2 += t5.html(n6.text);
                break;
              case "link":
                a2 += t5.link(n6.href, n6.title, this.parseInline(n6.tokens, t5));
                break;
              case "image":
                a2 += t5.image(n6.href, n6.title, n6.text);
                break;
              case "strong":
                a2 += t5.strong(this.parseInline(n6.tokens, t5));
                break;
              case "em":
                a2 += t5.em(this.parseInline(n6.tokens, t5));
                break;
              case "codespan":
                a2 += t5.codespan(n6.text);
                break;
              case "br":
                a2 += t5.br();
                break;
              case "del":
                a2 += t5.del(this.parseInline(n6.tokens, t5));
                break;
              default: {
                const e7 = 'Token with "' + n6.type + '" type was not found.';
                if (this.options.silent)
                  return void console.error(e7);
                throw new Error(e7);
              }
            }
        return a2;
      }
    }
    function We(e6, t5, r6) {
      if (null == e6)
        throw new Error("marked(): input parameter is undefined or null");
      if ("string" != typeof e6)
        throw new Error("marked(): input parameter is of type " + Object.prototype.toString.call(e6) + ", string expected");
      if ("function" == typeof t5 && (r6 = t5, t5 = null), _e(t5 = Ce({}, We.defaults, t5 || {})), r6) {
        const n7 = t5.highlight;
        let o5;
        try {
          o5 = qe.lex(e6, t5);
        } catch (e7) {
          return r6(e7);
        }
        const a2 = function(e7) {
          let a3;
          if (!e7)
            try {
              t5.walkTokens && We.walkTokens(o5, t5.walkTokens), a3 = He.parse(o5, t5);
            } catch (t6) {
              e7 = t6;
            }
          return t5.highlight = n7, e7 ? r6(e7) : r6(null, a3);
        };
        if (!n7 || n7.length < 3)
          return a2();
        if (delete t5.highlight, !o5.length)
          return a2();
        let i4 = 0;
        return We.walkTokens(o5, function(e7) {
          "code" === e7.type && (i4++, setTimeout(() => {
            n7(e7.text, e7.lang, function(t6, r7) {
              if (t6)
                return a2(t6);
              null != r7 && r7 !== e7.text && (e7.text = r7, e7.escaped = true), i4--, 0 === i4 && a2();
            });
          }, 0));
        }), void (0 === i4 && a2());
      }
      function n6(e7) {
        if (e7.message += "\nPlease report this to https://github.com/markedjs/marked.", t5.silent)
          return "<p>An error occurred:</p><pre>" + ye(e7.message + "", true) + "</pre>";
        throw e7;
      }
      try {
        const r7 = qe.lex(e6, t5);
        if (t5.walkTokens) {
          if (t5.async)
            return Promise.all(We.walkTokens(r7, t5.walkTokens)).then(() => He.parse(r7, t5)).catch(n6);
          We.walkTokens(r7, t5.walkTokens);
        }
        return He.parse(r7, t5);
      } catch (e7) {
        n6(e7);
      }
    }
    We.options = We.setOptions = function(e6) {
      var t5;
      return Ce(We.defaults, e6), t5 = We.defaults, ce = t5, We;
    }, We.getDefaults = le, We.defaults = ce, We.use = function(...e6) {
      const t5 = We.defaults.extensions || { renderers: {}, childTokens: {} };
      e6.forEach((e7) => {
        const r6 = Ce({}, e7);
        if (r6.async = We.defaults.async || r6.async, e7.extensions && (e7.extensions.forEach((e8) => {
          if (!e8.name)
            throw new Error("extension name required");
          if (e8.renderer) {
            const r7 = t5.renderers[e8.name];
            t5.renderers[e8.name] = r7 ? function(...t6) {
              let n6 = e8.renderer.apply(this, t6);
              return false === n6 && (n6 = r7.apply(this, t6)), n6;
            } : e8.renderer;
          }
          if (e8.tokenizer) {
            if (!e8.level || "block" !== e8.level && "inline" !== e8.level)
              throw new Error("extension level must be 'block' or 'inline'");
            t5[e8.level] ? t5[e8.level].unshift(e8.tokenizer) : t5[e8.level] = [e8.tokenizer], e8.start && ("block" === e8.level ? t5.startBlock ? t5.startBlock.push(e8.start) : t5.startBlock = [e8.start] : "inline" === e8.level && (t5.startInline ? t5.startInline.push(e8.start) : t5.startInline = [e8.start]));
          }
          e8.childTokens && (t5.childTokens[e8.name] = e8.childTokens);
        }), r6.extensions = t5), e7.renderer) {
          const t6 = We.defaults.renderer || new Ue();
          for (const r7 in e7.renderer) {
            const n6 = t6[r7];
            t6[r7] = (...o5) => {
              let a2 = e7.renderer[r7].apply(t6, o5);
              return false === a2 && (a2 = n6.apply(t6, o5)), a2;
            };
          }
          r6.renderer = t6;
        }
        if (e7.tokenizer) {
          const t6 = We.defaults.tokenizer || new Le();
          for (const r7 in e7.tokenizer) {
            const n6 = t6[r7];
            t6[r7] = (...o5) => {
              let a2 = e7.tokenizer[r7].apply(t6, o5);
              return false === a2 && (a2 = n6.apply(t6, o5)), a2;
            };
          }
          r6.tokenizer = t6;
        }
        if (e7.walkTokens) {
          const t6 = We.defaults.walkTokens;
          r6.walkTokens = function(r7) {
            let n6 = [];
            return n6.push(e7.walkTokens.call(this, r7)), t6 && (n6 = n6.concat(t6.call(this, r7))), n6;
          };
        }
        We.setOptions(r6);
      });
    }, We.walkTokens = function(e6, t5) {
      let r6 = [];
      for (const n6 of e6)
        switch (r6 = r6.concat(t5.call(We, n6)), n6.type) {
          case "table":
            for (const e7 of n6.header)
              r6 = r6.concat(We.walkTokens(e7.tokens, t5));
            for (const e7 of n6.rows)
              for (const n7 of e7)
                r6 = r6.concat(We.walkTokens(n7.tokens, t5));
            break;
          case "list":
            r6 = r6.concat(We.walkTokens(n6.items, t5));
            break;
          default:
            We.defaults.extensions && We.defaults.extensions.childTokens && We.defaults.extensions.childTokens[n6.type] ? We.defaults.extensions.childTokens[n6.type].forEach(function(e7) {
              r6 = r6.concat(We.walkTokens(n6[e7], t5));
            }) : n6.tokens && (r6 = r6.concat(We.walkTokens(n6.tokens, t5)));
        }
      return r6;
    }, We.parseInline = function(e6, t5) {
      if (null == e6)
        throw new Error("marked.parseInline(): input parameter is undefined or null");
      if ("string" != typeof e6)
        throw new Error("marked.parseInline(): input parameter is of type " + Object.prototype.toString.call(e6) + ", string expected");
      _e(t5 = Ce({}, We.defaults, t5 || {}));
      try {
        const r6 = qe.lexInline(e6, t5);
        return t5.walkTokens && We.walkTokens(r6, t5.walkTokens), He.parseInline(r6, t5);
      } catch (e7) {
        if (e7.message += "\nPlease report this to https://github.com/markedjs/marked.", t5.silent)
          return "<p>An error occurred:</p><pre>" + ye(e7.message + "", true) + "</pre>";
        throw e7;
      }
    }, We.Parser = He, We.parser = He.parse, We.Renderer = Ue, We.TextRenderer = ze, We.Lexer = qe, We.lexer = qe.lex, We.Tokenizer = Le, We.Slugger = Me, We.parse = We;
    We.options, We.setOptions, We.use, We.walkTokens, We.parseInline, He.parse, qe.lex;
    var Ve = r5(660), Ge = r5.n(Ve);
    r5(251), r5(358), r5(46), r5(503), r5(277), r5(874), r5(366), r5(57), r5(16);
    const Ke = c2`
  .hover-bg:hover{
    background: var(--bg3);
  }
  ::selection {
    background: var(--selection-bg);
    color: var(--selection-fg);
  }
  .regular-font{ 
    font-family:var(--font-regular); 
  }
  .mono-font { 
    font-family:var(--font-mono); 
  }
  .title { 
    font-size: calc(var(--font-size-small) + 18px);
    font-weight: normal 
  }
  .sub-title{ font-size: 20px;}
  .req-res-title {
    font-family: var(--font-regular);
    font-size: calc(var(--font-size-small) + 4px);
    font-weight:bold;
    margin-bottom:8px;
    text-align:left;
  }
  .tiny-title { 
    font-size:calc(var(--font-size-small) + 1px); 
    font-weight:bold; 
  }
  .regular-font-size { font-size: var(--font-size-regular); }
  .small-font-size { font-size: var(--font-size-small); }
  .upper { text-transform: uppercase; }
  .primary-text{ color: var(--primary-color); }
  .bold-text { font-weight:bold; }
  .gray-text { color: var(--light-fg); }
  .red-text {color: var(--red)}
  .blue-text {color: var(--blue)}
  .multiline {
    overflow: scroll;
    max-height: var(--resp-area-height, 400px);
    color: var(--fg3);  
  }
  .method-fg.put { color: var(--orange); }
  .method-fg.post { color: var(--green); }
  .method-fg.get { color: var(--blue); }
  .method-fg.delete { color: var(--red); }
  .method-fg.options, 
  .method-fg.head, 
  .method-fg.patch { 
    color: var(--yellow); 
  }

  h1{ font-family:var(--font-regular); font-size:28px; padding-top: 10px; letter-spacing:normal; font-weight:normal; }
  h2{ font-family:var(--font-regular); font-size:24px; padding-top: 10px; letter-spacing:normal; font-weight:normal; }
  h3{ font-family:var(--font-regular); font-size:18px; padding-top: 10px; letter-spacing:normal; font-weight:normal; }
  h4{ font-family:var(--font-regular); font-size:16px; padding-top: 10px; letter-spacing:normal; font-weight:normal; }
  h5{ font-family:var(--font-regular); font-size:14px; padding-top: 10px; letter-spacing:normal; font-weight:normal; }
  h6{ font-family:var(--font-regular); font-size:14px; padding-top: 10px; letter-spacing:normal; font-weight:normal; }

  h1,h2,h3,h4,h5,h5{
    margin-block-end: 0.2em;
  }
  p { margin-block-start: 0.5em; }
  a { color: var(--blue); cursor:pointer; }
  a.inactive-link { 
    color:var(--fg);
    text-decoration: none;
    cursor:text;
  }
  
  code,
  pre {
    margin: 0px;
    font-family: var(--font-mono);
    font-size: calc(var(--font-size-mono) - 1px);
  }

  .m-markdown,
  .m-markdown-small {
    display:block;
  }

  .m-markdown p,
  .m-markdown span {
    font-size: var(--font-size-regular);
    line-height:calc(var(--font-size-regular) + 8px);
  }
  .m-markdown li {
    font-size: var(--font-size-regular);
    line-height:calc(var(--font-size-regular) + 10px);
  }
  
  .m-markdown-small p,
  .m-markdown-small span,
  .m-markdown-small li {
    font-size: var(--font-size-small);
    line-height: calc(var(--font-size-small) + 6px);
  }
  .m-markdown-small li {
    line-height: calc(var(--font-size-small) + 8px);
  }

  .m-markdown p:not(:first-child) {
    margin-block-start: 24px;
  }

  .m-markdown-small p:not(:first-child) {
    margin-block-start: 12px;
  }
  .m-markdown-small p:first-child {
    margin-block-start: 0;
  }

  .m-markdown p,
  .m-markdown-small p {
    margin-block-end: 0
  }

  .m-markdown code span {
    font-size:var(--font-size-mono);
  }

  .m-markdown-small code,
  .m-markdown code {
    padding: 1px 6px;
    border-radius: 2px;
    color: var(--inline-code-fg);
    background-color: var(--bg3);
    font-size: calc(var(--font-size-mono));
    line-height: 1.2;
  }

  .m-markdown-small code {
    font-size: calc(var(--font-size-mono) - 1px);
  }

  .m-markdown-small pre,
  .m-markdown pre {
    white-space: pre-wrap;
    overflow-x: auto;
    line-height: normal;
    border-radius: 2px;
    border: 1px solid var(--code-border-color);
  }

  .m-markdown pre {
    padding: 12px;
    background-color: var(--code-bg);
    color:var(--code-fg);
  }

  .m-markdown-small pre {
    margin-top: 4px;
    padding: 2px 4px;
    background-color: var(--bg3);
    color: var(--fg2);
  }

  .m-markdown-small pre code,
  .m-markdown pre code {
    border:none;
    padding:0;
  }

  .m-markdown pre code {
    color: var(--code-fg);
    background-color: var(--code-bg);
    background-color: transparent;
  }

  .m-markdown-small pre code {
    color: var(--fg2);
    background-color: var(--bg3);
  }

  .m-markdown ul,
  .m-markdown ol {
    padding-inline-start: 30px;
  }

  .m-markdown-small ul,
  .m-markdown-small ol {
    padding-inline-start: 20px;
  }

  .m-markdown-small a,
  .m-markdown a {
    color:var(--blue);
  }

  .m-markdown-small img,
  .m-markdown img { 
    max-width: 100%; 
  }

  /* Markdown table */

  .m-markdown-small table,
  .m-markdown table {
    border-spacing: 0;
    margin: 10px 0;
    border-collapse: separate;
    border: 1px solid var(--border-color);
    border-radius: var(--border-radius);
    font-size: calc(var(--font-size-small) + 1px);
    line-height: calc(var(--font-size-small) + 4px);
    max-width: 100%;
  }

  .m-markdown-small table {
    font-size: var(--font-size-small);
    line-height: calc(var(--font-size-small) + 2px);
    margin: 8px 0;
  }

  .m-markdown-small td, 
  .m-markdown-small th,
  .m-markdown td, 
  .m-markdown th {
    vertical-align: top;
    border-top: 1px solid var(--border-color);
    line-height: calc(var(--font-size-small) + 4px);
  }

  .m-markdown-small tr:first-child th,
  .m-markdown tr:first-child th {
    border-top: 0 none;
  }

  .m-markdown th, 
  .m-markdown td { 
    padding: 10px 12px; 
  }

  .m-markdown-small th,
  .m-markdown-small td { 
    padding: 8px 8px; 
  }

  .m-markdown th,
  .m-markdown-small th {
    font-weight: 600;
    background-color: var(--bg2);
    vertical-align: middle;
  }

  .m-markdown-small table code {
    font-size: calc(var(--font-size-mono) - 2px);
  }

  .m-markdown table code {
    font-size: calc(var(--font-size-mono) - 1px);
  }

  .m-markdown blockquote,
  .m-markdown-small blockquote {
    margin-inline-start: 0;
    margin-inline-end: 0;
    border-left: 3px solid var(--border-color);
    padding: 6px 0 6px 6px;
  }
  .m-markdown hr{
    border: 1px solid var(--border-color);
  }
`, Je = c2`
/* Button */
.m-btn {
  border-radius: var(--border-radius);
  font-weight: 600;
  display: inline-block;
  padding: 6px 16px;
  font-size: var(--font-size-small);
  outline: 0;
  line-height: 1;
  text-align: center;
  white-space: nowrap;
  border: 2px solid var(--primary-color);
  background-color:transparent;
  transition: background-color 0.2s;
  user-select: none;
  cursor: pointer;
  box-shadow: 0 1px 3px rgba(0,0,0,0.12), 0 1px 2px rgba(0,0,0,0.24);
}
.m-btn.primary {
  background-color: var(--primary-color);
  color: var(--primary-color-invert);
}
.m-btn.thin-border { border-width: 1px; }
.m-btn.large { padding:8px 14px; }
.m-btn.small { padding:5px 12px; }
.m-btn.tiny { padding:5px 6px; }
.m-btn.circle { border-radius: 50%; }
.m-btn:hover { 
  background-color: var(--primary-color);
  color: var(--primary-color-invert);
}
.m-btn.nav { border: 2px solid var(--nav-accent-color); }
.m-btn.nav:hover { 
  background-color: var(--nav-accent-color);
}
.m-btn:disabled{ 
  background-color: var(--bg3);
  color: var(--fg3);
  border-color: var(--fg3);
  cursor: not-allowed;
  opacity: 0.4;
}
.toolbar-btn{
  cursor: pointer;
  padding: 4px;
  margin:0 2px;
  font-size: var(--font-size-small);
  min-width: 50px;
  color: var(--primary-color-invert);
  border-radius: 2px;
  border: none;
  background-color: var(--primary-color);
}

input, textarea, select, button, pre {
  color:var(--fg);
  outline: none;
  background-color: var(--input-bg);
  border: 1px solid var(--border-color);
  border-radius: var(--border-radius);
}
button {
  font-family: var(--font-regular);
}

/* Form Inputs */
pre,
select,
textarea,
input[type="file"],
input[type="text"],
input[type="password"] {
  font-family: var(--font-mono);
  font-weight: 400;
  font-size: var(--font-size-small);
  transition: border .2s;
  padding: 6px 5px;
}

select {
  font-family: var(--font-regular);
  padding: 5px 30px 5px 5px;
  background-image: url("data:image/svg+xml;charset=utf8,%3Csvg%20xmlns%3D%22http%3A%2F%2Fwww.w3.org%2F2000%2Fsvg%22%20width%3D%2212%22%20height%3D%2212%22%3E%3Cpath%20d%3D%22M10.3%203.3L6%207.6%201.7%203.3A1%201%200%2000.3%204.7l5%205a1%201%200%20001.4%200l5-5a1%201%200%2010-1.4-1.4z%22%20fill%3D%22%23777777%22%2F%3E%3C%2Fsvg%3E"); 
  background-position: calc(100% - 5px) center;
  background-repeat: no-repeat;  
  background-size: 10px;
  -webkit-appearance: none;
  -moz-appearance: none;
  appearance: none;
  cursor: pointer;
}

select:hover {
  border-color: var(--primary-color);
}

textarea::placeholder,
input[type="text"]::placeholder,
input[type="password"]::placeholder {
  color: var(--placeholder-color);
  opacity:1;
}


input[type="file"]{
  font-family: var(--font-regular);
  padding:2px;
  cursor:pointer;
  border: 1px solid var(--primary-color);
  min-height: calc(var(--font-size-small) + 18px);
}

input[type="file"]::-webkit-file-upload-button {
  font-family: var(--font-regular);
  font-size: var(--font-size-small);
  outline: none;
  cursor:pointer;
  padding: 3px 8px;
  border: 1px solid var(--primary-color);
  background-color: var(--primary-color);
  color: var(--primary-color-invert);
  border-radius: var(--border-radius);;
  -webkit-appearance: none;
}

pre,
textarea {
  scrollbar-width: thin;
  scrollbar-color: var(--border-color) var(--input-bg);
}

pre::-webkit-scrollbar,
textarea::-webkit-scrollbar {
  width: 8px;
  height: 8px;
}

pre::-webkit-scrollbar-track,
textarea::-webkit-scrollbar-track {
  background:var(--input-bg);
}
 
pre::-webkit-scrollbar-thumb,
textarea::-webkit-scrollbar-thumb {
  border-radius: 2px;
  background-color: var(--border-color);
}

.link {
  font-size:var(--font-size-small);
  text-decoration: underline;
  color:var(--blue);
  font-family:var(--font-mono);
  margin-bottom:2px;
}

/* Toggle Body */
input[type="checkbox"] {
  appearance: none;
  display: inline-block;
  background-color: var(--light-bg);
  border: 1px solid var(--light-bg);
  border-radius: 9px;
  cursor: pointer;
  height: 18px;
  position: relative;
  transition: border .25s .15s, box-shadow .25s .3s, padding .25s;
  min-width: 36px;
  width: 36px;
  vertical-align: top;
}
/* Toggle Thumb */
input[type="checkbox"]:after {
  position: absolute;
  background-color: var(--bg);
  border: 1px solid var(--light-bg);
  border-radius: 8px;
  content: '';
  top: 0px;
  left: 0px;
  right: 16px;
  display: block;
  height: 16px;
  transition: border .25s .15s, left .25s .1s, right .15s .175s;
}

/* Toggle Body - Checked */
input[type="checkbox"]:checked {
  background-color: var(--green);
  border-color: var(--green);
}
/* Toggle Thumb - Checked*/
input[type="checkbox"]:checked:after {
  border: 1px solid var(--green);
  left: 16px;
  right: 1px;
  transition: border .25s, left .15s .25s, right .25s .175s;
}`, Ye = c2`
.row, .col{
  display:flex;
} 
.row {
  align-items:center;
  flex-direction: row;
}
.col {
  align-items:stretch;
  flex-direction: column;
}
`, Ze = c2`
.m-table {
  border-spacing: 0;  
  border-collapse: separate;
  border: 1px solid var(--light-border-color);
  border-radius: var(--border-radius);
  margin: 0;
  max-width: 100%;
  direction: ltr;
}
.m-table tr:first-child td,
.m-table tr:first-child th {
    border-top: 0 none;
}
.m-table td, 
.m-table th {
  font-size: var(--font-size-small);
  line-height: calc(var(--font-size-small) + 4px);
  padding: 4px 5px 4px;
  vertical-align: top;
}

.m-table.padded-12 td, 
.m-table.padded-12 th {
  padding: 12px;
}

.m-table td:not([align]), 
.m-table th:not([align]) {
  text-align: left;
}

.m-table th {
  color: var(--fg2);
  font-size: var(--font-size-small);
  line-height: calc(var(--font-size-small) + 18px);
  font-weight: 600;
  letter-spacing: normal;
  background-color: var(--bg2);
  vertical-align: bottom;
  border-bottom: 1px solid var(--light-border-color);
}

.m-table > tbody > tr > td,
.m-table > tr > td {
  border-top: 1px solid var(--light-border-color);
  text-overflow: ellipsis;
  overflow: hidden;
}
.table-title {
  font-size:var(--font-size-small);
  font-weight:bold;
  vertical-align: middle;
  margin: 12px 0 4px 0;
}
`, Qe = c2`
.only-large-screen { display:none; }
.endpoint-head .path{
  display: flex;
  font-family:var(--font-mono);
  font-size: var(--font-size-small);
  align-items: center;
  overflow-wrap: break-word;
  word-break: break-all;
}

.endpoint-head .descr {
  font-size: var(--font-size-small);
  color:var(--light-fg);
  font-weight:400;
  align-items: center;
  overflow-wrap: break-word;
  word-break: break-all;
  display:none;
}

.m-endpoint.expanded{margin-bottom:16px; }
.m-endpoint > .endpoint-head{
  border-width:1px 1px 1px 5px;
  border-style:solid;
  border-color:transparent;
  border-top-color:var(--light-border-color);
  display:flex;
  padding:6px 16px;
  align-items: center;
  cursor: pointer;
}
.m-endpoint > .endpoint-head.put:hover,
.m-endpoint > .endpoint-head.put.expanded{
  border-color:var(--orange); 
  background-color:var(--light-orange); 
}
.m-endpoint > .endpoint-head.post:hover,
.m-endpoint > .endpoint-head.post.expanded {
  border-color:var(--green); 
  background-color:var(--light-green); 
}
.m-endpoint > .endpoint-head.get:hover,
.m-endpoint > .endpoint-head.get.expanded {
  border-color:var(--blue); 
  background-color:var(--light-blue); 
}
.m-endpoint > .endpoint-head.delete:hover,
.m-endpoint > .endpoint-head.delete.expanded {
  border-color:var(--red); 
  background-color:var(--light-red); 
}

.m-endpoint > .endpoint-head.head:hover,
.m-endpoint > .endpoint-head.head.expanded,
.m-endpoint > .endpoint-head.patch:hover,
.m-endpoint > .endpoint-head.patch.expanded,
.m-endpoint > .endpoint-head.options:hover,
.m-endpoint > .endpoint-head.options.expanded {
  border-color:var(--yellow); 
  background-color:var(--light-yellow); 
}

.m-endpoint > .endpoint-head.deprecated:hover,
.m-endpoint > .endpoint-head.deprecated.expanded {
  border-color:var(--border-color); 
  filter:opacity(0.6);
}

.m-endpoint .endpoint-body {
  flex-wrap:wrap;
  padding:16px 0px 0 0px;
  border-width:0px 1px 1px 5px;
  border-style:solid;
  box-shadow: 0px 4px 3px -3px rgba(0, 0, 0, 0.15);
}
.m-endpoint .endpoint-body.delete{ border-color:var(--red); }
.m-endpoint .endpoint-body.put{ border-color:var(--orange); }
.m-endpoint .endpoint-body.post{border-color:var(--green);}
.m-endpoint .endpoint-body.get{ border-color:var(--blue); }
.m-endpoint .endpoint-body.head,
.m-endpoint .endpoint-body.patch,
.m-endpoint .endpoint-body.options { 
  border-color:var(--yellow); 
}

.m-endpoint .endpoint-body.deprecated{ 
  border-color:var(--border-color);
  filter:opacity(0.6);
}

.endpoint-head .deprecated{
  color: var(--light-fg);
  filter:opacity(0.6);
}

.summary{
  padding:8px 8px;
}
.summary .title{
  font-size:calc(var(--font-size-regular) + 2px);
  margin-bottom: 6px;
  word-break: break-all;
}

.endpoint-head .method{
  padding:2px 5px;
  vertical-align: middle;
  font-size:var(--font-size-small);
  height: calc(var(--font-size-small) + 16px);
  line-height: calc(var(--font-size-small) + 8px);
  width: 60px;
  border-radius: 2px;
  display:inline-block;
  text-align: center;
  font-weight: bold;
  text-transform:uppercase;
  margin-right:5px;
}
.endpoint-head .method.delete{ border: 2px solid var(--red);}
.endpoint-head .method.put{ border: 2px solid var(--orange); }
.endpoint-head .method.post{ border: 2px solid var(--green); }
.endpoint-head .method.get{ border: 2px solid var(--blue); }
.endpoint-head .method.get.deprecated{ border: 2px solid var(--border-color); }
.endpoint-head .method.head,
.endpoint-head .method.patch,
.endpoint-head .method.options { 
  border: 2px solid var(--yellow); 
}

.req-resp-container {
  display: flex;
  margin-top:16px;
  align-items: stretch;
  flex-wrap: wrap;
  flex-direction: column;
  border-top:1px solid var(--light-border-color);
}

.view-mode-request,
api-response.view-mode {
  flex:1; 
  min-height:100px;
  padding:16px 8px;
  overflow:hidden;
}
.view-mode-request {
  border-width:0 0 1px 0;
  border-style:dashed;
}

.head .view-mode-request,
.patch .view-mode-request,
.options .view-mode-request { 
  border-color:var(--yellow); 
}
.put .view-mode-request { 
  border-color:var(--orange); 
}
.post .view-mode-request { 
  border-color:var(--green); 
}
.get .view-mode-request { 
  border-color:var(--blue); 
}
.delete .view-mode-request { 
  border-color:var(--red); 
}

@media only screen and (min-width: 1024px) {
  .only-large-screen { display:block; }
  .endpoint-head .path{
    font-size: var(--font-size-regular);
  }
  .endpoint-head .descr{
    display: flex;
  }
  .endpoint-head .m-markdown-small,
  .descr .m-markdown-small{
    display:block;
  }
  .req-resp-container{
    flex-direction: var(--layout, row);
    flex-wrap: nowrap;
  }
  api-response.view-mode {
    padding:16px;
  }
  .view-mode-request.row-layout {
    border-width:0 1px 0 0;
    padding:16px;
  }
  .summary{
    padding:8px 16px;
  }
}
`, Xe = c2`
code[class*="language-"],
pre[class*="language-"] {
  text-align: left;
  white-space: pre;
  word-spacing: normal;
  word-break: normal;
  word-wrap: normal;
  line-height: 1.5;
  tab-size: 2;

  -webkit-hyphens: none;
  -moz-hyphens: none;
  -ms-hyphens: none;
  hyphens: none;
}

/* Code blocks */
pre[class*="language-"] {
  padding: 1em;
  margin: .5em 0;
  overflow: auto;
}

/* Inline code */
:not(pre) > code[class*="language-"] {
  white-space: normal;
}

.token.comment,
.token.block-comment,
.token.prolog,
.token.doctype,
.token.cdata {
  color: var(--light-fg)
}

.token.punctuation {
  color: var(--fg);
}

.token.tag,
.token.attr-name,
.token.namespace,
.token.deleted {
  color:var(--pink);
}

.token.function-name {
  color: var(--blue);
}

.token.boolean,
.token.number,
.token.function {
  color: var(--red);
}

.token.property,
.token.class-name,
.token.constant,
.token.symbol {
  color: var(--code-property-color);
}

.token.selector,
.token.important,
.token.atrule,
.token.keyword,
.token.builtin {
  color: var(--code-keyword-color);
}

.token.string,
.token.char,
.token.attr-value,
.token.regex,
.token.variable { 
  color: var(--green);
}

.token.operator,
.token.entity,
.token.url {
  color: var(--code-operator-color);
}

.token.important,
.token.bold {
  font-weight: bold;
}
.token.italic {
  font-style: italic;
}

.token.entity {
  cursor: help;
}

.token.inserted {
  color: green;
}
`, et = c2`
.tab-panel {
  border: none;
}
.tab-buttons {
  height:30px;
  padding: 4px 4px 0 4px;
  border-bottom: 1px solid var(--light-border-color) ;
  align-items: stretch;
  overflow-y: hidden;
  overflow-x: auto;
  scrollbar-width: thin;
}
.tab-buttons::-webkit-scrollbar {
  height: 1px;
  background-color: var(--border-color);
}
.tab-btn {
  border: none;
  border-bottom: 3px solid transparent; 
  color: var(--light-fg);
  background-color: transparent;
  white-space: nowrap;
  cursor:pointer;
  outline:none;
  font-family:var(--font-regular); 
  font-size:var(--font-size-small);
  margin-right:16px;
  padding:1px;
}
.tab-btn.active {
  border-bottom: 3px solid var(--primary-color); 
  font-weight:bold;
  color:var(--primary-color);
}

.tab-btn:hover {
  color:var(--primary-color);
}
.tab-content {
  margin:-1px 0 0 0;
  position:relative;
  min-height: 50px;
}
`, tt = c2`
.nav-bar-info:focus-visible,
.nav-bar-tag:focus-visible,
.nav-bar-path:focus-visible {
  outline: 1px solid;
  box-shadow: none;
  outline-offset: -4px;
}
.nav-bar-expand-all:focus-visible,
.nav-bar-collapse-all:focus-visible,
.nav-bar-tag-icon:focus-visible {
  outline: 1px solid;
  box-shadow: none;
  outline-offset: 2px;
}
.nav-bar {
  width:0;
  height:100%;
  overflow: hidden;
  color:var(--nav-text-color);
  background-color: var(--nav-bg-color);
  background-blend-mode: multiply;
  line-height: calc(var(--font-size-small) + 4px);
  display:none;
  position:relative;
  flex-direction:column;
  flex-wrap:nowrap;
  word-break:break-word;
}
::slotted([slot=nav-logo]){
  padding:16px 16px 0 16px;
}
.nav-scroll {
  overflow-x: hidden;
  overflow-y: auto;
  overflow-y: overlay;
  scrollbar-width: thin;
  scrollbar-color: var(--nav-hover-bg-color) transparent;
}

.nav-bar-tag {
  display: flex;
  align-items: center;
  justify-content: space-between;
  flex-direction: row;
}
.nav-bar.read .nav-bar-tag-icon {
  display:none;
}
.nav-bar-paths-under-tag {
  overflow:hidden;
  transition: max-height .2s ease-out, visibility .3s;
}
.collapsed .nav-bar-paths-under-tag {
  visibility: hidden;
}

.nav-bar-expand-all {
  transform: rotate(90deg); 
  cursor:pointer; 
  margin-right:10px;
}
.nav-bar-collapse-all {
  transform: rotate(270deg); 
  cursor:pointer;
}
.nav-bar-expand-all:hover, .nav-bar-collapse-all:hover {
  color: var(--primary-color);
}

.nav-bar-tag-icon {
  color: var(--nav-text-color);
  font-size: 20px; 
}
.nav-bar-tag-icon:hover {
  color:var(--nav-hover-text-color);
}
.nav-bar.focused .nav-bar-tag-and-paths.collapsed .nav-bar-tag-icon::after {
  content: '⌵';
  width:16px;
  height:16px;
  text-align: center;
  display: inline-block;
  transform: rotate(-90deg);
  transition: transform 0.2s ease-out 0s;
}
.nav-bar.focused .nav-bar-tag-and-paths.expanded .nav-bar-tag-icon::after {
  content: '⌵';
  width:16px;
  height:16px;
  text-align: center;
  display: inline-block;
  transition: transform 0.2s ease-out 0s;
}
.nav-scroll::-webkit-scrollbar {
  width: var(--scroll-bar-width, 8px);
}
.nav-scroll::-webkit-scrollbar-track {
  background:transparent;
}
.nav-scroll::-webkit-scrollbar-thumb {
  background-color: var(--nav-hover-bg-color);
}

.nav-bar-tag {
  font-size: var(--font-size-regular);
  color: var(--nav-accent-color);
  border-left:4px solid transparent;
  font-weight:bold;
  padding: 15px 15px 15px 10px;
  text-transform: capitalize;
}

.nav-bar-components,
.nav-bar-h1,
.nav-bar-h2,
.nav-bar-info,
.nav-bar-tag,
.nav-bar-path {
  display:flex;
  cursor: pointer;
  width: 100%;
  border: none;
  border-radius:4px; 
  color: var(--nav-text-color);
  background: transparent;
  border-left:4px solid transparent;
}

.nav-bar-h1,
.nav-bar-h2,
.nav-bar-path {
  font-size: calc(var(--font-size-small) + 1px);
  padding: var(--nav-item-padding);
}
.nav-bar-path.small-font {
  font-size: var(--font-size-small);
}

.nav-bar-info {
  font-size: var(--font-size-regular);
  padding: 16px 10px;
  font-weight:bold;
}
.nav-bar-section {
  display: flex;
  flex-direction: row;
  justify-content: space-between;
  font-size: var(--font-size-small);
  color: var(--nav-text-color);
  padding: var(--nav-item-padding);
  font-weight:bold;
}
.nav-bar-section.operations {
  cursor:pointer;
}
.nav-bar-section.operations:hover {
  color:var(--nav-hover-text-color);
  background-color:var(--nav-hover-bg-color);
}

.nav-bar-section:first-child {
  display: none;
}
.nav-bar-h2 {margin-left:12px;}

.nav-bar-h1.left-bar.active,
.nav-bar-h2.left-bar.active,
.nav-bar-info.left-bar.active,
.nav-bar-tag.left-bar.active,
.nav-bar-path.left-bar.active,
.nav-bar-section.left-bar.operations.active {
  border-left:4px solid var(--nav-accent-color);
  color:var(--nav-hover-text-color);
}

.nav-bar-h1.colored-block.active,
.nav-bar-h2.colored-block.active,
.nav-bar-info.colored-block.active,
.nav-bar-tag.colored-block.active,
.nav-bar-path.colored-block.active,
.nav-bar-section.colored-block.operations.active {
  background-color: var(--nav-accent-color);
  color: var(--nav-accent-text-color);
  border-radius: 0;
}

.nav-bar-h1:hover,
.nav-bar-h2:hover,
.nav-bar-info:hover,
.nav-bar-tag:hover,
.nav-bar-path:hover {
  color:var(--nav-hover-text-color);
  background-color:var(--nav-hover-bg-color);
}
`, rt = c2`
#api-info {
  font-size: calc(var(--font-size-regular) - 1px);
  margin-top: 8px;
  margin-left: -15px;
}

#api-info span:before {
  content: "|";
  display: inline-block;
  opacity: 0.5;
  width: 15px;
  text-align: center;
}
#api-info span:first-child:before {
  content: "";
  width: 0px;
}
`, nt = c2`

`;
    const ot = /[\s#:?&={}]/g, at = "_rapidoc_api_key";
    function it(e6) {
      return new Promise((t5) => setTimeout(t5, e6));
    }
    function st(e6, t5) {
      const r6 = t5.target, n6 = document.createElement("textarea");
      n6.value = e6, n6.style.position = "fixed", document.body.appendChild(n6), n6.focus(), n6.select();
      try {
        document.execCommand("copy"), r6.innerText = "Copied", setTimeout(() => {
          r6.innerText = "Copy";
        }, 5e3);
      } catch (e7) {
        console.error("Unable to copy", e7);
      }
      document.body.removeChild(n6);
    }
    function lt(e6, t5, r6 = "includes") {
      if ("includes" === r6) {
        return `${t5.method} ${t5.path} ${t5.summary || t5.description || ""} ${t5.operationId || ""}`.toLowerCase().includes(e6.toLowerCase());
      }
      return new RegExp(e6, "i").test(`${t5.method} ${t5.path}`);
    }
    function ct(e6, t5 = /* @__PURE__ */ new Set()) {
      return e6 ? (Object.keys(e6).forEach((r6) => {
        var n6;
        if (t5.add(r6), e6[r6].properties)
          ct(e6[r6].properties, t5);
        else if (null !== (n6 = e6[r6].items) && void 0 !== n6 && n6.properties) {
          var o5;
          ct(null === (o5 = e6[r6].items) || void 0 === o5 ? void 0 : o5.properties, t5);
        }
      }), t5) : t5;
    }
    function pt(e6, t5) {
      if (e6) {
        const r6 = document.createElement("a");
        document.body.appendChild(r6), r6.style = "display: none", r6.href = e6, r6.download = t5, r6.click(), r6.remove();
      }
    }
    function dt(e6) {
      if (e6) {
        const t5 = document.createElement("a");
        document.body.appendChild(t5), t5.style = "display: none", t5.href = e6, t5.target = "_blank", t5.click(), t5.remove();
      }
    }
    function ut(e6) {
      return e6 && e6.t && Object.prototype.hasOwnProperty.call(e6, "default") ? e6.default : e6;
    }
    var ht = function(e6) {
      return e6 && e6.Math == Math && e6;
    }, ft = ht("object" == typeof globalThis && globalThis) || ht("object" == typeof window && window) || ht("object" == typeof self && self) || ht("object" == typeof ft && ft) || /* @__PURE__ */ function() {
      return this;
    }() || Function("return this")(), mt = function(e6) {
      try {
        return !!e6();
      } catch (e7) {
        return true;
      }
    }, yt = !mt(function() {
      var e6 = function() {
      }.bind();
      return "function" != typeof e6 || e6.hasOwnProperty("prototype");
    }), gt = yt, vt = Function.prototype, bt = vt.apply, xt = vt.call, wt = "object" == typeof Reflect && Reflect.apply || (gt ? xt.bind(bt) : function() {
      return xt.apply(bt, arguments);
    }), $t = yt, kt = Function.prototype, St = kt.bind, At = kt.call, Et = $t && St.bind(At, At), Ot = $t ? function(e6) {
      return e6 && Et(e6);
    } : function(e6) {
      return e6 && function() {
        return At.apply(e6, arguments);
      };
    }, Tt = function(e6) {
      return "function" == typeof e6;
    }, Ct = {}, jt = !mt(function() {
      return 7 != Object.defineProperty({}, 1, { get: function() {
        return 7;
      } })[1];
    }), It = yt, _t = Function.prototype.call, Pt = It ? _t.bind(_t) : function() {
      return _t.apply(_t, arguments);
    }, Rt = {}, Lt = {}.propertyIsEnumerable, Ft = Object.getOwnPropertyDescriptor, Dt = Ft && !Lt.call({ 1: 2 }, 1);
    Rt.f = Dt ? function(e6) {
      var t5 = Ft(this, e6);
      return !!t5 && t5.enumerable;
    } : Lt;
    var Bt, Nt, qt = function(e6, t5) {
      return { enumerable: !(1 & e6), configurable: !(2 & e6), writable: !(4 & e6), value: t5 };
    }, Ut = Ot, zt = Ut({}.toString), Mt = Ut("".slice), Ht = function(e6) {
      return Mt(zt(e6), 8, -1);
    }, Wt = Ot, Vt = mt, Gt = Ht, Kt = ft.Object, Jt = Wt("".split), Yt = Vt(function() {
      return !Kt("z").propertyIsEnumerable(0);
    }) ? function(e6) {
      return "String" == Gt(e6) ? Jt(e6, "") : Kt(e6);
    } : Kt, Zt = ft.TypeError, Qt = function(e6) {
      if (null == e6)
        throw Zt("Can't call method on " + e6);
      return e6;
    }, Xt = Yt, er = Qt, tr = function(e6) {
      return Xt(er(e6));
    }, rr = Tt, nr = function(e6) {
      return "object" == typeof e6 ? null !== e6 : rr(e6);
    }, or = {}, ar = or, ir = ft, sr = Tt, lr = function(e6) {
      return sr(e6) ? e6 : void 0;
    }, cr = function(e6, t5) {
      return arguments.length < 2 ? lr(ar[e6]) || lr(ir[e6]) : ar[e6] && ar[e6][t5] || ir[e6] && ir[e6][t5];
    }, pr = Ot({}.isPrototypeOf), dr = cr("navigator", "userAgent") || "", ur = ft, hr = dr, fr = ur.process, mr = ur.Deno, yr = fr && fr.versions || mr && mr.version, gr = yr && yr.v8;
    gr && (Nt = (Bt = gr.split("."))[0] > 0 && Bt[0] < 4 ? 1 : +(Bt[0] + Bt[1])), !Nt && hr && (!(Bt = hr.match(/Edge\/(\d+)/)) || Bt[1] >= 74) && (Bt = hr.match(/Chrome\/(\d+)/)) && (Nt = +Bt[1]);
    var vr = Nt, br = vr, xr = mt, wr = !!Object.getOwnPropertySymbols && !xr(function() {
      var e6 = Symbol();
      return !String(e6) || !(Object(e6) instanceof Symbol) || !Symbol.sham && br && br < 41;
    }), $r = wr && !Symbol.sham && "symbol" == typeof Symbol.iterator, kr = cr, Sr = Tt, Ar = pr, Er = $r, Or = ft.Object, Tr = Er ? function(e6) {
      return "symbol" == typeof e6;
    } : function(e6) {
      var t5 = kr("Symbol");
      return Sr(t5) && Ar(t5.prototype, Or(e6));
    }, Cr = ft.String, jr = function(e6) {
      try {
        return Cr(e6);
      } catch (e7) {
        return "Object";
      }
    }, Ir = Tt, _r = jr, Pr = ft.TypeError, Rr = function(e6) {
      if (Ir(e6))
        return e6;
      throw Pr(_r(e6) + " is not a function");
    }, Lr = Rr, Fr = function(e6, t5) {
      var r6 = e6[t5];
      return null == r6 ? void 0 : Lr(r6);
    }, Dr = Pt, Br = Tt, Nr = nr, qr = ft.TypeError, Ur = { exports: {} }, zr = ft, Mr = Object.defineProperty, Hr = ft.i || function(e6, t5) {
      try {
        Mr(zr, e6, { value: t5, configurable: true, writable: true });
      } catch (r6) {
        zr[e6] = t5;
      }
      return t5;
    }("__core-js_shared__", {}), Wr = Hr;
    (Ur.exports = function(e6, t5) {
      return Wr[e6] || (Wr[e6] = void 0 !== t5 ? t5 : {});
    })("versions", []).push({ version: "3.21.1", mode: "pure", copyright: "\xA9 2014-2022 Denis Pushkarev (zloirock.ru)", license: "https://github.com/zloirock/core-js/blob/v3.21.1/LICENSE", source: "https://github.com/zloirock/core-js" });
    var Vr = Qt, Gr = ft.Object, Kr = function(e6) {
      return Gr(Vr(e6));
    }, Jr = Kr, Yr = Ot({}.hasOwnProperty), Zr = Object.hasOwn || function(e6, t5) {
      return Yr(Jr(e6), t5);
    }, Qr = Ot, Xr = 0, en = Math.random(), tn = Qr(1 .toString), rn = function(e6) {
      return "Symbol(" + (void 0 === e6 ? "" : e6) + ")_" + tn(++Xr + en, 36);
    }, nn = ft, on = Ur.exports, an = Zr, sn = rn, ln = wr, cn = $r, pn = on("wks"), dn = nn.Symbol, un = dn && dn.for, hn = cn ? dn : dn && dn.withoutSetter || sn, fn = function(e6) {
      if (!an(pn, e6) || !ln && "string" != typeof pn[e6]) {
        var t5 = "Symbol." + e6;
        ln && an(dn, e6) ? pn[e6] = dn[e6] : pn[e6] = cn && un ? un(t5) : hn(t5);
      }
      return pn[e6];
    }, mn = Pt, yn = nr, gn = Tr, vn = Fr, bn = fn, xn = ft.TypeError, wn = bn("toPrimitive"), $n = function(e6, t5) {
      if (!yn(e6) || gn(e6))
        return e6;
      var r6, n6 = vn(e6, wn);
      if (n6) {
        if (void 0 === t5 && (t5 = "default"), r6 = mn(n6, e6, t5), !yn(r6) || gn(r6))
          return r6;
        throw xn("Can't convert object to primitive value");
      }
      return void 0 === t5 && (t5 = "number"), function(e7, t6) {
        var r7, n7;
        if ("string" === t6 && Br(r7 = e7.toString) && !Nr(n7 = Dr(r7, e7)))
          return n7;
        if (Br(r7 = e7.valueOf) && !Nr(n7 = Dr(r7, e7)))
          return n7;
        if ("string" !== t6 && Br(r7 = e7.toString) && !Nr(n7 = Dr(r7, e7)))
          return n7;
        throw qr("Can't convert object to primitive value");
      }(e6, t5);
    }, kn = Tr, Sn = function(e6) {
      var t5 = $n(e6, "string");
      return kn(t5) ? t5 : t5 + "";
    }, An = nr, En = ft.document, On = An(En) && An(En.createElement), Tn = function(e6) {
      return On ? En.createElement(e6) : {};
    }, Cn = Tn, jn = !jt && !mt(function() {
      return 7 != Object.defineProperty(Cn("div"), "a", { get: function() {
        return 7;
      } }).a;
    }), In = jt, _n = Pt, Pn = Rt, Rn = qt, Ln = tr, Fn = Sn, Dn = Zr, Bn = jn, Nn = Object.getOwnPropertyDescriptor;
    Ct.f = In ? Nn : function(e6, t5) {
      if (e6 = Ln(e6), t5 = Fn(t5), Bn)
        try {
          return Nn(e6, t5);
        } catch (e7) {
        }
      if (Dn(e6, t5))
        return Rn(!_n(Pn.f, e6, t5), e6[t5]);
    };
    var qn = mt, Un = Tt, zn = /#|\.prototype\./, Mn = function(e6, t5) {
      var r6 = Wn[Hn(e6)];
      return r6 == Gn || r6 != Vn && (Un(t5) ? qn(t5) : !!t5);
    }, Hn = Mn.normalize = function(e6) {
      return String(e6).replace(zn, ".").toLowerCase();
    }, Wn = Mn.data = {}, Vn = Mn.NATIVE = "N", Gn = Mn.POLYFILL = "P", Kn = Mn, Jn = Rr, Yn = yt, Zn = Ot(Ot.bind), Qn = function(e6, t5) {
      return Jn(e6), void 0 === t5 ? e6 : Yn ? Zn(e6, t5) : function() {
        return e6.apply(t5, arguments);
      };
    }, Xn = {}, eo = jt && mt(function() {
      return 42 != Object.defineProperty(function() {
      }, "prototype", { value: 42, writable: false }).prototype;
    }), to = ft, ro = nr, no = to.String, oo = to.TypeError, ao = function(e6) {
      if (ro(e6))
        return e6;
      throw oo(no(e6) + " is not an object");
    }, io = jt, so = jn, lo = eo, co = ao, po = Sn, uo = ft.TypeError, ho = Object.defineProperty, fo = Object.getOwnPropertyDescriptor;
    Xn.f = io ? lo ? function(e6, t5, r6) {
      if (co(e6), t5 = po(t5), co(r6), "function" == typeof e6 && "prototype" === t5 && "value" in r6 && "writable" in r6 && !r6.writable) {
        var n6 = fo(e6, t5);
        n6 && n6.writable && (e6[t5] = r6.value, r6 = { configurable: "configurable" in r6 ? r6.configurable : n6.configurable, enumerable: "enumerable" in r6 ? r6.enumerable : n6.enumerable, writable: false });
      }
      return ho(e6, t5, r6);
    } : ho : function(e6, t5, r6) {
      if (co(e6), t5 = po(t5), co(r6), so)
        try {
          return ho(e6, t5, r6);
        } catch (e7) {
        }
      if ("get" in r6 || "set" in r6)
        throw uo("Accessors not supported");
      return "value" in r6 && (e6[t5] = r6.value), e6;
    };
    var mo = Xn, yo = qt, go = jt ? function(e6, t5, r6) {
      return mo.f(e6, t5, yo(1, r6));
    } : function(e6, t5, r6) {
      return e6[t5] = r6, e6;
    }, vo = ft, bo = wt, xo = Ot, wo = Tt, $o = Ct.f, ko = Kn, So = or, Ao = Qn, Eo = go, Oo = Zr, To = function(e6) {
      var t5 = function(r6, n6, o5) {
        if (this instanceof t5) {
          switch (arguments.length) {
            case 0:
              return new e6();
            case 1:
              return new e6(r6);
            case 2:
              return new e6(r6, n6);
          }
          return new e6(r6, n6, o5);
        }
        return bo(e6, this, arguments);
      };
      return t5.prototype = e6.prototype, t5;
    }, Co = function(e6, t5) {
      var r6, n6, o5, a2, i4, s6, l2, c3, p2 = e6.target, d2 = e6.global, u3 = e6.stat, h2 = e6.proto, f3 = d2 ? vo : u3 ? vo[p2] : (vo[p2] || {}).prototype, m2 = d2 ? So : So[p2] || Eo(So, p2, {})[p2], y2 = m2.prototype;
      for (o5 in t5)
        r6 = !ko(d2 ? o5 : p2 + (u3 ? "." : "#") + o5, e6.forced) && f3 && Oo(f3, o5), i4 = m2[o5], r6 && (s6 = e6.noTargetGet ? (c3 = $o(f3, o5)) && c3.value : f3[o5]), a2 = r6 && s6 ? s6 : t5[o5], r6 && typeof i4 == typeof a2 || (l2 = e6.bind && r6 ? Ao(a2, vo) : e6.wrap && r6 ? To(a2) : h2 && wo(a2) ? xo(a2) : a2, (e6.sham || a2 && a2.sham || i4 && i4.sham) && Eo(l2, "sham", true), Eo(m2, o5, l2), h2 && (Oo(So, n6 = p2 + "Prototype") || Eo(So, n6, {}), Eo(So[n6], o5, a2), e6.real && y2 && !y2[o5] && Eo(y2, o5, a2)));
    }, jo = Math.ceil, Io = Math.floor, _o = function(e6) {
      var t5 = +e6;
      return t5 != t5 || 0 === t5 ? 0 : (t5 > 0 ? Io : jo)(t5);
    }, Po = _o, Ro = Math.max, Lo = Math.min, Fo = function(e6, t5) {
      var r6 = Po(e6);
      return r6 < 0 ? Ro(r6 + t5, 0) : Lo(r6, t5);
    }, Do = _o, Bo = Math.min, No = function(e6) {
      return e6 > 0 ? Bo(Do(e6), 9007199254740991) : 0;
    }, qo = No, Uo = function(e6) {
      return qo(e6.length);
    }, zo = tr, Mo = Fo, Ho = Uo, Wo = function(e6) {
      return function(t5, r6, n6) {
        var o5, a2 = zo(t5), i4 = Ho(a2), s6 = Mo(n6, i4);
        if (e6 && r6 != r6) {
          for (; i4 > s6; )
            if ((o5 = a2[s6++]) != o5)
              return true;
        } else
          for (; i4 > s6; s6++)
            if ((e6 || s6 in a2) && a2[s6] === r6)
              return e6 || s6 || 0;
        return !e6 && -1;
      };
    }, Vo = { includes: Wo(true), indexOf: Wo(false) }, Go = {}, Ko = Zr, Jo = tr, Yo = Vo.indexOf, Zo = Go, Qo = Ot([].push), Xo = function(e6, t5) {
      var r6, n6 = Jo(e6), o5 = 0, a2 = [];
      for (r6 in n6)
        !Ko(Zo, r6) && Ko(n6, r6) && Qo(a2, r6);
      for (; t5.length > o5; )
        Ko(n6, r6 = t5[o5++]) && (~Yo(a2, r6) || Qo(a2, r6));
      return a2;
    }, ea = ["constructor", "hasOwnProperty", "isPrototypeOf", "propertyIsEnumerable", "toLocaleString", "toString", "valueOf"], ta = Xo, ra = ea, na = Object.keys || function(e6) {
      return ta(e6, ra);
    }, oa = Kr, aa = na;
    Co({ target: "Object", stat: true, forced: mt(function() {
      aa(1);
    }) }, { keys: function(e6) {
      return aa(oa(e6));
    } });
    var ia = or.Object.keys;
    const sa = ut({ exports: {} }.exports = ia);
    var la = Ht, ca = Array.isArray || function(e6) {
      return "Array" == la(e6);
    }, pa = {};
    pa[fn("toStringTag")] = "z";
    var da = "[object z]" === String(pa), ua = ft, ha = da, fa = Tt, ma = Ht, ya = fn("toStringTag"), ga = ua.Object, va = "Arguments" == ma(/* @__PURE__ */ function() {
      return arguments;
    }()), ba = ha ? ma : function(e6) {
      var t5, r6, n6;
      return void 0 === e6 ? "Undefined" : null === e6 ? "Null" : "string" == typeof (r6 = function(e7, t6) {
        try {
          return e7[t6];
        } catch (e8) {
        }
      }(t5 = ga(e6), ya)) ? r6 : va ? ma(t5) : "Object" == (n6 = ma(t5)) && fa(t5.callee) ? "Arguments" : n6;
    }, xa = ba, wa = ft.String, $a = function(e6) {
      if ("Symbol" === xa(e6))
        throw TypeError("Cannot convert a Symbol value to a string");
      return wa(e6);
    }, ka = {}, Sa = jt, Aa = eo, Ea = Xn, Oa = ao, Ta = tr, Ca = na;
    ka.f = Sa && !Aa ? Object.defineProperties : function(e6, t5) {
      Oa(e6);
      for (var r6, n6 = Ta(t5), o5 = Ca(t5), a2 = o5.length, i4 = 0; a2 > i4; )
        Ea.f(e6, r6 = o5[i4++], n6[r6]);
      return e6;
    };
    var ja, Ia = cr("document", "documentElement"), _a = Ur.exports, Pa = rn, Ra = _a("keys"), La = function(e6) {
      return Ra[e6] || (Ra[e6] = Pa(e6));
    }, Fa = ao, Da = ka, Ba = ea, Na = Go, qa = Ia, Ua = Tn, za = La("IE_PROTO"), Ma = function() {
    }, Ha = function(e6) {
      return "<script>" + e6 + "<\/script>";
    }, Wa = function(e6) {
      e6.write(Ha("")), e6.close();
      var t5 = e6.parentWindow.Object;
      return e6 = null, t5;
    }, Va = function() {
      try {
        ja = new ActiveXObject("htmlfile");
      } catch (e7) {
      }
      var e6, t5;
      Va = "undefined" != typeof document ? document.domain && ja ? Wa(ja) : ((t5 = Ua("iframe")).style.display = "none", qa.appendChild(t5), t5.src = String("javascript:"), (e6 = t5.contentWindow.document).open(), e6.write(Ha("document.F=Object")), e6.close(), e6.F) : Wa(ja);
      for (var r6 = Ba.length; r6--; )
        delete Va.prototype[Ba[r6]];
      return Va();
    };
    Na[za] = true;
    var Ga = Object.create || function(e6, t5) {
      var r6;
      return null !== e6 ? (Ma.prototype = Fa(e6), r6 = new Ma(), Ma.prototype = null, r6[za] = e6) : r6 = Va(), void 0 === t5 ? r6 : Da.f(r6, t5);
    }, Ka = {}, Ja = Xo, Ya = ea.concat("length", "prototype");
    Ka.f = Object.getOwnPropertyNames || function(e6) {
      return Ja(e6, Ya);
    };
    var Za = {}, Qa = Sn, Xa = Xn, ei = qt, ti = function(e6, t5, r6) {
      var n6 = Qa(t5);
      n6 in e6 ? Xa.f(e6, n6, ei(0, r6)) : e6[n6] = r6;
    }, ri = Fo, ni = Uo, oi = ti, ai = ft.Array, ii = Math.max, si = function(e6, t5, r6) {
      for (var n6 = ni(e6), o5 = ri(t5, n6), a2 = ri(void 0 === r6 ? n6 : r6, n6), i4 = ai(ii(a2 - o5, 0)), s6 = 0; o5 < a2; o5++, s6++)
        oi(i4, s6, e6[o5]);
      return i4.length = s6, i4;
    }, li = Ht, ci = tr, pi = Ka.f, di = si, ui = "object" == typeof window && window && Object.getOwnPropertyNames ? Object.getOwnPropertyNames(window) : [];
    Za.f = function(e6) {
      return ui && "Window" == li(e6) ? function(e7) {
        try {
          return pi(e7);
        } catch (e8) {
          return di(ui);
        }
      }(e6) : pi(ci(e6));
    };
    var hi = {};
    hi.f = Object.getOwnPropertySymbols;
    var fi = Ot([].slice), mi = go, yi = function(e6, t5, r6, n6) {
      n6 && n6.enumerable ? e6[t5] = r6 : mi(e6, t5, r6);
    }, gi = {}, vi = fn;
    gi.f = vi;
    var bi = or, xi = Zr, wi = gi, $i = Xn.f, ki = function(e6) {
      var t5 = bi.Symbol || (bi.Symbol = {});
      xi(t5, e6) || $i(t5, e6, { value: wi.f(e6) });
    }, Si = ba, Ai = da ? {}.toString : function() {
      return "[object " + Si(this) + "]";
    }, Ei = da, Oi = Xn.f, Ti = go, Ci = Zr, ji = Ai, Ii = fn("toStringTag"), _i = function(e6, t5, r6, n6) {
      if (e6) {
        var o5 = r6 ? e6 : e6.prototype;
        Ci(o5, Ii) || Oi(o5, Ii, { configurable: true, value: t5 }), n6 && !Ei && Ti(o5, "toString", ji);
      }
    }, Pi = Tt, Ri = Hr, Li = Ot(Function.toString);
    Pi(Ri.inspectSource) || (Ri.inspectSource = function(e6) {
      return Li(e6);
    });
    var Fi, Di, Bi, Ni = Ri.inspectSource, qi = Tt, Ui = Ni, zi = ft.WeakMap, Mi = qi(zi) && /native code/.test(Ui(zi)), Hi = Mi, Wi = ft, Vi = Ot, Gi = nr, Ki = go, Ji = Zr, Yi = Hr, Zi = La, Qi = Go, Xi = Wi.TypeError, es = Wi.WeakMap;
    if (Hi || Yi.state) {
      var ts = Yi.state || (Yi.state = new es()), rs = Vi(ts.get), ns = Vi(ts.has), os = Vi(ts.set);
      Fi = function(e6, t5) {
        if (ns(ts, e6))
          throw new Xi("Object already initialized");
        return t5.facade = e6, os(ts, e6, t5), t5;
      }, Di = function(e6) {
        return rs(ts, e6) || {};
      }, Bi = function(e6) {
        return ns(ts, e6);
      };
    } else {
      var as = Zi("state");
      Qi[as] = true, Fi = function(e6, t5) {
        if (Ji(e6, as))
          throw new Xi("Object already initialized");
        return t5.facade = e6, Ki(e6, as, t5), t5;
      }, Di = function(e6) {
        return Ji(e6, as) ? e6[as] : {};
      }, Bi = function(e6) {
        return Ji(e6, as);
      };
    }
    var is = { set: Fi, get: Di, has: Bi, enforce: function(e6) {
      return Bi(e6) ? Di(e6) : Fi(e6, {});
    }, getterFor: function(e6) {
      return function(t5) {
        var r6;
        if (!Gi(t5) || (r6 = Di(t5)).type !== e6)
          throw Xi("Incompatible receiver, " + e6 + " required");
        return r6;
      };
    } }, ss = Ot, ls = mt, cs = Tt, ps = ba, ds = Ni, us = function() {
    }, hs = [], fs = cr("Reflect", "construct"), ms = /^\s*(?:class|function)\b/, ys = ss(ms.exec), gs = !ms.exec(us), vs = function(e6) {
      if (!cs(e6))
        return false;
      try {
        return fs(us, hs, e6), true;
      } catch (e7) {
        return false;
      }
    }, bs = function(e6) {
      if (!cs(e6))
        return false;
      switch (ps(e6)) {
        case "AsyncFunction":
        case "GeneratorFunction":
        case "AsyncGeneratorFunction":
          return false;
      }
      try {
        return gs || !!ys(ms, ds(e6));
      } catch (e7) {
        return true;
      }
    };
    bs.sham = true;
    var xs = !fs || ls(function() {
      var e6;
      return vs(vs.call) || !vs(Object) || !vs(function() {
        e6 = true;
      }) || e6;
    }) ? bs : vs, ws = ft, $s = ca, ks = xs, Ss = nr, As = fn("species"), Es = ws.Array, Os = function(e6, t5) {
      return new (function(e7) {
        var t6;
        return $s(e7) && (t6 = e7.constructor, (ks(t6) && (t6 === Es || $s(t6.prototype)) || Ss(t6) && null === (t6 = t6[As])) && (t6 = void 0)), void 0 === t6 ? Es : t6;
      }(e6))(0 === t5 ? 0 : t5);
    }, Ts = Qn, Cs = Yt, js = Kr, Is = Uo, _s = Os, Ps = Ot([].push), Rs = function(e6) {
      var t5 = 1 == e6, r6 = 2 == e6, n6 = 3 == e6, o5 = 4 == e6, a2 = 6 == e6, i4 = 7 == e6, s6 = 5 == e6 || a2;
      return function(l2, c3, p2, d2) {
        for (var u3, h2, f3 = js(l2), m2 = Cs(f3), y2 = Ts(c3, p2), g2 = Is(m2), v2 = 0, b2 = d2 || _s, x3 = t5 ? b2(l2, g2) : r6 || i4 ? b2(l2, 0) : void 0; g2 > v2; v2++)
          if ((s6 || v2 in m2) && (h2 = y2(u3 = m2[v2], v2, f3), e6))
            if (t5)
              x3[v2] = h2;
            else if (h2)
              switch (e6) {
                case 3:
                  return true;
                case 5:
                  return u3;
                case 6:
                  return v2;
                case 2:
                  Ps(x3, u3);
              }
            else
              switch (e6) {
                case 4:
                  return false;
                case 7:
                  Ps(x3, u3);
              }
        return a2 ? -1 : n6 || o5 ? o5 : x3;
      };
    }, Ls = { forEach: Rs(0), map: Rs(1), filter: Rs(2), some: Rs(3), every: Rs(4), find: Rs(5), findIndex: Rs(6), filterReject: Rs(7) }, Fs = Co, Ds = ft, Bs = cr, Ns = wt, qs = Pt, Us = Ot, zs = jt, Ms = wr, Hs = mt, Ws = Zr, Vs = ca, Gs = Tt, Ks = nr, Js = pr, Ys = Tr, Zs = ao, Qs = Kr, Xs = tr, el = Sn, tl = $a, rl = qt, nl = Ga, ol = na, al = Ka, il = Za, sl = hi, ll = Ct, cl = Xn, pl = ka, dl = Rt, ul = fi, hl = yi, fl = Ur.exports, ml = Go, yl = rn, gl = fn, vl = gi, bl = ki, xl = _i, wl = is, $l = Ls.forEach, kl = La("hidden"), Sl = gl("toPrimitive"), Al = wl.set, El = wl.getterFor("Symbol"), Ol = Object.prototype, Tl = Ds.Symbol, Cl = Tl && Tl.prototype, jl = Ds.TypeError, Il = Ds.QObject, _l = Bs("JSON", "stringify"), Pl = ll.f, Rl = cl.f, Ll = il.f, Fl = dl.f, Dl = Us([].push), Bl = fl("symbols"), Nl = fl("op-symbols"), ql = fl("string-to-symbol-registry"), Ul = fl("symbol-to-string-registry"), zl = fl("wks"), Ml = !Il || !Il.prototype || !Il.prototype.findChild, Hl = zs && Hs(function() {
      return 7 != nl(Rl({}, "a", { get: function() {
        return Rl(this, "a", { value: 7 }).a;
      } })).a;
    }) ? function(e6, t5, r6) {
      var n6 = Pl(Ol, t5);
      n6 && delete Ol[t5], Rl(e6, t5, r6), n6 && e6 !== Ol && Rl(Ol, t5, n6);
    } : Rl, Wl = function(e6, t5) {
      var r6 = Bl[e6] = nl(Cl);
      return Al(r6, { type: "Symbol", tag: e6, description: t5 }), zs || (r6.description = t5), r6;
    }, Vl = function(e6, t5, r6) {
      e6 === Ol && Vl(Nl, t5, r6), Zs(e6);
      var n6 = el(t5);
      return Zs(r6), Ws(Bl, n6) ? (r6.enumerable ? (Ws(e6, kl) && e6[kl][n6] && (e6[kl][n6] = false), r6 = nl(r6, { enumerable: rl(0, false) })) : (Ws(e6, kl) || Rl(e6, kl, rl(1, {})), e6[kl][n6] = true), Hl(e6, n6, r6)) : Rl(e6, n6, r6);
    }, Gl = function(e6, t5) {
      Zs(e6);
      var r6 = Xs(t5), n6 = ol(r6).concat(Zl(r6));
      return $l(n6, function(t6) {
        zs && !qs(Kl, r6, t6) || Vl(e6, t6, r6[t6]);
      }), e6;
    }, Kl = function(e6) {
      var t5 = el(e6), r6 = qs(Fl, this, t5);
      return !(this === Ol && Ws(Bl, t5) && !Ws(Nl, t5)) && (!(r6 || !Ws(this, t5) || !Ws(Bl, t5) || Ws(this, kl) && this[kl][t5]) || r6);
    }, Jl = function(e6, t5) {
      var r6 = Xs(e6), n6 = el(t5);
      if (r6 !== Ol || !Ws(Bl, n6) || Ws(Nl, n6)) {
        var o5 = Pl(r6, n6);
        return !o5 || !Ws(Bl, n6) || Ws(r6, kl) && r6[kl][n6] || (o5.enumerable = true), o5;
      }
    }, Yl = function(e6) {
      var t5 = Ll(Xs(e6)), r6 = [];
      return $l(t5, function(e7) {
        Ws(Bl, e7) || Ws(ml, e7) || Dl(r6, e7);
      }), r6;
    }, Zl = function(e6) {
      var t5 = e6 === Ol, r6 = Ll(t5 ? Nl : Xs(e6)), n6 = [];
      return $l(r6, function(e7) {
        !Ws(Bl, e7) || t5 && !Ws(Ol, e7) || Dl(n6, Bl[e7]);
      }), n6;
    };
    (Ms || (hl(Cl = (Tl = function() {
      if (Js(Cl, this))
        throw jl("Symbol is not a constructor");
      var e6 = arguments.length && void 0 !== arguments[0] ? tl(arguments[0]) : void 0, t5 = yl(e6), r6 = function(e7) {
        this === Ol && qs(r6, Nl, e7), Ws(this, kl) && Ws(this[kl], t5) && (this[kl][t5] = false), Hl(this, t5, rl(1, e7));
      };
      return zs && Ml && Hl(Ol, t5, { configurable: true, set: r6 }), Wl(t5, e6);
    }).prototype, "toString", function() {
      return El(this).tag;
    }), hl(Tl, "withoutSetter", function(e6) {
      return Wl(yl(e6), e6);
    }), dl.f = Kl, cl.f = Vl, pl.f = Gl, ll.f = Jl, al.f = il.f = Yl, sl.f = Zl, vl.f = function(e6) {
      return Wl(gl(e6), e6);
    }, zs && Rl(Cl, "description", { configurable: true, get: function() {
      return El(this).description;
    } })), Fs({ global: true, wrap: true, forced: !Ms, sham: !Ms }, { Symbol: Tl }), $l(ol(zl), function(e6) {
      bl(e6);
    }), Fs({ target: "Symbol", stat: true, forced: !Ms }, { for: function(e6) {
      var t5 = tl(e6);
      if (Ws(ql, t5))
        return ql[t5];
      var r6 = Tl(t5);
      return ql[t5] = r6, Ul[r6] = t5, r6;
    }, keyFor: function(e6) {
      if (!Ys(e6))
        throw jl(e6 + " is not a symbol");
      if (Ws(Ul, e6))
        return Ul[e6];
    }, useSetter: function() {
      Ml = true;
    }, useSimple: function() {
      Ml = false;
    } }), Fs({ target: "Object", stat: true, forced: !Ms, sham: !zs }, { create: function(e6, t5) {
      return void 0 === t5 ? nl(e6) : Gl(nl(e6), t5);
    }, defineProperty: Vl, defineProperties: Gl, getOwnPropertyDescriptor: Jl }), Fs({ target: "Object", stat: true, forced: !Ms }, { getOwnPropertyNames: Yl, getOwnPropertySymbols: Zl }), Fs({ target: "Object", stat: true, forced: Hs(function() {
      sl.f(1);
    }) }, { getOwnPropertySymbols: function(e6) {
      return sl.f(Qs(e6));
    } }), _l) && Fs({ target: "JSON", stat: true, forced: !Ms || Hs(function() {
      var e6 = Tl();
      return "[null]" != _l([e6]) || "{}" != _l({ a: e6 }) || "{}" != _l(Object(e6));
    }) }, { stringify: function(e6, t5, r6) {
      var n6 = ul(arguments), o5 = t5;
      if ((Ks(t5) || void 0 !== e6) && !Ys(e6))
        return Vs(t5) || (t5 = function(e7, t6) {
          if (Gs(o5) && (t6 = qs(o5, this, e7, t6)), !Ys(t6))
            return t6;
        }), n6[1] = t5, Ns(_l, null, n6);
    } });
    if (!Cl[Sl]) {
      var Ql = Cl.valueOf;
      hl(Cl, Sl, function(e6) {
        return qs(Ql, this);
      });
    }
    xl(Tl, "Symbol"), ml[kl] = true;
    var Xl = or.Object.getOwnPropertySymbols;
    const ec = ut({ exports: {} }.exports = Xl);
    var tc = mt, rc = vr, nc = fn("species"), oc = function(e6) {
      return rc >= 51 || !tc(function() {
        var t5 = [];
        return (t5.constructor = {})[nc] = function() {
          return { foo: 1 };
        }, 1 !== t5[e6](Boolean).foo;
      });
    }, ac = Ls.filter;
    Co({ target: "Array", proto: true, forced: !oc("filter") }, { filter: function(e6) {
      return ac(this, e6, arguments.length > 1 ? arguments[1] : void 0);
    } });
    var ic = or, sc = function(e6) {
      return ic[e6 + "Prototype"];
    }, lc = sc("Array").filter, cc = pr, pc = lc, dc = Array.prototype, uc = function(e6) {
      var t5 = e6.filter;
      return e6 === dc || cc(dc, e6) && t5 === dc.filter ? pc : t5;
    };
    const hc = ut({ exports: {} }.exports = uc);
    var fc = { exports: {} }, mc = Co, yc = mt, gc = tr, vc = Ct.f, bc = jt, xc = yc(function() {
      vc(1);
    });
    mc({ target: "Object", stat: true, forced: !bc || xc, sham: !bc }, { getOwnPropertyDescriptor: function(e6, t5) {
      return vc(gc(e6), t5);
    } });
    var wc = or.Object, $c = fc.exports = function(e6, t5) {
      return wc.getOwnPropertyDescriptor(e6, t5);
    };
    wc.getOwnPropertyDescriptor.sham && ($c.sham = true);
    var kc = fc.exports;
    const Sc = ut({ exports: {} }.exports = kc);
    var Ac, Ec, Oc, Tc = {}, Cc = jt, jc = Zr, Ic = Function.prototype, _c = Cc && Object.getOwnPropertyDescriptor, Pc = jc(Ic, "name"), Rc = { EXISTS: Pc, PROPER: Pc && "something" === function() {
    }.name, CONFIGURABLE: Pc && (!Cc || Cc && _c(Ic, "name").configurable) }, Lc = !mt(function() {
      function e6() {
      }
      return e6.prototype.constructor = null, Object.getPrototypeOf(new e6()) !== e6.prototype;
    }), Fc = ft, Dc = Zr, Bc = Tt, Nc = Kr, qc = Lc, Uc = La("IE_PROTO"), zc = Fc.Object, Mc = zc.prototype, Hc = qc ? zc.getPrototypeOf : function(e6) {
      var t5 = Nc(e6);
      if (Dc(t5, Uc))
        return t5[Uc];
      var r6 = t5.constructor;
      return Bc(r6) && t5 instanceof r6 ? r6.prototype : t5 instanceof zc ? Mc : null;
    }, Wc = mt, Vc = Tt, Gc = Ga, Kc = Hc, Jc = yi, Yc = fn("iterator"), Zc = false;
    [].keys && ("next" in (Oc = [].keys()) ? (Ec = Kc(Kc(Oc))) !== Object.prototype && (Ac = Ec) : Zc = true);
    var Qc = null == Ac || Wc(function() {
      var e6 = {};
      return Ac[Yc].call(e6) !== e6;
    });
    Vc((Ac = Qc ? {} : Gc(Ac))[Yc]) || Jc(Ac, Yc, function() {
      return this;
    });
    var Xc = { IteratorPrototype: Ac, BUGGY_SAFARI_ITERATORS: Zc }, ep = Xc.IteratorPrototype, tp = Ga, rp = qt, np = _i, op = Tc, ap = function() {
      return this;
    }, ip = function(e6, t5, r6, n6) {
      var o5 = t5 + " Iterator";
      return e6.prototype = tp(ep, { next: rp(+!n6, r6) }), np(e6, o5, false, true), op[o5] = ap, e6;
    }, sp = ft, lp = Tt, cp = sp.String, pp = sp.TypeError, dp = Ot, up = ao, hp = Object.setPrototypeOf || ("__proto__" in {} ? function() {
      var e6, t5 = false, r6 = {};
      try {
        (e6 = dp(Object.getOwnPropertyDescriptor(Object.prototype, "__proto__").set))(r6, []), t5 = r6 instanceof Array;
      } catch (e7) {
      }
      return function(r7, n6) {
        return up(r7), function(e7) {
          if ("object" == typeof e7 || lp(e7))
            return e7;
          throw pp("Can't set " + cp(e7) + " as a prototype");
        }(n6), t5 ? e6(r7, n6) : r7.__proto__ = n6, r7;
      };
    }() : void 0), fp = Co, mp = Pt, yp = ip, gp = Hc, vp = _i, bp = yi, xp = Tc, wp = Rc.PROPER, $p = Xc.BUGGY_SAFARI_ITERATORS, kp = fn("iterator"), Sp = function() {
      return this;
    }, Ap = function(e6, t5, r6, n6, o5, a2, i4) {
      yp(r6, t5, n6);
      var s6, l2, c3, p2 = function(e7) {
        if (e7 === o5 && m2)
          return m2;
        if (!$p && e7 in h2)
          return h2[e7];
        switch (e7) {
          case "keys":
          case "values":
          case "entries":
            return function() {
              return new r6(this, e7);
            };
        }
        return function() {
          return new r6(this);
        };
      }, d2 = t5 + " Iterator", u3 = false, h2 = e6.prototype, f3 = h2[kp] || h2["@@iterator"] || o5 && h2[o5], m2 = !$p && f3 || p2(o5), y2 = "Array" == t5 && h2.entries || f3;
      if (y2 && (s6 = gp(y2.call(new e6()))) !== Object.prototype && s6.next && (vp(s6, d2, true, true), xp[d2] = Sp), wp && "values" == o5 && f3 && "values" !== f3.name && (u3 = true, m2 = function() {
        return mp(f3, this);
      }), o5)
        if (l2 = { values: p2("values"), keys: a2 ? m2 : p2("keys"), entries: p2("entries") }, i4)
          for (c3 in l2)
            ($p || u3 || !(c3 in h2)) && bp(h2, c3, l2[c3]);
        else
          fp({ target: t5, proto: true, forced: $p || u3 }, l2);
      return i4 && h2[kp] !== m2 && bp(h2, kp, m2, { name: o5 }), xp[t5] = m2, l2;
    }, Ep = tr, Op = Tc, Tp = is;
    Xn.f;
    var Cp = Ap, jp = Tp.set, Ip = Tp.getterFor("Array Iterator");
    Cp(Array, "Array", function(e6, t5) {
      jp(this, { type: "Array Iterator", target: Ep(e6), index: 0, kind: t5 });
    }, function() {
      var e6 = Ip(this), t5 = e6.target, r6 = e6.kind, n6 = e6.index++;
      return !t5 || n6 >= t5.length ? (e6.target = void 0, { value: void 0, done: true }) : "keys" == r6 ? { value: n6, done: false } : "values" == r6 ? { value: t5[n6], done: false } : { value: [n6, t5[n6]], done: false };
    }, "values"), Op.Arguments = Op.Array;
    var _p = ft, Pp = ba, Rp = go, Lp = Tc, Fp = fn("toStringTag");
    for (var Dp in { CSSRuleList: 0, CSSStyleDeclaration: 0, CSSValueList: 0, ClientRectList: 0, DOMRectList: 0, DOMStringList: 0, DOMTokenList: 1, DataTransferItemList: 0, FileList: 0, HTMLAllCollection: 0, HTMLCollection: 0, HTMLFormElement: 0, HTMLSelectElement: 0, MediaList: 0, MimeTypeArray: 0, NamedNodeMap: 0, NodeList: 1, PaintRequestList: 0, Plugin: 0, PluginArray: 0, SVGLengthList: 0, SVGNumberList: 0, SVGPathSegList: 0, SVGPointList: 0, SVGStringList: 0, SVGTransformList: 0, SourceBufferList: 0, StyleSheetList: 0, TextTrackCueList: 0, TextTrackList: 0, TouchList: 0 }) {
      var Bp = _p[Dp], Np = Bp && Bp.prototype;
      Np && Pp(Np) !== Fp && Rp(Np, Fp, Dp), Lp[Dp] = Lp.Array;
    }
    var qp = mt, Up = function(e6, t5) {
      var r6 = [][e6];
      return !!r6 && qp(function() {
        r6.call(null, t5 || function() {
          return 1;
        }, 1);
      });
    }, zp = Ls.forEach, Mp = Up("forEach") ? [].forEach : function(e6) {
      return zp(this, e6, arguments.length > 1 ? arguments[1] : void 0);
    };
    Co({ target: "Array", proto: true, forced: [].forEach != Mp }, { forEach: Mp });
    var Hp = sc("Array").forEach, Wp = ba, Vp = Zr, Gp = pr, Kp = Hp, Jp = Array.prototype, Yp = { DOMTokenList: true, NodeList: true };
    const Zp = ut({ exports: {} }.exports = function(e6) {
      var t5 = e6.forEach;
      return e6 === Jp || Gp(Jp, e6) && t5 === Jp.forEach || Vp(Yp, Wp(e6)) ? Kp : t5;
    });
    var Qp = cr, Xp = Ka, ed = hi, td = ao, rd = Ot([].concat), nd = Qp("Reflect", "ownKeys") || function(e6) {
      var t5 = Xp.f(td(e6)), r6 = ed.f;
      return r6 ? rd(t5, r6(e6)) : t5;
    }, od = nd, ad = tr, id = Ct, sd = ti;
    Co({ target: "Object", stat: true, sham: !jt }, { getOwnPropertyDescriptors: function(e6) {
      for (var t5, r6, n6 = ad(e6), o5 = id.f, a2 = od(n6), i4 = {}, s6 = 0; a2.length > s6; )
        void 0 !== (r6 = o5(n6, t5 = a2[s6++])) && sd(i4, t5, r6);
      return i4;
    } });
    var ld = or.Object.getOwnPropertyDescriptors;
    const cd = ut({ exports: {} }.exports = ld);
    var pd = { exports: {} }, dd = Co, ud = jt, hd = ka.f;
    dd({ target: "Object", stat: true, forced: Object.defineProperties !== hd, sham: !ud }, { defineProperties: hd });
    var fd = or.Object, md = pd.exports = function(e6, t5) {
      return fd.defineProperties(e6, t5);
    };
    fd.defineProperties.sham && (md.sham = true);
    var yd = pd.exports;
    const gd = ut({ exports: {} }.exports = yd);
    var vd = { exports: {} }, bd = Co, xd = jt, wd = Xn.f;
    bd({ target: "Object", stat: true, forced: Object.defineProperty !== wd, sham: !xd }, { defineProperty: wd });
    var $d = or.Object, kd = vd.exports = function(e6, t5, r6) {
      return $d.defineProperty(e6, t5, r6);
    };
    $d.defineProperty.sham && (kd.sham = true);
    var Sd = vd.exports;
    const Ad = ut({ exports: {} }.exports = Sd);
    function Ed(e6, t5, r6) {
      return t5 in e6 ? Ad(e6, t5, { value: r6, enumerable: true, configurable: true, writable: true }) : e6[t5] = r6, e6;
    }
    function Od(e6, t5) {
      var r6 = sa(e6);
      if (ec) {
        var n6 = ec(e6);
        t5 && (n6 = hc(n6).call(n6, function(t6) {
          return Sc(e6, t6).enumerable;
        })), r6.push.apply(r6, n6);
      }
      return r6;
    }
    function Td(e6) {
      for (var t5 = 1; t5 < arguments.length; t5++) {
        var r6, n6, o5 = null != arguments[t5] ? arguments[t5] : {};
        t5 % 2 ? Zp(r6 = Od(Object(o5), true)).call(r6, function(t6) {
          Ed(e6, t6, o5[t6]);
        }) : cd ? gd(e6, cd(o5)) : Zp(n6 = Od(Object(o5))).call(n6, function(t6) {
          Ad(e6, t6, Sc(o5, t6));
        });
      }
      return e6;
    }
    var Cd = jt, jd = Ot, Id = Pt, _d = mt, Pd = na, Rd = hi, Ld = Rt, Fd = Kr, Dd = Yt, Bd = Object.assign, Nd = Object.defineProperty, qd = jd([].concat), Ud = !Bd || _d(function() {
      if (Cd && 1 !== Bd({ b: 1 }, Bd(Nd({}, "a", { enumerable: true, get: function() {
        Nd(this, "b", { value: 3, enumerable: false });
      } }), { b: 2 })).b)
        return true;
      var e6 = {}, t5 = {}, r6 = Symbol(), n6 = "abcdefghijklmnopqrst";
      return e6[r6] = 7, n6.split("").forEach(function(e7) {
        t5[e7] = e7;
      }), 7 != Bd({}, e6)[r6] || Pd(Bd({}, t5)).join("") != n6;
    }) ? function(e6, t5) {
      for (var r6 = Fd(e6), n6 = arguments.length, o5 = 1, a2 = Rd.f, i4 = Ld.f; n6 > o5; )
        for (var s6, l2 = Dd(arguments[o5++]), c3 = a2 ? qd(Pd(l2), a2(l2)) : Pd(l2), p2 = c3.length, d2 = 0; p2 > d2; )
          s6 = c3[d2++], Cd && !Id(i4, l2, s6) || (r6[s6] = l2[s6]);
      return r6;
    } : Bd, zd = Ud;
    Co({ target: "Object", stat: true, forced: Object.assign !== zd }, { assign: zd });
    var Md = or.Object.assign;
    const Hd = ut({ exports: {} }.exports = Md);
    var Wd = nr, Vd = Ht, Gd = fn("match"), Kd = ft.TypeError, Jd = function(e6) {
      if (function(e7) {
        var t5;
        return Wd(e7) && (void 0 !== (t5 = e7[Gd]) ? !!t5 : "RegExp" == Vd(e7));
      }(e6))
        throw Kd("The method doesn't accept regular expressions");
      return e6;
    }, Yd = fn("match"), Zd = function(e6) {
      var t5 = /./;
      try {
        "/./"[e6](t5);
      } catch (r6) {
        try {
          return t5[Yd] = false, "/./"[e6](t5);
        } catch (e7) {
        }
      }
      return false;
    }, Qd = Co, Xd = Ot, eu = No, tu = $a, ru = Jd, nu = Qt, ou = Zd, au = Xd("".startsWith), iu = Xd("".slice), su = Math.min;
    Qd({ target: "String", proto: true, forced: !ou("startsWith") }, { startsWith: function(e6) {
      var t5 = tu(nu(this));
      ru(e6);
      var r6 = eu(su(arguments.length > 1 ? arguments[1] : void 0, t5.length)), n6 = tu(e6);
      return au ? au(t5, n6, r6) : iu(t5, r6, r6 + n6.length) === n6;
    } });
    var lu = sc("String").startsWith, cu = pr, pu = lu, du = String.prototype;
    const uu = ut({ exports: {} }.exports = function(e6) {
      var t5 = e6.startsWith;
      return "string" == typeof e6 || e6 === du || cu(du, e6) && t5 === du.startsWith ? pu : t5;
    });
    var hu = {}, fu = { exports: {} };
    !function(e6, t5) {
      !function(r6) {
        var n6 = t5 && !t5.nodeType && t5, o5 = e6 && !e6.nodeType && e6, a2 = "object" == typeof global && global;
        a2.global !== a2 && a2.window !== a2 && a2.self !== a2 || (r6 = a2);
        var i4, s6, l2 = 2147483647, c3 = 36, p2 = /^xn--/, d2 = /[^\x20-\x7E]/, u3 = /[\x2E\u3002\uFF0E\uFF61]/g, h2 = { overflow: "Overflow: input needs wider integers to process", "not-basic": "Illegal input >= 0x80 (not a basic code point)", "invalid-input": "Invalid input" }, f3 = Math.floor, m2 = String.fromCharCode;
        function y2(e7) {
          throw RangeError(h2[e7]);
        }
        function g2(e7, t6) {
          for (var r7 = e7.length, n7 = []; r7--; )
            n7[r7] = t6(e7[r7]);
          return n7;
        }
        function v2(e7, t6) {
          var r7 = e7.split("@"), n7 = "";
          return r7.length > 1 && (n7 = r7[0] + "@", e7 = r7[1]), n7 + g2((e7 = e7.replace(u3, ".")).split("."), t6).join(".");
        }
        function b2(e7) {
          for (var t6, r7, n7 = [], o6 = 0, a3 = e7.length; o6 < a3; )
            (t6 = e7.charCodeAt(o6++)) >= 55296 && t6 <= 56319 && o6 < a3 ? 56320 == (64512 & (r7 = e7.charCodeAt(o6++))) ? n7.push(((1023 & t6) << 10) + (1023 & r7) + 65536) : (n7.push(t6), o6--) : n7.push(t6);
          return n7;
        }
        function x3(e7) {
          return g2(e7, function(e8) {
            var t6 = "";
            return e8 > 65535 && (t6 += m2((e8 -= 65536) >>> 10 & 1023 | 55296), e8 = 56320 | 1023 & e8), t6 + m2(e8);
          }).join("");
        }
        function w2(e7, t6) {
          return e7 + 22 + 75 * (e7 < 26) - ((0 != t6) << 5);
        }
        function $2(e7, t6, r7) {
          var n7 = 0;
          for (e7 = r7 ? f3(e7 / 700) : e7 >> 1, e7 += f3(e7 / t6); e7 > 455; n7 += c3)
            e7 = f3(e7 / 35);
          return f3(n7 + 36 * e7 / (e7 + 38));
        }
        function k2(e7) {
          var t6, r7, n7, o6, a3, i5, s7, p3, d3, u4, h3, m3 = [], g3 = e7.length, v3 = 0, b3 = 128, w3 = 72;
          for ((r7 = e7.lastIndexOf("-")) < 0 && (r7 = 0), n7 = 0; n7 < r7; ++n7)
            e7.charCodeAt(n7) >= 128 && y2("not-basic"), m3.push(e7.charCodeAt(n7));
          for (o6 = r7 > 0 ? r7 + 1 : 0; o6 < g3; ) {
            for (a3 = v3, i5 = 1, s7 = c3; o6 >= g3 && y2("invalid-input"), ((p3 = (h3 = e7.charCodeAt(o6++)) - 48 < 10 ? h3 - 22 : h3 - 65 < 26 ? h3 - 65 : h3 - 97 < 26 ? h3 - 97 : c3) >= c3 || p3 > f3((l2 - v3) / i5)) && y2("overflow"), v3 += p3 * i5, !(p3 < (d3 = s7 <= w3 ? 1 : s7 >= w3 + 26 ? 26 : s7 - w3)); s7 += c3)
              i5 > f3(l2 / (u4 = c3 - d3)) && y2("overflow"), i5 *= u4;
            w3 = $2(v3 - a3, t6 = m3.length + 1, 0 == a3), f3(v3 / t6) > l2 - b3 && y2("overflow"), b3 += f3(v3 / t6), v3 %= t6, m3.splice(v3++, 0, b3);
          }
          return x3(m3);
        }
        function S2(e7) {
          var t6, r7, n7, o6, a3, i5, s7, p3, d3, u4, h3, g3, v3, x4, k3, S3 = [];
          for (g3 = (e7 = b2(e7)).length, t6 = 128, r7 = 0, a3 = 72, i5 = 0; i5 < g3; ++i5)
            (h3 = e7[i5]) < 128 && S3.push(m2(h3));
          for (n7 = o6 = S3.length, o6 && S3.push("-"); n7 < g3; ) {
            for (s7 = l2, i5 = 0; i5 < g3; ++i5)
              (h3 = e7[i5]) >= t6 && h3 < s7 && (s7 = h3);
            for (s7 - t6 > f3((l2 - r7) / (v3 = n7 + 1)) && y2("overflow"), r7 += (s7 - t6) * v3, t6 = s7, i5 = 0; i5 < g3; ++i5)
              if ((h3 = e7[i5]) < t6 && ++r7 > l2 && y2("overflow"), h3 == t6) {
                for (p3 = r7, d3 = c3; !(p3 < (u4 = d3 <= a3 ? 1 : d3 >= a3 + 26 ? 26 : d3 - a3)); d3 += c3)
                  k3 = p3 - u4, x4 = c3 - u4, S3.push(m2(w2(u4 + k3 % x4, 0))), p3 = f3(k3 / x4);
                S3.push(m2(w2(p3, 0))), a3 = $2(r7, v3, n7 == o6), r7 = 0, ++n7;
              }
            ++r7, ++t6;
          }
          return S3.join("");
        }
        if (i4 = { version: "1.3.2", ucs2: { decode: b2, encode: x3 }, decode: k2, encode: S2, toASCII: function(e7) {
          return v2(e7, function(e8) {
            return d2.test(e8) ? "xn--" + S2(e8) : e8;
          });
        }, toUnicode: function(e7) {
          return v2(e7, function(e8) {
            return p2.test(e8) ? k2(e8.slice(4).toLowerCase()) : e8;
          });
        } }, n6 && o5)
          if (e6.exports == n6)
            o5.exports = i4;
          else
            for (s6 in i4)
              i4.hasOwnProperty(s6) && (n6[s6] = i4[s6]);
        else
          r6.punycode = i4;
      }(this);
    }(fu, fu.exports);
    var mu = {};
    function yu(e6, t5) {
      return Object.prototype.hasOwnProperty.call(e6, t5);
    }
    var gu = function(e6) {
      switch (typeof e6) {
        case "string":
          return e6;
        case "boolean":
          return e6 ? "true" : "false";
        case "number":
          return isFinite(e6) ? e6 : "";
        default:
          return "";
      }
    };
    mu.decode = mu.parse = function(e6, t5, r6, n6) {
      t5 = t5 || "&", r6 = r6 || "=";
      var o5 = {};
      if ("string" != typeof e6 || 0 === e6.length)
        return o5;
      var a2 = /\+/g;
      e6 = e6.split(t5);
      var i4 = 1e3;
      n6 && "number" == typeof n6.maxKeys && (i4 = n6.maxKeys);
      var s6 = e6.length;
      i4 > 0 && s6 > i4 && (s6 = i4);
      for (var l2 = 0; l2 < s6; ++l2) {
        var c3, p2, d2, u3, h2 = e6[l2].replace(a2, "%20"), f3 = h2.indexOf(r6);
        f3 >= 0 ? (c3 = h2.substr(0, f3), p2 = h2.substr(f3 + 1)) : (c3 = h2, p2 = ""), d2 = decodeURIComponent(c3), u3 = decodeURIComponent(p2), yu(o5, d2) ? Array.isArray(o5[d2]) ? o5[d2].push(u3) : o5[d2] = [o5[d2], u3] : o5[d2] = u3;
      }
      return o5;
    }, mu.encode = mu.stringify = function(e6, t5, r6, n6) {
      return t5 = t5 || "&", r6 = r6 || "=", null === e6 && (e6 = void 0), "object" == typeof e6 ? Object.keys(e6).map(function(n7) {
        var o5 = encodeURIComponent(gu(n7)) + r6;
        return Array.isArray(e6[n7]) ? e6[n7].map(function(e7) {
          return o5 + encodeURIComponent(gu(e7));
        }).join(t5) : o5 + encodeURIComponent(gu(e6[n7]));
      }).join(t5) : n6 ? encodeURIComponent(gu(n6)) + r6 + encodeURIComponent(gu(e6)) : "";
    };
    var vu = fu.exports, bu = function(e6) {
      return "string" == typeof e6;
    }, xu = function(e6) {
      return "object" == typeof e6 && null !== e6;
    }, wu = function(e6) {
      return null === e6;
    }, $u = function(e6) {
      return null == e6;
    };
    function ku() {
      this.protocol = null, this.slashes = null, this.auth = null, this.host = null, this.port = null, this.hostname = null, this.hash = null, this.search = null, this.query = null, this.pathname = null, this.path = null, this.href = null;
    }
    hu.parse = Du, hu.resolve = function(e6, t5) {
      return Du(e6, false, true).resolve(t5);
    }, hu.resolveObject = function(e6, t5) {
      return e6 ? Du(e6, false, true).resolveObject(t5) : t5;
    }, hu.format = function(e6) {
      return bu(e6) && (e6 = Du(e6)), e6 instanceof ku ? e6.format() : ku.prototype.format.call(e6);
    }, hu.Url = ku;
    var Su = /^([a-z0-9.+-]+:)/i, Au = /:[0-9]*$/, Eu = /^(\/\/?(?!\/)[^\?\s]*)(\?[^\s]*)?$/, Ou = ["{", "}", "|", "\\", "^", "`"].concat(["<", ">", '"', "`", " ", "\r", "\n", "	"]), Tu = ["'"].concat(Ou), Cu = ["%", "/", "?", ";", "#"].concat(Tu), ju = ["/", "?", "#"], Iu = /^[+a-z0-9A-Z_-]{0,63}$/, _u = /^([+a-z0-9A-Z_-]{0,63})(.*)$/, Pu = { javascript: true, "javascript:": true }, Ru = { javascript: true, "javascript:": true }, Lu = { http: true, https: true, ftp: true, gopher: true, file: true, "http:": true, "https:": true, "ftp:": true, "gopher:": true, "file:": true }, Fu = mu;
    function Du(e6, t5, r6) {
      if (e6 && xu(e6) && e6 instanceof ku)
        return e6;
      var n6 = new ku();
      return n6.parse(e6, t5, r6), n6;
    }
    ku.prototype.parse = function(e6, t5, r6) {
      if (!bu(e6))
        throw new TypeError("Parameter 'url' must be a string, not " + typeof e6);
      var n6 = e6.indexOf("?"), o5 = -1 !== n6 && n6 < e6.indexOf("#") ? "?" : "#", a2 = e6.split(o5);
      a2[0] = a2[0].replace(/\\/g, "/");
      var i4 = e6 = a2.join(o5);
      if (i4 = i4.trim(), !r6 && 1 === e6.split("#").length) {
        var s6 = Eu.exec(i4);
        if (s6)
          return this.path = i4, this.href = i4, this.pathname = s6[1], s6[2] ? (this.search = s6[2], this.query = t5 ? Fu.parse(this.search.substr(1)) : this.search.substr(1)) : t5 && (this.search = "", this.query = {}), this;
      }
      var l2 = Su.exec(i4);
      if (l2) {
        var c3 = (l2 = l2[0]).toLowerCase();
        this.protocol = c3, i4 = i4.substr(l2.length);
      }
      if (r6 || l2 || i4.match(/^\/\/[^@\/]+@[^@\/]+/)) {
        var p2 = "//" === i4.substr(0, 2);
        !p2 || l2 && Ru[l2] || (i4 = i4.substr(2), this.slashes = true);
      }
      if (!Ru[l2] && (p2 || l2 && !Lu[l2])) {
        for (var d2, u3, h2 = -1, f3 = 0; f3 < ju.length; f3++)
          -1 !== (m2 = i4.indexOf(ju[f3])) && (-1 === h2 || m2 < h2) && (h2 = m2);
        for (-1 !== (u3 = -1 === h2 ? i4.lastIndexOf("@") : i4.lastIndexOf("@", h2)) && (d2 = i4.slice(0, u3), i4 = i4.slice(u3 + 1), this.auth = decodeURIComponent(d2)), h2 = -1, f3 = 0; f3 < Cu.length; f3++) {
          var m2;
          -1 !== (m2 = i4.indexOf(Cu[f3])) && (-1 === h2 || m2 < h2) && (h2 = m2);
        }
        -1 === h2 && (h2 = i4.length), this.host = i4.slice(0, h2), i4 = i4.slice(h2), this.parseHost(), this.hostname = this.hostname || "";
        var y2 = "[" === this.hostname[0] && "]" === this.hostname[this.hostname.length - 1];
        if (!y2)
          for (var g2 = this.hostname.split(/\./), v2 = (f3 = 0, g2.length); f3 < v2; f3++) {
            var b2 = g2[f3];
            if (b2 && !b2.match(Iu)) {
              for (var x3 = "", w2 = 0, $2 = b2.length; w2 < $2; w2++)
                b2.charCodeAt(w2) > 127 ? x3 += "x" : x3 += b2[w2];
              if (!x3.match(Iu)) {
                var k2 = g2.slice(0, f3), S2 = g2.slice(f3 + 1), A2 = b2.match(_u);
                A2 && (k2.push(A2[1]), S2.unshift(A2[2])), S2.length && (i4 = "/" + S2.join(".") + i4), this.hostname = k2.join(".");
                break;
              }
            }
          }
        this.hostname.length > 255 ? this.hostname = "" : this.hostname = this.hostname.toLowerCase(), y2 || (this.hostname = vu.toASCII(this.hostname));
        var E2 = this.port ? ":" + this.port : "", O2 = this.hostname || "";
        this.host = O2 + E2, this.href += this.host, y2 && (this.hostname = this.hostname.substr(1, this.hostname.length - 2), "/" !== i4[0] && (i4 = "/" + i4));
      }
      if (!Pu[c3])
        for (f3 = 0, v2 = Tu.length; f3 < v2; f3++) {
          var T3 = Tu[f3];
          if (-1 !== i4.indexOf(T3)) {
            var C2 = encodeURIComponent(T3);
            C2 === T3 && (C2 = escape(T3)), i4 = i4.split(T3).join(C2);
          }
        }
      var j2 = i4.indexOf("#");
      -1 !== j2 && (this.hash = i4.substr(j2), i4 = i4.slice(0, j2));
      var I2 = i4.indexOf("?");
      if (-1 !== I2 ? (this.search = i4.substr(I2), this.query = i4.substr(I2 + 1), t5 && (this.query = Fu.parse(this.query)), i4 = i4.slice(0, I2)) : t5 && (this.search = "", this.query = {}), i4 && (this.pathname = i4), Lu[c3] && this.hostname && !this.pathname && (this.pathname = "/"), this.pathname || this.search) {
        E2 = this.pathname || "";
        var _2 = this.search || "";
        this.path = E2 + _2;
      }
      return this.href = this.format(), this;
    }, ku.prototype.format = function() {
      var e6 = this.auth || "";
      e6 && (e6 = (e6 = encodeURIComponent(e6)).replace(/%3A/i, ":"), e6 += "@");
      var t5 = this.protocol || "", r6 = this.pathname || "", n6 = this.hash || "", o5 = false, a2 = "";
      this.host ? o5 = e6 + this.host : this.hostname && (o5 = e6 + (-1 === this.hostname.indexOf(":") ? this.hostname : "[" + this.hostname + "]"), this.port && (o5 += ":" + this.port)), this.query && xu(this.query) && Object.keys(this.query).length && (a2 = Fu.stringify(this.query));
      var i4 = this.search || a2 && "?" + a2 || "";
      return t5 && ":" !== t5.substr(-1) && (t5 += ":"), this.slashes || (!t5 || Lu[t5]) && false !== o5 ? (o5 = "//" + (o5 || ""), r6 && "/" !== r6.charAt(0) && (r6 = "/" + r6)) : o5 || (o5 = ""), n6 && "#" !== n6.charAt(0) && (n6 = "#" + n6), i4 && "?" !== i4.charAt(0) && (i4 = "?" + i4), t5 + o5 + (r6 = r6.replace(/[?#]/g, function(e7) {
        return encodeURIComponent(e7);
      })) + (i4 = i4.replace("#", "%23")) + n6;
    }, ku.prototype.resolve = function(e6) {
      return this.resolveObject(Du(e6, false, true)).format();
    }, ku.prototype.resolveObject = function(e6) {
      if (bu(e6)) {
        var t5 = new ku();
        t5.parse(e6, false, true), e6 = t5;
      }
      for (var r6 = new ku(), n6 = Object.keys(this), o5 = 0; o5 < n6.length; o5++) {
        var a2 = n6[o5];
        r6[a2] = this[a2];
      }
      if (r6.hash = e6.hash, "" === e6.href)
        return r6.href = r6.format(), r6;
      if (e6.slashes && !e6.protocol) {
        for (var i4 = Object.keys(e6), s6 = 0; s6 < i4.length; s6++) {
          var l2 = i4[s6];
          "protocol" !== l2 && (r6[l2] = e6[l2]);
        }
        return Lu[r6.protocol] && r6.hostname && !r6.pathname && (r6.path = r6.pathname = "/"), r6.href = r6.format(), r6;
      }
      if (e6.protocol && e6.protocol !== r6.protocol) {
        if (!Lu[e6.protocol]) {
          for (var c3 = Object.keys(e6), p2 = 0; p2 < c3.length; p2++) {
            var d2 = c3[p2];
            r6[d2] = e6[d2];
          }
          return r6.href = r6.format(), r6;
        }
        if (r6.protocol = e6.protocol, e6.host || Ru[e6.protocol])
          r6.pathname = e6.pathname;
        else {
          for (var u3 = (e6.pathname || "").split("/"); u3.length && !(e6.host = u3.shift()); )
            ;
          e6.host || (e6.host = ""), e6.hostname || (e6.hostname = ""), "" !== u3[0] && u3.unshift(""), u3.length < 2 && u3.unshift(""), r6.pathname = u3.join("/");
        }
        if (r6.search = e6.search, r6.query = e6.query, r6.host = e6.host || "", r6.auth = e6.auth, r6.hostname = e6.hostname || e6.host, r6.port = e6.port, r6.pathname || r6.search) {
          var h2 = r6.pathname || "", f3 = r6.search || "";
          r6.path = h2 + f3;
        }
        return r6.slashes = r6.slashes || e6.slashes, r6.href = r6.format(), r6;
      }
      var m2 = r6.pathname && "/" === r6.pathname.charAt(0), y2 = e6.host || e6.pathname && "/" === e6.pathname.charAt(0), g2 = y2 || m2 || r6.host && e6.pathname, v2 = g2, b2 = r6.pathname && r6.pathname.split("/") || [], x3 = (u3 = e6.pathname && e6.pathname.split("/") || [], r6.protocol && !Lu[r6.protocol]);
      if (x3 && (r6.hostname = "", r6.port = null, r6.host && ("" === b2[0] ? b2[0] = r6.host : b2.unshift(r6.host)), r6.host = "", e6.protocol && (e6.hostname = null, e6.port = null, e6.host && ("" === u3[0] ? u3[0] = e6.host : u3.unshift(e6.host)), e6.host = null), g2 = g2 && ("" === u3[0] || "" === b2[0])), y2)
        r6.host = e6.host || "" === e6.host ? e6.host : r6.host, r6.hostname = e6.hostname || "" === e6.hostname ? e6.hostname : r6.hostname, r6.search = e6.search, r6.query = e6.query, b2 = u3;
      else if (u3.length)
        b2 || (b2 = []), b2.pop(), b2 = b2.concat(u3), r6.search = e6.search, r6.query = e6.query;
      else if (!$u(e6.search))
        return x3 && (r6.hostname = r6.host = b2.shift(), (A2 = !!(r6.host && r6.host.indexOf("@") > 0) && r6.host.split("@")) && (r6.auth = A2.shift(), r6.host = r6.hostname = A2.shift())), r6.search = e6.search, r6.query = e6.query, wu(r6.pathname) && wu(r6.search) || (r6.path = (r6.pathname ? r6.pathname : "") + (r6.search ? r6.search : "")), r6.href = r6.format(), r6;
      if (!b2.length)
        return r6.pathname = null, r6.search ? r6.path = "/" + r6.search : r6.path = null, r6.href = r6.format(), r6;
      for (var w2 = b2.slice(-1)[0], $2 = (r6.host || e6.host || b2.length > 1) && ("." === w2 || ".." === w2) || "" === w2, k2 = 0, S2 = b2.length; S2 >= 0; S2--)
        "." === (w2 = b2[S2]) ? b2.splice(S2, 1) : ".." === w2 ? (b2.splice(S2, 1), k2++) : k2 && (b2.splice(S2, 1), k2--);
      if (!g2 && !v2)
        for (; k2--; k2)
          b2.unshift("..");
      !g2 || "" === b2[0] || b2[0] && "/" === b2[0].charAt(0) || b2.unshift(""), $2 && "/" !== b2.join("/").substr(-1) && b2.push("");
      var A2, E2 = "" === b2[0] || b2[0] && "/" === b2[0].charAt(0);
      return x3 && (r6.hostname = r6.host = E2 ? "" : b2.length ? b2.shift() : "", (A2 = !!(r6.host && r6.host.indexOf("@") > 0) && r6.host.split("@")) && (r6.auth = A2.shift(), r6.host = r6.hostname = A2.shift())), (g2 = g2 || r6.host && b2.length) && !E2 && b2.unshift(""), b2.length ? r6.pathname = b2.join("/") : (r6.pathname = null, r6.path = null), wu(r6.pathname) && wu(r6.search) || (r6.path = (r6.pathname ? r6.pathname : "") + (r6.search ? r6.search : "")), r6.auth = e6.auth || r6.auth, r6.slashes = r6.slashes || e6.slashes, r6.href = r6.format(), r6;
    }, ku.prototype.parseHost = function() {
      var e6 = this.host, t5 = Au.exec(e6);
      t5 && (":" !== (t5 = t5[0]) && (this.port = t5.substr(1)), e6 = e6.substr(0, e6.length - t5.length)), e6 && (this.hostname = e6);
    };
    var Bu = Co, Nu = ft, qu = mt, Uu = ca, zu = nr, Mu = Kr, Hu = Uo, Wu = ti, Vu = Os, Gu = oc, Ku = vr, Ju = fn("isConcatSpreadable"), Yu = Nu.TypeError, Zu = Ku >= 51 || !qu(function() {
      var e6 = [];
      return e6[Ju] = false, e6.concat()[0] !== e6;
    }), Qu = Gu("concat"), Xu = function(e6) {
      if (!zu(e6))
        return false;
      var t5 = e6[Ju];
      return void 0 !== t5 ? !!t5 : Uu(e6);
    };
    Bu({ target: "Array", proto: true, forced: !Zu || !Qu }, { concat: function(e6) {
      var t5, r6, n6, o5, a2, i4 = Mu(this), s6 = Vu(i4, 0), l2 = 0;
      for (t5 = -1, n6 = arguments.length; t5 < n6; t5++)
        if (Xu(a2 = -1 === t5 ? i4 : arguments[t5])) {
          if (l2 + (o5 = Hu(a2)) > 9007199254740991)
            throw Yu("Maximum allowed index exceeded");
          for (r6 = 0; r6 < o5; r6++, l2++)
            r6 in a2 && Wu(s6, l2, a2[r6]);
        } else {
          if (l2 >= 9007199254740991)
            throw Yu("Maximum allowed index exceeded");
          Wu(s6, l2++, a2);
        }
      return s6.length = l2, s6;
    } }), ki("asyncIterator"), ki("hasInstance"), ki("isConcatSpreadable"), ki("iterator"), ki("match"), ki("matchAll"), ki("replace"), ki("search"), ki("species"), ki("split"), ki("toPrimitive"), ki("toStringTag"), ki("unscopables"), _i(ft.JSON, "JSON", true);
    var eh = or.Symbol;
    ki("asyncDispose"), ki("dispose"), ki("matcher"), ki("metadata"), ki("observable"), ki("patternMatch"), ki("replaceAll");
    const th = ut({ exports: {} }.exports = eh);
    var rh = Ot, nh = _o, oh = $a, ah = Qt, ih = rh("".charAt), sh = rh("".charCodeAt), lh = rh("".slice), ch = function(e6) {
      return function(t5, r6) {
        var n6, o5, a2 = oh(ah(t5)), i4 = nh(r6), s6 = a2.length;
        return i4 < 0 || i4 >= s6 ? e6 ? "" : void 0 : (n6 = sh(a2, i4)) < 55296 || n6 > 56319 || i4 + 1 === s6 || (o5 = sh(a2, i4 + 1)) < 56320 || o5 > 57343 ? e6 ? ih(a2, i4) : n6 : e6 ? lh(a2, i4, i4 + 2) : o5 - 56320 + (n6 - 55296 << 10) + 65536;
      };
    }, ph = (ch(false), ch(true)), dh = $a, uh = is, hh = Ap, fh = uh.set, mh = uh.getterFor("String Iterator");
    hh(String, "String", function(e6) {
      fh(this, { type: "String Iterator", string: dh(e6), index: 0 });
    }, function() {
      var e6, t5 = mh(this), r6 = t5.string, n6 = t5.index;
      return n6 >= r6.length ? { value: void 0, done: true } : (e6 = ph(r6, n6), t5.index += e6.length, { value: e6, done: false });
    });
    var yh = ba, gh = Fr, vh = Tc, bh = fn("iterator"), xh = function(e6) {
      if (null != e6)
        return gh(e6, bh) || gh(e6, "@@iterator") || vh[yh(e6)];
    };
    const wh = ut({ exports: {} }.exports = xh);
    Co({ target: "Array", stat: true }, { isArray: ca });
    var $h = or.Array.isArray;
    const kh = ut({ exports: {} }.exports = $h);
    var Sh = Co, Ah = ft, Eh = ca, Oh = xs, Th = nr, Ch = Fo, jh = Uo, Ih = tr, _h = ti, Ph = fn, Rh = fi, Lh = oc("slice"), Fh = Ph("species"), Dh = Ah.Array, Bh = Math.max;
    Sh({ target: "Array", proto: true, forced: !Lh }, { slice: function(e6, t5) {
      var r6, n6, o5, a2 = Ih(this), i4 = jh(a2), s6 = Ch(e6, i4), l2 = Ch(void 0 === t5 ? i4 : t5, i4);
      if (Eh(a2) && (r6 = a2.constructor, (Oh(r6) && (r6 === Dh || Eh(r6.prototype)) || Th(r6) && null === (r6 = r6[Fh])) && (r6 = void 0), r6 === Dh || void 0 === r6))
        return Rh(a2, s6, l2);
      for (n6 = new (void 0 === r6 ? Dh : r6)(Bh(l2 - s6, 0)), o5 = 0; s6 < l2; s6++, o5++)
        s6 in a2 && _h(n6, o5, a2[s6]);
      return n6.length = o5, n6;
    } });
    var Nh = sc("Array").slice, qh = pr, Uh = Nh, zh = Array.prototype, Mh = function(e6) {
      var t5 = e6.slice;
      return e6 === zh || qh(zh, e6) && t5 === zh.slice ? Uh : t5;
    };
    const Hh = ut({ exports: {} }.exports = Mh);
    var Wh = Pt, Vh = ao, Gh = Fr, Kh = function(e6, t5, r6) {
      var n6, o5;
      Vh(e6);
      try {
        if (!(n6 = Gh(e6, "return"))) {
          if ("throw" === t5)
            throw r6;
          return r6;
        }
        n6 = Wh(n6, e6);
      } catch (e7) {
        o5 = true, n6 = e7;
      }
      if ("throw" === t5)
        throw r6;
      if (o5)
        throw n6;
      return Vh(n6), r6;
    }, Jh = ao, Yh = Kh, Zh = Tc, Qh = fn("iterator"), Xh = Array.prototype, ef = function(e6) {
      return void 0 !== e6 && (Zh.Array === e6 || Xh[Qh] === e6);
    }, tf = Pt, rf = Rr, nf = ao, of = jr, af = xh, sf = ft.TypeError, lf = function(e6, t5) {
      var r6 = arguments.length < 2 ? af(e6) : t5;
      if (rf(r6))
        return nf(tf(r6, e6));
      throw sf(of(e6) + " is not iterable");
    }, cf = Qn, pf = Pt, df = Kr, uf = function(e6, t5, r6, n6) {
      try {
        return n6 ? t5(Jh(r6)[0], r6[1]) : t5(r6);
      } catch (t6) {
        Yh(e6, "throw", t6);
      }
    }, hf = ef, ff = xs, mf = Uo, yf = ti, gf = lf, vf = xh, bf = ft.Array, xf = fn("iterator"), wf = false;
    try {
      var $f = 0, kf = { next: function() {
        return { done: !!$f++ };
      }, return: function() {
        wf = true;
      } };
      kf[xf] = function() {
        return this;
      }, Array.from(kf, function() {
        throw 2;
      });
    } catch (e6) {
    }
    var Sf = function(e6, t5) {
      if (!t5 && !wf)
        return false;
      var r6 = false;
      try {
        var n6 = {};
        n6[xf] = function() {
          return { next: function() {
            return { done: r6 = true };
          } };
        }, e6(n6);
      } catch (e7) {
      }
      return r6;
    };
    Co({ target: "Array", stat: true, forced: !Sf(function(e6) {
      Array.from(e6);
    }) }, { from: function(e6) {
      var t5 = df(e6), r6 = ff(this), n6 = arguments.length, o5 = n6 > 1 ? arguments[1] : void 0, a2 = void 0 !== o5;
      a2 && (o5 = cf(o5, n6 > 2 ? arguments[2] : void 0));
      var i4, s6, l2, c3, p2, d2, u3 = vf(t5), h2 = 0;
      if (!u3 || this == bf && hf(u3))
        for (i4 = mf(t5), s6 = r6 ? new this(i4) : bf(i4); i4 > h2; h2++)
          d2 = a2 ? o5(t5[h2], h2) : t5[h2], yf(s6, h2, d2);
      else
        for (p2 = (c3 = gf(t5, u3)).next, s6 = r6 ? new this() : []; !(l2 = pf(p2, c3)).done; h2++)
          d2 = a2 ? uf(c3, o5, [l2.value, h2], true) : l2.value, yf(s6, h2, d2);
      return s6.length = h2, s6;
    } });
    var Af = or.Array.from;
    const Ef = ut({ exports: {} }.exports = Af);
    function Of(e6, t5) {
      (null == t5 || t5 > e6.length) && (t5 = e6.length);
      for (var r6 = 0, n6 = new Array(t5); r6 < t5; r6++)
        n6[r6] = e6[r6];
      return n6;
    }
    function Tf(e6, t5) {
      var r6;
      if (e6) {
        if ("string" == typeof e6)
          return Of(e6, t5);
        var n6 = Hh(r6 = Object.prototype.toString.call(e6)).call(r6, 8, -1);
        return "Object" === n6 && e6.constructor && (n6 = e6.constructor.name), "Map" === n6 || "Set" === n6 ? Ef(e6) : "Arguments" === n6 || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n6) ? Of(e6, t5) : void 0;
      }
    }
    function Cf(e6, t5) {
      var r6 = void 0 !== th && wh(e6) || e6["@@iterator"];
      if (!r6) {
        if (kh(e6) || (r6 = Tf(e6)) || t5 && e6 && "number" == typeof e6.length) {
          r6 && (e6 = r6);
          var n6 = 0, o5 = function() {
          };
          return { s: o5, n: function() {
            return n6 >= e6.length ? { done: true } : { done: false, value: e6[n6++] };
          }, e: function(e7) {
            throw e7;
          }, f: o5 };
        }
        throw new TypeError("Invalid attempt to iterate non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.");
      }
      var a2, i4 = true, s6 = false;
      return { s: function() {
        r6 = r6.call(e6);
      }, n: function() {
        var e7 = r6.next();
        return i4 = e7.done, e7;
      }, e: function(e7) {
        s6 = true, a2 = e7;
      }, f: function() {
        try {
          i4 || null == r6.return || r6.return();
        } finally {
          if (s6)
            throw a2;
        }
      } };
    }
    var jf = gi.f("iterator");
    const If = ut({ exports: {} }.exports = jf);
    function _f(e6) {
      return (_f = "function" == typeof th && "symbol" == typeof If ? function(e7) {
        return typeof e7;
      } : function(e7) {
        return e7 && "function" == typeof th && e7.constructor === th && e7 !== th.prototype ? "symbol" : typeof e7;
      })(e6);
    }
    function Pf(e6, t5) {
      return function(e7) {
        if (kh(e7))
          return e7;
      }(e6) || function(e7, t6) {
        var r6 = null == e7 ? null : void 0 !== th && wh(e7) || e7["@@iterator"];
        if (null != r6) {
          var n6, o5, a2 = [], i4 = true, s6 = false;
          try {
            for (r6 = r6.call(e7); !(i4 = (n6 = r6.next()).done) && (a2.push(n6.value), !t6 || a2.length !== t6); i4 = true)
              ;
          } catch (e8) {
            s6 = true, o5 = e8;
          } finally {
            try {
              i4 || null == r6.return || r6.return();
            } finally {
              if (s6)
                throw o5;
            }
          }
          return a2;
        }
      }(e6, t5) || Tf(e6, t5) || function() {
        throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.");
      }();
    }
    var Rf = Zr, Lf = nd, Ff = Ct, Df = Xn, Bf = Ot("".replace), Nf = String(Error("zxcasd").stack), qf = /\n\s*at [^:]*:[^\n]*/, Uf = qf.test(Nf), zf = nr, Mf = go, Hf = Qn, Wf = Pt, Vf = ao, Gf = jr, Kf = ef, Jf = Uo, Yf = pr, Zf = lf, Qf = xh, Xf = Kh, em = ft.TypeError, tm = function(e6, t5) {
      this.stopped = e6, this.result = t5;
    }, rm = tm.prototype, nm = function(e6, t5, r6) {
      var n6, o5, a2, i4, s6, l2, c3, p2 = r6 && r6.that, d2 = !(!r6 || !r6.AS_ENTRIES), u3 = !(!r6 || !r6.IS_ITERATOR), h2 = !(!r6 || !r6.INTERRUPTED), f3 = Hf(t5, p2), m2 = function(e7) {
        return n6 && Xf(n6, "normal", e7), new tm(true, e7);
      }, y2 = function(e7) {
        return d2 ? (Vf(e7), h2 ? f3(e7[0], e7[1], m2) : f3(e7[0], e7[1])) : h2 ? f3(e7, m2) : f3(e7);
      };
      if (u3)
        n6 = e6;
      else {
        if (!(o5 = Qf(e6)))
          throw em(Gf(e6) + " is not iterable");
        if (Kf(o5)) {
          for (a2 = 0, i4 = Jf(e6); i4 > a2; a2++)
            if ((s6 = y2(e6[a2])) && Yf(rm, s6))
              return s6;
          return new tm(false);
        }
        n6 = Zf(e6, o5);
      }
      for (l2 = n6.next; !(c3 = Wf(l2, n6)).done; ) {
        try {
          s6 = y2(c3.value);
        } catch (e7) {
          Xf(n6, "throw", e7);
        }
        if ("object" == typeof s6 && s6 && Yf(rm, s6))
          return s6;
      }
      return new tm(false);
    }, om = $a, am = qt, im = !mt(function() {
      var e6 = Error("a");
      return !("stack" in e6) || (Object.defineProperty(e6, "stack", am(1, 7)), 7 !== e6.stack);
    }), sm = Co, lm = ft, cm = pr, pm = Hc, dm = hp, um = Ga, hm = go, fm = qt, mm = function(e6, t5) {
      if (Uf && "string" == typeof e6)
        for (; t5--; )
          e6 = Bf(e6, qf, "");
      return e6;
    }, ym = function(e6, t5) {
      zf(t5) && "cause" in t5 && Mf(e6, "cause", t5.cause);
    }, gm = nm, vm = function(e6, t5) {
      return void 0 === e6 ? arguments.length < 2 ? "" : t5 : om(e6);
    }, bm = im, xm = fn("toStringTag"), wm = lm.Error, $m = [].push, km = function(e6, t5) {
      var r6, n6 = arguments.length > 2 ? arguments[2] : void 0, o5 = cm(Sm, this);
      dm ? r6 = dm(new wm(), o5 ? pm(this) : Sm) : (r6 = o5 ? this : um(Sm), hm(r6, xm, "Error")), void 0 !== t5 && hm(r6, "message", vm(t5)), bm && hm(r6, "stack", mm(r6.stack, 1)), ym(r6, n6);
      var a2 = [];
      return gm(e6, $m, { that: a2 }), hm(r6, "errors", a2), r6;
    };
    dm ? dm(km, wm) : function(e6, t5, r6) {
      for (var n6 = Lf(t5), o5 = Df.f, a2 = Ff.f, i4 = 0; i4 < n6.length; i4++) {
        var s6 = n6[i4];
        Rf(e6, s6) || r6 && Rf(r6, s6) || o5(e6, s6, a2(t5, s6));
      }
    }(km, wm, { name: true });
    var Sm = km.prototype = um(wm.prototype, { constructor: fm(1, km), message: fm(1, ""), name: fm(1, "AggregateError") });
    sm({ global: true }, { AggregateError: km });
    var Am, Em, Om, Tm, Cm = ft.Promise, jm = yi, Im = function(e6, t5, r6) {
      for (var n6 in t5)
        r6 && r6.unsafe && e6[n6] ? e6[n6] = t5[n6] : jm(e6, n6, t5[n6], r6);
      return e6;
    }, _m = cr, Pm = Xn, Rm = jt, Lm = fn("species"), Fm = pr, Dm = ft.TypeError, Bm = function(e6, t5) {
      if (Fm(t5, e6))
        return e6;
      throw Dm("Incorrect invocation");
    }, Nm = xs, qm = jr, Um = ft.TypeError, zm = ao, Mm = fn("species"), Hm = function(e6, t5) {
      var r6, n6 = zm(e6).constructor;
      return void 0 === n6 || null == (r6 = zm(n6)[Mm]) ? t5 : function(e7) {
        if (Nm(e7))
          return e7;
        throw Um(qm(e7) + " is not a constructor");
      }(r6);
    }, Wm = ft.TypeError, Vm = function(e6, t5) {
      if (e6 < t5)
        throw Wm("Not enough arguments");
      return e6;
    }, Gm = /(?:ipad|iphone|ipod).*applewebkit/i.test(dr), Km = "process" == Ht(ft.process), Jm = ft, Ym = wt, Zm = Qn, Qm = Tt, Xm = Zr, ey = mt, ty = Ia, ry = fi, ny = Tn, oy = Vm, ay = Gm, iy = Km, sy = Jm.setImmediate, ly = Jm.clearImmediate, cy = Jm.process, py = Jm.Dispatch, dy = Jm.Function, uy = Jm.MessageChannel, hy = Jm.String, fy = 0, my = {};
    try {
      Am = Jm.location;
    } catch (e6) {
    }
    var yy = function(e6) {
      if (Xm(my, e6)) {
        var t5 = my[e6];
        delete my[e6], t5();
      }
    }, gy = function(e6) {
      return function() {
        yy(e6);
      };
    }, vy = function(e6) {
      yy(e6.data);
    }, by = function(e6) {
      Jm.postMessage(hy(e6), Am.protocol + "//" + Am.host);
    };
    sy && ly || (sy = function(e6) {
      oy(arguments.length, 1);
      var t5 = Qm(e6) ? e6 : dy(e6), r6 = ry(arguments, 1);
      return my[++fy] = function() {
        Ym(t5, void 0, r6);
      }, Em(fy), fy;
    }, ly = function(e6) {
      delete my[e6];
    }, iy ? Em = function(e6) {
      cy.nextTick(gy(e6));
    } : py && py.now ? Em = function(e6) {
      py.now(gy(e6));
    } : uy && !ay ? (Tm = (Om = new uy()).port2, Om.port1.onmessage = vy, Em = Zm(Tm.postMessage, Tm)) : Jm.addEventListener && Qm(Jm.postMessage) && !Jm.importScripts && Am && "file:" !== Am.protocol && !ey(by) ? (Em = by, Jm.addEventListener("message", vy, false)) : Em = "onreadystatechange" in ny("script") ? function(e6) {
      ty.appendChild(ny("script")).onreadystatechange = function() {
        ty.removeChild(this), yy(e6);
      };
    } : function(e6) {
      setTimeout(gy(e6), 0);
    });
    var xy, wy, $y, ky, Sy, Ay, Ey, Oy, Ty = { set: sy, clear: ly }, Cy = ft, jy = /ipad|iphone|ipod/i.test(dr) && void 0 !== Cy.Pebble, Iy = /web0s(?!.*chrome)/i.test(dr), _y = ft, Py = Qn, Ry = Ct.f, Ly = Ty.set, Fy = Gm, Dy = jy, By = Iy, Ny = Km, qy = _y.MutationObserver || _y.WebKitMutationObserver, Uy = _y.document, zy = _y.process, My = _y.Promise, Hy = Ry(_y, "queueMicrotask"), Wy = Hy && Hy.value;
    Wy || (xy = function() {
      var e6, t5;
      for (Ny && (e6 = zy.domain) && e6.exit(); wy; ) {
        t5 = wy.fn, wy = wy.next;
        try {
          t5();
        } catch (e7) {
          throw wy ? ky() : $y = void 0, e7;
        }
      }
      $y = void 0, e6 && e6.enter();
    }, Fy || Ny || By || !qy || !Uy ? !Dy && My && My.resolve ? ((Ey = My.resolve(void 0)).constructor = My, Oy = Py(Ey.then, Ey), ky = function() {
      Oy(xy);
    }) : Ny ? ky = function() {
      zy.nextTick(xy);
    } : (Ly = Py(Ly, _y), ky = function() {
      Ly(xy);
    }) : (Sy = true, Ay = Uy.createTextNode(""), new qy(xy).observe(Ay, { characterData: true }), ky = function() {
      Ay.data = Sy = !Sy;
    }));
    var Vy = Wy || function(e6) {
      var t5 = { fn: e6, next: void 0 };
      $y && ($y.next = t5), wy || (wy = t5, ky()), $y = t5;
    }, Gy = {}, Ky = Rr, Jy = function(e6) {
      var t5, r6;
      this.promise = new e6(function(e7, n6) {
        if (void 0 !== t5 || void 0 !== r6)
          throw TypeError("Bad Promise constructor");
        t5 = e7, r6 = n6;
      }), this.resolve = Ky(t5), this.reject = Ky(r6);
    };
    Gy.f = function(e6) {
      return new Jy(e6);
    };
    var Yy = ao, Zy = nr, Qy = Gy, Xy = function(e6, t5) {
      if (Yy(e6), Zy(t5) && t5.constructor === e6)
        return t5;
      var r6 = Qy.f(e6);
      return (0, r6.resolve)(t5), r6.promise;
    }, eg = ft, tg = function(e6) {
      try {
        return { error: false, value: e6() };
      } catch (e7) {
        return { error: true, value: e7 };
      }
    }, rg = function() {
      this.head = null, this.tail = null;
    };
    rg.prototype = { add: function(e6) {
      var t5 = { item: e6, next: null };
      this.head ? this.tail.next = t5 : this.head = t5, this.tail = t5;
    }, get: function() {
      var e6 = this.head;
      if (e6)
        return this.head = e6.next, this.tail === e6 && (this.tail = null), e6.item;
    } };
    var ng, og, ag, ig, sg, lg = "object" == typeof window, cg = Co, pg = ft, dg = cr, ug = Pt, hg = Cm, fg = Im, mg = _i, yg = Rr, gg = Tt, vg = nr, bg = Bm, xg = Ni, wg = nm, $g = Sf, kg = Hm, Sg = Ty.set, Ag = Vy, Eg = Xy, Og = Gy, Tg = tg, Cg = rg, jg = is, Ig = Kn, _g = lg, Pg = Km, Rg = vr, Lg = fn("species"), Fg = "Promise", Dg = jg.getterFor(Fg), Bg = jg.set, Ng = jg.getterFor(Fg), qg = hg && hg.prototype, Ug = hg, zg = qg, Mg = pg.TypeError, Hg = pg.document, Wg = pg.process, Vg = Og.f, Gg = Vg, Kg = !!(Hg && Hg.createEvent && pg.dispatchEvent), Jg = gg(pg.PromiseRejectionEvent), Yg = Ig(Fg, function() {
      var e6 = xg(Ug), t5 = e6 !== String(Ug);
      if (!t5 && 66 === Rg)
        return true;
      if (!zg.finally)
        return true;
      if (Rg >= 51 && /native code/.test(e6))
        return false;
      var r6 = new Ug(function(e7) {
        e7(1);
      }), n6 = function(e7) {
        e7(function() {
        }, function() {
        });
      };
      return (r6.constructor = {})[Lg] = n6, !(r6.then(function() {
      }) instanceof n6) || !t5 && _g && !Jg;
    }), Zg = Yg || !$g(function(e6) {
      Ug.all(e6).catch(function() {
      });
    }), Qg = function(e6) {
      var t5;
      return !(!vg(e6) || !gg(t5 = e6.then)) && t5;
    }, Xg = function(e6, t5) {
      var r6, n6, o5, a2 = t5.value, i4 = 1 == t5.state, s6 = i4 ? e6.ok : e6.fail, l2 = e6.resolve, c3 = e6.reject, p2 = e6.domain;
      try {
        s6 ? (i4 || (2 === t5.rejection && ov(t5), t5.rejection = 1), true === s6 ? r6 = a2 : (p2 && p2.enter(), r6 = s6(a2), p2 && (p2.exit(), o5 = true)), r6 === e6.promise ? c3(Mg("Promise-chain cycle")) : (n6 = Qg(r6)) ? ug(n6, r6, l2, c3) : l2(r6)) : c3(a2);
      } catch (e7) {
        p2 && !o5 && p2.exit(), c3(e7);
      }
    }, ev = function(e6, t5) {
      e6.notified || (e6.notified = true, Ag(function() {
        for (var r6, n6 = e6.reactions; r6 = n6.get(); )
          Xg(r6, e6);
        e6.notified = false, t5 && !e6.rejection && rv(e6);
      }));
    }, tv = function(e6, t5, r6) {
      var n6, o5;
      Kg ? ((n6 = Hg.createEvent("Event")).promise = t5, n6.reason = r6, n6.initEvent(e6, false, true), pg.dispatchEvent(n6)) : n6 = { promise: t5, reason: r6 }, !Jg && (o5 = pg["on" + e6]) ? o5(n6) : "unhandledrejection" === e6 && function(e7, t6) {
        var r7 = eg.console;
        r7 && r7.error && (1 == arguments.length ? r7.error(e7) : r7.error(e7, t6));
      }("Unhandled promise rejection", r6);
    }, rv = function(e6) {
      ug(Sg, pg, function() {
        var t5, r6 = e6.facade, n6 = e6.value;
        if (nv(e6) && (t5 = Tg(function() {
          Pg ? Wg.emit("unhandledRejection", n6, r6) : tv("unhandledrejection", r6, n6);
        }), e6.rejection = Pg || nv(e6) ? 2 : 1, t5.error))
          throw t5.value;
      });
    }, nv = function(e6) {
      return 1 !== e6.rejection && !e6.parent;
    }, ov = function(e6) {
      ug(Sg, pg, function() {
        var t5 = e6.facade;
        Pg ? Wg.emit("rejectionHandled", t5) : tv("rejectionhandled", t5, e6.value);
      });
    }, av = function(e6, t5, r6) {
      return function(n6) {
        e6(t5, n6, r6);
      };
    }, iv = function(e6, t5, r6) {
      e6.done || (e6.done = true, r6 && (e6 = r6), e6.value = t5, e6.state = 2, ev(e6, true));
    }, sv = function(e6, t5, r6) {
      if (!e6.done) {
        e6.done = true, r6 && (e6 = r6);
        try {
          if (e6.facade === t5)
            throw Mg("Promise can't be resolved itself");
          var n6 = Qg(t5);
          n6 ? Ag(function() {
            var r7 = { done: false };
            try {
              ug(n6, t5, av(sv, r7, e6), av(iv, r7, e6));
            } catch (t6) {
              iv(r7, t6, e6);
            }
          }) : (e6.value = t5, e6.state = 1, ev(e6, false));
        } catch (t6) {
          iv({ done: false }, t6, e6);
        }
      }
    };
    Yg && (zg = (Ug = function(e6) {
      bg(this, zg), yg(e6), ug(ng, this);
      var t5 = Dg(this);
      try {
        e6(av(sv, t5), av(iv, t5));
      } catch (e7) {
        iv(t5, e7);
      }
    }).prototype, (ng = function(e6) {
      Bg(this, { type: Fg, done: false, notified: false, parent: false, reactions: new Cg(), rejection: false, state: 0, value: void 0 });
    }).prototype = fg(zg, { then: function(e6, t5) {
      var r6 = Ng(this), n6 = Vg(kg(this, Ug));
      return r6.parent = true, n6.ok = !gg(e6) || e6, n6.fail = gg(t5) && t5, n6.domain = Pg ? Wg.domain : void 0, 0 == r6.state ? r6.reactions.add(n6) : Ag(function() {
        Xg(n6, r6);
      }), n6.promise;
    }, catch: function(e6) {
      return this.then(void 0, e6);
    } }), og = function() {
      var e6 = new ng(), t5 = Dg(e6);
      this.promise = e6, this.resolve = av(sv, t5), this.reject = av(iv, t5);
    }, Og.f = Vg = function(e6) {
      return e6 === Ug || e6 === ag ? new og(e6) : Gg(e6);
    }), cg({ global: true, wrap: true, forced: Yg }, { Promise: Ug }), mg(Ug, Fg, false, true), ig = _m(Fg), sg = Pm.f, Rm && ig && !ig[Lm] && sg(ig, Lm, { configurable: true, get: function() {
      return this;
    } }), ag = dg(Fg), cg({ target: Fg, stat: true, forced: Yg }, { reject: function(e6) {
      var t5 = Vg(this);
      return ug(t5.reject, void 0, e6), t5.promise;
    } }), cg({ target: Fg, stat: true, forced: true }, { resolve: function(e6) {
      return Eg(this === ag ? Ug : this, e6);
    } }), cg({ target: Fg, stat: true, forced: Zg }, { all: function(e6) {
      var t5 = this, r6 = Vg(t5), n6 = r6.resolve, o5 = r6.reject, a2 = Tg(function() {
        var r7 = yg(t5.resolve), a3 = [], i4 = 0, s6 = 1;
        wg(e6, function(e7) {
          var l2 = i4++, c3 = false;
          s6++, ug(r7, t5, e7).then(function(e8) {
            c3 || (c3 = true, a3[l2] = e8, --s6 || n6(a3));
          }, o5);
        }), --s6 || n6(a3);
      });
      return a2.error && o5(a2.value), r6.promise;
    }, race: function(e6) {
      var t5 = this, r6 = Vg(t5), n6 = r6.reject, o5 = Tg(function() {
        var o6 = yg(t5.resolve);
        wg(e6, function(e7) {
          ug(o6, t5, e7).then(r6.resolve, n6);
        });
      });
      return o5.error && n6(o5.value), r6.promise;
    } });
    var lv = Pt, cv = Rr, pv = Gy, dv = tg, uv = nm;
    Co({ target: "Promise", stat: true }, { allSettled: function(e6) {
      var t5 = this, r6 = pv.f(t5), n6 = r6.resolve, o5 = r6.reject, a2 = dv(function() {
        var r7 = cv(t5.resolve), o6 = [], a3 = 0, i4 = 1;
        uv(e6, function(e7) {
          var s6 = a3++, l2 = false;
          i4++, lv(r7, t5, e7).then(function(e8) {
            l2 || (l2 = true, o6[s6] = { status: "fulfilled", value: e8 }, --i4 || n6(o6));
          }, function(e8) {
            l2 || (l2 = true, o6[s6] = { status: "rejected", reason: e8 }, --i4 || n6(o6));
          });
        }), --i4 || n6(o6);
      });
      return a2.error && o5(a2.value), r6.promise;
    } });
    var hv = Rr, fv = cr, mv = Pt, yv = Gy, gv = tg, vv = nm;
    Co({ target: "Promise", stat: true }, { any: function(e6) {
      var t5 = this, r6 = fv("AggregateError"), n6 = yv.f(t5), o5 = n6.resolve, a2 = n6.reject, i4 = gv(function() {
        var n7 = hv(t5.resolve), i5 = [], s6 = 0, l2 = 1, c3 = false;
        vv(e6, function(e7) {
          var p2 = s6++, d2 = false;
          l2++, mv(n7, t5, e7).then(function(e8) {
            d2 || c3 || (c3 = true, o5(e8));
          }, function(e8) {
            d2 || c3 || (d2 = true, i5[p2] = e8, --l2 || a2(new r6(i5, "No one promise resolved")));
          });
        }), --l2 || a2(new r6(i5, "No one promise resolved"));
      });
      return i4.error && a2(i4.value), n6.promise;
    } });
    var bv = Cm, xv = cr, wv = Tt, $v = Hm, kv = Xy;
    Co({ target: "Promise", proto: true, real: true, forced: !!bv && mt(function() {
      bv.prototype.finally.call({ then: function() {
      } }, function() {
      });
    }) }, { finally: function(e6) {
      var t5 = $v(this, xv("Promise")), r6 = wv(e6);
      return this.then(r6 ? function(r7) {
        return kv(t5, e6()).then(function() {
          return r7;
        });
      } : e6, r6 ? function(r7) {
        return kv(t5, e6()).then(function() {
          throw r7;
        });
      } : e6);
    } });
    var Sv = or.Promise, Av = Sv, Ev = Gy, Ov = tg;
    Co({ target: "Promise", stat: true, forced: true }, { try: function(e6) {
      var t5 = Ev.f(this), r6 = Ov(e6);
      return (r6.error ? t5.reject : t5.resolve)(r6.value), t5.promise;
    } });
    const Tv = ut({ exports: {} }.exports = Av);
    function Cv(e6, t5, r6, n6, o5, a2, i4) {
      try {
        var s6 = e6[a2](i4), l2 = s6.value;
      } catch (e7) {
        return void r6(e7);
      }
      s6.done ? t5(l2) : Tv.resolve(l2).then(n6, o5);
    }
    function jv(e6) {
      return function() {
        var t5 = this, r6 = arguments;
        return new Tv(function(n6, o5) {
          var a2 = e6.apply(t5, r6);
          function i4(e7) {
            Cv(a2, n6, o5, i4, s6, "next", e7);
          }
          function s6(e7) {
            Cv(a2, n6, o5, i4, s6, "throw", e7);
          }
          i4(void 0);
        });
      };
    }
    var Iv = { exports: {} };
    !function(e6) {
      var t5 = function(e7) {
        var t6, r6 = Object.prototype, n6 = r6.hasOwnProperty, o5 = "function" == typeof Symbol ? Symbol : {}, a2 = o5.iterator || "@@iterator", i4 = o5.asyncIterator || "@@asyncIterator", s6 = o5.toStringTag || "@@toStringTag";
        function l2(e8, t7, r7) {
          return Object.defineProperty(e8, t7, { value: r7, enumerable: true, configurable: true, writable: true }), e8[t7];
        }
        try {
          l2({}, "");
        } catch (e8) {
          l2 = function(e9, t7, r7) {
            return e9[t7] = r7;
          };
        }
        function c3(e8, t7, r7, n7) {
          var o6, a3, i5, s7, l3 = t7 && t7.prototype instanceof y2 ? t7 : y2, c4 = Object.create(l3.prototype), g3 = new T3(n7 || []);
          return c4._invoke = (o6 = e8, a3 = r7, i5 = g3, s7 = d2, function(e9, t8) {
            if (s7 === h2)
              throw new Error("Generator is already running");
            if (s7 === f3) {
              if ("throw" === e9)
                throw t8;
              return j2();
            }
            for (i5.method = e9, i5.arg = t8; ; ) {
              var r8 = i5.delegate;
              if (r8) {
                var n8 = A2(r8, i5);
                if (n8) {
                  if (n8 === m2)
                    continue;
                  return n8;
                }
              }
              if ("next" === i5.method)
                i5.sent = i5._sent = i5.arg;
              else if ("throw" === i5.method) {
                if (s7 === d2)
                  throw s7 = f3, i5.arg;
                i5.dispatchException(i5.arg);
              } else
                "return" === i5.method && i5.abrupt("return", i5.arg);
              s7 = h2;
              var l4 = p2(o6, a3, i5);
              if ("normal" === l4.type) {
                if (s7 = i5.done ? f3 : u3, l4.arg === m2)
                  continue;
                return { value: l4.arg, done: i5.done };
              }
              "throw" === l4.type && (s7 = f3, i5.method = "throw", i5.arg = l4.arg);
            }
          }), c4;
        }
        function p2(e8, t7, r7) {
          try {
            return { type: "normal", arg: e8.call(t7, r7) };
          } catch (e9) {
            return { type: "throw", arg: e9 };
          }
        }
        e7.wrap = c3;
        var d2 = "suspendedStart", u3 = "suspendedYield", h2 = "executing", f3 = "completed", m2 = {};
        function y2() {
        }
        function g2() {
        }
        function v2() {
        }
        var b2 = {};
        l2(b2, a2, function() {
          return this;
        });
        var x3 = Object.getPrototypeOf, w2 = x3 && x3(x3(C2([])));
        w2 && w2 !== r6 && n6.call(w2, a2) && (b2 = w2);
        var $2 = v2.prototype = y2.prototype = Object.create(b2);
        function k2(e8) {
          ["next", "throw", "return"].forEach(function(t7) {
            l2(e8, t7, function(e9) {
              return this._invoke(t7, e9);
            });
          });
        }
        function S2(e8, t7) {
          function r7(o7, a3, i5, s7) {
            var l3 = p2(e8[o7], e8, a3);
            if ("throw" !== l3.type) {
              var c4 = l3.arg, d3 = c4.value;
              return d3 && "object" == typeof d3 && n6.call(d3, "__await") ? t7.resolve(d3.u).then(function(e9) {
                r7("next", e9, i5, s7);
              }, function(e9) {
                r7("throw", e9, i5, s7);
              }) : t7.resolve(d3).then(function(e9) {
                c4.value = e9, i5(c4);
              }, function(e9) {
                return r7("throw", e9, i5, s7);
              });
            }
            s7(l3.arg);
          }
          var o6;
          this._invoke = function(e9, n7) {
            function a3() {
              return new t7(function(t8, o7) {
                r7(e9, n7, t8, o7);
              });
            }
            return o6 = o6 ? o6.then(a3, a3) : a3();
          };
        }
        function A2(e8, r7) {
          var n7 = e8.iterator[r7.method];
          if (n7 === t6) {
            if (r7.delegate = null, "throw" === r7.method) {
              if (e8.iterator.return && (r7.method = "return", r7.arg = t6, A2(e8, r7), "throw" === r7.method))
                return m2;
              r7.method = "throw", r7.arg = new TypeError("The iterator does not provide a 'throw' method");
            }
            return m2;
          }
          var o6 = p2(n7, e8.iterator, r7.arg);
          if ("throw" === o6.type)
            return r7.method = "throw", r7.arg = o6.arg, r7.delegate = null, m2;
          var a3 = o6.arg;
          return a3 ? a3.done ? (r7[e8.resultName] = a3.value, r7.next = e8.nextLoc, "return" !== r7.method && (r7.method = "next", r7.arg = t6), r7.delegate = null, m2) : a3 : (r7.method = "throw", r7.arg = new TypeError("iterator result is not an object"), r7.delegate = null, m2);
        }
        function E2(e8) {
          var t7 = { tryLoc: e8[0] };
          1 in e8 && (t7.catchLoc = e8[1]), 2 in e8 && (t7.finallyLoc = e8[2], t7.afterLoc = e8[3]), this.tryEntries.push(t7);
        }
        function O2(e8) {
          var t7 = e8.completion || {};
          t7.type = "normal", delete t7.arg, e8.completion = t7;
        }
        function T3(e8) {
          this.tryEntries = [{ tryLoc: "root" }], e8.forEach(E2, this), this.reset(true);
        }
        function C2(e8) {
          if (e8) {
            var r7 = e8[a2];
            if (r7)
              return r7.call(e8);
            if ("function" == typeof e8.next)
              return e8;
            if (!isNaN(e8.length)) {
              var o6 = -1, i5 = function r8() {
                for (; ++o6 < e8.length; )
                  if (n6.call(e8, o6))
                    return r8.value = e8[o6], r8.done = false, r8;
                return r8.value = t6, r8.done = true, r8;
              };
              return i5.next = i5;
            }
          }
          return { next: j2 };
        }
        function j2() {
          return { value: t6, done: true };
        }
        return g2.prototype = v2, l2($2, "constructor", v2), l2(v2, "constructor", g2), g2.displayName = l2(v2, s6, "GeneratorFunction"), e7.isGeneratorFunction = function(e8) {
          var t7 = "function" == typeof e8 && e8.constructor;
          return !!t7 && (t7 === g2 || "GeneratorFunction" === (t7.displayName || t7.name));
        }, e7.mark = function(e8) {
          return Object.setPrototypeOf ? Object.setPrototypeOf(e8, v2) : (e8.__proto__ = v2, l2(e8, s6, "GeneratorFunction")), e8.prototype = Object.create($2), e8;
        }, e7.awrap = function(e8) {
          return { u: e8 };
        }, k2(S2.prototype), l2(S2.prototype, i4, function() {
          return this;
        }), e7.AsyncIterator = S2, e7.async = function(t7, r7, n7, o6, a3) {
          void 0 === a3 && (a3 = Promise);
          var i5 = new S2(c3(t7, r7, n7, o6), a3);
          return e7.isGeneratorFunction(r7) ? i5 : i5.next().then(function(e8) {
            return e8.done ? e8.value : i5.next();
          });
        }, k2($2), l2($2, s6, "Generator"), l2($2, a2, function() {
          return this;
        }), l2($2, "toString", function() {
          return "[object Generator]";
        }), e7.keys = function(e8) {
          var t7 = [];
          for (var r7 in e8)
            t7.push(r7);
          return t7.reverse(), function r8() {
            for (; t7.length; ) {
              var n7 = t7.pop();
              if (n7 in e8)
                return r8.value = n7, r8.done = false, r8;
            }
            return r8.done = true, r8;
          };
        }, e7.values = C2, T3.prototype = { constructor: T3, reset: function(e8) {
          if (this.prev = 0, this.next = 0, this.sent = this._sent = t6, this.done = false, this.delegate = null, this.method = "next", this.arg = t6, this.tryEntries.forEach(O2), !e8)
            for (var r7 in this)
              "t" === r7.charAt(0) && n6.call(this, r7) && !isNaN(+r7.slice(1)) && (this[r7] = t6);
        }, stop: function() {
          this.done = true;
          var e8 = this.tryEntries[0].completion;
          if ("throw" === e8.type)
            throw e8.arg;
          return this.rval;
        }, dispatchException: function(e8) {
          if (this.done)
            throw e8;
          var r7 = this;
          function o6(n7, o7) {
            return s7.type = "throw", s7.arg = e8, r7.next = n7, o7 && (r7.method = "next", r7.arg = t6), !!o7;
          }
          for (var a3 = this.tryEntries.length - 1; a3 >= 0; --a3) {
            var i5 = this.tryEntries[a3], s7 = i5.completion;
            if ("root" === i5.tryLoc)
              return o6("end");
            if (i5.tryLoc <= this.prev) {
              var l3 = n6.call(i5, "catchLoc"), c4 = n6.call(i5, "finallyLoc");
              if (l3 && c4) {
                if (this.prev < i5.catchLoc)
                  return o6(i5.catchLoc, true);
                if (this.prev < i5.finallyLoc)
                  return o6(i5.finallyLoc);
              } else if (l3) {
                if (this.prev < i5.catchLoc)
                  return o6(i5.catchLoc, true);
              } else {
                if (!c4)
                  throw new Error("try statement without catch or finally");
                if (this.prev < i5.finallyLoc)
                  return o6(i5.finallyLoc);
              }
            }
          }
        }, abrupt: function(e8, t7) {
          for (var r7 = this.tryEntries.length - 1; r7 >= 0; --r7) {
            var o6 = this.tryEntries[r7];
            if (o6.tryLoc <= this.prev && n6.call(o6, "finallyLoc") && this.prev < o6.finallyLoc) {
              var a3 = o6;
              break;
            }
          }
          a3 && ("break" === e8 || "continue" === e8) && a3.tryLoc <= t7 && t7 <= a3.finallyLoc && (a3 = null);
          var i5 = a3 ? a3.completion : {};
          return i5.type = e8, i5.arg = t7, a3 ? (this.method = "next", this.next = a3.finallyLoc, m2) : this.complete(i5);
        }, complete: function(e8, t7) {
          if ("throw" === e8.type)
            throw e8.arg;
          return "break" === e8.type || "continue" === e8.type ? this.next = e8.arg : "return" === e8.type ? (this.rval = this.arg = e8.arg, this.method = "return", this.next = "end") : "normal" === e8.type && t7 && (this.next = t7), m2;
        }, finish: function(e8) {
          for (var t7 = this.tryEntries.length - 1; t7 >= 0; --t7) {
            var r7 = this.tryEntries[t7];
            if (r7.finallyLoc === e8)
              return this.complete(r7.completion, r7.afterLoc), O2(r7), m2;
          }
        }, catch: function(e8) {
          for (var t7 = this.tryEntries.length - 1; t7 >= 0; --t7) {
            var r7 = this.tryEntries[t7];
            if (r7.tryLoc === e8) {
              var n7 = r7.completion;
              if ("throw" === n7.type) {
                var o6 = n7.arg;
                O2(r7);
              }
              return o6;
            }
          }
          throw new Error("illegal catch attempt");
        }, delegateYield: function(e8, r7, n7) {
          return this.delegate = { iterator: C2(e8), resultName: r7, nextLoc: n7 }, "next" === this.method && (this.arg = t6), m2;
        } }, e7;
      }(e6.exports);
      try {
        regeneratorRuntime = t5;
      } catch (e7) {
        "object" == typeof globalThis ? globalThis.regeneratorRuntime = t5 : Function("r", "regeneratorRuntime = r")(t5);
      }
    }(Iv);
    const _v = ut({ exports: {} }.exports = Iv.exports);
    var Pv = Vo.includes;
    Co({ target: "Array", proto: true }, { includes: function(e6) {
      return Pv(this, e6, arguments.length > 1 ? arguments[1] : void 0);
    } });
    var Rv = sc("Array").includes, Lv = Co, Fv = Jd, Dv = Qt, Bv = $a, Nv = Zd, qv = Ot("".indexOf);
    Lv({ target: "String", proto: true, forced: !Nv("includes") }, { includes: function(e6) {
      return !!~qv(Bv(Dv(this)), Bv(Fv(e6)), arguments.length > 1 ? arguments[1] : void 0);
    } });
    var Uv = sc("String").includes, zv = pr, Mv = Rv, Hv = Uv, Wv = Array.prototype, Vv = String.prototype;
    const Gv = ut({ exports: {} }.exports = function(e6) {
      var t5 = e6.includes;
      return e6 === Wv || zv(Wv, e6) && t5 === Wv.includes ? Mv : "string" == typeof e6 || e6 === Vv || zv(Vv, e6) && t5 === Vv.includes ? Hv : t5;
    });
    var Kv = sc("Array").entries, Jv = ba, Yv = Zr, Zv = pr, Qv = Kv, Xv = Array.prototype, eb = { DOMTokenList: true, NodeList: true };
    const tb = ut({ exports: {} }.exports = function(e6) {
      var t5 = e6.entries;
      return e6 === Xv || Zv(Xv, e6) && t5 === Xv.entries || Yv(eb, Jv(e6)) ? Qv : t5;
    });
    const rb = ut({ exports: {} }.exports = Af);
    var nb = Co, ob = cr, ab = wt, ib = Ot, sb = mt, lb = ft.Array, cb = ob("JSON", "stringify"), pb = ib(/./.exec), db = ib("".charAt), ub = ib("".charCodeAt), hb = ib("".replace), fb = ib(1 .toString), mb = /[\uD800-\uDFFF]/g, yb = /^[\uD800-\uDBFF]$/, gb = /^[\uDC00-\uDFFF]$/, vb = function(e6, t5, r6) {
      var n6 = db(r6, t5 - 1), o5 = db(r6, t5 + 1);
      return pb(yb, e6) && !pb(gb, o5) || pb(gb, e6) && !pb(yb, n6) ? "\\u" + fb(ub(e6, 0), 16) : e6;
    }, bb = sb(function() {
      return '"\\udf06\\ud834"' !== cb("\uDF06\uD834") || '"\\udead"' !== cb("\uDEAD");
    });
    cb && nb({ target: "JSON", stat: true, forced: bb }, { stringify: function(e6, t5, r6) {
      for (var n6 = 0, o5 = arguments.length, a2 = lb(o5); n6 < o5; n6++)
        a2[n6] = arguments[n6];
      var i4 = ab(cb, null, a2);
      return "string" == typeof i4 ? hb(i4, mb, vb) : i4;
    } });
    var xb = or, wb = wt;
    xb.JSON || (xb.JSON = { stringify: JSON.stringify });
    const $b = ut({ exports: {} }.exports = function(e6, t5, r6) {
      return wb(xb.JSON.stringify, null, arguments);
    });
    var kb = Ls.map;
    Co({ target: "Array", proto: true, forced: !oc("map") }, { map: function(e6) {
      return kb(this, e6, arguments.length > 1 ? arguments[1] : void 0);
    } });
    var Sb = sc("Array").map, Ab = pr, Eb = Sb, Ob = Array.prototype;
    const Tb = ut({ exports: {} }.exports = function(e6) {
      var t5 = e6.map;
      return e6 === Ob || Ab(Ob, e6) && t5 === Ob.map ? Eb : t5;
    });
    const Cb = ut({ exports: {} }.exports = ia);
    var jb = sc("Array").concat, Ib = pr, _b = jb, Pb = Array.prototype;
    const Rb = ut({ exports: {} }.exports = function(e6) {
      var t5 = e6.concat;
      return e6 === Pb || Ib(Pb, e6) && t5 === Pb.concat ? _b : t5;
    });
    var Lb = jt, Fb = Ot, Db = na, Bb = tr, Nb = Fb(Rt.f), qb = Fb([].push), Ub = function(e6) {
      return function(t5) {
        for (var r6, n6 = Bb(t5), o5 = Db(n6), a2 = o5.length, i4 = 0, s6 = []; a2 > i4; )
          r6 = o5[i4++], Lb && !Nb(n6, r6) || qb(s6, e6 ? [r6, n6[r6]] : n6[r6]);
        return s6;
      };
    }, zb = [Ub(true), Ub(false)][0];
    Co({ target: "Object", stat: true }, { entries: function(e6) {
      return zb(e6);
    } });
    var Mb = or.Object.entries;
    const Hb = ut({ exports: {} }.exports = Mb);
    const Wb = ut({ exports: {} }.exports = uc);
    !function() {
      !function(e6) {
        !function(t5) {
          var r6 = "URLSearchParams" in e6, n6 = "Symbol" in e6 && "iterator" in Symbol, o5 = "FileReader" in e6 && "Blob" in e6 && function() {
            try {
              return new Blob(), true;
            } catch (e7) {
              return false;
            }
          }(), a2 = "FormData" in e6, i4 = "ArrayBuffer" in e6;
          if (i4)
            var s6 = ["[object Int8Array]", "[object Uint8Array]", "[object Uint8ClampedArray]", "[object Int16Array]", "[object Uint16Array]", "[object Int32Array]", "[object Uint32Array]", "[object Float32Array]", "[object Float64Array]"], l2 = ArrayBuffer.isView || function(e7) {
              return e7 && s6.indexOf(Object.prototype.toString.call(e7)) > -1;
            };
          function c3(e7) {
            if ("string" != typeof e7 && (e7 = String(e7)), /[^a-z0-9\-#$%&'*+.^_`|~]/i.test(e7))
              throw new TypeError("Invalid character in header field name");
            return e7.toLowerCase();
          }
          function p2(e7) {
            return "string" != typeof e7 && (e7 = String(e7)), e7;
          }
          function d2(e7) {
            var t6 = { next: function() {
              var t7 = e7.shift();
              return { done: void 0 === t7, value: t7 };
            } };
            return n6 && (t6[Symbol.iterator] = function() {
              return t6;
            }), t6;
          }
          function u3(e7) {
            this.map = {}, e7 instanceof u3 ? e7.forEach(function(e8, t6) {
              this.append(t6, e8);
            }, this) : Array.isArray(e7) ? e7.forEach(function(e8) {
              this.append(e8[0], e8[1]);
            }, this) : e7 && Object.getOwnPropertyNames(e7).forEach(function(t6) {
              this.append(t6, e7[t6]);
            }, this);
          }
          function h2(e7) {
            if (e7.bodyUsed)
              return Promise.reject(new TypeError("Already read"));
            e7.bodyUsed = true;
          }
          function f3(e7) {
            return new Promise(function(t6, r7) {
              e7.onload = function() {
                t6(e7.result);
              }, e7.onerror = function() {
                r7(e7.error);
              };
            });
          }
          function m2(e7) {
            var t6 = new FileReader(), r7 = f3(t6);
            return t6.readAsArrayBuffer(e7), r7;
          }
          function y2(e7) {
            if (e7.slice)
              return e7.slice(0);
            var t6 = new Uint8Array(e7.byteLength);
            return t6.set(new Uint8Array(e7)), t6.buffer;
          }
          function g2() {
            return this.bodyUsed = false, this._initBody = function(e7) {
              var t6;
              this._bodyInit = e7, e7 ? "string" == typeof e7 ? this._bodyText = e7 : o5 && Blob.prototype.isPrototypeOf(e7) ? this._bodyBlob = e7 : a2 && FormData.prototype.isPrototypeOf(e7) ? this._bodyFormData = e7 : r6 && URLSearchParams.prototype.isPrototypeOf(e7) ? this._bodyText = e7.toString() : i4 && o5 && (t6 = e7) && DataView.prototype.isPrototypeOf(t6) ? (this._bodyArrayBuffer = y2(e7.buffer), this._bodyInit = new Blob([this._bodyArrayBuffer])) : i4 && (ArrayBuffer.prototype.isPrototypeOf(e7) || l2(e7)) ? this._bodyArrayBuffer = y2(e7) : this._bodyText = e7 = Object.prototype.toString.call(e7) : this._bodyText = "", this.headers.get("content-type") || ("string" == typeof e7 ? this.headers.set("content-type", "text/plain;charset=UTF-8") : this._bodyBlob && this._bodyBlob.type ? this.headers.set("content-type", this._bodyBlob.type) : r6 && URLSearchParams.prototype.isPrototypeOf(e7) && this.headers.set("content-type", "application/x-www-form-urlencoded;charset=UTF-8"));
            }, o5 && (this.blob = function() {
              var e7 = h2(this);
              if (e7)
                return e7;
              if (this._bodyBlob)
                return Promise.resolve(this._bodyBlob);
              if (this._bodyArrayBuffer)
                return Promise.resolve(new Blob([this._bodyArrayBuffer]));
              if (this._bodyFormData)
                throw new Error("could not read FormData body as blob");
              return Promise.resolve(new Blob([this._bodyText]));
            }, this.arrayBuffer = function() {
              return this._bodyArrayBuffer ? h2(this) || Promise.resolve(this._bodyArrayBuffer) : this.blob().then(m2);
            }), this.text = function() {
              var e7, t6, r7, n7 = h2(this);
              if (n7)
                return n7;
              if (this._bodyBlob)
                return e7 = this._bodyBlob, t6 = new FileReader(), r7 = f3(t6), t6.readAsText(e7), r7;
              if (this._bodyArrayBuffer)
                return Promise.resolve(function(e8) {
                  for (var t7 = new Uint8Array(e8), r8 = new Array(t7.length), n8 = 0; n8 < t7.length; n8++)
                    r8[n8] = String.fromCharCode(t7[n8]);
                  return r8.join("");
                }(this._bodyArrayBuffer));
              if (this._bodyFormData)
                throw new Error("could not read FormData body as text");
              return Promise.resolve(this._bodyText);
            }, a2 && (this.formData = function() {
              return this.text().then(x3);
            }), this.json = function() {
              return this.text().then(JSON.parse);
            }, this;
          }
          u3.prototype.append = function(e7, t6) {
            e7 = c3(e7), t6 = p2(t6);
            var r7 = this.map[e7];
            this.map[e7] = r7 ? r7 + ", " + t6 : t6;
          }, u3.prototype.delete = function(e7) {
            delete this.map[c3(e7)];
          }, u3.prototype.get = function(e7) {
            return e7 = c3(e7), this.has(e7) ? this.map[e7] : null;
          }, u3.prototype.has = function(e7) {
            return this.map.hasOwnProperty(c3(e7));
          }, u3.prototype.set = function(e7, t6) {
            this.map[c3(e7)] = p2(t6);
          }, u3.prototype.forEach = function(e7, t6) {
            for (var r7 in this.map)
              this.map.hasOwnProperty(r7) && e7.call(t6, this.map[r7], r7, this);
          }, u3.prototype.keys = function() {
            var e7 = [];
            return this.forEach(function(t6, r7) {
              e7.push(r7);
            }), d2(e7);
          }, u3.prototype.values = function() {
            var e7 = [];
            return this.forEach(function(t6) {
              e7.push(t6);
            }), d2(e7);
          }, u3.prototype.entries = function() {
            var e7 = [];
            return this.forEach(function(t6, r7) {
              e7.push([r7, t6]);
            }), d2(e7);
          }, n6 && (u3.prototype[Symbol.iterator] = u3.prototype.entries);
          var v2 = ["DELETE", "GET", "HEAD", "OPTIONS", "POST", "PUT"];
          function b2(e7, t6) {
            var r7, n7, o6 = (t6 = t6 || {}).body;
            if (e7 instanceof b2) {
              if (e7.bodyUsed)
                throw new TypeError("Already read");
              this.url = e7.url, this.credentials = e7.credentials, t6.headers || (this.headers = new u3(e7.headers)), this.method = e7.method, this.mode = e7.mode, this.signal = e7.signal, o6 || null == e7._bodyInit || (o6 = e7._bodyInit, e7.bodyUsed = true);
            } else
              this.url = String(e7);
            if (this.credentials = t6.credentials || this.credentials || "same-origin", !t6.headers && this.headers || (this.headers = new u3(t6.headers)), this.method = (r7 = t6.method || this.method || "GET", n7 = r7.toUpperCase(), v2.indexOf(n7) > -1 ? n7 : r7), this.mode = t6.mode || this.mode || null, this.signal = t6.signal || this.signal, this.referrer = null, ("GET" === this.method || "HEAD" === this.method) && o6)
              throw new TypeError("Body not allowed for GET or HEAD requests");
            this._initBody(o6);
          }
          function x3(e7) {
            var t6 = new FormData();
            return e7.trim().split("&").forEach(function(e8) {
              if (e8) {
                var r7 = e8.split("="), n7 = r7.shift().replace(/\+/g, " "), o6 = r7.join("=").replace(/\+/g, " ");
                t6.append(decodeURIComponent(n7), decodeURIComponent(o6));
              }
            }), t6;
          }
          function w2(e7, t6) {
            t6 || (t6 = {}), this.type = "default", this.status = void 0 === t6.status ? 200 : t6.status, this.ok = this.status >= 200 && this.status < 300, this.statusText = "statusText" in t6 ? t6.statusText : "OK", this.headers = new u3(t6.headers), this.url = t6.url || "", this._initBody(e7);
          }
          b2.prototype.clone = function() {
            return new b2(this, { body: this._bodyInit });
          }, g2.call(b2.prototype), g2.call(w2.prototype), w2.prototype.clone = function() {
            return new w2(this._bodyInit, { status: this.status, statusText: this.statusText, headers: new u3(this.headers), url: this.url });
          }, w2.error = function() {
            var e7 = new w2(null, { status: 0, statusText: "" });
            return e7.type = "error", e7;
          };
          var $2 = [301, 302, 303, 307, 308];
          w2.redirect = function(e7, t6) {
            if (-1 === $2.indexOf(t6))
              throw new RangeError("Invalid status code");
            return new w2(null, { status: t6, headers: { location: e7 } });
          }, t5.DOMException = e6.DOMException;
          try {
            new t5.DOMException();
          } catch (e7) {
            t5.DOMException = function(e8, t6) {
              this.message = e8, this.name = t6;
              var r7 = Error(e8);
              this.stack = r7.stack;
            }, t5.DOMException.prototype = Object.create(Error.prototype), t5.DOMException.prototype.constructor = t5.DOMException;
          }
          function k2(e7, r7) {
            return new Promise(function(n7, a3) {
              var i5 = new b2(e7, r7);
              if (i5.signal && i5.signal.aborted)
                return a3(new t5.DOMException("Aborted", "AbortError"));
              var s7 = new XMLHttpRequest();
              function l3() {
                s7.abort();
              }
              s7.onload = function() {
                var e8, t6, r8 = { status: s7.status, statusText: s7.statusText, headers: (e8 = s7.getAllResponseHeaders() || "", t6 = new u3(), e8.replace(/\r?\n[\t ]+/g, " ").split(/\r?\n/).forEach(function(e9) {
                  var r9 = e9.split(":"), n8 = r9.shift().trim();
                  if (n8) {
                    var o7 = r9.join(":").trim();
                    t6.append(n8, o7);
                  }
                }), t6) };
                r8.url = "responseURL" in s7 ? s7.responseURL : r8.headers.get("X-Request-URL");
                var o6 = "response" in s7 ? s7.response : s7.responseText;
                n7(new w2(o6, r8));
              }, s7.onerror = function() {
                a3(new TypeError("Network request failed"));
              }, s7.ontimeout = function() {
                a3(new TypeError("Network request failed"));
              }, s7.onabort = function() {
                a3(new t5.DOMException("Aborted", "AbortError"));
              }, s7.open(i5.method, i5.url, true), "include" === i5.credentials ? s7.withCredentials = true : "omit" === i5.credentials && (s7.withCredentials = false), "responseType" in s7 && o5 && (s7.responseType = "blob"), i5.headers.forEach(function(e8, t6) {
                s7.setRequestHeader(t6, e8);
              }), i5.signal && (i5.signal.addEventListener("abort", l3), s7.onreadystatechange = function() {
                4 === s7.readyState && i5.signal.removeEventListener("abort", l3);
              }), s7.send(void 0 === i5._bodyInit ? null : i5._bodyInit);
            });
          }
          k2.polyfill = true, e6.fetch || (e6.fetch = k2, e6.Headers = u3, e6.Request = b2, e6.Response = w2), t5.Headers = u3, t5.Request = b2, t5.Response = w2, t5.fetch = k2, Object.defineProperty(t5, "t", { value: true });
        }({});
      }("undefined" != typeof self ? self : this);
    }();
    var Vb = "undefined" != typeof Symbol && Symbol, Gb = "Function.prototype.bind called on incompatible ", Kb = Array.prototype.slice, Jb = Object.prototype.toString, Yb = Function.prototype.bind || function(e6) {
      var t5 = this;
      if ("function" != typeof t5 || "[object Function]" !== Jb.call(t5))
        throw new TypeError(Gb + t5);
      for (var r6, n6 = Kb.call(arguments, 1), o5 = function() {
        if (this instanceof r6) {
          var o6 = t5.apply(this, n6.concat(Kb.call(arguments)));
          return Object(o6) === o6 ? o6 : this;
        }
        return t5.apply(e6, n6.concat(Kb.call(arguments)));
      }, a2 = Math.max(0, t5.length - n6.length), i4 = [], s6 = 0; s6 < a2; s6++)
        i4.push("$" + s6);
      if (r6 = Function("binder", "return function (" + i4.join(",") + "){ return binder.apply(this,arguments); }")(o5), t5.prototype) {
        var l2 = function() {
        };
        l2.prototype = t5.prototype, r6.prototype = new l2(), l2.prototype = null;
      }
      return r6;
    }, Zb = Yb.call(Function.call, Object.prototype.hasOwnProperty), Qb = SyntaxError, Xb = Function, ex = TypeError, tx = function(e6) {
      try {
        return Xb('"use strict"; return (' + e6 + ").constructor;")();
      } catch (e7) {
      }
    }, rx = Object.getOwnPropertyDescriptor;
    if (rx)
      try {
        rx({}, "");
      } catch (e6) {
        rx = null;
      }
    var nx = function() {
      throw new ex();
    }, ox = rx ? function() {
      try {
        return nx;
      } catch (e6) {
        try {
          return rx(arguments, "callee").get;
        } catch (e7) {
          return nx;
        }
      }
    }() : nx, ax = "function" == typeof Vb && "function" == typeof Symbol && "symbol" == typeof Vb("foo") && "symbol" == typeof Symbol("bar") && function() {
      if ("function" != typeof Symbol || "function" != typeof Object.getOwnPropertySymbols)
        return false;
      if ("symbol" == typeof Symbol.iterator)
        return true;
      var e6 = {}, t5 = Symbol("test"), r6 = Object(t5);
      if ("string" == typeof t5)
        return false;
      if ("[object Symbol]" !== Object.prototype.toString.call(t5))
        return false;
      if ("[object Symbol]" !== Object.prototype.toString.call(r6))
        return false;
      for (t5 in e6[t5] = 42, e6)
        return false;
      if ("function" == typeof Object.keys && 0 !== Object.keys(e6).length)
        return false;
      if ("function" == typeof Object.getOwnPropertyNames && 0 !== Object.getOwnPropertyNames(e6).length)
        return false;
      var n6 = Object.getOwnPropertySymbols(e6);
      if (1 !== n6.length || n6[0] !== t5)
        return false;
      if (!Object.prototype.propertyIsEnumerable.call(e6, t5))
        return false;
      if ("function" == typeof Object.getOwnPropertyDescriptor) {
        var o5 = Object.getOwnPropertyDescriptor(e6, t5);
        if (42 !== o5.value || true !== o5.enumerable)
          return false;
      }
      return true;
    }(), ix = Object.getPrototypeOf || function(e6) {
      return e6.__proto__;
    }, sx = {}, lx = "undefined" == typeof Uint8Array ? void 0 : ix(Uint8Array), cx = { "%AggregateError%": "undefined" == typeof AggregateError ? void 0 : AggregateError, "%Array%": Array, "%ArrayBuffer%": "undefined" == typeof ArrayBuffer ? void 0 : ArrayBuffer, "%ArrayIteratorPrototype%": ax ? ix([][Symbol.iterator]()) : void 0, "%AsyncFromSyncIteratorPrototype%": void 0, "%AsyncFunction%": sx, "%AsyncGenerator%": sx, "%AsyncGeneratorFunction%": sx, "%AsyncIteratorPrototype%": sx, "%Atomics%": "undefined" == typeof Atomics ? void 0 : Atomics, "%BigInt%": "undefined" == typeof BigInt ? void 0 : BigInt, "%Boolean%": Boolean, "%DataView%": "undefined" == typeof DataView ? void 0 : DataView, "%Date%": Date, "%decodeURI%": decodeURI, "%decodeURIComponent%": decodeURIComponent, "%encodeURI%": encodeURI, "%encodeURIComponent%": encodeURIComponent, "%Error%": Error, "%eval%": eval, "%EvalError%": EvalError, "%Float32Array%": "undefined" == typeof Float32Array ? void 0 : Float32Array, "%Float64Array%": "undefined" == typeof Float64Array ? void 0 : Float64Array, "%FinalizationRegistry%": "undefined" == typeof FinalizationRegistry ? void 0 : FinalizationRegistry, "%Function%": Xb, "%GeneratorFunction%": sx, "%Int8Array%": "undefined" == typeof Int8Array ? void 0 : Int8Array, "%Int16Array%": "undefined" == typeof Int16Array ? void 0 : Int16Array, "%Int32Array%": "undefined" == typeof Int32Array ? void 0 : Int32Array, "%isFinite%": isFinite, "%isNaN%": isNaN, "%IteratorPrototype%": ax ? ix(ix([][Symbol.iterator]())) : void 0, "%JSON%": "object" == typeof JSON ? JSON : void 0, "%Map%": "undefined" == typeof Map ? void 0 : Map, "%MapIteratorPrototype%": "undefined" != typeof Map && ax ? ix((/* @__PURE__ */ new Map())[Symbol.iterator]()) : void 0, "%Math%": Math, "%Number%": Number, "%Object%": Object, "%parseFloat%": parseFloat, "%parseInt%": parseInt, "%Promise%": "undefined" == typeof Promise ? void 0 : Promise, "%Proxy%": "undefined" == typeof Proxy ? void 0 : Proxy, "%RangeError%": RangeError, "%ReferenceError%": ReferenceError, "%Reflect%": "undefined" == typeof Reflect ? void 0 : Reflect, "%RegExp%": RegExp, "%Set%": "undefined" == typeof Set ? void 0 : Set, "%SetIteratorPrototype%": "undefined" != typeof Set && ax ? ix((/* @__PURE__ */ new Set())[Symbol.iterator]()) : void 0, "%SharedArrayBuffer%": "undefined" == typeof SharedArrayBuffer ? void 0 : SharedArrayBuffer, "%String%": String, "%StringIteratorPrototype%": ax ? ix(""[Symbol.iterator]()) : void 0, "%Symbol%": ax ? Symbol : void 0, "%SyntaxError%": Qb, "%ThrowTypeError%": ox, "%TypedArray%": lx, "%TypeError%": ex, "%Uint8Array%": "undefined" == typeof Uint8Array ? void 0 : Uint8Array, "%Uint8ClampedArray%": "undefined" == typeof Uint8ClampedArray ? void 0 : Uint8ClampedArray, "%Uint16Array%": "undefined" == typeof Uint16Array ? void 0 : Uint16Array, "%Uint32Array%": "undefined" == typeof Uint32Array ? void 0 : Uint32Array, "%URIError%": URIError, "%WeakMap%": "undefined" == typeof WeakMap ? void 0 : WeakMap, "%WeakRef%": "undefined" == typeof WeakRef ? void 0 : WeakRef, "%WeakSet%": "undefined" == typeof WeakSet ? void 0 : WeakSet }, px = function e6(t5) {
      var r6;
      if ("%AsyncFunction%" === t5)
        r6 = tx("async function () {}");
      else if ("%GeneratorFunction%" === t5)
        r6 = tx("function* () {}");
      else if ("%AsyncGeneratorFunction%" === t5)
        r6 = tx("async function* () {}");
      else if ("%AsyncGenerator%" === t5) {
        var n6 = e6("%AsyncGeneratorFunction%");
        n6 && (r6 = n6.prototype);
      } else if ("%AsyncIteratorPrototype%" === t5) {
        var o5 = e6("%AsyncGenerator%");
        o5 && (r6 = ix(o5.prototype));
      }
      return cx[t5] = r6, r6;
    }, dx = { "%ArrayBufferPrototype%": ["ArrayBuffer", "prototype"], "%ArrayPrototype%": ["Array", "prototype"], "%ArrayProto_entries%": ["Array", "prototype", "entries"], "%ArrayProto_forEach%": ["Array", "prototype", "forEach"], "%ArrayProto_keys%": ["Array", "prototype", "keys"], "%ArrayProto_values%": ["Array", "prototype", "values"], "%AsyncFunctionPrototype%": ["AsyncFunction", "prototype"], "%AsyncGenerator%": ["AsyncGeneratorFunction", "prototype"], "%AsyncGeneratorPrototype%": ["AsyncGeneratorFunction", "prototype", "prototype"], "%BooleanPrototype%": ["Boolean", "prototype"], "%DataViewPrototype%": ["DataView", "prototype"], "%DatePrototype%": ["Date", "prototype"], "%ErrorPrototype%": ["Error", "prototype"], "%EvalErrorPrototype%": ["EvalError", "prototype"], "%Float32ArrayPrototype%": ["Float32Array", "prototype"], "%Float64ArrayPrototype%": ["Float64Array", "prototype"], "%FunctionPrototype%": ["Function", "prototype"], "%Generator%": ["GeneratorFunction", "prototype"], "%GeneratorPrototype%": ["GeneratorFunction", "prototype", "prototype"], "%Int8ArrayPrototype%": ["Int8Array", "prototype"], "%Int16ArrayPrototype%": ["Int16Array", "prototype"], "%Int32ArrayPrototype%": ["Int32Array", "prototype"], "%JSONParse%": ["JSON", "parse"], "%JSONStringify%": ["JSON", "stringify"], "%MapPrototype%": ["Map", "prototype"], "%NumberPrototype%": ["Number", "prototype"], "%ObjectPrototype%": ["Object", "prototype"], "%ObjProto_toString%": ["Object", "prototype", "toString"], "%ObjProto_valueOf%": ["Object", "prototype", "valueOf"], "%PromisePrototype%": ["Promise", "prototype"], "%PromiseProto_then%": ["Promise", "prototype", "then"], "%Promise_all%": ["Promise", "all"], "%Promise_reject%": ["Promise", "reject"], "%Promise_resolve%": ["Promise", "resolve"], "%RangeErrorPrototype%": ["RangeError", "prototype"], "%ReferenceErrorPrototype%": ["ReferenceError", "prototype"], "%RegExpPrototype%": ["RegExp", "prototype"], "%SetPrototype%": ["Set", "prototype"], "%SharedArrayBufferPrototype%": ["SharedArrayBuffer", "prototype"], "%StringPrototype%": ["String", "prototype"], "%SymbolPrototype%": ["Symbol", "prototype"], "%SyntaxErrorPrototype%": ["SyntaxError", "prototype"], "%TypedArrayPrototype%": ["TypedArray", "prototype"], "%TypeErrorPrototype%": ["TypeError", "prototype"], "%Uint8ArrayPrototype%": ["Uint8Array", "prototype"], "%Uint8ClampedArrayPrototype%": ["Uint8ClampedArray", "prototype"], "%Uint16ArrayPrototype%": ["Uint16Array", "prototype"], "%Uint32ArrayPrototype%": ["Uint32Array", "prototype"], "%URIErrorPrototype%": ["URIError", "prototype"], "%WeakMapPrototype%": ["WeakMap", "prototype"], "%WeakSetPrototype%": ["WeakSet", "prototype"] }, ux = Yb, hx = Zb, fx = ux.call(Function.call, Array.prototype.concat), mx = ux.call(Function.apply, Array.prototype.splice), yx = ux.call(Function.call, String.prototype.replace), gx = ux.call(Function.call, String.prototype.slice), vx = /[^%.[\]]+|\[(?:(-?\d+(?:\.\d+)?)|(["'])((?:(?!\2)[^\\]|\\.)*?)\2)\]|(?=(?:\.|\[\])(?:\.|\[\]|%$))/g, bx = /\\(\\)?/g, xx = function(e6) {
      var t5 = gx(e6, 0, 1), r6 = gx(e6, -1);
      if ("%" === t5 && "%" !== r6)
        throw new Qb("invalid intrinsic syntax, expected closing `%`");
      if ("%" === r6 && "%" !== t5)
        throw new Qb("invalid intrinsic syntax, expected opening `%`");
      var n6 = [];
      return yx(e6, vx, function(e7, t6, r7, o5) {
        n6[n6.length] = r7 ? yx(o5, bx, "$1") : t6 || e7;
      }), n6;
    }, wx = function(e6, t5) {
      var r6, n6 = e6;
      if (hx(dx, n6) && (n6 = "%" + (r6 = dx[n6])[0] + "%"), hx(cx, n6)) {
        var o5 = cx[n6];
        if (o5 === sx && (o5 = px(n6)), void 0 === o5 && !t5)
          throw new ex("intrinsic " + e6 + " exists, but is not available. Please file an issue!");
        return { alias: r6, name: n6, value: o5 };
      }
      throw new Qb("intrinsic " + e6 + " does not exist!");
    }, $x = function(e6, t5) {
      if ("string" != typeof e6 || 0 === e6.length)
        throw new ex("intrinsic name must be a non-empty string");
      if (arguments.length > 1 && "boolean" != typeof t5)
        throw new ex('"allowMissing" argument must be a boolean');
      var r6 = xx(e6), n6 = r6.length > 0 ? r6[0] : "", o5 = wx("%" + n6 + "%", t5), a2 = o5.name, i4 = o5.value, s6 = false, l2 = o5.alias;
      l2 && (n6 = l2[0], mx(r6, fx([0, 1], l2)));
      for (var c3 = 1, p2 = true; c3 < r6.length; c3 += 1) {
        var d2 = r6[c3], u3 = gx(d2, 0, 1), h2 = gx(d2, -1);
        if (('"' === u3 || "'" === u3 || "`" === u3 || '"' === h2 || "'" === h2 || "`" === h2) && u3 !== h2)
          throw new Qb("property names with quotes must have matching quotes");
        if ("constructor" !== d2 && p2 || (s6 = true), hx(cx, a2 = "%" + (n6 += "." + d2) + "%"))
          i4 = cx[a2];
        else if (null != i4) {
          if (!(d2 in i4)) {
            if (!t5)
              throw new ex("base intrinsic for " + e6 + " exists, but the property is not available.");
            return;
          }
          if (rx && c3 + 1 >= r6.length) {
            var f3 = rx(i4, d2);
            i4 = (p2 = !!f3) && "get" in f3 && !("originalValue" in f3.get) ? f3.get : i4[d2];
          } else
            p2 = hx(i4, d2), i4 = i4[d2];
          p2 && !s6 && (cx[a2] = i4);
        }
      }
      return i4;
    }, kx = { exports: {} };
    !function(e6) {
      var t5 = Yb, r6 = $x, n6 = r6("%Function.prototype.apply%"), o5 = r6("%Function.prototype.call%"), a2 = r6("%Reflect.apply%", true) || t5.call(o5, n6), i4 = r6("%Object.getOwnPropertyDescriptor%", true), s6 = r6("%Object.defineProperty%", true), l2 = r6("%Math.max%");
      if (s6)
        try {
          s6({}, "a", { value: 1 });
        } catch (e7) {
          s6 = null;
        }
      e6.exports = function(e7) {
        var r7 = a2(t5, o5, arguments);
        if (i4 && s6) {
          var n7 = i4(r7, "length");
          n7.configurable && s6(r7, "length", { value: 1 + l2(0, e7.length - (arguments.length - 1)) });
        }
        return r7;
      };
      var c3 = function() {
        return a2(t5, n6, arguments);
      };
      s6 ? s6(e6.exports, "apply", { value: c3 }) : e6.exports.apply = c3;
    }(kx);
    var Sx = $x, Ax = kx.exports, Ex = Ax(Sx("String.prototype.indexOf"));
    const Ox = function(e6) {
      var t5 = e6.default;
      if ("function" == typeof t5) {
        var r6 = function() {
          return t5.apply(this, arguments);
        };
        r6.prototype = t5.prototype;
      } else
        r6 = {};
      return Object.defineProperty(r6, "t", { value: true }), Object.keys(e6).forEach(function(t6) {
        var n6 = Object.getOwnPropertyDescriptor(e6, t6);
        Object.defineProperty(r6, t6, n6.get ? n6 : { enumerable: true, get: function() {
          return e6[t6];
        } });
      }), r6;
    }(Object.freeze(Object.defineProperty({ __proto__: null, default: {} }, Symbol.toStringTag, { value: "Module" })));
    var Tx = "function" == typeof Map && Map.prototype, Cx = Object.getOwnPropertyDescriptor && Tx ? Object.getOwnPropertyDescriptor(Map.prototype, "size") : null, jx = Tx && Cx && "function" == typeof Cx.get ? Cx.get : null, Ix = Tx && Map.prototype.forEach, _x = "function" == typeof Set && Set.prototype, Px = Object.getOwnPropertyDescriptor && _x ? Object.getOwnPropertyDescriptor(Set.prototype, "size") : null, Rx = _x && Px && "function" == typeof Px.get ? Px.get : null, Lx = _x && Set.prototype.forEach, Fx = "function" == typeof WeakMap && WeakMap.prototype ? WeakMap.prototype.has : null, Dx = "function" == typeof WeakSet && WeakSet.prototype ? WeakSet.prototype.has : null, Bx = "function" == typeof WeakRef && WeakRef.prototype ? WeakRef.prototype.deref : null, Nx = Boolean.prototype.valueOf, qx = Object.prototype.toString, Ux = Function.prototype.toString, zx = String.prototype.match, Mx = String.prototype.slice, Hx = String.prototype.replace, Wx = String.prototype.toUpperCase, Vx = String.prototype.toLowerCase, Gx = RegExp.prototype.test, Kx = Array.prototype.concat, Jx = Array.prototype.join, Yx = Array.prototype.slice, Zx = Math.floor, Qx = "function" == typeof BigInt ? BigInt.prototype.valueOf : null, Xx = Object.getOwnPropertySymbols, ew = "function" == typeof Symbol && "symbol" == typeof Symbol.iterator ? Symbol.prototype.toString : null, tw = "function" == typeof Symbol && "object" == typeof Symbol.iterator, rw = "function" == typeof Symbol && Symbol.toStringTag && (Symbol.toStringTag, 1) ? Symbol.toStringTag : null, nw = Object.prototype.propertyIsEnumerable, ow = ("function" == typeof Reflect ? Reflect.getPrototypeOf : Object.getPrototypeOf) || ([].__proto__ === Array.prototype ? function(e6) {
      return e6.__proto__;
    } : null);
    function aw(e6, t5) {
      if (e6 === 1 / 0 || e6 === -1 / 0 || e6 != e6 || e6 && e6 > -1e3 && e6 < 1e3 || Gx.call(/e/, t5))
        return t5;
      var r6 = /[0-9](?=(?:[0-9]{3})+(?![0-9]))/g;
      if ("number" == typeof e6) {
        var n6 = e6 < 0 ? -Zx(-e6) : Zx(e6);
        if (n6 !== e6) {
          var o5 = String(n6), a2 = Mx.call(t5, o5.length + 1);
          return Hx.call(o5, r6, "$&_") + "." + Hx.call(Hx.call(a2, /([0-9]{3})/g, "$&_"), /_$/, "");
        }
      }
      return Hx.call(t5, r6, "$&_");
    }
    var iw = Ox.custom, sw = iw && dw(iw) ? iw : null;
    function lw(e6, t5, r6) {
      var n6 = "double" === (r6.quoteStyle || t5) ? '"' : "'";
      return n6 + e6 + n6;
    }
    function cw(e6) {
      return Hx.call(String(e6), /"/g, "&quot;");
    }
    function pw(e6) {
      return !("[object Array]" !== fw(e6) || rw && "object" == typeof e6 && rw in e6);
    }
    function dw(e6) {
      if (tw)
        return e6 && "object" == typeof e6 && e6 instanceof Symbol;
      if ("symbol" == typeof e6)
        return true;
      if (!e6 || "object" != typeof e6 || !ew)
        return false;
      try {
        return ew.call(e6), true;
      } catch (e7) {
      }
      return false;
    }
    var uw = Object.prototype.hasOwnProperty || function(e6) {
      return e6 in this;
    };
    function hw(e6, t5) {
      return uw.call(e6, t5);
    }
    function fw(e6) {
      return qx.call(e6);
    }
    function mw(e6, t5) {
      if (e6.indexOf)
        return e6.indexOf(t5);
      for (var r6 = 0, n6 = e6.length; r6 < n6; r6++)
        if (e6[r6] === t5)
          return r6;
      return -1;
    }
    function yw(e6, t5) {
      if (e6.length > t5.maxStringLength) {
        var r6 = e6.length - t5.maxStringLength, n6 = "... " + r6 + " more character" + (r6 > 1 ? "s" : "");
        return yw(Mx.call(e6, 0, t5.maxStringLength), t5) + n6;
      }
      return lw(Hx.call(Hx.call(e6, /(['\\])/g, "\\$1"), /[\x00-\x1f]/g, gw), "single", t5);
    }
    function gw(e6) {
      var t5 = e6.charCodeAt(0), r6 = { 8: "b", 9: "t", 10: "n", 12: "f", 13: "r" }[t5];
      return r6 ? "\\" + r6 : "\\x" + (t5 < 16 ? "0" : "") + Wx.call(t5.toString(16));
    }
    function vw(e6) {
      return "Object(" + e6 + ")";
    }
    function bw(e6) {
      return e6 + " { ? }";
    }
    function xw(e6, t5, r6, n6) {
      return e6 + " (" + t5 + ") {" + (n6 ? ww(r6, n6) : Jx.call(r6, ", ")) + "}";
    }
    function ww(e6, t5) {
      if (0 === e6.length)
        return "";
      var r6 = "\n" + t5.prev + t5.base;
      return r6 + Jx.call(e6, "," + r6) + "\n" + t5.prev;
    }
    function $w(e6, t5) {
      var r6 = pw(e6), n6 = [];
      if (r6) {
        n6.length = e6.length;
        for (var o5 = 0; o5 < e6.length; o5++)
          n6[o5] = hw(e6, o5) ? t5(e6[o5], e6) : "";
      }
      var a2, i4 = "function" == typeof Xx ? Xx(e6) : [];
      if (tw) {
        a2 = {};
        for (var s6 = 0; s6 < i4.length; s6++)
          a2["$" + i4[s6]] = i4[s6];
      }
      for (var l2 in e6)
        hw(e6, l2) && (r6 && String(Number(l2)) === l2 && l2 < e6.length || tw && a2["$" + l2] instanceof Symbol || (Gx.call(/[^\w$]/, l2) ? n6.push(t5(l2, e6) + ": " + t5(e6[l2], e6)) : n6.push(l2 + ": " + t5(e6[l2], e6))));
      if ("function" == typeof Xx)
        for (var c3 = 0; c3 < i4.length; c3++)
          nw.call(e6, i4[c3]) && n6.push("[" + t5(i4[c3]) + "]: " + t5(e6[i4[c3]], e6));
      return n6;
    }
    var kw = $x, Sw = function(e6, t5) {
      var r6 = Sx(e6, !!t5);
      return "function" == typeof r6 && Ex(e6, ".prototype.") > -1 ? Ax(r6) : r6;
    }, Aw = function e6(t5, r6, n6, o5) {
      var a2 = r6 || {};
      if (hw(a2, "quoteStyle") && "single" !== a2.quoteStyle && "double" !== a2.quoteStyle)
        throw new TypeError('option "quoteStyle" must be "single" or "double"');
      if (hw(a2, "maxStringLength") && ("number" == typeof a2.maxStringLength ? a2.maxStringLength < 0 && a2.maxStringLength !== 1 / 0 : null !== a2.maxStringLength))
        throw new TypeError('option "maxStringLength", if provided, must be a positive integer, Infinity, or `null`');
      var i4 = !hw(a2, "customInspect") || a2.customInspect;
      if ("boolean" != typeof i4 && "symbol" !== i4)
        throw new TypeError("option \"customInspect\", if provided, must be `true`, `false`, or `'symbol'`");
      if (hw(a2, "indent") && null !== a2.indent && "	" !== a2.indent && !(parseInt(a2.indent, 10) === a2.indent && a2.indent > 0))
        throw new TypeError('option "indent" must be "\\t", an integer > 0, or `null`');
      if (hw(a2, "numericSeparator") && "boolean" != typeof a2.numericSeparator)
        throw new TypeError('option "numericSeparator", if provided, must be `true` or `false`');
      var s6 = a2.numericSeparator;
      if (void 0 === t5)
        return "undefined";
      if (null === t5)
        return "null";
      if ("boolean" == typeof t5)
        return t5 ? "true" : "false";
      if ("string" == typeof t5)
        return yw(t5, a2);
      if ("number" == typeof t5) {
        if (0 === t5)
          return 1 / 0 / t5 > 0 ? "0" : "-0";
        var l2 = String(t5);
        return s6 ? aw(t5, l2) : l2;
      }
      if ("bigint" == typeof t5) {
        var c3 = String(t5) + "n";
        return s6 ? aw(t5, c3) : c3;
      }
      var p2 = void 0 === a2.depth ? 5 : a2.depth;
      if (void 0 === n6 && (n6 = 0), n6 >= p2 && p2 > 0 && "object" == typeof t5)
        return pw(t5) ? "[Array]" : "[Object]";
      var d2 = function(e7, t6) {
        var r7;
        if ("	" === e7.indent)
          r7 = "	";
        else {
          if (!("number" == typeof e7.indent && e7.indent > 0))
            return null;
          r7 = Jx.call(Array(e7.indent + 1), " ");
        }
        return { base: r7, prev: Jx.call(Array(t6 + 1), r7) };
      }(a2, n6);
      if (void 0 === o5)
        o5 = [];
      else if (mw(o5, t5) >= 0)
        return "[Circular]";
      function u3(t6, r7, i5) {
        if (r7 && (o5 = Yx.call(o5)).push(r7), i5) {
          var s7 = { depth: a2.depth };
          return hw(a2, "quoteStyle") && (s7.quoteStyle = a2.quoteStyle), e6(t6, s7, n6 + 1, o5);
        }
        return e6(t6, a2, n6 + 1, o5);
      }
      if ("function" == typeof t5) {
        var h2 = function(e7) {
          if (e7.name)
            return e7.name;
          var t6 = zx.call(Ux.call(e7), /^function\s*([\w$]+)/);
          return t6 ? t6[1] : null;
        }(t5), f3 = $w(t5, u3);
        return "[Function" + (h2 ? ": " + h2 : " (anonymous)") + "]" + (f3.length > 0 ? " { " + Jx.call(f3, ", ") + " }" : "");
      }
      if (dw(t5)) {
        var m2 = tw ? Hx.call(String(t5), /^(Symbol\(.*\))_[^)]*$/, "$1") : ew.call(t5);
        return "object" != typeof t5 || tw ? m2 : vw(m2);
      }
      if (function(e7) {
        return !(!e7 || "object" != typeof e7) && ("undefined" != typeof HTMLElement && e7 instanceof HTMLElement || "string" == typeof e7.nodeName && "function" == typeof e7.getAttribute);
      }(t5)) {
        for (var y2 = "<" + Vx.call(String(t5.nodeName)), g2 = t5.attributes || [], v2 = 0; v2 < g2.length; v2++)
          y2 += " " + g2[v2].name + "=" + lw(cw(g2[v2].value), "double", a2);
        return y2 += ">", t5.childNodes && t5.childNodes.length && (y2 += "..."), y2 + "</" + Vx.call(String(t5.nodeName)) + ">";
      }
      if (pw(t5)) {
        if (0 === t5.length)
          return "[]";
        var b2 = $w(t5, u3);
        return d2 && !function(e7) {
          for (var t6 = 0; t6 < e7.length; t6++)
            if (mw(e7[t6], "\n") >= 0)
              return false;
          return true;
        }(b2) ? "[" + ww(b2, d2) + "]" : "[ " + Jx.call(b2, ", ") + " ]";
      }
      if (function(e7) {
        return !("[object Error]" !== fw(e7) || rw && "object" == typeof e7 && rw in e7);
      }(t5)) {
        var x3 = $w(t5, u3);
        return "cause" in t5 && !nw.call(t5, "cause") ? "{ [" + String(t5) + "] " + Jx.call(Kx.call("[cause]: " + u3(t5.cause), x3), ", ") + " }" : 0 === x3.length ? "[" + String(t5) + "]" : "{ [" + String(t5) + "] " + Jx.call(x3, ", ") + " }";
      }
      if ("object" == typeof t5 && i4) {
        if (sw && "function" == typeof t5[sw])
          return t5[sw]();
        if ("symbol" !== i4 && "function" == typeof t5.inspect)
          return t5.inspect();
      }
      if (function(e7) {
        if (!jx || !e7 || "object" != typeof e7)
          return false;
        try {
          jx.call(e7);
          try {
            Rx.call(e7);
          } catch (e8) {
            return true;
          }
          return e7 instanceof Map;
        } catch (e8) {
        }
        return false;
      }(t5)) {
        var w2 = [];
        return Ix.call(t5, function(e7, r7) {
          w2.push(u3(r7, t5, true) + " => " + u3(e7, t5));
        }), xw("Map", jx.call(t5), w2, d2);
      }
      if (function(e7) {
        if (!Rx || !e7 || "object" != typeof e7)
          return false;
        try {
          Rx.call(e7);
          try {
            jx.call(e7);
          } catch (e8) {
            return true;
          }
          return e7 instanceof Set;
        } catch (e8) {
        }
        return false;
      }(t5)) {
        var $2 = [];
        return Lx.call(t5, function(e7) {
          $2.push(u3(e7, t5));
        }), xw("Set", Rx.call(t5), $2, d2);
      }
      if (function(e7) {
        if (!Fx || !e7 || "object" != typeof e7)
          return false;
        try {
          Fx.call(e7, Fx);
          try {
            Dx.call(e7, Dx);
          } catch (e8) {
            return true;
          }
          return e7 instanceof WeakMap;
        } catch (e8) {
        }
        return false;
      }(t5))
        return bw("WeakMap");
      if (function(e7) {
        if (!Dx || !e7 || "object" != typeof e7)
          return false;
        try {
          Dx.call(e7, Dx);
          try {
            Fx.call(e7, Fx);
          } catch (e8) {
            return true;
          }
          return e7 instanceof WeakSet;
        } catch (e8) {
        }
        return false;
      }(t5))
        return bw("WeakSet");
      if (function(e7) {
        if (!Bx || !e7 || "object" != typeof e7)
          return false;
        try {
          return Bx.call(e7), true;
        } catch (e8) {
        }
        return false;
      }(t5))
        return bw("WeakRef");
      if (function(e7) {
        return !("[object Number]" !== fw(e7) || rw && "object" == typeof e7 && rw in e7);
      }(t5))
        return vw(u3(Number(t5)));
      if (function(e7) {
        if (!e7 || "object" != typeof e7 || !Qx)
          return false;
        try {
          return Qx.call(e7), true;
        } catch (e8) {
        }
        return false;
      }(t5))
        return vw(u3(Qx.call(t5)));
      if (function(e7) {
        return !("[object Boolean]" !== fw(e7) || rw && "object" == typeof e7 && rw in e7);
      }(t5))
        return vw(Nx.call(t5));
      if (function(e7) {
        return !("[object String]" !== fw(e7) || rw && "object" == typeof e7 && rw in e7);
      }(t5))
        return vw(u3(String(t5)));
      if (!function(e7) {
        return !("[object Date]" !== fw(e7) || rw && "object" == typeof e7 && rw in e7);
      }(t5) && !function(e7) {
        return !("[object RegExp]" !== fw(e7) || rw && "object" == typeof e7 && rw in e7);
      }(t5)) {
        var k2 = $w(t5, u3), S2 = ow ? ow(t5) === Object.prototype : t5 instanceof Object || t5.constructor === Object, A2 = t5 instanceof Object ? "" : "null prototype", E2 = !S2 && rw && Object(t5) === t5 && rw in t5 ? Mx.call(fw(t5), 8, -1) : A2 ? "Object" : "", O2 = (S2 || "function" != typeof t5.constructor ? "" : t5.constructor.name ? t5.constructor.name + " " : "") + (E2 || A2 ? "[" + Jx.call(Kx.call([], E2 || [], A2 || []), ": ") + "] " : "");
        return 0 === k2.length ? O2 + "{}" : d2 ? O2 + "{" + ww(k2, d2) + "}" : O2 + "{ " + Jx.call(k2, ", ") + " }";
      }
      return String(t5);
    }, Ew = kw("%TypeError%"), Ow = kw("%WeakMap%", true), Tw = kw("%Map%", true), Cw = Sw("WeakMap.prototype.get", true), jw = Sw("WeakMap.prototype.set", true), Iw = Sw("WeakMap.prototype.has", true), _w = Sw("Map.prototype.get", true), Pw = Sw("Map.prototype.set", true), Rw = Sw("Map.prototype.has", true), Lw = function(e6, t5) {
      for (var r6, n6 = e6; null !== (r6 = n6.next); n6 = r6)
        if (r6.key === t5)
          return n6.next = r6.next, r6.next = e6.next, e6.next = r6, r6;
    }, Fw = String.prototype.replace, Dw = /%20/g, Bw = "RFC3986", Nw = { default: Bw, formatters: { RFC1738: function(e6) {
      return Fw.call(e6, Dw, "+");
    }, RFC3986: function(e6) {
      return String(e6);
    } }, RFC1738: "RFC1738", RFC3986: Bw }, qw = Nw, Uw = Object.prototype.hasOwnProperty, zw = Array.isArray, Mw = function() {
      for (var e6 = [], t5 = 0; t5 < 256; ++t5)
        e6.push("%" + ((t5 < 16 ? "0" : "") + t5.toString(16)).toUpperCase());
      return e6;
    }(), Hw = function(e6, t5) {
      for (var r6 = t5 && t5.plainObjects ? /* @__PURE__ */ Object.create(null) : {}, n6 = 0; n6 < e6.length; ++n6)
        void 0 !== e6[n6] && (r6[n6] = e6[n6]);
      return r6;
    }, Ww = { arrayToObject: Hw, assign: function(e6, t5) {
      return Object.keys(t5).reduce(function(e7, r6) {
        return e7[r6] = t5[r6], e7;
      }, e6);
    }, combine: function(e6, t5) {
      return [].concat(e6, t5);
    }, compact: function(e6) {
      for (var t5 = [{ obj: { o: e6 }, prop: "o" }], r6 = [], n6 = 0; n6 < t5.length; ++n6)
        for (var o5 = t5[n6], a2 = o5.obj[o5.prop], i4 = Object.keys(a2), s6 = 0; s6 < i4.length; ++s6) {
          var l2 = i4[s6], c3 = a2[l2];
          "object" == typeof c3 && null !== c3 && -1 === r6.indexOf(c3) && (t5.push({ obj: a2, prop: l2 }), r6.push(c3));
        }
      return function(e7) {
        for (; e7.length > 1; ) {
          var t6 = e7.pop(), r7 = t6.obj[t6.prop];
          if (zw(r7)) {
            for (var n7 = [], o6 = 0; o6 < r7.length; ++o6)
              void 0 !== r7[o6] && n7.push(r7[o6]);
            t6.obj[t6.prop] = n7;
          }
        }
      }(t5), e6;
    }, decode: function(e6, t5, r6) {
      var n6 = e6.replace(/\+/g, " ");
      if ("iso-8859-1" === r6)
        return n6.replace(/%[0-9a-f]{2}/gi, unescape);
      try {
        return decodeURIComponent(n6);
      } catch (e7) {
        return n6;
      }
    }, encode: function(e6, t5, r6, n6, o5) {
      if (0 === e6.length)
        return e6;
      var a2 = e6;
      if ("symbol" == typeof e6 ? a2 = Symbol.prototype.toString.call(e6) : "string" != typeof e6 && (a2 = String(e6)), "iso-8859-1" === r6)
        return escape(a2).replace(/%u[0-9a-f]{4}/gi, function(e7) {
          return "%26%23" + parseInt(e7.slice(2), 16) + "%3B";
        });
      for (var i4 = "", s6 = 0; s6 < a2.length; ++s6) {
        var l2 = a2.charCodeAt(s6);
        45 === l2 || 46 === l2 || 95 === l2 || 126 === l2 || l2 >= 48 && l2 <= 57 || l2 >= 65 && l2 <= 90 || l2 >= 97 && l2 <= 122 || o5 === qw.RFC1738 && (40 === l2 || 41 === l2) ? i4 += a2.charAt(s6) : l2 < 128 ? i4 += Mw[l2] : l2 < 2048 ? i4 += Mw[192 | l2 >> 6] + Mw[128 | 63 & l2] : l2 < 55296 || l2 >= 57344 ? i4 += Mw[224 | l2 >> 12] + Mw[128 | l2 >> 6 & 63] + Mw[128 | 63 & l2] : (s6 += 1, l2 = 65536 + ((1023 & l2) << 10 | 1023 & a2.charCodeAt(s6)), i4 += Mw[240 | l2 >> 18] + Mw[128 | l2 >> 12 & 63] + Mw[128 | l2 >> 6 & 63] + Mw[128 | 63 & l2]);
      }
      return i4;
    }, isBuffer: function(e6) {
      return !(!e6 || "object" != typeof e6 || !(e6.constructor && e6.constructor.isBuffer && e6.constructor.isBuffer(e6)));
    }, isRegExp: function(e6) {
      return "[object RegExp]" === Object.prototype.toString.call(e6);
    }, maybeMap: function(e6, t5) {
      if (zw(e6)) {
        for (var r6 = [], n6 = 0; n6 < e6.length; n6 += 1)
          r6.push(t5(e6[n6]));
        return r6;
      }
      return t5(e6);
    }, merge: function e6(t5, r6, n6) {
      if (!r6)
        return t5;
      if ("object" != typeof r6) {
        if (zw(t5))
          t5.push(r6);
        else {
          if (!t5 || "object" != typeof t5)
            return [t5, r6];
          (n6 && (n6.plainObjects || n6.allowPrototypes) || !Uw.call(Object.prototype, r6)) && (t5[r6] = true);
        }
        return t5;
      }
      if (!t5 || "object" != typeof t5)
        return [t5].concat(r6);
      var o5 = t5;
      return zw(t5) && !zw(r6) && (o5 = Hw(t5, n6)), zw(t5) && zw(r6) ? (r6.forEach(function(r7, o6) {
        if (Uw.call(t5, o6)) {
          var a2 = t5[o6];
          a2 && "object" == typeof a2 && r7 && "object" == typeof r7 ? t5[o6] = e6(a2, r7, n6) : t5.push(r7);
        } else
          t5[o6] = r7;
      }), t5) : Object.keys(r6).reduce(function(t6, o6) {
        var a2 = r6[o6];
        return Uw.call(t6, o6) ? t6[o6] = e6(t6[o6], a2, n6) : t6[o6] = a2, t6;
      }, o5);
    } }, Vw = function() {
      var e6, t5, r6, n6 = { assert: function(e7) {
        if (!n6.has(e7))
          throw new Ew("Side channel does not contain " + Aw(e7));
      }, get: function(n7) {
        if (Ow && n7 && ("object" == typeof n7 || "function" == typeof n7)) {
          if (e6)
            return Cw(e6, n7);
        } else if (Tw) {
          if (t5)
            return _w(t5, n7);
        } else if (r6)
          return (o5 = Lw(r6, n7)) && o5.value;
        var o5;
      }, has: function(n7) {
        if (Ow && n7 && ("object" == typeof n7 || "function" == typeof n7)) {
          if (e6)
            return Iw(e6, n7);
        } else if (Tw) {
          if (t5)
            return Rw(t5, n7);
        } else if (r6)
          return !!Lw(r6, n7);
        return false;
      }, set: function(n7, o5) {
        var a2, i4, s6, l2;
        Ow && n7 && ("object" == typeof n7 || "function" == typeof n7) ? (e6 || (e6 = new Ow()), jw(e6, n7, o5)) : Tw ? (t5 || (t5 = new Tw()), Pw(t5, n7, o5)) : (r6 || (r6 = { key: {}, next: null }), s6 = o5, (l2 = Lw(a2 = r6, i4 = n7)) ? l2.value = s6 : a2.next = { key: i4, next: a2.next, value: s6 });
      } };
      return n6;
    }, Gw = Ww, Kw = Nw, Jw = Object.prototype.hasOwnProperty, Yw = { brackets: function(e6) {
      return e6 + "[]";
    }, comma: "comma", indices: function(e6, t5) {
      return e6 + "[" + t5 + "]";
    }, repeat: function(e6) {
      return e6;
    } }, Zw = Array.isArray, Qw = String.prototype.split, Xw = Array.prototype.push, e$ = function(e6, t5) {
      Xw.apply(e6, Zw(t5) ? t5 : [t5]);
    }, t$ = Date.prototype.toISOString, r$ = Kw.default, n$ = { addQueryPrefix: false, allowDots: false, charset: "utf-8", charsetSentinel: false, delimiter: "&", encode: true, encoder: Gw.encode, encodeValuesOnly: false, format: r$, formatter: Kw.formatters[r$], indices: false, serializeDate: function(e6) {
      return t$.call(e6);
    }, skipNulls: false, strictNullHandling: false }, o$ = {}, a$ = function e6(t5, r6, n6, o5, a2, i4, s6, l2, c3, p2, d2, u3, h2, f3, m2) {
      for (var y2, g2 = t5, v2 = m2, b2 = 0, x3 = false; void 0 !== (v2 = v2.get(o$)) && !x3; ) {
        var w2 = v2.get(t5);
        if (b2 += 1, void 0 !== w2) {
          if (w2 === b2)
            throw new RangeError("Cyclic object value");
          x3 = true;
        }
        void 0 === v2.get(o$) && (b2 = 0);
      }
      if ("function" == typeof s6 ? g2 = s6(r6, g2) : g2 instanceof Date ? g2 = p2(g2) : "comma" === n6 && Zw(g2) && (g2 = Gw.maybeMap(g2, function(e7) {
        return e7 instanceof Date ? p2(e7) : e7;
      })), null === g2) {
        if (o5)
          return i4 && !h2 ? i4(r6, n$.encoder, f3, "key", d2) : r6;
        g2 = "";
      }
      if ("string" == typeof (y2 = g2) || "number" == typeof y2 || "boolean" == typeof y2 || "symbol" == typeof y2 || "bigint" == typeof y2 || Gw.isBuffer(g2)) {
        if (i4) {
          var $2 = h2 ? r6 : i4(r6, n$.encoder, f3, "key", d2);
          if ("comma" === n6 && h2) {
            for (var k2 = Qw.call(String(g2), ","), S2 = "", A2 = 0; A2 < k2.length; ++A2)
              S2 += (0 === A2 ? "" : ",") + u3(i4(k2[A2], n$.encoder, f3, "value", d2));
            return [u3($2) + "=" + S2];
          }
          return [u3($2) + "=" + u3(i4(g2, n$.encoder, f3, "value", d2))];
        }
        return [u3(r6) + "=" + u3(String(g2))];
      }
      var E2, O2 = [];
      if (void 0 === g2)
        return O2;
      if ("comma" === n6 && Zw(g2))
        E2 = [{ value: g2.length > 0 ? g2.join(",") || null : void 0 }];
      else if (Zw(s6))
        E2 = s6;
      else {
        var T3 = Object.keys(g2);
        E2 = l2 ? T3.sort(l2) : T3;
      }
      for (var C2 = 0; C2 < E2.length; ++C2) {
        var j2 = E2[C2], I2 = "object" == typeof j2 && void 0 !== j2.value ? j2.value : g2[j2];
        if (!a2 || null !== I2) {
          var _2 = Zw(g2) ? "function" == typeof n6 ? n6(r6, j2) : r6 : r6 + (c3 ? "." + j2 : "[" + j2 + "]");
          m2.set(t5, b2);
          var P2 = Vw();
          P2.set(o$, m2), e$(O2, e6(I2, _2, n6, o5, a2, i4, s6, l2, c3, p2, d2, u3, h2, f3, P2));
        }
      }
      return O2;
    }, i$ = Ww, s$ = Object.prototype.hasOwnProperty, l$ = Array.isArray, c$ = { allowDots: false, allowPrototypes: false, allowSparse: false, arrayLimit: 20, charset: "utf-8", charsetSentinel: false, comma: false, decoder: i$.decode, delimiter: "&", depth: 5, ignoreQueryPrefix: false, interpretNumericEntities: false, parameterLimit: 1e3, parseArrays: true, plainObjects: false, strictNullHandling: false }, p$ = function(e6) {
      return e6.replace(/&#(\d+);/g, function(e7, t5) {
        return String.fromCharCode(parseInt(t5, 10));
      });
    }, d$ = function(e6, t5) {
      return e6 && "string" == typeof e6 && t5.comma && e6.indexOf(",") > -1 ? e6.split(",") : e6;
    }, u$ = function(e6, t5, r6, n6) {
      if (e6) {
        var o5 = r6.allowDots ? e6.replace(/\.([^.[]+)/g, "[$1]") : e6, a2 = /(\[[^[\]]*])/g, i4 = r6.depth > 0 && /(\[[^[\]]*])/.exec(o5), s6 = i4 ? o5.slice(0, i4.index) : o5, l2 = [];
        if (s6) {
          if (!r6.plainObjects && s$.call(Object.prototype, s6) && !r6.allowPrototypes)
            return;
          l2.push(s6);
        }
        for (var c3 = 0; r6.depth > 0 && null !== (i4 = a2.exec(o5)) && c3 < r6.depth; ) {
          if (c3 += 1, !r6.plainObjects && s$.call(Object.prototype, i4[1].slice(1, -1)) && !r6.allowPrototypes)
            return;
          l2.push(i4[1]);
        }
        return i4 && l2.push("[" + o5.slice(i4.index) + "]"), function(e7, t6, r7, n7) {
          for (var o6 = n7 ? t6 : d$(t6, r7), a3 = e7.length - 1; a3 >= 0; --a3) {
            var i5, s7 = e7[a3];
            if ("[]" === s7 && r7.parseArrays)
              i5 = [].concat(o6);
            else {
              i5 = r7.plainObjects ? /* @__PURE__ */ Object.create(null) : {};
              var l3 = "[" === s7.charAt(0) && "]" === s7.charAt(s7.length - 1) ? s7.slice(1, -1) : s7, c4 = parseInt(l3, 10);
              r7.parseArrays || "" !== l3 ? !isNaN(c4) && s7 !== l3 && String(c4) === l3 && c4 >= 0 && r7.parseArrays && c4 <= r7.arrayLimit ? (i5 = [])[c4] = o6 : "__proto__" !== l3 && (i5[l3] = o6) : i5 = { 0: o6 };
            }
            o6 = i5;
          }
          return o6;
        }(l2, t5, r6, n6);
      }
    }, h$ = function(e6, t5) {
      var r6 = function(e7) {
        if (!e7)
          return c$;
        if (null !== e7.decoder && void 0 !== e7.decoder && "function" != typeof e7.decoder)
          throw new TypeError("Decoder has to be a function.");
        if (void 0 !== e7.charset && "utf-8" !== e7.charset && "iso-8859-1" !== e7.charset)
          throw new TypeError("The charset option must be either utf-8, iso-8859-1, or undefined");
        var t6 = void 0 === e7.charset ? c$.charset : e7.charset;
        return { allowDots: void 0 === e7.allowDots ? c$.allowDots : !!e7.allowDots, allowPrototypes: "boolean" == typeof e7.allowPrototypes ? e7.allowPrototypes : c$.allowPrototypes, allowSparse: "boolean" == typeof e7.allowSparse ? e7.allowSparse : c$.allowSparse, arrayLimit: "number" == typeof e7.arrayLimit ? e7.arrayLimit : c$.arrayLimit, charset: t6, charsetSentinel: "boolean" == typeof e7.charsetSentinel ? e7.charsetSentinel : c$.charsetSentinel, comma: "boolean" == typeof e7.comma ? e7.comma : c$.comma, decoder: "function" == typeof e7.decoder ? e7.decoder : c$.decoder, delimiter: "string" == typeof e7.delimiter || i$.isRegExp(e7.delimiter) ? e7.delimiter : c$.delimiter, depth: "number" == typeof e7.depth || false === e7.depth ? +e7.depth : c$.depth, ignoreQueryPrefix: true === e7.ignoreQueryPrefix, interpretNumericEntities: "boolean" == typeof e7.interpretNumericEntities ? e7.interpretNumericEntities : c$.interpretNumericEntities, parameterLimit: "number" == typeof e7.parameterLimit ? e7.parameterLimit : c$.parameterLimit, parseArrays: false !== e7.parseArrays, plainObjects: "boolean" == typeof e7.plainObjects ? e7.plainObjects : c$.plainObjects, strictNullHandling: "boolean" == typeof e7.strictNullHandling ? e7.strictNullHandling : c$.strictNullHandling };
      }(t5);
      if ("" === e6 || null == e6)
        return r6.plainObjects ? /* @__PURE__ */ Object.create(null) : {};
      for (var n6 = "string" == typeof e6 ? function(e7, t6) {
        var r7, n7 = {}, o6 = t6.ignoreQueryPrefix ? e7.replace(/^\?/, "") : e7, a3 = t6.parameterLimit === 1 / 0 ? void 0 : t6.parameterLimit, i5 = o6.split(t6.delimiter, a3), s7 = -1, l3 = t6.charset;
        if (t6.charsetSentinel)
          for (r7 = 0; r7 < i5.length; ++r7)
            0 === i5[r7].indexOf("utf8=") && ("utf8=%E2%9C%93" === i5[r7] ? l3 = "utf-8" : "utf8=%26%2310003%3B" === i5[r7] && (l3 = "iso-8859-1"), s7 = r7, r7 = i5.length);
        for (r7 = 0; r7 < i5.length; ++r7)
          if (r7 !== s7) {
            var c3, p2, d2 = i5[r7], u3 = d2.indexOf("]="), h2 = -1 === u3 ? d2.indexOf("=") : u3 + 1;
            -1 === h2 ? (c3 = t6.decoder(d2, c$.decoder, l3, "key"), p2 = t6.strictNullHandling ? null : "") : (c3 = t6.decoder(d2.slice(0, h2), c$.decoder, l3, "key"), p2 = i$.maybeMap(d$(d2.slice(h2 + 1), t6), function(e8) {
              return t6.decoder(e8, c$.decoder, l3, "value");
            })), p2 && t6.interpretNumericEntities && "iso-8859-1" === l3 && (p2 = p$(p2)), d2.indexOf("[]=") > -1 && (p2 = l$(p2) ? [p2] : p2), s$.call(n7, c3) ? n7[c3] = i$.combine(n7[c3], p2) : n7[c3] = p2;
          }
        return n7;
      }(e6, r6) : e6, o5 = r6.plainObjects ? /* @__PURE__ */ Object.create(null) : {}, a2 = Object.keys(n6), i4 = 0; i4 < a2.length; ++i4) {
        var s6 = a2[i4], l2 = u$(s6, n6[s6], r6, "string" == typeof e6);
        o5 = i$.merge(o5, l2, r6);
      }
      return true === r6.allowSparse ? o5 : i$.compact(o5);
    }, f$ = function(e6, t5) {
      var r6, n6 = e6, o5 = function(e7) {
        if (!e7)
          return n$;
        if (null !== e7.encoder && void 0 !== e7.encoder && "function" != typeof e7.encoder)
          throw new TypeError("Encoder has to be a function.");
        var t6 = e7.charset || n$.charset;
        if (void 0 !== e7.charset && "utf-8" !== e7.charset && "iso-8859-1" !== e7.charset)
          throw new TypeError("The charset option must be either utf-8, iso-8859-1, or undefined");
        var r7 = Kw.default;
        if (void 0 !== e7.format) {
          if (!Jw.call(Kw.formatters, e7.format))
            throw new TypeError("Unknown format option provided.");
          r7 = e7.format;
        }
        var n7 = Kw.formatters[r7], o6 = n$.filter;
        return ("function" == typeof e7.filter || Zw(e7.filter)) && (o6 = e7.filter), { addQueryPrefix: "boolean" == typeof e7.addQueryPrefix ? e7.addQueryPrefix : n$.addQueryPrefix, allowDots: void 0 === e7.allowDots ? n$.allowDots : !!e7.allowDots, charset: t6, charsetSentinel: "boolean" == typeof e7.charsetSentinel ? e7.charsetSentinel : n$.charsetSentinel, delimiter: void 0 === e7.delimiter ? n$.delimiter : e7.delimiter, encode: "boolean" == typeof e7.encode ? e7.encode : n$.encode, encoder: "function" == typeof e7.encoder ? e7.encoder : n$.encoder, encodeValuesOnly: "boolean" == typeof e7.encodeValuesOnly ? e7.encodeValuesOnly : n$.encodeValuesOnly, filter: o6, format: r7, formatter: n7, serializeDate: "function" == typeof e7.serializeDate ? e7.serializeDate : n$.serializeDate, skipNulls: "boolean" == typeof e7.skipNulls ? e7.skipNulls : n$.skipNulls, sort: "function" == typeof e7.sort ? e7.sort : null, strictNullHandling: "boolean" == typeof e7.strictNullHandling ? e7.strictNullHandling : n$.strictNullHandling };
      }(t5);
      "function" == typeof o5.filter ? n6 = (0, o5.filter)("", n6) : Zw(o5.filter) && (r6 = o5.filter);
      var a2, i4 = [];
      if ("object" != typeof n6 || null === n6)
        return "";
      a2 = t5 && t5.arrayFormat in Yw ? t5.arrayFormat : t5 && "indices" in t5 ? t5.indices ? "indices" : "repeat" : "indices";
      var s6 = Yw[a2];
      r6 || (r6 = Object.keys(n6)), o5.sort && r6.sort(o5.sort);
      for (var l2 = Vw(), c3 = 0; c3 < r6.length; ++c3) {
        var p2 = r6[c3];
        o5.skipNulls && null === n6[p2] || e$(i4, a$(n6[p2], p2, s6, o5.strictNullHandling, o5.skipNulls, o5.encode ? o5.encoder : null, o5.filter, o5.sort, o5.allowDots, o5.serializeDate, o5.format, o5.formatter, o5.encodeValuesOnly, o5.charset, l2));
      }
      var d2 = i4.join(o5.delimiter), u3 = true === o5.addQueryPrefix ? "?" : "";
      return o5.charsetSentinel && ("iso-8859-1" === o5.charset ? u3 += "utf8=%26%2310003%3B&" : u3 += "utf8=%E2%9C%93&"), d2.length > 0 ? u3 + d2 : "";
    };
    function m$(e6) {
      return null == e6;
    }
    var y$ = { isNothing: m$, isObject: function(e6) {
      return "object" == typeof e6 && null !== e6;
    }, toArray: function(e6) {
      return Array.isArray(e6) ? e6 : m$(e6) ? [] : [e6];
    }, repeat: function(e6, t5) {
      var r6, n6 = "";
      for (r6 = 0; r6 < t5; r6 += 1)
        n6 += e6;
      return n6;
    }, isNegativeZero: function(e6) {
      return 0 === e6 && Number.NEGATIVE_INFINITY === 1 / e6;
    }, extend: function(e6, t5) {
      var r6, n6, o5, a2;
      if (t5)
        for (r6 = 0, n6 = (a2 = Object.keys(t5)).length; r6 < n6; r6 += 1)
          e6[o5 = a2[r6]] = t5[o5];
      return e6;
    } };
    function g$(e6, t5) {
      var r6 = "", n6 = e6.reason || "(unknown reason)";
      return e6.mark ? (e6.mark.name && (r6 += 'in "' + e6.mark.name + '" '), r6 += "(" + (e6.mark.line + 1) + ":" + (e6.mark.column + 1) + ")", !t5 && e6.mark.snippet && (r6 += "\n\n" + e6.mark.snippet), n6 + " " + r6) : n6;
    }
    function v$(e6, t5) {
      Error.call(this), this.name = "YAMLException", this.reason = e6, this.mark = t5, this.message = g$(this, false), Error.captureStackTrace ? Error.captureStackTrace(this, this.constructor) : this.stack = new Error().stack || "";
    }
    v$.prototype = Object.create(Error.prototype), v$.prototype.constructor = v$, v$.prototype.toString = function(e6) {
      return this.name + ": " + g$(this, e6);
    };
    var b$ = v$;
    function x$(e6, t5, r6, n6, o5) {
      var a2 = "", i4 = "", s6 = Math.floor(o5 / 2) - 1;
      return n6 - t5 > s6 && (t5 = n6 - s6 + (a2 = " ... ").length), r6 - n6 > s6 && (r6 = n6 + s6 - (i4 = " ...").length), { str: a2 + e6.slice(t5, r6).replace(/\t/g, "\u2192") + i4, pos: n6 - t5 + a2.length };
    }
    function w$(e6, t5) {
      return y$.repeat(" ", t5 - e6.length) + e6;
    }
    var $$ = ["kind", "multi", "resolve", "construct", "instanceOf", "predicate", "represent", "representName", "defaultStyle", "styleAliases"], k$ = ["scalar", "sequence", "mapping"], S$ = function(e6, t5) {
      if (t5 = t5 || {}, Object.keys(t5).forEach(function(t6) {
        if (-1 === $$.indexOf(t6))
          throw new b$('Unknown option "' + t6 + '" is met in definition of "' + e6 + '" YAML type.');
      }), this.options = t5, this.tag = e6, this.kind = t5.kind || null, this.resolve = t5.resolve || function() {
        return true;
      }, this.construct = t5.construct || function(e7) {
        return e7;
      }, this.instanceOf = t5.instanceOf || null, this.predicate = t5.predicate || null, this.represent = t5.represent || null, this.representName = t5.representName || null, this.defaultStyle = t5.defaultStyle || null, this.multi = t5.multi || false, this.styleAliases = (r6 = t5.styleAliases || null, n6 = {}, null !== r6 && Object.keys(r6).forEach(function(e7) {
        r6[e7].forEach(function(t6) {
          n6[String(t6)] = e7;
        });
      }), n6), -1 === k$.indexOf(this.kind))
        throw new b$('Unknown kind "' + this.kind + '" is specified for "' + e6 + '" YAML type.');
      var r6, n6;
    };
    function A$(e6, t5) {
      var r6 = [];
      return e6[t5].forEach(function(e7) {
        var t6 = r6.length;
        r6.forEach(function(r7, n6) {
          r7.tag === e7.tag && r7.kind === e7.kind && r7.multi === e7.multi && (t6 = n6);
        }), r6[t6] = e7;
      }), r6;
    }
    function E$(e6) {
      return this.extend(e6);
    }
    E$.prototype.extend = function(e6) {
      var t5 = [], r6 = [];
      if (e6 instanceof S$)
        r6.push(e6);
      else if (Array.isArray(e6))
        r6 = r6.concat(e6);
      else {
        if (!e6 || !Array.isArray(e6.implicit) && !Array.isArray(e6.explicit))
          throw new b$("Schema.extend argument should be a Type, [ Type ], or a schema definition ({ implicit: [...], explicit: [...] })");
        e6.implicit && (t5 = t5.concat(e6.implicit)), e6.explicit && (r6 = r6.concat(e6.explicit));
      }
      t5.forEach(function(e7) {
        if (!(e7 instanceof S$))
          throw new b$("Specified list of YAML types (or a single Type object) contains a non-Type object.");
        if (e7.loadKind && "scalar" !== e7.loadKind)
          throw new b$("There is a non-scalar type in the implicit list of a schema. Implicit resolving of such types is not supported.");
        if (e7.multi)
          throw new b$("There is a multi type in the implicit list of a schema. Multi tags can only be listed as explicit.");
      }), r6.forEach(function(e7) {
        if (!(e7 instanceof S$))
          throw new b$("Specified list of YAML types (or a single Type object) contains a non-Type object.");
      });
      var n6 = Object.create(E$.prototype);
      return n6.implicit = (this.implicit || []).concat(t5), n6.explicit = (this.explicit || []).concat(r6), n6.compiledImplicit = A$(n6, "implicit"), n6.compiledExplicit = A$(n6, "explicit"), n6.compiledTypeMap = function() {
        var e7, t6, r7 = { scalar: {}, sequence: {}, mapping: {}, fallback: {}, multi: { scalar: [], sequence: [], mapping: [], fallback: [] } };
        function n7(e8) {
          e8.multi ? (r7.multi[e8.kind].push(e8), r7.multi.fallback.push(e8)) : r7[e8.kind][e8.tag] = r7.fallback[e8.tag] = e8;
        }
        for (e7 = 0, t6 = arguments.length; e7 < t6; e7 += 1)
          arguments[e7].forEach(n7);
        return r7;
      }(n6.compiledImplicit, n6.compiledExplicit), n6;
    };
    var O$ = E$, T$ = new S$("tag:yaml.org,2002:str", { kind: "scalar", construct: function(e6) {
      return null !== e6 ? e6 : "";
    } }), C$ = new S$("tag:yaml.org,2002:seq", { kind: "sequence", construct: function(e6) {
      return null !== e6 ? e6 : [];
    } }), j$ = new S$("tag:yaml.org,2002:map", { kind: "mapping", construct: function(e6) {
      return null !== e6 ? e6 : {};
    } }), I$ = new O$({ explicit: [T$, C$, j$] }), _$ = new S$("tag:yaml.org,2002:null", { kind: "scalar", resolve: function(e6) {
      if (null === e6)
        return true;
      var t5 = e6.length;
      return 1 === t5 && "~" === e6 || 4 === t5 && ("null" === e6 || "Null" === e6 || "NULL" === e6);
    }, construct: function() {
      return null;
    }, predicate: function(e6) {
      return null === e6;
    }, represent: { canonical: function() {
      return "~";
    }, lowercase: function() {
      return "null";
    }, uppercase: function() {
      return "NULL";
    }, camelcase: function() {
      return "Null";
    }, empty: function() {
      return "";
    } }, defaultStyle: "lowercase" }), P$ = new S$("tag:yaml.org,2002:bool", { kind: "scalar", resolve: function(e6) {
      if (null === e6)
        return false;
      var t5 = e6.length;
      return 4 === t5 && ("true" === e6 || "True" === e6 || "TRUE" === e6) || 5 === t5 && ("false" === e6 || "False" === e6 || "FALSE" === e6);
    }, construct: function(e6) {
      return "true" === e6 || "True" === e6 || "TRUE" === e6;
    }, predicate: function(e6) {
      return "[object Boolean]" === Object.prototype.toString.call(e6);
    }, represent: { lowercase: function(e6) {
      return e6 ? "true" : "false";
    }, uppercase: function(e6) {
      return e6 ? "TRUE" : "FALSE";
    }, camelcase: function(e6) {
      return e6 ? "True" : "False";
    } }, defaultStyle: "lowercase" });
    function R$(e6) {
      return 48 <= e6 && e6 <= 55;
    }
    function L$(e6) {
      return 48 <= e6 && e6 <= 57;
    }
    var F$ = new S$("tag:yaml.org,2002:int", { kind: "scalar", resolve: function(e6) {
      if (null === e6)
        return false;
      var t5, r6, n6 = e6.length, o5 = 0, a2 = false;
      if (!n6)
        return false;
      if ("-" !== (t5 = e6[o5]) && "+" !== t5 || (t5 = e6[++o5]), "0" === t5) {
        if (o5 + 1 === n6)
          return true;
        if ("b" === (t5 = e6[++o5])) {
          for (o5++; o5 < n6; o5++)
            if ("_" !== (t5 = e6[o5])) {
              if ("0" !== t5 && "1" !== t5)
                return false;
              a2 = true;
            }
          return a2 && "_" !== t5;
        }
        if ("x" === t5) {
          for (o5++; o5 < n6; o5++)
            if ("_" !== (t5 = e6[o5])) {
              if (!(48 <= (r6 = e6.charCodeAt(o5)) && r6 <= 57 || 65 <= r6 && r6 <= 70 || 97 <= r6 && r6 <= 102))
                return false;
              a2 = true;
            }
          return a2 && "_" !== t5;
        }
        if ("o" === t5) {
          for (o5++; o5 < n6; o5++)
            if ("_" !== (t5 = e6[o5])) {
              if (!R$(e6.charCodeAt(o5)))
                return false;
              a2 = true;
            }
          return a2 && "_" !== t5;
        }
      }
      if ("_" === t5)
        return false;
      for (; o5 < n6; o5++)
        if ("_" !== (t5 = e6[o5])) {
          if (!L$(e6.charCodeAt(o5)))
            return false;
          a2 = true;
        }
      return !(!a2 || "_" === t5);
    }, construct: function(e6) {
      var t5, r6 = e6, n6 = 1;
      if (-1 !== r6.indexOf("_") && (r6 = r6.replace(/_/g, "")), "-" !== (t5 = r6[0]) && "+" !== t5 || ("-" === t5 && (n6 = -1), t5 = (r6 = r6.slice(1))[0]), "0" === r6)
        return 0;
      if ("0" === t5) {
        if ("b" === r6[1])
          return n6 * parseInt(r6.slice(2), 2);
        if ("x" === r6[1])
          return n6 * parseInt(r6.slice(2), 16);
        if ("o" === r6[1])
          return n6 * parseInt(r6.slice(2), 8);
      }
      return n6 * parseInt(r6, 10);
    }, predicate: function(e6) {
      return "[object Number]" === Object.prototype.toString.call(e6) && e6 % 1 == 0 && !y$.isNegativeZero(e6);
    }, represent: { binary: function(e6) {
      return e6 >= 0 ? "0b" + e6.toString(2) : "-0b" + e6.toString(2).slice(1);
    }, octal: function(e6) {
      return e6 >= 0 ? "0o" + e6.toString(8) : "-0o" + e6.toString(8).slice(1);
    }, decimal: function(e6) {
      return e6.toString(10);
    }, hexadecimal: function(e6) {
      return e6 >= 0 ? "0x" + e6.toString(16).toUpperCase() : "-0x" + e6.toString(16).toUpperCase().slice(1);
    } }, defaultStyle: "decimal", styleAliases: { binary: [2, "bin"], octal: [8, "oct"], decimal: [10, "dec"], hexadecimal: [16, "hex"] } }), D$ = new RegExp("^(?:[-+]?(?:[0-9][0-9_]*)(?:\\.[0-9_]*)?(?:[eE][-+]?[0-9]+)?|\\.[0-9_]+(?:[eE][-+]?[0-9]+)?|[-+]?\\.(?:inf|Inf|INF)|\\.(?:nan|NaN|NAN))$"), B$ = /^[-+]?[0-9]+e/, N$ = new S$("tag:yaml.org,2002:float", { kind: "scalar", resolve: function(e6) {
      return null !== e6 && !(!D$.test(e6) || "_" === e6[e6.length - 1]);
    }, construct: function(e6) {
      var t5, r6;
      return r6 = "-" === (t5 = e6.replace(/_/g, "").toLowerCase())[0] ? -1 : 1, "+-".indexOf(t5[0]) >= 0 && (t5 = t5.slice(1)), ".inf" === t5 ? 1 === r6 ? Number.POSITIVE_INFINITY : Number.NEGATIVE_INFINITY : ".nan" === t5 ? NaN : r6 * parseFloat(t5, 10);
    }, predicate: function(e6) {
      return "[object Number]" === Object.prototype.toString.call(e6) && (e6 % 1 != 0 || y$.isNegativeZero(e6));
    }, represent: function(e6, t5) {
      var r6;
      if (isNaN(e6))
        switch (t5) {
          case "lowercase":
            return ".nan";
          case "uppercase":
            return ".NAN";
          case "camelcase":
            return ".NaN";
        }
      else if (Number.POSITIVE_INFINITY === e6)
        switch (t5) {
          case "lowercase":
            return ".inf";
          case "uppercase":
            return ".INF";
          case "camelcase":
            return ".Inf";
        }
      else if (Number.NEGATIVE_INFINITY === e6)
        switch (t5) {
          case "lowercase":
            return "-.inf";
          case "uppercase":
            return "-.INF";
          case "camelcase":
            return "-.Inf";
        }
      else if (y$.isNegativeZero(e6))
        return "-0.0";
      return r6 = e6.toString(10), B$.test(r6) ? r6.replace("e", ".e") : r6;
    }, defaultStyle: "lowercase" }), q$ = I$.extend({ implicit: [_$, P$, F$, N$] }), U$ = q$, z$ = new RegExp("^([0-9][0-9][0-9][0-9])-([0-9][0-9])-([0-9][0-9])$"), M$ = new RegExp("^([0-9][0-9][0-9][0-9])-([0-9][0-9]?)-([0-9][0-9]?)(?:[Tt]|[ \\t]+)([0-9][0-9]?):([0-9][0-9]):([0-9][0-9])(?:\\.([0-9]*))?(?:[ \\t]*(Z|([-+])([0-9][0-9]?)(?::([0-9][0-9]))?))?$"), H$ = new S$("tag:yaml.org,2002:timestamp", { kind: "scalar", resolve: function(e6) {
      return null !== e6 && (null !== z$.exec(e6) || null !== M$.exec(e6));
    }, construct: function(e6) {
      var t5, r6, n6, o5, a2, i4, s6, l2, c3 = 0, p2 = null;
      if (null === (t5 = z$.exec(e6)) && (t5 = M$.exec(e6)), null === t5)
        throw new Error("Date resolve error");
      if (r6 = +t5[1], n6 = +t5[2] - 1, o5 = +t5[3], !t5[4])
        return new Date(Date.UTC(r6, n6, o5));
      if (a2 = +t5[4], i4 = +t5[5], s6 = +t5[6], t5[7]) {
        for (c3 = t5[7].slice(0, 3); c3.length < 3; )
          c3 += "0";
        c3 = +c3;
      }
      return t5[9] && (p2 = 6e4 * (60 * +t5[10] + +(t5[11] || 0)), "-" === t5[9] && (p2 = -p2)), l2 = new Date(Date.UTC(r6, n6, o5, a2, i4, s6, c3)), p2 && l2.setTime(l2.getTime() - p2), l2;
    }, instanceOf: Date, represent: function(e6) {
      return e6.toISOString();
    } }), W$ = new S$("tag:yaml.org,2002:merge", { kind: "scalar", resolve: function(e6) {
      return "<<" === e6 || null === e6;
    } }), V$ = "ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/=\n\r", G$ = new S$("tag:yaml.org,2002:binary", { kind: "scalar", resolve: function(e6) {
      if (null === e6)
        return false;
      var t5, r6, n6 = 0, o5 = e6.length, a2 = V$;
      for (r6 = 0; r6 < o5; r6++)
        if (!((t5 = a2.indexOf(e6.charAt(r6))) > 64)) {
          if (t5 < 0)
            return false;
          n6 += 6;
        }
      return n6 % 8 == 0;
    }, construct: function(e6) {
      var t5, r6, n6 = e6.replace(/[\r\n=]/g, ""), o5 = n6.length, a2 = V$, i4 = 0, s6 = [];
      for (t5 = 0; t5 < o5; t5++)
        t5 % 4 == 0 && t5 && (s6.push(i4 >> 16 & 255), s6.push(i4 >> 8 & 255), s6.push(255 & i4)), i4 = i4 << 6 | a2.indexOf(n6.charAt(t5));
      return 0 == (r6 = o5 % 4 * 6) ? (s6.push(i4 >> 16 & 255), s6.push(i4 >> 8 & 255), s6.push(255 & i4)) : 18 === r6 ? (s6.push(i4 >> 10 & 255), s6.push(i4 >> 2 & 255)) : 12 === r6 && s6.push(i4 >> 4 & 255), new Uint8Array(s6);
    }, predicate: function(e6) {
      return "[object Uint8Array]" === Object.prototype.toString.call(e6);
    }, represent: function(e6) {
      var t5, r6, n6 = "", o5 = 0, a2 = e6.length, i4 = V$;
      for (t5 = 0; t5 < a2; t5++)
        t5 % 3 == 0 && t5 && (n6 += i4[o5 >> 18 & 63], n6 += i4[o5 >> 12 & 63], n6 += i4[o5 >> 6 & 63], n6 += i4[63 & o5]), o5 = (o5 << 8) + e6[t5];
      return 0 == (r6 = a2 % 3) ? (n6 += i4[o5 >> 18 & 63], n6 += i4[o5 >> 12 & 63], n6 += i4[o5 >> 6 & 63], n6 += i4[63 & o5]) : 2 === r6 ? (n6 += i4[o5 >> 10 & 63], n6 += i4[o5 >> 4 & 63], n6 += i4[o5 << 2 & 63], n6 += i4[64]) : 1 === r6 && (n6 += i4[o5 >> 2 & 63], n6 += i4[o5 << 4 & 63], n6 += i4[64], n6 += i4[64]), n6;
    } }), K$ = Object.prototype.hasOwnProperty, J$ = Object.prototype.toString, Y$ = new S$("tag:yaml.org,2002:omap", { kind: "sequence", resolve: function(e6) {
      if (null === e6)
        return true;
      var t5, r6, n6, o5, a2, i4 = [], s6 = e6;
      for (t5 = 0, r6 = s6.length; t5 < r6; t5 += 1) {
        if (n6 = s6[t5], a2 = false, "[object Object]" !== J$.call(n6))
          return false;
        for (o5 in n6)
          if (K$.call(n6, o5)) {
            if (a2)
              return false;
            a2 = true;
          }
        if (!a2)
          return false;
        if (-1 !== i4.indexOf(o5))
          return false;
        i4.push(o5);
      }
      return true;
    }, construct: function(e6) {
      return null !== e6 ? e6 : [];
    } }), Z$ = Object.prototype.toString, Q$ = new S$("tag:yaml.org,2002:pairs", { kind: "sequence", resolve: function(e6) {
      if (null === e6)
        return true;
      var t5, r6, n6, o5, a2, i4 = e6;
      for (a2 = new Array(i4.length), t5 = 0, r6 = i4.length; t5 < r6; t5 += 1) {
        if (n6 = i4[t5], "[object Object]" !== Z$.call(n6))
          return false;
        if (1 !== (o5 = Object.keys(n6)).length)
          return false;
        a2[t5] = [o5[0], n6[o5[0]]];
      }
      return true;
    }, construct: function(e6) {
      if (null === e6)
        return [];
      var t5, r6, n6, o5, a2, i4 = e6;
      for (a2 = new Array(i4.length), t5 = 0, r6 = i4.length; t5 < r6; t5 += 1)
        n6 = i4[t5], o5 = Object.keys(n6), a2[t5] = [o5[0], n6[o5[0]]];
      return a2;
    } }), X$ = Object.prototype.hasOwnProperty, ek = new S$("tag:yaml.org,2002:set", { kind: "mapping", resolve: function(e6) {
      if (null === e6)
        return true;
      var t5, r6 = e6;
      for (t5 in r6)
        if (X$.call(r6, t5) && null !== r6[t5])
          return false;
      return true;
    }, construct: function(e6) {
      return null !== e6 ? e6 : {};
    } }), tk = U$.extend({ implicit: [H$, W$], explicit: [G$, Y$, Q$, ek] }), rk = Object.prototype.hasOwnProperty, nk = /[\x00-\x08\x0B\x0C\x0E-\x1F\x7F-\x84\x86-\x9F\uFFFE\uFFFF]|[\uD800-\uDBFF](?![\uDC00-\uDFFF])|(?:[^\uD800-\uDBFF]|^)[\uDC00-\uDFFF]/, ok = /[\x85\u2028\u2029]/, ak = /[,\[\]\{\}]/, ik = /^(?:!|!!|![a-z\-]+!)$/i, sk = /^(?:!|[^,\[\]\{\}])(?:%[0-9a-f]{2}|[0-9a-z\-#;\/\?:@&=\+\$,_\.!~\*'\(\)\[\]])*$/i;
    function lk(e6) {
      return Object.prototype.toString.call(e6);
    }
    function ck(e6) {
      return 10 === e6 || 13 === e6;
    }
    function pk(e6) {
      return 9 === e6 || 32 === e6;
    }
    function dk(e6) {
      return 9 === e6 || 32 === e6 || 10 === e6 || 13 === e6;
    }
    function uk(e6) {
      return 44 === e6 || 91 === e6 || 93 === e6 || 123 === e6 || 125 === e6;
    }
    function hk(e6) {
      var t5;
      return 48 <= e6 && e6 <= 57 ? e6 - 48 : 97 <= (t5 = 32 | e6) && t5 <= 102 ? t5 - 97 + 10 : -1;
    }
    function fk(e6) {
      return 48 === e6 ? "\0" : 97 === e6 ? "\x07" : 98 === e6 ? "\b" : 116 === e6 || 9 === e6 ? "	" : 110 === e6 ? "\n" : 118 === e6 ? "\v" : 102 === e6 ? "\f" : 114 === e6 ? "\r" : 101 === e6 ? "\x1B" : 32 === e6 ? " " : 34 === e6 ? '"' : 47 === e6 ? "/" : 92 === e6 ? "\\" : 78 === e6 ? "\x85" : 95 === e6 ? "\xA0" : 76 === e6 ? "\u2028" : 80 === e6 ? "\u2029" : "";
    }
    function mk(e6) {
      return e6 <= 65535 ? String.fromCharCode(e6) : String.fromCharCode(55296 + (e6 - 65536 >> 10), 56320 + (e6 - 65536 & 1023));
    }
    for (var yk = new Array(256), gk = new Array(256), vk = 0; vk < 256; vk++)
      yk[vk] = fk(vk) ? 1 : 0, gk[vk] = fk(vk);
    function bk(e6, t5) {
      this.input = e6, this.filename = t5.filename || null, this.schema = t5.schema || tk, this.onWarning = t5.onWarning || null, this.legacy = t5.legacy || false, this.json = t5.json || false, this.listener = t5.listener || null, this.implicitTypes = this.schema.compiledImplicit, this.typeMap = this.schema.compiledTypeMap, this.length = e6.length, this.position = 0, this.line = 0, this.lineStart = 0, this.lineIndent = 0, this.firstTabInLine = -1, this.documents = [];
    }
    function xk(e6, t5) {
      var r6 = { name: e6.filename, buffer: e6.input.slice(0, -1), position: e6.position, line: e6.line, column: e6.position - e6.lineStart };
      return r6.snippet = function(e7, t6) {
        if (t6 = Object.create(t6 || null), !e7.buffer)
          return null;
        t6.maxLength || (t6.maxLength = 79), "number" != typeof t6.indent && (t6.indent = 1), "number" != typeof t6.linesBefore && (t6.linesBefore = 3), "number" != typeof t6.linesAfter && (t6.linesAfter = 2);
        for (var r7, n6 = /\r?\n|\r|\0/g, o5 = [0], a2 = [], i4 = -1; r7 = n6.exec(e7.buffer); )
          a2.push(r7.index), o5.push(r7.index + r7[0].length), e7.position <= r7.index && i4 < 0 && (i4 = o5.length - 2);
        i4 < 0 && (i4 = o5.length - 1);
        var s6, l2, c3 = "", p2 = Math.min(e7.line + t6.linesAfter, a2.length).toString().length, d2 = t6.maxLength - (t6.indent + p2 + 3);
        for (s6 = 1; s6 <= t6.linesBefore && !(i4 - s6 < 0); s6++)
          l2 = x$(e7.buffer, o5[i4 - s6], a2[i4 - s6], e7.position - (o5[i4] - o5[i4 - s6]), d2), c3 = y$.repeat(" ", t6.indent) + w$((e7.line - s6 + 1).toString(), p2) + " | " + l2.str + "\n" + c3;
        for (l2 = x$(e7.buffer, o5[i4], a2[i4], e7.position, d2), c3 += y$.repeat(" ", t6.indent) + w$((e7.line + 1).toString(), p2) + " | " + l2.str + "\n", c3 += y$.repeat("-", t6.indent + p2 + 3 + l2.pos) + "^\n", s6 = 1; s6 <= t6.linesAfter && !(i4 + s6 >= a2.length); s6++)
          l2 = x$(e7.buffer, o5[i4 + s6], a2[i4 + s6], e7.position - (o5[i4] - o5[i4 + s6]), d2), c3 += y$.repeat(" ", t6.indent) + w$((e7.line + s6 + 1).toString(), p2) + " | " + l2.str + "\n";
        return c3.replace(/\n$/, "");
      }(r6), new b$(t5, r6);
    }
    function wk(e6, t5) {
      throw xk(e6, t5);
    }
    function $k(e6, t5) {
      e6.onWarning && e6.onWarning.call(null, xk(e6, t5));
    }
    var kk = { YAML: function(e6, t5, r6) {
      var n6, o5, a2;
      null !== e6.version && wk(e6, "duplication of %YAML directive"), 1 !== r6.length && wk(e6, "YAML directive accepts exactly one argument"), null === (n6 = /^([0-9]+)\.([0-9]+)$/.exec(r6[0])) && wk(e6, "ill-formed argument of the YAML directive"), o5 = parseInt(n6[1], 10), a2 = parseInt(n6[2], 10), 1 !== o5 && wk(e6, "unacceptable YAML version of the document"), e6.version = r6[0], e6.checkLineBreaks = a2 < 2, 1 !== a2 && 2 !== a2 && $k(e6, "unsupported YAML version of the document");
    }, TAG: function(e6, t5, r6) {
      var n6, o5;
      2 !== r6.length && wk(e6, "TAG directive accepts exactly two arguments"), n6 = r6[0], o5 = r6[1], ik.test(n6) || wk(e6, "ill-formed tag handle (first argument) of the TAG directive"), rk.call(e6.tagMap, n6) && wk(e6, 'there is a previously declared suffix for "' + n6 + '" tag handle'), sk.test(o5) || wk(e6, "ill-formed tag prefix (second argument) of the TAG directive");
      try {
        o5 = decodeURIComponent(o5);
      } catch (t6) {
        wk(e6, "tag prefix is malformed: " + o5);
      }
      e6.tagMap[n6] = o5;
    } };
    function Sk(e6, t5, r6, n6) {
      var o5, a2, i4, s6;
      if (t5 < r6) {
        if (s6 = e6.input.slice(t5, r6), n6)
          for (o5 = 0, a2 = s6.length; o5 < a2; o5 += 1)
            9 === (i4 = s6.charCodeAt(o5)) || 32 <= i4 && i4 <= 1114111 || wk(e6, "expected valid JSON character");
        else
          nk.test(s6) && wk(e6, "the stream contains non-printable characters");
        e6.result += s6;
      }
    }
    function Ak(e6, t5, r6, n6) {
      var o5, a2, i4, s6;
      for (y$.isObject(r6) || wk(e6, "cannot merge mappings; the provided source object is unacceptable"), i4 = 0, s6 = (o5 = Object.keys(r6)).length; i4 < s6; i4 += 1)
        a2 = o5[i4], rk.call(t5, a2) || (t5[a2] = r6[a2], n6[a2] = true);
    }
    function Ek(e6, t5, r6, n6, o5, a2, i4, s6, l2) {
      var c3, p2;
      if (Array.isArray(o5))
        for (c3 = 0, p2 = (o5 = Array.prototype.slice.call(o5)).length; c3 < p2; c3 += 1)
          Array.isArray(o5[c3]) && wk(e6, "nested arrays are not supported inside keys"), "object" == typeof o5 && "[object Object]" === lk(o5[c3]) && (o5[c3] = "[object Object]");
      if ("object" == typeof o5 && "[object Object]" === lk(o5) && (o5 = "[object Object]"), o5 = String(o5), null === t5 && (t5 = {}), "tag:yaml.org,2002:merge" === n6)
        if (Array.isArray(a2))
          for (c3 = 0, p2 = a2.length; c3 < p2; c3 += 1)
            Ak(e6, t5, a2[c3], r6);
        else
          Ak(e6, t5, a2, r6);
      else
        e6.json || rk.call(r6, o5) || !rk.call(t5, o5) || (e6.line = i4 || e6.line, e6.lineStart = s6 || e6.lineStart, e6.position = l2 || e6.position, wk(e6, "duplicated mapping key")), "__proto__" === o5 ? Object.defineProperty(t5, o5, { configurable: true, enumerable: true, writable: true, value: a2 }) : t5[o5] = a2, delete r6[o5];
      return t5;
    }
    function Ok(e6) {
      var t5;
      10 === (t5 = e6.input.charCodeAt(e6.position)) ? e6.position++ : 13 === t5 ? (e6.position++, 10 === e6.input.charCodeAt(e6.position) && e6.position++) : wk(e6, "a line break is expected"), e6.line += 1, e6.lineStart = e6.position, e6.firstTabInLine = -1;
    }
    function Tk(e6, t5, r6) {
      for (var n6 = 0, o5 = e6.input.charCodeAt(e6.position); 0 !== o5; ) {
        for (; pk(o5); )
          9 === o5 && -1 === e6.firstTabInLine && (e6.firstTabInLine = e6.position), o5 = e6.input.charCodeAt(++e6.position);
        if (t5 && 35 === o5)
          do {
            o5 = e6.input.charCodeAt(++e6.position);
          } while (10 !== o5 && 13 !== o5 && 0 !== o5);
        if (!ck(o5))
          break;
        for (Ok(e6), o5 = e6.input.charCodeAt(e6.position), n6++, e6.lineIndent = 0; 32 === o5; )
          e6.lineIndent++, o5 = e6.input.charCodeAt(++e6.position);
      }
      return -1 !== r6 && 0 !== n6 && e6.lineIndent < r6 && $k(e6, "deficient indentation"), n6;
    }
    function Ck(e6) {
      var t5, r6 = e6.position;
      return !(45 !== (t5 = e6.input.charCodeAt(r6)) && 46 !== t5 || t5 !== e6.input.charCodeAt(r6 + 1) || t5 !== e6.input.charCodeAt(r6 + 2) || (r6 += 3, 0 !== (t5 = e6.input.charCodeAt(r6)) && !dk(t5)));
    }
    function jk(e6, t5) {
      1 === t5 ? e6.result += " " : t5 > 1 && (e6.result += y$.repeat("\n", t5 - 1));
    }
    function Ik(e6, t5) {
      var r6, n6, o5 = e6.tag, a2 = e6.anchor, i4 = [], s6 = false;
      if (-1 !== e6.firstTabInLine)
        return false;
      for (null !== e6.anchor && (e6.anchorMap[e6.anchor] = i4), n6 = e6.input.charCodeAt(e6.position); 0 !== n6 && (-1 !== e6.firstTabInLine && (e6.position = e6.firstTabInLine, wk(e6, "tab characters must not be used in indentation")), 45 === n6) && dk(e6.input.charCodeAt(e6.position + 1)); )
        if (s6 = true, e6.position++, Tk(e6, true, -1) && e6.lineIndent <= t5)
          i4.push(null), n6 = e6.input.charCodeAt(e6.position);
        else if (r6 = e6.line, Rk(e6, t5, 3, false, true), i4.push(e6.result), Tk(e6, true, -1), n6 = e6.input.charCodeAt(e6.position), (e6.line === r6 || e6.lineIndent > t5) && 0 !== n6)
          wk(e6, "bad indentation of a sequence entry");
        else if (e6.lineIndent < t5)
          break;
      return !!s6 && (e6.tag = o5, e6.anchor = a2, e6.kind = "sequence", e6.result = i4, true);
    }
    function _k(e6) {
      var t5, r6, n6, o5, a2 = false, i4 = false;
      if (33 !== (o5 = e6.input.charCodeAt(e6.position)))
        return false;
      if (null !== e6.tag && wk(e6, "duplication of a tag property"), 60 === (o5 = e6.input.charCodeAt(++e6.position)) ? (a2 = true, o5 = e6.input.charCodeAt(++e6.position)) : 33 === o5 ? (i4 = true, r6 = "!!", o5 = e6.input.charCodeAt(++e6.position)) : r6 = "!", t5 = e6.position, a2) {
        do {
          o5 = e6.input.charCodeAt(++e6.position);
        } while (0 !== o5 && 62 !== o5);
        e6.position < e6.length ? (n6 = e6.input.slice(t5, e6.position), o5 = e6.input.charCodeAt(++e6.position)) : wk(e6, "unexpected end of the stream within a verbatim tag");
      } else {
        for (; 0 !== o5 && !dk(o5); )
          33 === o5 && (i4 ? wk(e6, "tag suffix cannot contain exclamation marks") : (r6 = e6.input.slice(t5 - 1, e6.position + 1), ik.test(r6) || wk(e6, "named tag handle cannot contain such characters"), i4 = true, t5 = e6.position + 1)), o5 = e6.input.charCodeAt(++e6.position);
        n6 = e6.input.slice(t5, e6.position), ak.test(n6) && wk(e6, "tag suffix cannot contain flow indicator characters");
      }
      n6 && !sk.test(n6) && wk(e6, "tag name cannot contain such characters: " + n6);
      try {
        n6 = decodeURIComponent(n6);
      } catch (t6) {
        wk(e6, "tag name is malformed: " + n6);
      }
      return a2 ? e6.tag = n6 : rk.call(e6.tagMap, r6) ? e6.tag = e6.tagMap[r6] + n6 : "!" === r6 ? e6.tag = "!" + n6 : "!!" === r6 ? e6.tag = "tag:yaml.org,2002:" + n6 : wk(e6, 'undeclared tag handle "' + r6 + '"'), true;
    }
    function Pk(e6) {
      var t5, r6;
      if (38 !== (r6 = e6.input.charCodeAt(e6.position)))
        return false;
      for (null !== e6.anchor && wk(e6, "duplication of an anchor property"), r6 = e6.input.charCodeAt(++e6.position), t5 = e6.position; 0 !== r6 && !dk(r6) && !uk(r6); )
        r6 = e6.input.charCodeAt(++e6.position);
      return e6.position === t5 && wk(e6, "name of an anchor node must contain at least one character"), e6.anchor = e6.input.slice(t5, e6.position), true;
    }
    function Rk(e6, t5, r6, n6, o5) {
      var a2, i4, s6, l2, c3, p2, d2, u3, h2, f3 = 1, m2 = false, y2 = false;
      if (null !== e6.listener && e6.listener("open", e6), e6.tag = null, e6.anchor = null, e6.kind = null, e6.result = null, a2 = i4 = s6 = 4 === r6 || 3 === r6, n6 && Tk(e6, true, -1) && (m2 = true, e6.lineIndent > t5 ? f3 = 1 : e6.lineIndent === t5 ? f3 = 0 : e6.lineIndent < t5 && (f3 = -1)), 1 === f3)
        for (; _k(e6) || Pk(e6); )
          Tk(e6, true, -1) ? (m2 = true, s6 = a2, e6.lineIndent > t5 ? f3 = 1 : e6.lineIndent === t5 ? f3 = 0 : e6.lineIndent < t5 && (f3 = -1)) : s6 = false;
      if (s6 && (s6 = m2 || o5), 1 !== f3 && 4 !== r6 || (u3 = 1 === r6 || 2 === r6 ? t5 : t5 + 1, h2 = e6.position - e6.lineStart, 1 === f3 ? s6 && (Ik(e6, h2) || function(e7, t6, r7) {
        var n7, o6, a3, i5, s7, l3, c4, p3 = e7.tag, d3 = e7.anchor, u4 = {}, h3 = /* @__PURE__ */ Object.create(null), f4 = null, m3 = null, y3 = null, g2 = false, v2 = false;
        if (-1 !== e7.firstTabInLine)
          return false;
        for (null !== e7.anchor && (e7.anchorMap[e7.anchor] = u4), c4 = e7.input.charCodeAt(e7.position); 0 !== c4; ) {
          if (g2 || -1 === e7.firstTabInLine || (e7.position = e7.firstTabInLine, wk(e7, "tab characters must not be used in indentation")), n7 = e7.input.charCodeAt(e7.position + 1), a3 = e7.line, 63 !== c4 && 58 !== c4 || !dk(n7)) {
            if (i5 = e7.line, s7 = e7.lineStart, l3 = e7.position, !Rk(e7, r7, 2, false, true))
              break;
            if (e7.line === a3) {
              for (c4 = e7.input.charCodeAt(e7.position); pk(c4); )
                c4 = e7.input.charCodeAt(++e7.position);
              if (58 === c4)
                dk(c4 = e7.input.charCodeAt(++e7.position)) || wk(e7, "a whitespace character is expected after the key-value separator within a block mapping"), g2 && (Ek(e7, u4, h3, f4, m3, null, i5, s7, l3), f4 = m3 = y3 = null), v2 = true, g2 = false, o6 = false, f4 = e7.tag, m3 = e7.result;
              else {
                if (!v2)
                  return e7.tag = p3, e7.anchor = d3, true;
                wk(e7, "can not read an implicit mapping pair; a colon is missed");
              }
            } else {
              if (!v2)
                return e7.tag = p3, e7.anchor = d3, true;
              wk(e7, "can not read a block mapping entry; a multiline key may not be an implicit key");
            }
          } else
            63 === c4 ? (g2 && (Ek(e7, u4, h3, f4, m3, null, i5, s7, l3), f4 = m3 = y3 = null), v2 = true, g2 = true, o6 = true) : g2 ? (g2 = false, o6 = true) : wk(e7, "incomplete explicit mapping pair; a key node is missed; or followed by a non-tabulated empty line"), e7.position += 1, c4 = n7;
          if ((e7.line === a3 || e7.lineIndent > t6) && (g2 && (i5 = e7.line, s7 = e7.lineStart, l3 = e7.position), Rk(e7, t6, 4, true, o6) && (g2 ? m3 = e7.result : y3 = e7.result), g2 || (Ek(e7, u4, h3, f4, m3, y3, i5, s7, l3), f4 = m3 = y3 = null), Tk(e7, true, -1), c4 = e7.input.charCodeAt(e7.position)), (e7.line === a3 || e7.lineIndent > t6) && 0 !== c4)
            wk(e7, "bad indentation of a mapping entry");
          else if (e7.lineIndent < t6)
            break;
        }
        return g2 && Ek(e7, u4, h3, f4, m3, null, i5, s7, l3), v2 && (e7.tag = p3, e7.anchor = d3, e7.kind = "mapping", e7.result = u4), v2;
      }(e6, h2, u3)) || function(e7, t6) {
        var r7, n7, o6, a3, i5, s7, l3, c4, p3, d3, u4, h3, f4 = true, m3 = e7.tag, y3 = e7.anchor, g2 = /* @__PURE__ */ Object.create(null);
        if (91 === (h3 = e7.input.charCodeAt(e7.position)))
          i5 = 93, c4 = false, a3 = [];
        else {
          if (123 !== h3)
            return false;
          i5 = 125, c4 = true, a3 = {};
        }
        for (null !== e7.anchor && (e7.anchorMap[e7.anchor] = a3), h3 = e7.input.charCodeAt(++e7.position); 0 !== h3; ) {
          if (Tk(e7, true, t6), (h3 = e7.input.charCodeAt(e7.position)) === i5)
            return e7.position++, e7.tag = m3, e7.anchor = y3, e7.kind = c4 ? "mapping" : "sequence", e7.result = a3, true;
          f4 ? 44 === h3 && wk(e7, "expected the node content, but found ','") : wk(e7, "missed comma between flow collection entries"), u4 = null, s7 = l3 = false, 63 === h3 && dk(e7.input.charCodeAt(e7.position + 1)) && (s7 = l3 = true, e7.position++, Tk(e7, true, t6)), r7 = e7.line, n7 = e7.lineStart, o6 = e7.position, Rk(e7, t6, 1, false, true), d3 = e7.tag, p3 = e7.result, Tk(e7, true, t6), h3 = e7.input.charCodeAt(e7.position), !l3 && e7.line !== r7 || 58 !== h3 || (s7 = true, h3 = e7.input.charCodeAt(++e7.position), Tk(e7, true, t6), Rk(e7, t6, 1, false, true), u4 = e7.result), c4 ? Ek(e7, a3, g2, d3, p3, u4, r7, n7, o6) : s7 ? a3.push(Ek(e7, null, g2, d3, p3, u4, r7, n7, o6)) : a3.push(p3), Tk(e7, true, t6), 44 === (h3 = e7.input.charCodeAt(e7.position)) ? (f4 = true, h3 = e7.input.charCodeAt(++e7.position)) : f4 = false;
        }
        wk(e7, "unexpected end of the stream within a flow collection");
      }(e6, u3) ? y2 = true : (i4 && function(e7, t6) {
        var r7, n7, o6, a3, i5, s7 = 1, l3 = false, c4 = false, p3 = t6, d3 = 0, u4 = false;
        if (124 === (a3 = e7.input.charCodeAt(e7.position)))
          n7 = false;
        else {
          if (62 !== a3)
            return false;
          n7 = true;
        }
        for (e7.kind = "scalar", e7.result = ""; 0 !== a3; )
          if (43 === (a3 = e7.input.charCodeAt(++e7.position)) || 45 === a3)
            1 === s7 ? s7 = 43 === a3 ? 3 : 2 : wk(e7, "repeat of a chomping mode identifier");
          else {
            if (!((o6 = 48 <= (i5 = a3) && i5 <= 57 ? i5 - 48 : -1) >= 0))
              break;
            0 === o6 ? wk(e7, "bad explicit indentation width of a block scalar; it cannot be less than one") : c4 ? wk(e7, "repeat of an indentation width identifier") : (p3 = t6 + o6 - 1, c4 = true);
          }
        if (pk(a3)) {
          do {
            a3 = e7.input.charCodeAt(++e7.position);
          } while (pk(a3));
          if (35 === a3)
            do {
              a3 = e7.input.charCodeAt(++e7.position);
            } while (!ck(a3) && 0 !== a3);
        }
        for (; 0 !== a3; ) {
          for (Ok(e7), e7.lineIndent = 0, a3 = e7.input.charCodeAt(e7.position); (!c4 || e7.lineIndent < p3) && 32 === a3; )
            e7.lineIndent++, a3 = e7.input.charCodeAt(++e7.position);
          if (!c4 && e7.lineIndent > p3 && (p3 = e7.lineIndent), ck(a3))
            d3++;
          else {
            if (e7.lineIndent < p3) {
              3 === s7 ? e7.result += y$.repeat("\n", l3 ? 1 + d3 : d3) : 1 === s7 && l3 && (e7.result += "\n");
              break;
            }
            for (n7 ? pk(a3) ? (u4 = true, e7.result += y$.repeat("\n", l3 ? 1 + d3 : d3)) : u4 ? (u4 = false, e7.result += y$.repeat("\n", d3 + 1)) : 0 === d3 ? l3 && (e7.result += " ") : e7.result += y$.repeat("\n", d3) : e7.result += y$.repeat("\n", l3 ? 1 + d3 : d3), l3 = true, c4 = true, d3 = 0, r7 = e7.position; !ck(a3) && 0 !== a3; )
              a3 = e7.input.charCodeAt(++e7.position);
            Sk(e7, r7, e7.position, false);
          }
        }
        return true;
      }(e6, u3) || function(e7, t6) {
        var r7, n7, o6;
        if (39 !== (r7 = e7.input.charCodeAt(e7.position)))
          return false;
        for (e7.kind = "scalar", e7.result = "", e7.position++, n7 = o6 = e7.position; 0 !== (r7 = e7.input.charCodeAt(e7.position)); )
          if (39 === r7) {
            if (Sk(e7, n7, e7.position, true), 39 !== (r7 = e7.input.charCodeAt(++e7.position)))
              return true;
            n7 = e7.position, e7.position++, o6 = e7.position;
          } else
            ck(r7) ? (Sk(e7, n7, o6, true), jk(e7, Tk(e7, false, t6)), n7 = o6 = e7.position) : e7.position === e7.lineStart && Ck(e7) ? wk(e7, "unexpected end of the document within a single quoted scalar") : (e7.position++, o6 = e7.position);
        wk(e7, "unexpected end of the stream within a single quoted scalar");
      }(e6, u3) || function(e7, t6) {
        var r7, n7, o6, a3, i5, s7, l3;
        if (34 !== (s7 = e7.input.charCodeAt(e7.position)))
          return false;
        for (e7.kind = "scalar", e7.result = "", e7.position++, r7 = n7 = e7.position; 0 !== (s7 = e7.input.charCodeAt(e7.position)); ) {
          if (34 === s7)
            return Sk(e7, r7, e7.position, true), e7.position++, true;
          if (92 === s7) {
            if (Sk(e7, r7, e7.position, true), ck(s7 = e7.input.charCodeAt(++e7.position)))
              Tk(e7, false, t6);
            else if (s7 < 256 && yk[s7])
              e7.result += gk[s7], e7.position++;
            else if ((i5 = 120 === (l3 = s7) ? 2 : 117 === l3 ? 4 : 85 === l3 ? 8 : 0) > 0) {
              for (o6 = i5, a3 = 0; o6 > 0; o6--)
                (i5 = hk(s7 = e7.input.charCodeAt(++e7.position))) >= 0 ? a3 = (a3 << 4) + i5 : wk(e7, "expected hexadecimal character");
              e7.result += mk(a3), e7.position++;
            } else
              wk(e7, "unknown escape sequence");
            r7 = n7 = e7.position;
          } else
            ck(s7) ? (Sk(e7, r7, n7, true), jk(e7, Tk(e7, false, t6)), r7 = n7 = e7.position) : e7.position === e7.lineStart && Ck(e7) ? wk(e7, "unexpected end of the document within a double quoted scalar") : (e7.position++, n7 = e7.position);
        }
        wk(e7, "unexpected end of the stream within a double quoted scalar");
      }(e6, u3) ? y2 = true : function(e7) {
        var t6, r7, n7;
        if (42 !== (n7 = e7.input.charCodeAt(e7.position)))
          return false;
        for (n7 = e7.input.charCodeAt(++e7.position), t6 = e7.position; 0 !== n7 && !dk(n7) && !uk(n7); )
          n7 = e7.input.charCodeAt(++e7.position);
        return e7.position === t6 && wk(e7, "name of an alias node must contain at least one character"), r7 = e7.input.slice(t6, e7.position), rk.call(e7.anchorMap, r7) || wk(e7, 'unidentified alias "' + r7 + '"'), e7.result = e7.anchorMap[r7], Tk(e7, true, -1), true;
      }(e6) ? (y2 = true, null === e6.tag && null === e6.anchor || wk(e6, "alias node should not have any properties")) : function(e7, t6, r7) {
        var n7, o6, a3, i5, s7, l3, c4, p3, d3 = e7.kind, u4 = e7.result;
        if (dk(p3 = e7.input.charCodeAt(e7.position)) || uk(p3) || 35 === p3 || 38 === p3 || 42 === p3 || 33 === p3 || 124 === p3 || 62 === p3 || 39 === p3 || 34 === p3 || 37 === p3 || 64 === p3 || 96 === p3)
          return false;
        if ((63 === p3 || 45 === p3) && (dk(n7 = e7.input.charCodeAt(e7.position + 1)) || r7 && uk(n7)))
          return false;
        for (e7.kind = "scalar", e7.result = "", o6 = a3 = e7.position, i5 = false; 0 !== p3; ) {
          if (58 === p3) {
            if (dk(n7 = e7.input.charCodeAt(e7.position + 1)) || r7 && uk(n7))
              break;
          } else if (35 === p3) {
            if (dk(e7.input.charCodeAt(e7.position - 1)))
              break;
          } else {
            if (e7.position === e7.lineStart && Ck(e7) || r7 && uk(p3))
              break;
            if (ck(p3)) {
              if (s7 = e7.line, l3 = e7.lineStart, c4 = e7.lineIndent, Tk(e7, false, -1), e7.lineIndent >= t6) {
                i5 = true, p3 = e7.input.charCodeAt(e7.position);
                continue;
              }
              e7.position = a3, e7.line = s7, e7.lineStart = l3, e7.lineIndent = c4;
              break;
            }
          }
          i5 && (Sk(e7, o6, a3, false), jk(e7, e7.line - s7), o6 = a3 = e7.position, i5 = false), pk(p3) || (a3 = e7.position + 1), p3 = e7.input.charCodeAt(++e7.position);
        }
        return Sk(e7, o6, a3, false), !!e7.result || (e7.kind = d3, e7.result = u4, false);
      }(e6, u3, 1 === r6) && (y2 = true, null === e6.tag && (e6.tag = "?")), null !== e6.anchor && (e6.anchorMap[e6.anchor] = e6.result)) : 0 === f3 && (y2 = s6 && Ik(e6, h2))), null === e6.tag)
        null !== e6.anchor && (e6.anchorMap[e6.anchor] = e6.result);
      else if ("?" === e6.tag) {
        for (null !== e6.result && "scalar" !== e6.kind && wk(e6, 'unacceptable node kind for !<?> tag; it should be "scalar", not "' + e6.kind + '"'), l2 = 0, c3 = e6.implicitTypes.length; l2 < c3; l2 += 1)
          if ((d2 = e6.implicitTypes[l2]).resolve(e6.result)) {
            e6.result = d2.construct(e6.result), e6.tag = d2.tag, null !== e6.anchor && (e6.anchorMap[e6.anchor] = e6.result);
            break;
          }
      } else if ("!" !== e6.tag) {
        if (rk.call(e6.typeMap[e6.kind || "fallback"], e6.tag))
          d2 = e6.typeMap[e6.kind || "fallback"][e6.tag];
        else
          for (d2 = null, l2 = 0, c3 = (p2 = e6.typeMap.multi[e6.kind || "fallback"]).length; l2 < c3; l2 += 1)
            if (e6.tag.slice(0, p2[l2].tag.length) === p2[l2].tag) {
              d2 = p2[l2];
              break;
            }
        d2 || wk(e6, "unknown tag !<" + e6.tag + ">"), null !== e6.result && d2.kind !== e6.kind && wk(e6, "unacceptable node kind for !<" + e6.tag + '> tag; it should be "' + d2.kind + '", not "' + e6.kind + '"'), d2.resolve(e6.result, e6.tag) ? (e6.result = d2.construct(e6.result, e6.tag), null !== e6.anchor && (e6.anchorMap[e6.anchor] = e6.result)) : wk(e6, "cannot resolve a node with !<" + e6.tag + "> explicit tag");
      }
      return null !== e6.listener && e6.listener("close", e6), null !== e6.tag || null !== e6.anchor || y2;
    }
    function Lk(e6) {
      var t5, r6, n6, o5, a2 = e6.position, i4 = false;
      for (e6.version = null, e6.checkLineBreaks = e6.legacy, e6.tagMap = /* @__PURE__ */ Object.create(null), e6.anchorMap = /* @__PURE__ */ Object.create(null); 0 !== (o5 = e6.input.charCodeAt(e6.position)) && (Tk(e6, true, -1), o5 = e6.input.charCodeAt(e6.position), !(e6.lineIndent > 0 || 37 !== o5)); ) {
        for (i4 = true, o5 = e6.input.charCodeAt(++e6.position), t5 = e6.position; 0 !== o5 && !dk(o5); )
          o5 = e6.input.charCodeAt(++e6.position);
        for (n6 = [], (r6 = e6.input.slice(t5, e6.position)).length < 1 && wk(e6, "directive name must not be less than one character in length"); 0 !== o5; ) {
          for (; pk(o5); )
            o5 = e6.input.charCodeAt(++e6.position);
          if (35 === o5) {
            do {
              o5 = e6.input.charCodeAt(++e6.position);
            } while (0 !== o5 && !ck(o5));
            break;
          }
          if (ck(o5))
            break;
          for (t5 = e6.position; 0 !== o5 && !dk(o5); )
            o5 = e6.input.charCodeAt(++e6.position);
          n6.push(e6.input.slice(t5, e6.position));
        }
        0 !== o5 && Ok(e6), rk.call(kk, r6) ? kk[r6](e6, r6, n6) : $k(e6, 'unknown document directive "' + r6 + '"');
      }
      Tk(e6, true, -1), 0 === e6.lineIndent && 45 === e6.input.charCodeAt(e6.position) && 45 === e6.input.charCodeAt(e6.position + 1) && 45 === e6.input.charCodeAt(e6.position + 2) ? (e6.position += 3, Tk(e6, true, -1)) : i4 && wk(e6, "directives end mark is expected"), Rk(e6, e6.lineIndent - 1, 4, false, true), Tk(e6, true, -1), e6.checkLineBreaks && ok.test(e6.input.slice(a2, e6.position)) && $k(e6, "non-ASCII line breaks are interpreted as content"), e6.documents.push(e6.result), e6.position === e6.lineStart && Ck(e6) ? 46 === e6.input.charCodeAt(e6.position) && (e6.position += 3, Tk(e6, true, -1)) : e6.position < e6.length - 1 && wk(e6, "end of the stream or a document separator is expected");
    }
    function Fk(e6, t5) {
      t5 = t5 || {}, 0 !== (e6 = String(e6)).length && (10 !== e6.charCodeAt(e6.length - 1) && 13 !== e6.charCodeAt(e6.length - 1) && (e6 += "\n"), 65279 === e6.charCodeAt(0) && (e6 = e6.slice(1)));
      var r6 = new bk(e6, t5), n6 = e6.indexOf("\0");
      for (-1 !== n6 && (r6.position = n6, wk(r6, "null byte is not allowed in input")), r6.input += "\0"; 32 === r6.input.charCodeAt(r6.position); )
        r6.lineIndent += 1, r6.position += 1;
      for (; r6.position < r6.length - 1; )
        Lk(r6);
      return r6.documents;
    }
    var Dk = { loadAll: function(e6, t5, r6) {
      null !== t5 && "object" == typeof t5 && void 0 === r6 && (r6 = t5, t5 = null);
      var n6 = Fk(e6, r6);
      if ("function" != typeof t5)
        return n6;
      for (var o5 = 0, a2 = n6.length; o5 < a2; o5 += 1)
        t5(n6[o5]);
    }, load: function(e6, t5) {
      var r6 = Fk(e6, t5);
      if (0 !== r6.length) {
        if (1 === r6.length)
          return r6[0];
        throw new b$("expected a single document in the stream, but found more");
      }
    } }, Bk = Object.prototype.toString, Nk = Object.prototype.hasOwnProperty, qk = { 0: "\\0", 7: "\\a", 8: "\\b", 9: "\\t", 10: "\\n", 11: "\\v", 12: "\\f", 13: "\\r", 27: "\\e", 34: '\\"', 92: "\\\\", 133: "\\N", 160: "\\_", 8232: "\\L", 8233: "\\P" }, Uk = ["y", "Y", "yes", "Yes", "YES", "on", "On", "ON", "n", "N", "no", "No", "NO", "off", "Off", "OFF"], zk = /^[-+]?[0-9_]+(?::[0-9_]+)+(?:\.[0-9_]*)?$/;
    function Mk(e6) {
      var t5, r6, n6;
      if (t5 = e6.toString(16).toUpperCase(), e6 <= 255)
        r6 = "x", n6 = 2;
      else if (e6 <= 65535)
        r6 = "u", n6 = 4;
      else {
        if (!(e6 <= 4294967295))
          throw new b$("code point within a string may not be greater than 0xFFFFFFFF");
        r6 = "U", n6 = 8;
      }
      return "\\" + r6 + y$.repeat("0", n6 - t5.length) + t5;
    }
    function Hk(e6) {
      this.schema = e6.schema || tk, this.indent = Math.max(1, e6.indent || 2), this.noArrayIndent = e6.noArrayIndent || false, this.skipInvalid = e6.skipInvalid || false, this.flowLevel = y$.isNothing(e6.flowLevel) ? -1 : e6.flowLevel, this.styleMap = function(e7, t5) {
        var r6, n6, o5, a2, i4, s6, l2;
        if (null === t5)
          return {};
        for (r6 = {}, o5 = 0, a2 = (n6 = Object.keys(t5)).length; o5 < a2; o5 += 1)
          i4 = n6[o5], s6 = String(t5[i4]), "!!" === i4.slice(0, 2) && (i4 = "tag:yaml.org,2002:" + i4.slice(2)), (l2 = e7.compiledTypeMap.fallback[i4]) && Nk.call(l2.styleAliases, s6) && (s6 = l2.styleAliases[s6]), r6[i4] = s6;
        return r6;
      }(this.schema, e6.styles || null), this.sortKeys = e6.sortKeys || false, this.lineWidth = e6.lineWidth || 80, this.noRefs = e6.noRefs || false, this.noCompatMode = e6.noCompatMode || false, this.condenseFlow = e6.condenseFlow || false, this.quotingType = '"' === e6.quotingType ? 2 : 1, this.forceQuotes = e6.forceQuotes || false, this.replacer = "function" == typeof e6.replacer ? e6.replacer : null, this.implicitTypes = this.schema.compiledImplicit, this.explicitTypes = this.schema.compiledExplicit, this.tag = null, this.result = "", this.duplicates = [], this.usedDuplicates = null;
    }
    function Wk(e6, t5) {
      for (var r6, n6 = y$.repeat(" ", t5), o5 = 0, a2 = -1, i4 = "", s6 = e6.length; o5 < s6; )
        -1 === (a2 = e6.indexOf("\n", o5)) ? (r6 = e6.slice(o5), o5 = s6) : (r6 = e6.slice(o5, a2 + 1), o5 = a2 + 1), r6.length && "\n" !== r6 && (i4 += n6), i4 += r6;
      return i4;
    }
    function Vk(e6, t5) {
      return "\n" + y$.repeat(" ", e6.indent * t5);
    }
    function Gk(e6) {
      return 32 === e6 || 9 === e6;
    }
    function Kk(e6) {
      return 32 <= e6 && e6 <= 126 || 161 <= e6 && e6 <= 55295 && 8232 !== e6 && 8233 !== e6 || 57344 <= e6 && e6 <= 65533 && 65279 !== e6 || 65536 <= e6 && e6 <= 1114111;
    }
    function Jk(e6) {
      return Kk(e6) && 65279 !== e6 && 13 !== e6 && 10 !== e6;
    }
    function Yk(e6, t5, r6) {
      var n6 = Jk(e6), o5 = n6 && !Gk(e6);
      return (r6 ? n6 : n6 && 44 !== e6 && 91 !== e6 && 93 !== e6 && 123 !== e6 && 125 !== e6) && 35 !== e6 && !(58 === t5 && !o5) || Jk(t5) && !Gk(t5) && 35 === e6 || 58 === t5 && o5;
    }
    function Zk(e6, t5) {
      var r6, n6 = e6.charCodeAt(t5);
      return n6 >= 55296 && n6 <= 56319 && t5 + 1 < e6.length && (r6 = e6.charCodeAt(t5 + 1)) >= 56320 && r6 <= 57343 ? 1024 * (n6 - 55296) + r6 - 56320 + 65536 : n6;
    }
    function Qk(e6) {
      return /^\n* /.test(e6);
    }
    function Xk(e6, t5, r6, n6, o5) {
      e6.dump = function() {
        if (0 === t5.length)
          return 2 === e6.quotingType ? '""' : "''";
        if (!e6.noCompatMode && (-1 !== Uk.indexOf(t5) || zk.test(t5)))
          return 2 === e6.quotingType ? '"' + t5 + '"' : "'" + t5 + "'";
        var a2 = e6.indent * Math.max(1, r6), i4 = -1 === e6.lineWidth ? -1 : Math.max(Math.min(e6.lineWidth, 40), e6.lineWidth - a2), s6 = n6 || e6.flowLevel > -1 && r6 >= e6.flowLevel;
        switch (function(e7, t6, r7, n7, o6, a3, i5, s7) {
          var l2, c3, p2, d2 = 0, u3 = null, h2 = false, f3 = false, m2 = -1 !== n7, y2 = -1, g2 = Kk(c3 = Zk(e7, 0)) && 65279 !== c3 && !Gk(c3) && 45 !== c3 && 63 !== c3 && 58 !== c3 && 44 !== c3 && 91 !== c3 && 93 !== c3 && 123 !== c3 && 125 !== c3 && 35 !== c3 && 38 !== c3 && 42 !== c3 && 33 !== c3 && 124 !== c3 && 61 !== c3 && 62 !== c3 && 39 !== c3 && 34 !== c3 && 37 !== c3 && 64 !== c3 && 96 !== c3 && !Gk(p2 = Zk(e7, e7.length - 1)) && 58 !== p2;
          if (t6 || i5)
            for (l2 = 0; l2 < e7.length; d2 >= 65536 ? l2 += 2 : l2++) {
              if (!Kk(d2 = Zk(e7, l2)))
                return 5;
              g2 = g2 && Yk(d2, u3, s7), u3 = d2;
            }
          else {
            for (l2 = 0; l2 < e7.length; d2 >= 65536 ? l2 += 2 : l2++) {
              if (10 === (d2 = Zk(e7, l2)))
                h2 = true, m2 && (f3 = f3 || l2 - y2 - 1 > n7 && " " !== e7[y2 + 1], y2 = l2);
              else if (!Kk(d2))
                return 5;
              g2 = g2 && Yk(d2, u3, s7), u3 = d2;
            }
            f3 = f3 || m2 && l2 - y2 - 1 > n7 && " " !== e7[y2 + 1];
          }
          return h2 || f3 ? r7 > 9 && Qk(e7) ? 5 : i5 ? 2 === a3 ? 5 : 2 : f3 ? 4 : 3 : !g2 || i5 || o6(e7) ? 2 === a3 ? 5 : 2 : 1;
        }(t5, s6, e6.indent, i4, function(t6) {
          return function(e7, t7) {
            var r7, n7;
            for (r7 = 0, n7 = e7.implicitTypes.length; r7 < n7; r7 += 1)
              if (e7.implicitTypes[r7].resolve(t7))
                return true;
            return false;
          }(e6, t6);
        }, e6.quotingType, e6.forceQuotes && !n6, o5)) {
          case 1:
            return t5;
          case 2:
            return "'" + t5.replace(/'/g, "''") + "'";
          case 3:
            return "|" + eS(t5, e6.indent) + tS(Wk(t5, a2));
          case 4:
            return ">" + eS(t5, e6.indent) + tS(Wk(function(e7, t6) {
              for (var r7, n7, o6, a3 = /(\n+)([^\n]*)/g, i5 = (o6 = -1 !== (o6 = e7.indexOf("\n")) ? o6 : e7.length, a3.lastIndex = o6, rS(e7.slice(0, o6), t6)), s7 = "\n" === e7[0] || " " === e7[0]; n7 = a3.exec(e7); ) {
                var l2 = n7[1], c3 = n7[2];
                r7 = " " === c3[0], i5 += l2 + (s7 || r7 || "" === c3 ? "" : "\n") + rS(c3, t6), s7 = r7;
              }
              return i5;
            }(t5, i4), a2));
          case 5:
            return '"' + function(e7) {
              for (var t6, r7 = "", n7 = 0, o6 = 0; o6 < e7.length; n7 >= 65536 ? o6 += 2 : o6++)
                n7 = Zk(e7, o6), !(t6 = qk[n7]) && Kk(n7) ? (r7 += e7[o6], n7 >= 65536 && (r7 += e7[o6 + 1])) : r7 += t6 || Mk(n7);
              return r7;
            }(t5) + '"';
          default:
            throw new b$("impossible error: invalid scalar style");
        }
      }();
    }
    function eS(e6, t5) {
      var r6 = Qk(e6) ? String(t5) : "", n6 = "\n" === e6[e6.length - 1];
      return r6 + (!n6 || "\n" !== e6[e6.length - 2] && "\n" !== e6 ? n6 ? "" : "-" : "+") + "\n";
    }
    function tS(e6) {
      return "\n" === e6[e6.length - 1] ? e6.slice(0, -1) : e6;
    }
    function rS(e6, t5) {
      if ("" === e6 || " " === e6[0])
        return e6;
      for (var r6, n6, o5 = / [^ ]/g, a2 = 0, i4 = 0, s6 = 0, l2 = ""; r6 = o5.exec(e6); )
        (s6 = r6.index) - a2 > t5 && (n6 = i4 > a2 ? i4 : s6, l2 += "\n" + e6.slice(a2, n6), a2 = n6 + 1), i4 = s6;
      return l2 += "\n", e6.length - a2 > t5 && i4 > a2 ? l2 += e6.slice(a2, i4) + "\n" + e6.slice(i4 + 1) : l2 += e6.slice(a2), l2.slice(1);
    }
    function nS(e6, t5, r6, n6) {
      var o5, a2, i4, s6 = "", l2 = e6.tag;
      for (o5 = 0, a2 = r6.length; o5 < a2; o5 += 1)
        i4 = r6[o5], e6.replacer && (i4 = e6.replacer.call(r6, String(o5), i4)), (aS(e6, t5 + 1, i4, true, true, false, true) || void 0 === i4 && aS(e6, t5 + 1, null, true, true, false, true)) && (n6 && "" === s6 || (s6 += Vk(e6, t5)), e6.dump && 10 === e6.dump.charCodeAt(0) ? s6 += "-" : s6 += "- ", s6 += e6.dump);
      e6.tag = l2, e6.dump = s6 || "[]";
    }
    function oS(e6, t5, r6) {
      var n6, o5, a2, i4, s6, l2;
      for (a2 = 0, i4 = (o5 = r6 ? e6.explicitTypes : e6.implicitTypes).length; a2 < i4; a2 += 1)
        if (((s6 = o5[a2]).instanceOf || s6.predicate) && (!s6.instanceOf || "object" == typeof t5 && t5 instanceof s6.instanceOf) && (!s6.predicate || s6.predicate(t5))) {
          if (r6 ? s6.multi && s6.representName ? e6.tag = s6.representName(t5) : e6.tag = s6.tag : e6.tag = "?", s6.represent) {
            if (l2 = e6.styleMap[s6.tag] || s6.defaultStyle, "[object Function]" === Bk.call(s6.represent))
              n6 = s6.represent(t5, l2);
            else {
              if (!Nk.call(s6.represent, l2))
                throw new b$("!<" + s6.tag + '> tag resolver accepts not "' + l2 + '" style');
              n6 = s6.represent[l2](t5, l2);
            }
            e6.dump = n6;
          }
          return true;
        }
      return false;
    }
    function aS(e6, t5, r6, n6, o5, a2, i4) {
      e6.tag = null, e6.dump = r6, oS(e6, r6, false) || oS(e6, r6, true);
      var s6, l2 = Bk.call(e6.dump), c3 = n6;
      n6 && (n6 = e6.flowLevel < 0 || e6.flowLevel > t5);
      var p2, d2, u3 = "[object Object]" === l2 || "[object Array]" === l2;
      if (u3 && (d2 = -1 !== (p2 = e6.duplicates.indexOf(r6))), (null !== e6.tag && "?" !== e6.tag || d2 || 2 !== e6.indent && t5 > 0) && (o5 = false), d2 && e6.usedDuplicates[p2])
        e6.dump = "*ref_" + p2;
      else {
        if (u3 && d2 && !e6.usedDuplicates[p2] && (e6.usedDuplicates[p2] = true), "[object Object]" === l2)
          n6 && 0 !== Object.keys(e6.dump).length ? (function(e7, t6, r7, n7) {
            var o6, a3, i5, s7, l3, c4, p3 = "", d3 = e7.tag, u4 = Object.keys(r7);
            if (true === e7.sortKeys)
              u4.sort();
            else if ("function" == typeof e7.sortKeys)
              u4.sort(e7.sortKeys);
            else if (e7.sortKeys)
              throw new b$("sortKeys must be a boolean or a function");
            for (o6 = 0, a3 = u4.length; o6 < a3; o6 += 1)
              c4 = "", n7 && "" === p3 || (c4 += Vk(e7, t6)), s7 = r7[i5 = u4[o6]], e7.replacer && (s7 = e7.replacer.call(r7, i5, s7)), aS(e7, t6 + 1, i5, true, true, true) && ((l3 = null !== e7.tag && "?" !== e7.tag || e7.dump && e7.dump.length > 1024) && (e7.dump && 10 === e7.dump.charCodeAt(0) ? c4 += "?" : c4 += "? "), c4 += e7.dump, l3 && (c4 += Vk(e7, t6)), aS(e7, t6 + 1, s7, true, l3) && (e7.dump && 10 === e7.dump.charCodeAt(0) ? c4 += ":" : c4 += ": ", p3 += c4 += e7.dump));
            e7.tag = d3, e7.dump = p3 || "{}";
          }(e6, t5, e6.dump, o5), d2 && (e6.dump = "&ref_" + p2 + e6.dump)) : (function(e7, t6, r7) {
            var n7, o6, a3, i5, s7, l3 = "", c4 = e7.tag, p3 = Object.keys(r7);
            for (n7 = 0, o6 = p3.length; n7 < o6; n7 += 1)
              s7 = "", "" !== l3 && (s7 += ", "), e7.condenseFlow && (s7 += '"'), i5 = r7[a3 = p3[n7]], e7.replacer && (i5 = e7.replacer.call(r7, a3, i5)), aS(e7, t6, a3, false, false) && (e7.dump.length > 1024 && (s7 += "? "), s7 += e7.dump + (e7.condenseFlow ? '"' : "") + ":" + (e7.condenseFlow ? "" : " "), aS(e7, t6, i5, false, false) && (l3 += s7 += e7.dump));
            e7.tag = c4, e7.dump = "{" + l3 + "}";
          }(e6, t5, e6.dump), d2 && (e6.dump = "&ref_" + p2 + " " + e6.dump));
        else if ("[object Array]" === l2)
          n6 && 0 !== e6.dump.length ? (e6.noArrayIndent && !i4 && t5 > 0 ? nS(e6, t5 - 1, e6.dump, o5) : nS(e6, t5, e6.dump, o5), d2 && (e6.dump = "&ref_" + p2 + e6.dump)) : (function(e7, t6, r7) {
            var n7, o6, a3, i5 = "", s7 = e7.tag;
            for (n7 = 0, o6 = r7.length; n7 < o6; n7 += 1)
              a3 = r7[n7], e7.replacer && (a3 = e7.replacer.call(r7, String(n7), a3)), (aS(e7, t6, a3, false, false) || void 0 === a3 && aS(e7, t6, null, false, false)) && ("" !== i5 && (i5 += "," + (e7.condenseFlow ? "" : " ")), i5 += e7.dump);
            e7.tag = s7, e7.dump = "[" + i5 + "]";
          }(e6, t5, e6.dump), d2 && (e6.dump = "&ref_" + p2 + " " + e6.dump));
        else {
          if ("[object String]" !== l2) {
            if ("[object Undefined]" === l2)
              return false;
            if (e6.skipInvalid)
              return false;
            throw new b$("unacceptable kind of an object to dump " + l2);
          }
          "?" !== e6.tag && Xk(e6, e6.dump, t5, a2, c3);
        }
        null !== e6.tag && "?" !== e6.tag && (s6 = encodeURI("!" === e6.tag[0] ? e6.tag.slice(1) : e6.tag).replace(/!/g, "%21"), s6 = "!" === e6.tag[0] ? "!" + s6 : "tag:yaml.org,2002:" === s6.slice(0, 18) ? "!!" + s6.slice(18) : "!<" + s6 + ">", e6.dump = s6 + " " + e6.dump);
      }
      return true;
    }
    function iS(e6, t5) {
      var r6, n6, o5 = [], a2 = [];
      for (sS(e6, o5, a2), r6 = 0, n6 = a2.length; r6 < n6; r6 += 1)
        t5.duplicates.push(o5[a2[r6]]);
      t5.usedDuplicates = new Array(n6);
    }
    function sS(e6, t5, r6) {
      var n6, o5, a2;
      if (null !== e6 && "object" == typeof e6)
        if (-1 !== (o5 = t5.indexOf(e6)))
          -1 === r6.indexOf(o5) && r6.push(o5);
        else if (t5.push(e6), Array.isArray(e6))
          for (o5 = 0, a2 = e6.length; o5 < a2; o5 += 1)
            sS(e6[o5], t5, r6);
        else
          for (o5 = 0, a2 = (n6 = Object.keys(e6)).length; o5 < a2; o5 += 1)
            sS(e6[n6[o5]], t5, r6);
    }
    function lS(e6, t5) {
      return function() {
        throw new Error("Function yaml." + e6 + " is removed in js-yaml 4. Use yaml." + t5 + " instead, which is now safe by default.");
      };
    }
    var cS = { Type: S$, Schema: O$, FAILSAFE_SCHEMA: I$, JSON_SCHEMA: q$, CORE_SCHEMA: U$, DEFAULT_SCHEMA: tk, load: Dk.load, loadAll: Dk.loadAll, dump: function(e6, t5) {
      var r6 = new Hk(t5 = t5 || {});
      r6.noRefs || iS(e6, r6);
      var n6 = e6;
      return r6.replacer && (n6 = r6.replacer.call({ "": n6 }, "", n6)), aS(r6, 0, n6, true, true) ? r6.dump + "\n" : "";
    }, YAMLException: b$, types: { binary: G$, float: N$, map: j$, null: _$, pairs: Q$, set: ek, timestamp: H$, bool: P$, int: F$, merge: W$, omap: Y$, seq: C$, str: T$ }, safeLoad: lS("safeLoad", "load"), safeLoadAll: lS("safeLoadAll", "loadAll"), safeDump: lS("safeDump", "dump") };
    const pS = "undefined" != typeof globalThis ? globalThis : "undefined" != typeof self ? self : window, { FormData: dS, Blob: uS, File: hS } = pS;
    function fS(e6) {
      return function(e7) {
        if (kh(e7))
          return Of(e7);
      }(e6) || function(e7) {
        if (void 0 !== th && null != wh(e7) || null != e7["@@iterator"])
          return Ef(e7);
      }(e6) || Tf(e6) || function() {
        throw new TypeError("Invalid attempt to spread non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.");
      }();
    }
    const mS = ut({ exports: {} }.exports = Mh);
    var yS = function(e6) {
      return ":/?#[]@!$&'()*+,;=".indexOf(e6) > -1;
    }, gS = function(e6) {
      return /^[a-z0-9\-._~]+$/i.test(e6);
    };
    function vS(e6) {
      var t5, r6 = arguments.length > 1 && void 0 !== arguments[1] ? arguments[1] : {}, n6 = r6.escape, o5 = arguments.length > 2 ? arguments[2] : void 0;
      return "number" == typeof e6 && (e6 = e6.toString()), "string" == typeof e6 && e6.length && n6 ? o5 ? JSON.parse(e6) : Tb(t5 = fS(e6)).call(t5, function(e7) {
        var t6, r7;
        if (gS(e7))
          return e7;
        if (yS(e7) && "unsafe" === n6)
          return e7;
        var o6 = new TextEncoder();
        return Tb(t6 = Tb(r7 = rb(o6.encode(e7))).call(r7, function(e8) {
          var t7;
          return mS(t7 = "0".concat(e8.toString(16).toUpperCase())).call(t7, -2);
        })).call(t6, function(e8) {
          return "%".concat(e8);
        }).join("");
      }).join("") : e6;
    }
    function bS(e6) {
      var t5 = e6.value;
      return Array.isArray(t5) ? function(e7) {
        var t6 = e7.key, r6 = e7.value, n6 = e7.style, o5 = e7.explode, a2 = e7.escape, i4 = function(e8) {
          return vS(e8, { escape: a2 });
        };
        if ("simple" === n6)
          return Tb(r6).call(r6, function(e8) {
            return i4(e8);
          }).join(",");
        if ("label" === n6)
          return ".".concat(Tb(r6).call(r6, function(e8) {
            return i4(e8);
          }).join("."));
        if ("matrix" === n6)
          return Tb(r6).call(r6, function(e8) {
            return i4(e8);
          }).reduce(function(e8, r7) {
            var n7, a3, i5;
            return !e8 || o5 ? Rb(a3 = Rb(i5 = "".concat(e8 || "", ";")).call(i5, t6, "=")).call(a3, r7) : Rb(n7 = "".concat(e8, ",")).call(n7, r7);
          }, "");
        if ("form" === n6) {
          var s6 = o5 ? "&".concat(t6, "=") : ",";
          return Tb(r6).call(r6, function(e8) {
            return i4(e8);
          }).join(s6);
        }
        if ("spaceDelimited" === n6) {
          var l2 = o5 ? "".concat(t6, "=") : "";
          return Tb(r6).call(r6, function(e8) {
            return i4(e8);
          }).join(" ".concat(l2));
        }
        if ("pipeDelimited" === n6) {
          var c3 = o5 ? "".concat(t6, "=") : "";
          return Tb(r6).call(r6, function(e8) {
            return i4(e8);
          }).join("|".concat(c3));
        }
      }(e6) : "object" === _f(t5) ? function(e7) {
        var t6 = e7.key, r6 = e7.value, n6 = e7.style, o5 = e7.explode, a2 = e7.escape, i4 = function(e8) {
          return vS(e8, { escape: a2 });
        }, s6 = Cb(r6);
        return "simple" === n6 ? s6.reduce(function(e8, t7) {
          var n7, a3, s7, l2 = i4(r6[t7]), c3 = o5 ? "=" : ",", p2 = e8 ? "".concat(e8, ",") : "";
          return Rb(n7 = Rb(a3 = Rb(s7 = "".concat(p2)).call(s7, t7)).call(a3, c3)).call(n7, l2);
        }, "") : "label" === n6 ? s6.reduce(function(e8, t7) {
          var n7, a3, s7, l2 = i4(r6[t7]), c3 = o5 ? "=" : ".", p2 = e8 ? "".concat(e8, ".") : ".";
          return Rb(n7 = Rb(a3 = Rb(s7 = "".concat(p2)).call(s7, t7)).call(a3, c3)).call(n7, l2);
        }, "") : "matrix" === n6 && o5 ? s6.reduce(function(e8, t7) {
          var n7, o6, a3 = i4(r6[t7]), s7 = e8 ? "".concat(e8, ";") : ";";
          return Rb(n7 = Rb(o6 = "".concat(s7)).call(o6, t7, "=")).call(n7, a3);
        }, "") : "matrix" === n6 ? s6.reduce(function(e8, n7) {
          var o6, a3, s7 = i4(r6[n7]), l2 = e8 ? "".concat(e8, ",") : ";".concat(t6, "=");
          return Rb(o6 = Rb(a3 = "".concat(l2)).call(a3, n7, ",")).call(o6, s7);
        }, "") : "form" === n6 ? s6.reduce(function(e8, t7) {
          var n7, a3, s7, l2, c3 = i4(r6[t7]), p2 = e8 ? Rb(n7 = "".concat(e8)).call(n7, o5 ? "&" : ",") : "", d2 = o5 ? "=" : ",";
          return Rb(a3 = Rb(s7 = Rb(l2 = "".concat(p2)).call(l2, t7)).call(s7, d2)).call(a3, c3);
        }, "") : void 0;
      }(e6) : function(e7) {
        var t6, r6 = e7.key, n6 = e7.value, o5 = e7.style, a2 = e7.escape, i4 = function(e8) {
          return vS(e8, { escape: a2 });
        };
        return "simple" === o5 ? i4(n6) : "label" === o5 ? ".".concat(i4(n6)) : "matrix" === o5 ? Rb(t6 = ";".concat(r6, "=")).call(t6, i4(n6)) : "form" === o5 || "deepObject" === o5 ? i4(n6) : void 0;
      }(e6);
    }
    var xS = function(e6, t5) {
      t5.body = e6;
    }, wS = { serializeRes: ES, mergeInQueryOrForm: DS };
    function $S(e6) {
      return kS.apply(this, arguments);
    }
    function kS() {
      return kS = jv(_v.mark(function e6(t5) {
        var r6, n6, o5, a2, i4, s6 = arguments;
        return _v.wrap(function(e7) {
          for (; ; )
            switch (e7.prev = e7.next) {
              case 0:
                if (r6 = s6.length > 1 && void 0 !== s6[1] ? s6[1] : {}, "object" === _f(t5) && (t5 = (r6 = t5).url), r6.headers = r6.headers || {}, wS.mergeInQueryOrForm(r6), r6.headers && Cb(r6.headers).forEach(function(e8) {
                  var t6 = r6.headers[e8];
                  "string" == typeof t6 && (r6.headers[e8] = t6.replace(/\n+/g, " "));
                }), !r6.requestInterceptor) {
                  e7.next = 12;
                  break;
                }
                return e7.next = 8, r6.requestInterceptor(r6);
              case 8:
                if (e7.t0 = e7.sent, e7.t0) {
                  e7.next = 11;
                  break;
                }
                e7.t0 = r6;
              case 11:
                r6 = e7.t0;
              case 12:
                return n6 = r6.headers["content-type"] || r6.headers["Content-Type"], /multipart\/form-data/i.test(n6) && r6.body instanceof dS && (delete r6.headers["content-type"], delete r6.headers["Content-Type"]), e7.prev = 14, e7.next = 17, (r6.userFetch || fetch)(r6.url, r6);
              case 17:
                return o5 = e7.sent, e7.next = 20, wS.serializeRes(o5, t5, r6);
              case 20:
                if (o5 = e7.sent, !r6.responseInterceptor) {
                  e7.next = 28;
                  break;
                }
                return e7.next = 24, r6.responseInterceptor(o5);
              case 24:
                if (e7.t1 = e7.sent, e7.t1) {
                  e7.next = 27;
                  break;
                }
                e7.t1 = o5;
              case 27:
                o5 = e7.t1;
              case 28:
                e7.next = 39;
                break;
              case 30:
                if (e7.prev = 30, e7.t2 = e7.catch(14), o5) {
                  e7.next = 34;
                  break;
                }
                throw e7.t2;
              case 34:
                throw (a2 = new Error(o5.statusText || "response status is ".concat(o5.status))).status = o5.status, a2.statusCode = o5.status, a2.responseError = e7.t2, a2;
              case 39:
                if (o5.ok) {
                  e7.next = 45;
                  break;
                }
                throw (i4 = new Error(o5.statusText || "response status is ".concat(o5.status))).status = o5.status, i4.statusCode = o5.status, i4.response = o5, i4;
              case 45:
                return e7.abrupt("return", o5);
              case 46:
              case "end":
                return e7.stop();
            }
        }, e6, null, [[14, 30]]);
      })), kS.apply(this, arguments);
    }
    var SS = function() {
      var e6 = arguments.length > 0 && void 0 !== arguments[0] ? arguments[0] : "";
      return /(json|xml|yaml|text)\b/.test(e6);
    };
    function AS(e6, t5) {
      return t5 && (0 === t5.indexOf("application/json") || t5.indexOf("+json") > 0) ? JSON.parse(e6) : cS.load(e6);
    }
    function ES(e6, t5) {
      var r6 = arguments.length > 2 && void 0 !== arguments[2] ? arguments[2] : {}, n6 = r6.loadSpec, o5 = void 0 !== n6 && n6, a2 = { ok: e6.ok, url: e6.url || t5, status: e6.status, statusText: e6.statusText, headers: TS(e6.headers) }, i4 = a2.headers["content-type"], s6 = o5 || SS(i4), l2 = s6 ? e6.text : e6.blob || e6.buffer;
      return l2.call(e6).then(function(e7) {
        if (a2.text = e7, a2.data = e7, s6)
          try {
            var t6 = AS(e7, i4);
            a2.body = t6, a2.obj = t6;
          } catch (e8) {
            a2.parseError = e8;
          }
        return a2;
      });
    }
    function OS(e6) {
      return Gv(e6).call(e6, ", ") ? e6.split(", ") : e6;
    }
    function TS() {
      var e6 = arguments.length > 0 && void 0 !== arguments[0] ? arguments[0] : {};
      return "function" != typeof tb(e6) ? {} : rb(tb(e6).call(e6)).reduce(function(e7, t5) {
        var r6 = Pf(t5, 2), n6 = r6[0], o5 = r6[1];
        return e7[n6] = OS(o5), e7;
      }, {});
    }
    function CS(e6, t5) {
      return t5 || "undefined" == typeof navigator || (t5 = navigator), t5 && "ReactNative" === t5.product ? !(!e6 || "object" !== _f(e6) || "string" != typeof e6.uri) : void 0 !== hS && e6 instanceof hS || void 0 !== uS && e6 instanceof uS || !!ArrayBuffer.isView(e6) || null !== e6 && "object" === _f(e6) && "function" == typeof e6.pipe;
    }
    function jS(e6, t5) {
      return Array.isArray(e6) && e6.some(function(e7) {
        return CS(e7, t5);
      });
    }
    var IS = { form: ",", spaceDelimited: "%20", pipeDelimited: "|" }, _S = { csv: ",", ssv: "%20", tsv: "%09", pipes: "|" };
    function PS(e6, t5) {
      var r6 = arguments.length > 2 && void 0 !== arguments[2] && arguments[2], n6 = t5.collectionFormat, o5 = t5.allowEmptyValue, a2 = t5.serializationOption, i4 = t5.encoding, s6 = "object" !== _f(t5) || Array.isArray(t5) ? t5 : t5.value, l2 = r6 ? function(e7) {
        return e7.toString();
      } : function(e7) {
        return encodeURIComponent(e7);
      }, c3 = l2(e6);
      if (void 0 === s6 && o5)
        return [[c3, ""]];
      if (CS(s6) || jS(s6))
        return [[c3, s6]];
      if (a2)
        return RS(e6, s6, r6, a2);
      if (i4) {
        if ([_f(i4.style), _f(i4.explode), _f(i4.allowReserved)].some(function(e7) {
          return "undefined" !== e7;
        })) {
          var p2 = i4.style, d2 = i4.explode, u3 = i4.allowReserved;
          return RS(e6, s6, r6, { style: p2, explode: d2, allowReserved: u3 });
        }
        if (i4.contentType) {
          if ("application/json" === i4.contentType) {
            var h2 = "string" == typeof s6 ? s6 : $b(s6);
            return [[c3, l2(h2)]];
          }
          return [[c3, l2(s6.toString())]];
        }
        return "object" !== _f(s6) ? [[c3, l2(s6)]] : Array.isArray(s6) && s6.every(function(e7) {
          return "object" !== _f(e7);
        }) ? [[c3, Tb(s6).call(s6, l2).join(",")]] : [[c3, l2($b(s6))]];
      }
      return "object" !== _f(s6) ? [[c3, l2(s6)]] : Array.isArray(s6) ? "multi" === n6 ? [[c3, Tb(s6).call(s6, l2)]] : [[c3, Tb(s6).call(s6, l2).join(_S[n6 || "csv"])]] : [[c3, ""]];
    }
    function RS(e6, t5, r6, n6) {
      var o5, a2, i4, s6 = n6.style || "form", l2 = void 0 === n6.explode ? "form" === s6 : n6.explode, c3 = !r6 && (n6 && n6.allowReserved ? "unsafe" : "reserved"), p2 = function(e7) {
        return vS(e7, { escape: c3 });
      }, d2 = r6 ? function(e7) {
        return e7;
      } : function(e7) {
        return vS(e7, { escape: c3 });
      };
      return "object" !== _f(t5) ? [[d2(e6), p2(t5)]] : Array.isArray(t5) ? l2 ? [[d2(e6), Tb(t5).call(t5, p2)]] : [[d2(e6), Tb(t5).call(t5, p2).join(IS[s6])]] : "deepObject" === s6 ? Tb(a2 = Cb(t5)).call(a2, function(r7) {
        var n7;
        return [d2(Rb(n7 = "".concat(e6, "[")).call(n7, r7, "]")), p2(t5[r7])];
      }) : l2 ? Tb(i4 = Cb(t5)).call(i4, function(e7) {
        return [d2(e7), p2(t5[e7])];
      }) : [[d2(e6), Tb(o5 = Cb(t5)).call(o5, function(e7) {
        var r7;
        return [Rb(r7 = "".concat(d2(e7), ",")).call(r7, p2(t5[e7]))];
      }).join(",")]];
    }
    function LS(e6) {
      return Hb(e6).reduce(function(e7, t5) {
        var r6, n6 = Pf(t5, 2), o5 = Cf(PS(n6[0], n6[1], true));
        try {
          for (o5.s(); !(r6 = o5.n()).done; ) {
            var a2 = Pf(r6.value, 2), i4 = a2[0], s6 = a2[1];
            if (Array.isArray(s6)) {
              var l2, c3 = Cf(s6);
              try {
                for (c3.s(); !(l2 = c3.n()).done; ) {
                  var p2 = l2.value;
                  if (ArrayBuffer.isView(p2)) {
                    var d2 = new uS([p2]);
                    e7.append(i4, d2);
                  } else
                    e7.append(i4, p2);
                }
              } catch (e8) {
                c3.e(e8);
              } finally {
                c3.f();
              }
            } else if (ArrayBuffer.isView(s6)) {
              var u3 = new uS([s6]);
              e7.append(i4, u3);
            } else
              e7.append(i4, s6);
          }
        } catch (e8) {
          o5.e(e8);
        } finally {
          o5.f();
        }
        return e7;
      }, new dS());
    }
    function FS(e6) {
      var t5 = Cb(e6).reduce(function(t6, r6) {
        var n6, o5 = Cf(PS(r6, e6[r6]));
        try {
          for (o5.s(); !(n6 = o5.n()).done; ) {
            var a2 = Pf(n6.value, 2), i4 = a2[0], s6 = a2[1];
            t6[i4] = s6;
          }
        } catch (e7) {
          o5.e(e7);
        } finally {
          o5.f();
        }
        return t6;
      }, {});
      return f$(t5, { encode: false, indices: false }) || "";
    }
    function DS() {
      var e6 = arguments.length > 0 && void 0 !== arguments[0] ? arguments[0] : {}, t5 = e6.url, r6 = void 0 === t5 ? "" : t5, n6 = e6.query, o5 = e6.form, a2 = function() {
        for (var e7 = arguments.length, t6 = new Array(e7), r7 = 0; r7 < e7; r7++)
          t6[r7] = arguments[r7];
        var n7 = Wb(t6).call(t6, function(e8) {
          return e8;
        }).join("&");
        return n7 ? "?".concat(n7) : "";
      };
      if (o5) {
        var i4 = Cb(o5).some(function(e7) {
          var t6 = o5[e7].value;
          return CS(t6) || jS(t6);
        }), s6 = e6.headers["content-type"] || e6.headers["Content-Type"];
        if (i4 || /multipart\/form-data/i.test(s6)) {
          var l2 = LS(e6.form);
          xS(l2, e6);
        } else
          e6.body = FS(o5);
        delete e6.form;
      }
      if (n6) {
        var c3 = r6.split("?"), p2 = Pf(c3, 2), d2 = p2[0], u3 = p2[1], h2 = "";
        if (u3) {
          var f3 = h$(u3), m2 = Cb(n6);
          m2.forEach(function(e7) {
            return delete f3[e7];
          }), h2 = f$(f3, { encode: true });
        }
        var y2 = a2(h2, FS(n6));
        e6.url = d2 + y2, delete e6.query;
      }
      return e6;
    }
    function BS(e6, t5) {
      if (!(e6 instanceof t5))
        throw new TypeError("Cannot call a class as a function");
    }
    function NS(e6, t5) {
      for (var r6 = 0; r6 < t5.length; r6++) {
        var n6 = t5[r6];
        n6.enumerable = n6.enumerable || false, n6.configurable = true, "value" in n6 && (n6.writable = true), Ad(e6, n6.key, n6);
      }
    }
    function qS(e6, t5, r6) {
      return t5 && NS(e6.prototype, t5), r6 && NS(e6, r6), Ad(e6, "prototype", { writable: false }), e6;
    }
    var US = Co, zS = Ls.find, MS = true;
    "find" in [] && Array(1).find(function() {
      MS = false;
    }), US({ target: "Array", proto: true, forced: MS }, { find: function(e6) {
      return zS(this, e6, arguments.length > 1 ? arguments[1] : void 0);
    } });
    var HS = sc("Array").find, WS = pr, VS = HS, GS = Array.prototype;
    const KS = ut({ exports: {} }.exports = function(e6) {
      var t5 = e6.find;
      return e6 === GS || WS(GS, e6) && t5 === GS.find ? VS : t5;
    });
    const JS = ut({ exports: {} }.exports = Sv);
    var YS = Co, ZS = ft, QS = Fo, XS = _o, eA = Uo, tA = Kr, rA = Os, nA = ti, oA = oc("splice"), aA = ZS.TypeError, iA = Math.max, sA = Math.min;
    YS({ target: "Array", proto: true, forced: !oA }, { splice: function(e6, t5) {
      var r6, n6, o5, a2, i4, s6, l2 = tA(this), c3 = eA(l2), p2 = QS(e6, c3), d2 = arguments.length;
      if (0 === d2 ? r6 = n6 = 0 : 1 === d2 ? (r6 = 0, n6 = c3 - p2) : (r6 = d2 - 2, n6 = sA(iA(XS(t5), 0), c3 - p2)), c3 + r6 - n6 > 9007199254740991)
        throw aA("Maximum allowed length exceeded");
      for (o5 = rA(l2, n6), a2 = 0; a2 < n6; a2++)
        (i4 = p2 + a2) in l2 && nA(o5, a2, l2[i4]);
      if (o5.length = n6, r6 < n6) {
        for (a2 = p2; a2 < c3 - n6; a2++)
          s6 = a2 + r6, (i4 = a2 + n6) in l2 ? l2[s6] = l2[i4] : delete l2[s6];
        for (a2 = c3; a2 > c3 - n6 + r6; a2--)
          delete l2[a2 - 1];
      } else if (r6 > n6)
        for (a2 = c3 - n6; a2 > p2; a2--)
          s6 = a2 + r6 - 1, (i4 = a2 + n6 - 1) in l2 ? l2[s6] = l2[i4] : delete l2[s6];
      for (a2 = 0; a2 < r6; a2++)
        l2[a2 + p2] = arguments[a2 + 2];
      return l2.length = c3 - n6 + r6, o5;
    } });
    var lA = sc("Array").splice, cA = pr, pA = lA, dA = Array.prototype;
    const uA = ut({ exports: {} }.exports = function(e6) {
      var t5 = e6.splice;
      return e6 === dA || cA(dA, e6) && t5 === dA.splice ? pA : t5;
    });
    var hA, fA = globalThis && globalThis.__extends || (hA = function(e6, t5) {
      return hA = Object.setPrototypeOf || { __proto__: [] } instanceof Array && function(e7, t6) {
        e7.__proto__ = t6;
      } || function(e7, t6) {
        for (var r6 in t6)
          t6.hasOwnProperty(r6) && (e7[r6] = t6[r6]);
      }, hA(e6, t5);
    }, function(e6, t5) {
      function r6() {
        this.constructor = e6;
      }
      hA(e6, t5), e6.prototype = null === t5 ? Object.create(t5) : (r6.prototype = t5.prototype, new r6());
    }), mA = Object.prototype.hasOwnProperty;
    function yA(e6, t5) {
      return mA.call(e6, t5);
    }
    function gA(e6) {
      if (Array.isArray(e6)) {
        for (var t5 = new Array(e6.length), r6 = 0; r6 < t5.length; r6++)
          t5[r6] = "" + r6;
        return t5;
      }
      if (Object.keys)
        return Object.keys(e6);
      for (var n6 in t5 = [], e6)
        yA(e6, n6) && t5.push(n6);
      return t5;
    }
    function vA(e6) {
      switch (typeof e6) {
        case "object":
          return JSON.parse(JSON.stringify(e6));
        case "undefined":
          return null;
        default:
          return e6;
      }
    }
    function bA(e6) {
      for (var t5, r6 = 0, n6 = e6.length; r6 < n6; ) {
        if (!((t5 = e6.charCodeAt(r6)) >= 48 && t5 <= 57))
          return false;
        r6++;
      }
      return true;
    }
    function xA(e6) {
      return -1 === e6.indexOf("/") && -1 === e6.indexOf("~") ? e6 : e6.replace(/~/g, "~0").replace(/\//g, "~1");
    }
    function wA(e6) {
      return e6.replace(/~1/g, "/").replace(/~0/g, "~");
    }
    function $A(e6) {
      if (void 0 === e6)
        return true;
      if (e6) {
        if (Array.isArray(e6)) {
          for (var t5 = 0, r6 = e6.length; t5 < r6; t5++)
            if ($A(e6[t5]))
              return true;
        } else if ("object" == typeof e6) {
          var n6 = gA(e6), o5 = n6.length;
          for (t5 = 0; t5 < o5; t5++)
            if ($A(e6[n6[t5]]))
              return true;
        }
      }
      return false;
    }
    function kA(e6, t5) {
      var r6 = [e6];
      for (var n6 in t5) {
        var o5 = "object" == typeof t5[n6] ? JSON.stringify(t5[n6], null, 2) : t5[n6];
        void 0 !== o5 && r6.push(n6 + ": " + o5);
      }
      return r6.join("\n");
    }
    var SA = function(e6) {
      function t5(t6, r6, n6, o5, a2) {
        var i4 = this.constructor, s6 = e6.call(this, kA(t6, { name: r6, index: n6, operation: o5, tree: a2 })) || this;
        return s6.name = r6, s6.index = n6, s6.operation = o5, s6.tree = a2, Object.setPrototypeOf(s6, i4.prototype), s6.message = kA(t6, { name: r6, index: n6, operation: o5, tree: a2 }), s6;
      }
      return fA(t5, e6), t5;
    }(Error), AA = SA, EA = vA, OA = { add: function(e6, t5, r6) {
      return e6[t5] = this.value, { newDocument: r6 };
    }, remove: function(e6, t5, r6) {
      var n6 = e6[t5];
      return delete e6[t5], { newDocument: r6, removed: n6 };
    }, replace: function(e6, t5, r6) {
      var n6 = e6[t5];
      return e6[t5] = this.value, { newDocument: r6, removed: n6 };
    }, move: function(e6, t5, r6) {
      var n6 = CA(r6, this.path);
      n6 && (n6 = vA(n6));
      var o5 = jA(r6, { op: "remove", path: this.from }).removed;
      return jA(r6, { op: "add", path: this.path, value: o5 }), { newDocument: r6, removed: n6 };
    }, copy: function(e6, t5, r6) {
      var n6 = CA(r6, this.from);
      return jA(r6, { op: "add", path: this.path, value: vA(n6) }), { newDocument: r6 };
    }, test: function(e6, t5, r6) {
      return { newDocument: r6, test: RA(e6[t5], this.value) };
    }, _get: function(e6, t5, r6) {
      return this.value = e6[t5], { newDocument: r6 };
    } }, TA = { add: function(e6, t5, r6) {
      return bA(t5) ? e6.splice(t5, 0, this.value) : e6[t5] = this.value, { newDocument: r6, index: t5 };
    }, remove: function(e6, t5, r6) {
      return { newDocument: r6, removed: e6.splice(t5, 1)[0] };
    }, replace: function(e6, t5, r6) {
      var n6 = e6[t5];
      return e6[t5] = this.value, { newDocument: r6, removed: n6 };
    }, move: OA.move, copy: OA.copy, test: OA.test, _get: OA._get };
    function CA(e6, t5) {
      if ("" == t5)
        return e6;
      var r6 = { op: "_get", path: t5 };
      return jA(e6, r6), r6.value;
    }
    function jA(e6, t5, r6, n6, o5, a2) {
      if (void 0 === r6 && (r6 = false), void 0 === n6 && (n6 = true), void 0 === o5 && (o5 = true), void 0 === a2 && (a2 = 0), r6 && ("function" == typeof r6 ? r6(t5, 0, e6, t5.path) : _A(t5, 0)), "" === t5.path) {
        var i4 = { newDocument: e6 };
        if ("add" === t5.op)
          return i4.newDocument = t5.value, i4;
        if ("replace" === t5.op)
          return i4.newDocument = t5.value, i4.removed = e6, i4;
        if ("move" === t5.op || "copy" === t5.op)
          return i4.newDocument = CA(e6, t5.from), "move" === t5.op && (i4.removed = e6), i4;
        if ("test" === t5.op) {
          if (i4.test = RA(e6, t5.value), false === i4.test)
            throw new AA("Test operation failed", "TEST_OPERATION_FAILED", a2, t5, e6);
          return i4.newDocument = e6, i4;
        }
        if ("remove" === t5.op)
          return i4.removed = e6, i4.newDocument = null, i4;
        if ("_get" === t5.op)
          return t5.value = e6, i4;
        if (r6)
          throw new AA("Operation `op` property is not one of operations defined in RFC-6902", "OPERATION_OP_INVALID", a2, t5, e6);
        return i4;
      }
      n6 || (e6 = vA(e6));
      var s6 = (t5.path || "").split("/"), l2 = e6, c3 = 1, p2 = s6.length, d2 = void 0, u3 = void 0, h2 = void 0;
      for (h2 = "function" == typeof r6 ? r6 : _A; ; ) {
        if ((u3 = s6[c3]) && -1 != u3.indexOf("~") && (u3 = wA(u3)), o5 && "__proto__" == u3)
          throw new TypeError("JSON-Patch: modifying `__proto__` prop is banned for security reasons, if this was on purpose, please set `banPrototypeModifications` flag false and pass it to this function. More info in fast-json-patch README");
        if (r6 && void 0 === d2 && (void 0 === l2[u3] ? d2 = s6.slice(0, c3).join("/") : c3 == p2 - 1 && (d2 = t5.path), void 0 !== d2 && h2(t5, 0, e6, d2)), c3++, Array.isArray(l2)) {
          if ("-" === u3)
            u3 = l2.length;
          else {
            if (r6 && !bA(u3))
              throw new AA("Expected an unsigned base-10 integer value, making the new referenced value the array element with the zero-based index", "OPERATION_PATH_ILLEGAL_ARRAY_INDEX", a2, t5, e6);
            bA(u3) && (u3 = ~~u3);
          }
          if (c3 >= p2) {
            if (r6 && "add" === t5.op && u3 > l2.length)
              throw new AA("The specified index MUST NOT be greater than the number of elements in the array", "OPERATION_VALUE_OUT_OF_BOUNDS", a2, t5, e6);
            if (false === (i4 = TA[t5.op].call(t5, l2, u3, e6)).test)
              throw new AA("Test operation failed", "TEST_OPERATION_FAILED", a2, t5, e6);
            return i4;
          }
        } else if (c3 >= p2) {
          if (false === (i4 = OA[t5.op].call(t5, l2, u3, e6)).test)
            throw new AA("Test operation failed", "TEST_OPERATION_FAILED", a2, t5, e6);
          return i4;
        }
        if (l2 = l2[u3], r6 && c3 < p2 && (!l2 || "object" != typeof l2))
          throw new AA("Cannot perform operation at the desired path", "OPERATION_PATH_UNRESOLVABLE", a2, t5, e6);
      }
    }
    function IA(e6, t5, r6, n6, o5) {
      if (void 0 === n6 && (n6 = true), void 0 === o5 && (o5 = true), r6 && !Array.isArray(t5))
        throw new AA("Patch sequence must be an array", "SEQUENCE_NOT_AN_ARRAY");
      n6 || (e6 = vA(e6));
      for (var a2 = new Array(t5.length), i4 = 0, s6 = t5.length; i4 < s6; i4++)
        a2[i4] = jA(e6, t5[i4], r6, true, o5, i4), e6 = a2[i4].newDocument;
      return a2.newDocument = e6, a2;
    }
    function _A(e6, t5, r6, n6) {
      if ("object" != typeof e6 || null === e6 || Array.isArray(e6))
        throw new AA("Operation is not an object", "OPERATION_NOT_AN_OBJECT", t5, e6, r6);
      if (!OA[e6.op])
        throw new AA("Operation `op` property is not one of operations defined in RFC-6902", "OPERATION_OP_INVALID", t5, e6, r6);
      if ("string" != typeof e6.path)
        throw new AA("Operation `path` property is not a string", "OPERATION_PATH_INVALID", t5, e6, r6);
      if (0 !== e6.path.indexOf("/") && e6.path.length > 0)
        throw new AA('Operation `path` property must start with "/"', "OPERATION_PATH_INVALID", t5, e6, r6);
      if (("move" === e6.op || "copy" === e6.op) && "string" != typeof e6.from)
        throw new AA("Operation `from` property is not present (applicable in `move` and `copy` operations)", "OPERATION_FROM_REQUIRED", t5, e6, r6);
      if (("add" === e6.op || "replace" === e6.op || "test" === e6.op) && void 0 === e6.value)
        throw new AA("Operation `value` property is not present (applicable in `add`, `replace` and `test` operations)", "OPERATION_VALUE_REQUIRED", t5, e6, r6);
      if (("add" === e6.op || "replace" === e6.op || "test" === e6.op) && $A(e6.value))
        throw new AA("Operation `value` property is not present (applicable in `add`, `replace` and `test` operations)", "OPERATION_VALUE_CANNOT_CONTAIN_UNDEFINED", t5, e6, r6);
      if (r6) {
        if ("add" == e6.op) {
          var o5 = e6.path.split("/").length, a2 = n6.split("/").length;
          if (o5 !== a2 + 1 && o5 !== a2)
            throw new AA("Cannot perform an `add` operation at the desired path", "OPERATION_PATH_CANNOT_ADD", t5, e6, r6);
        } else if ("replace" === e6.op || "remove" === e6.op || "_get" === e6.op) {
          if (e6.path !== n6)
            throw new AA("Cannot perform the operation at a path that does not exist", "OPERATION_PATH_UNRESOLVABLE", t5, e6, r6);
        } else if ("move" === e6.op || "copy" === e6.op) {
          var i4 = PA([{ op: "_get", path: e6.from, value: void 0 }], r6);
          if (i4 && "OPERATION_PATH_UNRESOLVABLE" === i4.name)
            throw new AA("Cannot perform the operation from a path that does not exist", "OPERATION_FROM_UNRESOLVABLE", t5, e6, r6);
        }
      }
    }
    function PA(e6, t5, r6) {
      try {
        if (!Array.isArray(e6))
          throw new AA("Patch sequence must be an array", "SEQUENCE_NOT_AN_ARRAY");
        if (t5)
          IA(vA(t5), vA(e6), r6 || true);
        else {
          r6 = r6 || _A;
          for (var n6 = 0; n6 < e6.length; n6++)
            r6(e6[n6], n6, t5, void 0);
        }
      } catch (e7) {
        if (e7 instanceof AA)
          return e7;
        throw e7;
      }
    }
    function RA(e6, t5) {
      if (e6 === t5)
        return true;
      if (e6 && t5 && "object" == typeof e6 && "object" == typeof t5) {
        var r6, n6, o5, a2 = Array.isArray(e6), i4 = Array.isArray(t5);
        if (a2 && i4) {
          if ((n6 = e6.length) != t5.length)
            return false;
          for (r6 = n6; 0 != r6--; )
            if (!RA(e6[r6], t5[r6]))
              return false;
          return true;
        }
        if (a2 != i4)
          return false;
        var s6 = Object.keys(e6);
        if ((n6 = s6.length) !== Object.keys(t5).length)
          return false;
        for (r6 = n6; 0 != r6--; )
          if (!t5.hasOwnProperty(s6[r6]))
            return false;
        for (r6 = n6; 0 != r6--; )
          if (!RA(e6[o5 = s6[r6]], t5[o5]))
            return false;
        return true;
      }
      return e6 != e6 && t5 != t5;
    }
    const LA = Object.freeze(Object.defineProperty({ __proto__: null, JsonPatchError: AA, deepClone: EA, getValueByPointer: CA, applyOperation: jA, applyPatch: IA, applyReducer: function(e6, t5, r6) {
      var n6 = jA(e6, t5);
      if (false === n6.test)
        throw new AA("Test operation failed", "TEST_OPERATION_FAILED", r6, t5, e6);
      return n6.newDocument;
    }, validator: _A, validate: PA, _areEquals: RA }, Symbol.toStringTag, { value: "Module" }));
    var FA = /* @__PURE__ */ new WeakMap(), DA = function(e6) {
      this.observers = /* @__PURE__ */ new Map(), this.obj = e6;
    }, BA = function(e6, t5) {
      this.callback = e6, this.observer = t5;
    };
    function NA(e6, t5) {
      void 0 === t5 && (t5 = false);
      var r6 = FA.get(e6.object);
      qA(r6.value, e6.object, e6.patches, "", t5), e6.patches.length && IA(r6.value, e6.patches);
      var n6 = e6.patches;
      return n6.length > 0 && (e6.patches = [], e6.callback && e6.callback(n6)), n6;
    }
    function qA(e6, t5, r6, n6, o5) {
      if (t5 !== e6) {
        "function" == typeof t5.toJSON && (t5 = t5.toJSON());
        for (var a2 = gA(t5), i4 = gA(e6), s6 = false, l2 = i4.length - 1; l2 >= 0; l2--) {
          var c3 = e6[d2 = i4[l2]];
          if (!yA(t5, d2) || void 0 === t5[d2] && void 0 !== c3 && false === Array.isArray(t5))
            Array.isArray(e6) === Array.isArray(t5) ? (o5 && r6.push({ op: "test", path: n6 + "/" + xA(d2), value: vA(c3) }), r6.push({ op: "remove", path: n6 + "/" + xA(d2) }), s6 = true) : (o5 && r6.push({ op: "test", path: n6, value: e6 }), r6.push({ op: "replace", path: n6, value: t5 }));
          else {
            var p2 = t5[d2];
            "object" == typeof c3 && null != c3 && "object" == typeof p2 && null != p2 && Array.isArray(c3) === Array.isArray(p2) ? qA(c3, p2, r6, n6 + "/" + xA(d2), o5) : c3 !== p2 && (o5 && r6.push({ op: "test", path: n6 + "/" + xA(d2), value: vA(c3) }), r6.push({ op: "replace", path: n6 + "/" + xA(d2), value: vA(p2) }));
          }
        }
        if (s6 || a2.length != i4.length)
          for (l2 = 0; l2 < a2.length; l2++) {
            var d2;
            yA(e6, d2 = a2[l2]) || void 0 === t5[d2] || r6.push({ op: "add", path: n6 + "/" + xA(d2), value: vA(t5[d2]) });
          }
      }
    }
    const UA = Object.freeze(Object.defineProperty({ __proto__: null, unobserve: function(e6, t5) {
      t5.unobserve();
    }, observe: function(e6, t5) {
      var r6, n6, o5 = (n6 = e6, FA.get(n6));
      if (o5) {
        var a2 = function(e7, t6) {
          return e7.observers.get(t6);
        }(o5, t5);
        r6 = a2 && a2.observer;
      } else
        o5 = new DA(e6), FA.set(e6, o5);
      if (r6)
        return r6;
      if (r6 = {}, o5.value = vA(e6), t5) {
        r6.callback = t5, r6.next = null;
        var i4 = function() {
          NA(r6);
        }, s6 = function() {
          clearTimeout(r6.next), r6.next = setTimeout(i4);
        };
        "undefined" != typeof window && (window.addEventListener("mouseup", s6), window.addEventListener("keyup", s6), window.addEventListener("mousedown", s6), window.addEventListener("keydown", s6), window.addEventListener("change", s6));
      }
      return r6.patches = [], r6.object = e6, r6.unobserve = function() {
        NA(r6), clearTimeout(r6.next), function(e7, t6) {
          e7.observers.delete(t6.callback);
        }(o5, r6), "undefined" != typeof window && (window.removeEventListener("mouseup", s6), window.removeEventListener("keyup", s6), window.removeEventListener("mousedown", s6), window.removeEventListener("keydown", s6), window.removeEventListener("change", s6));
      }, o5.observers.set(t5, new BA(t5, r6)), r6;
    }, generate: NA, compare: function(e6, t5, r6) {
      void 0 === r6 && (r6 = false);
      var n6 = [];
      return qA(e6, t5, n6, "", r6), n6;
    } }, Symbol.toStringTag, { value: "Module" }));
    Object.assign({}, LA, UA, { JsonPatchError: SA, deepClone: vA, escapePathComponent: xA, unescapePathComponent: wA });
    var zA = function(e6) {
      return !(t5 = e6, !t5 || "object" != typeof t5 || function(e7) {
        var t6 = Object.prototype.toString.call(e7);
        return "[object RegExp]" === t6 || "[object Date]" === t6 || e7.$$typeof === MA;
      }(e6));
      var t5;
    }, MA = "function" == typeof Symbol && Symbol.for ? Symbol.for("react.element") : 60103;
    function HA(e6, t5) {
      return false !== t5.clone && t5.isMergeableObject(e6) ? KA((r6 = e6, Array.isArray(r6) ? [] : {}), e6, t5) : e6;
      var r6;
    }
    function WA(e6, t5, r6) {
      return e6.concat(t5).map(function(e7) {
        return HA(e7, r6);
      });
    }
    function VA(e6) {
      return Object.keys(e6).concat((t5 = e6, Object.getOwnPropertySymbols ? Object.getOwnPropertySymbols(t5).filter(function(e7) {
        return t5.propertyIsEnumerable(e7);
      }) : []));
      var t5;
    }
    function GA(e6, t5) {
      try {
        return t5 in e6;
      } catch (e7) {
        return false;
      }
    }
    function KA(e6, t5, r6) {
      (r6 = r6 || {}).arrayMerge = r6.arrayMerge || WA, r6.isMergeableObject = r6.isMergeableObject || zA, r6.cloneUnlessOtherwiseSpecified = HA;
      var n6 = Array.isArray(t5);
      return n6 === Array.isArray(e6) ? n6 ? r6.arrayMerge(e6, t5, r6) : function(e7, t6, r7) {
        var n7 = {};
        return r7.isMergeableObject(e7) && VA(e7).forEach(function(t7) {
          n7[t7] = HA(e7[t7], r7);
        }), VA(t6).forEach(function(o5) {
          var a2, i4;
          GA(a2 = e7, i4 = o5) && (!Object.hasOwnProperty.call(a2, i4) || !Object.propertyIsEnumerable.call(a2, i4)) || (GA(e7, o5) && r7.isMergeableObject(t6[o5]) ? n7[o5] = function(e8, t7) {
            if (!t7.customMerge)
              return KA;
            var r8 = t7.customMerge(e8);
            return "function" == typeof r8 ? r8 : KA;
          }(o5, r7)(e7[o5], t6[o5], r7) : n7[o5] = HA(t6[o5], r7));
        }), n7;
      }(e6, t5, r6) : HA(t5, r6);
    }
    KA.all = function(e6, t5) {
      if (!Array.isArray(e6))
        throw new Error("first argument should be an array");
      return e6.reduce(function(e7, r6) {
        return KA(e7, r6, t5);
      }, {});
    };
    var JA = KA;
    const YA = { add: function(e6, t5) {
      return { op: "add", path: e6, value: t5 };
    }, replace: QA, remove: function(e6) {
      return { op: "remove", path: e6 };
    }, merge: function(e6, t5) {
      return { type: "mutation", op: "merge", path: e6, value: t5 };
    }, mergeDeep: function(e6, t5) {
      return { type: "mutation", op: "mergeDeep", path: e6, value: t5 };
    }, context: function(e6, t5) {
      return { type: "context", path: e6, value: t5 };
    }, getIn: function(e6, t5) {
      return t5.reduce(function(e7, t6) {
        return void 0 !== t6 && e7 ? e7[t6] : e7;
      }, e6);
    }, applyPatch: function(e6, t5, r6) {
      if (r6 = r6 || {}, "merge" === (t5 = Td(Td({}, t5), {}, { path: t5.path && ZA(t5.path) })).op) {
        var n6 = dE(e6, t5.path);
        Hd(n6, t5.value), IA(e6, [QA(t5.path, n6)]);
      } else if ("mergeDeep" === t5.op) {
        var o5 = dE(e6, t5.path), a2 = JA(o5, t5.value);
        e6 = IA(e6, [QA(t5.path, a2)]).newDocument;
      } else if ("add" === t5.op && "" === t5.path && aE(t5.value)) {
        IA(e6, Cb(t5.value).reduce(function(e7, r7) {
          return e7.push({ op: "add", path: "/".concat(ZA(r7)), value: t5.value[r7] }), e7;
        }, []));
      } else if ("replace" === t5.op && "" === t5.path) {
        var i4 = t5.value;
        r6.allowMetaPatches && t5.meta && cE(t5) && (Array.isArray(t5.value) || aE(t5.value)) && (i4 = Td(Td({}, i4), t5.meta)), e6 = i4;
      } else if (IA(e6, [t5]), r6.allowMetaPatches && t5.meta && cE(t5) && (Array.isArray(t5.value) || aE(t5.value))) {
        var s6 = Td(Td({}, dE(e6, t5.path)), t5.meta);
        IA(e6, [QA(t5.path, s6)]);
      }
      return e6;
    }, parentPathMatch: function(e6, t5) {
      if (!Array.isArray(t5))
        return false;
      for (var r6 = 0, n6 = t5.length; r6 < n6; r6 += 1)
        if (t5[r6] !== e6[r6])
          return false;
      return true;
    }, flatten: nE, fullyNormalizeArray: function(e6) {
      return oE(nE(rE(e6)));
    }, normalizeArray: rE, isPromise: function(e6) {
      return aE(e6) && iE(e6.then);
    }, forEachNew: function(e6, t5) {
      try {
        return XA(e6, tE, t5);
      } catch (e7) {
        return e7;
      }
    }, forEachNewPrimitive: function(e6, t5) {
      try {
        return XA(e6, eE, t5);
      } catch (e7) {
        return e7;
      }
    }, isJsonPatch: sE, isContextPatch: function(e6) {
      return pE(e6) && "context" === e6.type;
    }, isPatch: pE, isMutation: lE, isAdditiveMutation: cE, isGenerator: function(e6) {
      return "[object GeneratorFunction]" === Object.prototype.toString.call(e6);
    }, isFunction: iE, isObject: aE, isError: function(e6) {
      return e6 instanceof Error;
    } };
    function ZA(e6) {
      return Array.isArray(e6) ? e6.length < 1 ? "" : "/".concat(Tb(e6).call(e6, function(e7) {
        return (e7 + "").replace(/~/g, "~0").replace(/\//g, "~1");
      }).join("/")) : e6;
    }
    function QA(e6, t5, r6) {
      return { op: "replace", path: e6, value: t5, meta: r6 };
    }
    function XA(e6, t5, r6) {
      var n6;
      return oE(nE(Tb(n6 = Wb(e6).call(e6, cE)).call(n6, function(e7) {
        return t5(e7.value, r6, e7.path);
      }) || []));
    }
    function eE(e6, t5, r6) {
      return r6 = r6 || [], Array.isArray(e6) ? Tb(e6).call(e6, function(e7, n7) {
        return eE(e7, t5, Rb(r6).call(r6, n7));
      }) : aE(e6) ? Tb(n6 = Cb(e6)).call(n6, function(n7) {
        return eE(e6[n7], t5, Rb(r6).call(r6, n7));
      }) : t5(e6, r6[r6.length - 1], r6);
      var n6;
    }
    function tE(e6, t5, r6) {
      var n6 = [];
      if ((r6 = r6 || []).length > 0) {
        var o5 = t5(e6, r6[r6.length - 1], r6);
        o5 && (n6 = Rb(n6).call(n6, o5));
      }
      if (Array.isArray(e6)) {
        var a2 = Tb(e6).call(e6, function(e7, n7) {
          return tE(e7, t5, Rb(r6).call(r6, n7));
        });
        a2 && (n6 = Rb(n6).call(n6, a2));
      } else if (aE(e6)) {
        var i4, s6 = Tb(i4 = Cb(e6)).call(i4, function(n7) {
          return tE(e6[n7], t5, Rb(r6).call(r6, n7));
        });
        s6 && (n6 = Rb(n6).call(n6, s6));
      }
      return nE(n6);
    }
    function rE(e6) {
      return Array.isArray(e6) ? e6 : [e6];
    }
    function nE(e6) {
      var t5;
      return Rb(t5 = []).apply(t5, fS(Tb(e6).call(e6, function(e7) {
        return Array.isArray(e7) ? nE(e7) : e7;
      })));
    }
    function oE(e6) {
      return Wb(e6).call(e6, function(e7) {
        return void 0 !== e7;
      });
    }
    function aE(e6) {
      return e6 && "object" === _f(e6);
    }
    function iE(e6) {
      return e6 && "function" == typeof e6;
    }
    function sE(e6) {
      if (pE(e6)) {
        var t5 = e6.op;
        return "add" === t5 || "remove" === t5 || "replace" === t5;
      }
      return false;
    }
    function lE(e6) {
      return sE(e6) || pE(e6) && "mutation" === e6.type;
    }
    function cE(e6) {
      return lE(e6) && ("add" === e6.op || "replace" === e6.op || "merge" === e6.op || "mergeDeep" === e6.op);
    }
    function pE(e6) {
      return e6 && "object" === _f(e6);
    }
    function dE(e6, t5) {
      try {
        return CA(e6, t5);
      } catch (e7) {
        return console.error(e7), {};
      }
    }
    var uE = { exports: {} }, hE = mt(function() {
      if ("function" == typeof ArrayBuffer) {
        var e6 = new ArrayBuffer(8);
        Object.isExtensible(e6) && Object.defineProperty(e6, "a", { value: 8 });
      }
    }), fE = mt, mE = nr, yE = Ht, gE = hE, vE = Object.isExtensible, bE = fE(function() {
      vE(1);
    }) || gE ? function(e6) {
      return !!mE(e6) && (!gE || "ArrayBuffer" != yE(e6)) && (!vE || vE(e6));
    } : vE, xE = !mt(function() {
      return Object.isExtensible(Object.preventExtensions({}));
    }), wE = Co, $E = Ot, kE = Go, SE = nr, AE = Zr, EE = Xn.f, OE = Ka, TE = Za, CE = bE, jE = xE, IE = false, _E = rn("meta"), PE = 0, RE = function(e6) {
      EE(e6, _E, { value: { objectID: "O" + PE++, weakData: {} } });
    }, LE = uE.exports = { enable: function() {
      LE.enable = function() {
      }, IE = true;
      var e6 = OE.f, t5 = $E([].splice), r6 = {};
      r6[_E] = 1, e6(r6).length && (OE.f = function(r7) {
        for (var n6 = e6(r7), o5 = 0, a2 = n6.length; o5 < a2; o5++)
          if (n6[o5] === _E) {
            t5(n6, o5, 1);
            break;
          }
        return n6;
      }, wE({ target: "Object", stat: true, forced: true }, { getOwnPropertyNames: TE.f }));
    }, fastKey: function(e6, t5) {
      if (!SE(e6))
        return "symbol" == typeof e6 ? e6 : ("string" == typeof e6 ? "S" : "P") + e6;
      if (!AE(e6, _E)) {
        if (!CE(e6))
          return "F";
        if (!t5)
          return "E";
        RE(e6);
      }
      return e6[_E].objectID;
    }, getWeakData: function(e6, t5) {
      if (!AE(e6, _E)) {
        if (!CE(e6))
          return true;
        if (!t5)
          return false;
        RE(e6);
      }
      return e6[_E].weakData;
    }, onFreeze: function(e6) {
      return jE && IE && CE(e6) && !AE(e6, _E) && RE(e6), e6;
    } };
    kE[_E] = true;
    var FE = Co, DE = ft, BE = uE.exports, NE = mt, qE = go, UE = nm, zE = Bm, ME = Tt, HE = nr, WE = _i, VE = Xn.f, GE = Ls.forEach, KE = jt, JE = is.set, YE = is.getterFor, ZE = Ot, QE = Im, XE = uE.exports.getWeakData, eO = ao, tO = nr, rO = Bm, nO = nm, oO = Zr, aO = is.set, iO = is.getterFor, sO = Ls.find, lO = Ls.findIndex, cO = ZE([].splice), pO = 0, dO = function(e6) {
      return e6.frozen || (e6.frozen = new uO());
    }, uO = function() {
      this.entries = [];
    }, hO = function(e6, t5) {
      return sO(e6.entries, function(e7) {
        return e7[0] === t5;
      });
    };
    uO.prototype = { get: function(e6) {
      var t5 = hO(this, e6);
      if (t5)
        return t5[1];
    }, has: function(e6) {
      return !!hO(this, e6);
    }, set: function(e6, t5) {
      var r6 = hO(this, e6);
      r6 ? r6[1] = t5 : this.entries.push([e6, t5]);
    }, delete: function(e6) {
      var t5 = lO(this.entries, function(t6) {
        return t6[0] === e6;
      });
      return ~t5 && cO(this.entries, t5, 1), !!~t5;
    } };
    var fO, mO = { getConstructor: function(e6, t5, r6, n6) {
      var o5 = e6(function(e7, o6) {
        rO(e7, a2), aO(e7, { type: t5, id: pO++, frozen: void 0 }), null != o6 && nO(o6, e7[n6], { that: e7, AS_ENTRIES: r6 });
      }), a2 = o5.prototype, i4 = iO(t5), s6 = function(e7, t6, r7) {
        var n7 = i4(e7), o6 = XE(eO(t6), true);
        return true === o6 ? dO(n7).set(t6, r7) : o6[n7.id] = r7, e7;
      };
      return QE(a2, { delete: function(e7) {
        var t6 = i4(this);
        if (!tO(e7))
          return false;
        var r7 = XE(e7);
        return true === r7 ? dO(t6).delete(e7) : r7 && oO(r7, t6.id) && delete r7[t6.id];
      }, has: function(e7) {
        var t6 = i4(this);
        if (!tO(e7))
          return false;
        var r7 = XE(e7);
        return true === r7 ? dO(t6).has(e7) : r7 && oO(r7, t6.id);
      } }), QE(a2, r6 ? { get: function(e7) {
        var t6 = i4(this);
        if (tO(e7)) {
          var r7 = XE(e7);
          return true === r7 ? dO(t6).get(e7) : r7 ? r7[t6.id] : void 0;
        }
      }, set: function(e7, t6) {
        return s6(this, e7, t6);
      } } : { add: function(e7) {
        return s6(this, e7, true);
      } }), o5;
    } }, yO = ft, gO = Ot, vO = Im, bO = uE.exports, xO = mO, wO = nr, $O = bE, kO = is.enforce, SO = Mi, AO = !yO.ActiveXObject && "ActiveXObject" in yO, EO = function(e6) {
      return function() {
        return e6(this, arguments.length ? arguments[0] : void 0);
      };
    }, OO = function(e6, t5, r6) {
      var n6, o5 = -1 !== e6.indexOf("Map"), a2 = -1 !== e6.indexOf("Weak"), i4 = o5 ? "set" : "add", s6 = DE[e6], l2 = s6 && s6.prototype, c3 = {};
      if (KE && ME(s6) && (a2 || l2.forEach && !NE(function() {
        new s6().entries().next();
      }))) {
        var p2 = (n6 = t5(function(t6, r7) {
          JE(zE(t6, p2), { type: e6, collection: new s6() }), null != r7 && UE(r7, t6[i4], { that: t6, AS_ENTRIES: o5 });
        })).prototype, d2 = YE(e6);
        GE(["add", "clear", "delete", "forEach", "get", "has", "set", "keys", "values", "entries"], function(e7) {
          var t6 = "add" == e7 || "set" == e7;
          !(e7 in l2) || a2 && "clear" == e7 || qE(p2, e7, function(r7, n7) {
            var o6 = d2(this).collection;
            if (!t6 && a2 && !HE(r7))
              return "get" == e7 && void 0;
            var i5 = o6[e7](0 === r7 ? 0 : r7, n7);
            return t6 ? this : i5;
          });
        }), a2 || VE(p2, "size", { configurable: true, get: function() {
          return d2(this).collection.size;
        } });
      } else
        n6 = r6.getConstructor(t5, e6, o5, i4), BE.enable();
      return WE(n6, e6, false, true), c3[e6] = n6, FE({ global: true, forced: true }, c3), a2 || r6.setStrong(n6, e6, o5), n6;
    }("WeakMap", EO, xO);
    if (SO && AO) {
      fO = xO.getConstructor(EO, "WeakMap", true), bO.enable();
      var TO = OO.prototype, CO = gO(TO.delete), jO = gO(TO.has), IO = gO(TO.get), _O = gO(TO.set);
      vO(TO, { delete: function(e6) {
        if (wO(e6) && !$O(e6)) {
          var t5 = kO(this);
          return t5.frozen || (t5.frozen = new fO()), CO(this, e6) || t5.frozen.delete(e6);
        }
        return CO(this, e6);
      }, has: function(e6) {
        if (wO(e6) && !$O(e6)) {
          var t5 = kO(this);
          return t5.frozen || (t5.frozen = new fO()), jO(this, e6) || t5.frozen.has(e6);
        }
        return jO(this, e6);
      }, get: function(e6) {
        if (wO(e6) && !$O(e6)) {
          var t5 = kO(this);
          return t5.frozen || (t5.frozen = new fO()), jO(this, e6) ? IO(this, e6) : t5.frozen.get(e6);
        }
        return IO(this, e6);
      }, set: function(e6, t5) {
        if (wO(e6) && !$O(e6)) {
          var r6 = kO(this);
          r6.frozen || (r6.frozen = new fO()), jO(this, e6) ? _O(this, e6, t5) : r6.frozen.set(e6, t5);
        } else
          _O(this, e6, t5);
        return this;
      } });
    }
    const PO = ut({ exports: {} }.exports = or.WeakMap);
    var RO = mt, LO = fn("iterator"), FO = !RO(function() {
      var e6 = new URL("b?a=1&b=2&c=3", "http://a"), t5 = e6.searchParams, r6 = "";
      return e6.pathname = "c%20d", t5.forEach(function(e7, n6) {
        t5.delete("b"), r6 += n6 + e7;
      }), !e6.toJSON || !t5.sort || "http://a/c%20d?a=1&c=3" !== e6.href || "3" !== t5.get("c") || "a=1" !== String(new URLSearchParams("?a=1")) || !t5[LO] || "a" !== new URL("https://a@b").username || "b" !== new URLSearchParams(new URLSearchParams("a=b")).get("a") || "xn--e1aybc" !== new URL("http://\u0442\u0435\u0441\u0442").host || "#%D0%B1" !== new URL("http://a#\u0431").hash || "a1c3" !== r6 || "x" !== new URL("http://x", void 0).host;
    }), DO = si, BO = Math.floor, NO = function(e6, t5) {
      var r6 = e6.length, n6 = BO(r6 / 2);
      return r6 < 8 ? qO(e6, t5) : UO(e6, NO(DO(e6, 0, n6), t5), NO(DO(e6, n6), t5), t5);
    }, qO = function(e6, t5) {
      for (var r6, n6, o5 = e6.length, a2 = 1; a2 < o5; ) {
        for (n6 = a2, r6 = e6[a2]; n6 && t5(e6[n6 - 1], r6) > 0; )
          e6[n6] = e6[--n6];
        n6 !== a2++ && (e6[n6] = r6);
      }
      return e6;
    }, UO = function(e6, t5, r6, n6) {
      for (var o5 = t5.length, a2 = r6.length, i4 = 0, s6 = 0; i4 < o5 || s6 < a2; )
        e6[i4 + s6] = i4 < o5 && s6 < a2 ? n6(t5[i4], r6[s6]) <= 0 ? t5[i4++] : r6[s6++] : i4 < o5 ? t5[i4++] : r6[s6++];
      return e6;
    }, zO = Co, MO = ft, HO = cr, WO = Pt, VO = Ot, GO = FO, KO = yi, JO = Im, YO = _i, ZO = ip, QO = is, XO = Bm, eT = Tt, tT = Zr, rT = Qn, nT = ba, oT = ao, aT = nr, iT = $a, sT = Ga, lT = qt, cT = lf, pT = xh, dT = Vm, uT = NO, hT = fn("iterator"), fT = QO.set, mT = QO.getterFor("URLSearchParams"), yT = QO.getterFor("URLSearchParamsIterator"), gT = HO("fetch"), vT = HO("Request"), bT = HO("Headers"), xT = vT && vT.prototype, wT = bT && bT.prototype, $T = MO.RegExp, kT = MO.TypeError, ST = MO.decodeURIComponent, AT = MO.encodeURIComponent, ET = VO("".charAt), OT = VO([].join), TT = VO([].push), CT = VO("".replace), jT = VO([].shift), IT = VO([].splice), _T = VO("".split), PT = VO("".slice), RT = /\+/g, LT = Array(4), FT = function(e6) {
      return LT[e6 - 1] || (LT[e6 - 1] = $T("((?:%[\\da-f]{2}){" + e6 + "})", "gi"));
    }, DT = function(e6) {
      try {
        return ST(e6);
      } catch (t5) {
        return e6;
      }
    }, BT = function(e6) {
      var t5 = CT(e6, RT, " "), r6 = 4;
      try {
        return ST(t5);
      } catch (e7) {
        for (; r6; )
          t5 = CT(t5, FT(r6--), DT);
        return t5;
      }
    }, NT = /[!'()~]|%20/g, qT = { "!": "%21", "'": "%27", "(": "%28", ")": "%29", "~": "%7E", "%20": "+" }, UT = function(e6) {
      return qT[e6];
    }, zT = function(e6) {
      return CT(AT(e6), NT, UT);
    }, MT = ZO(function(e6, t5) {
      fT(this, { type: "URLSearchParamsIterator", iterator: cT(mT(e6).entries), kind: t5 });
    }, "Iterator", function() {
      var e6 = yT(this), t5 = e6.kind, r6 = e6.iterator.next(), n6 = r6.value;
      return r6.done || (r6.value = "keys" === t5 ? n6.key : "values" === t5 ? n6.value : [n6.key, n6.value]), r6;
    }, true), HT = function(e6) {
      this.entries = [], this.url = null, void 0 !== e6 && (aT(e6) ? this.parseObject(e6) : this.parseQuery("string" == typeof e6 ? "?" === ET(e6, 0) ? PT(e6, 1) : e6 : iT(e6)));
    };
    HT.prototype = { type: "URLSearchParams", bindURL: function(e6) {
      this.url = e6, this.update();
    }, parseObject: function(e6) {
      var t5, r6, n6, o5, a2, i4, s6, l2 = pT(e6);
      if (l2)
        for (r6 = (t5 = cT(e6, l2)).next; !(n6 = WO(r6, t5)).done; ) {
          if (a2 = (o5 = cT(oT(n6.value))).next, (i4 = WO(a2, o5)).done || (s6 = WO(a2, o5)).done || !WO(a2, o5).done)
            throw kT("Expected sequence with length 2");
          TT(this.entries, { key: iT(i4.value), value: iT(s6.value) });
        }
      else
        for (var c3 in e6)
          tT(e6, c3) && TT(this.entries, { key: c3, value: iT(e6[c3]) });
    }, parseQuery: function(e6) {
      if (e6)
        for (var t5, r6, n6 = _T(e6, "&"), o5 = 0; o5 < n6.length; )
          (t5 = n6[o5++]).length && (r6 = _T(t5, "="), TT(this.entries, { key: BT(jT(r6)), value: BT(OT(r6, "=")) }));
    }, serialize: function() {
      for (var e6, t5 = this.entries, r6 = [], n6 = 0; n6 < t5.length; )
        e6 = t5[n6++], TT(r6, zT(e6.key) + "=" + zT(e6.value));
      return OT(r6, "&");
    }, update: function() {
      this.entries.length = 0, this.parseQuery(this.url.query);
    }, updateURL: function() {
      this.url && this.url.update();
    } };
    var WT = function() {
      XO(this, VT);
      var e6 = arguments.length > 0 ? arguments[0] : void 0;
      fT(this, new HT(e6));
    }, VT = WT.prototype;
    if (JO(VT, { append: function(e6, t5) {
      dT(arguments.length, 2);
      var r6 = mT(this);
      TT(r6.entries, { key: iT(e6), value: iT(t5) }), r6.updateURL();
    }, delete: function(e6) {
      dT(arguments.length, 1);
      for (var t5 = mT(this), r6 = t5.entries, n6 = iT(e6), o5 = 0; o5 < r6.length; )
        r6[o5].key === n6 ? IT(r6, o5, 1) : o5++;
      t5.updateURL();
    }, get: function(e6) {
      dT(arguments.length, 1);
      for (var t5 = mT(this).entries, r6 = iT(e6), n6 = 0; n6 < t5.length; n6++)
        if (t5[n6].key === r6)
          return t5[n6].value;
      return null;
    }, getAll: function(e6) {
      dT(arguments.length, 1);
      for (var t5 = mT(this).entries, r6 = iT(e6), n6 = [], o5 = 0; o5 < t5.length; o5++)
        t5[o5].key === r6 && TT(n6, t5[o5].value);
      return n6;
    }, has: function(e6) {
      dT(arguments.length, 1);
      for (var t5 = mT(this).entries, r6 = iT(e6), n6 = 0; n6 < t5.length; )
        if (t5[n6++].key === r6)
          return true;
      return false;
    }, set: function(e6, t5) {
      dT(arguments.length, 1);
      for (var r6, n6 = mT(this), o5 = n6.entries, a2 = false, i4 = iT(e6), s6 = iT(t5), l2 = 0; l2 < o5.length; l2++)
        (r6 = o5[l2]).key === i4 && (a2 ? IT(o5, l2--, 1) : (a2 = true, r6.value = s6));
      a2 || TT(o5, { key: i4, value: s6 }), n6.updateURL();
    }, sort: function() {
      var e6 = mT(this);
      uT(e6.entries, function(e7, t5) {
        return e7.key > t5.key ? 1 : -1;
      }), e6.updateURL();
    }, forEach: function(e6) {
      for (var t5, r6 = mT(this).entries, n6 = rT(e6, arguments.length > 1 ? arguments[1] : void 0), o5 = 0; o5 < r6.length; )
        n6((t5 = r6[o5++]).value, t5.key, this);
    }, keys: function() {
      return new MT(this, "keys");
    }, values: function() {
      return new MT(this, "values");
    }, entries: function() {
      return new MT(this, "entries");
    } }, { enumerable: true }), KO(VT, hT, VT.entries, { name: "entries" }), KO(VT, "toString", function() {
      return mT(this).serialize();
    }, { enumerable: true }), YO(WT, "URLSearchParams"), zO({ global: true, forced: !GO }, { URLSearchParams: WT }), !GO && eT(bT)) {
      var GT = VO(wT.has), KT = VO(wT.set), JT = function(e6) {
        if (aT(e6)) {
          var t5, r6 = e6.body;
          if ("URLSearchParams" === nT(r6))
            return t5 = e6.headers ? new bT(e6.headers) : new bT(), GT(t5, "content-type") || KT(t5, "content-type", "application/x-www-form-urlencoded;charset=UTF-8"), sT(e6, { body: lT(0, iT(r6)), headers: lT(0, t5) });
        }
        return e6;
      };
      if (eT(gT) && zO({ global: true, enumerable: true, forced: true }, { fetch: function(e6) {
        return gT(e6, arguments.length > 1 ? JT(arguments[1]) : {});
      } }), eT(vT)) {
        var YT = function(e6) {
          return XO(this, xT), new vT(e6, arguments.length > 1 ? JT(arguments[1]) : {});
        };
        xT.constructor = YT, YT.prototype = xT, zO({ global: true, forced: true }, { Request: YT });
      }
    }
    const ZT = ut({ exports: {} }.exports = or.URLSearchParams);
    function QT(e6, t5) {
      function r6() {
        Error.captureStackTrace ? Error.captureStackTrace(this, this.constructor) : this.stack = new Error().stack;
        for (var e7 = arguments.length, r7 = new Array(e7), n6 = 0; n6 < e7; n6++)
          r7[n6] = arguments[n6];
        this.message = r7[0], t5 && t5.apply(this, r7);
      }
      return r6.prototype = new Error(), r6.prototype.name = e6, r6.prototype.constructor = r6, r6;
    }
    var XT = { exports: {} }, eC = XT.exports = function(e6) {
      return new tC(e6);
    };
    function tC(e6) {
      this.value = e6;
    }
    function rC(e6, t5, r6) {
      var n6 = [], o5 = [], a2 = true;
      return function e7(i4) {
        var s6 = r6 ? nC(i4) : i4, l2 = {}, c3 = true, p2 = { node: s6, node_: i4, path: [].concat(n6), parent: o5[o5.length - 1], parents: o5, key: n6.slice(-1)[0], isRoot: 0 === n6.length, level: n6.length, circular: null, update: function(e8, t6) {
          p2.isRoot || (p2.parent.node[p2.key] = e8), p2.node = e8, t6 && (c3 = false);
        }, delete: function(e8) {
          delete p2.parent.node[p2.key], e8 && (c3 = false);
        }, remove: function(e8) {
          iC(p2.parent.node) ? p2.parent.node.splice(p2.key, 1) : delete p2.parent.node[p2.key], e8 && (c3 = false);
        }, keys: null, before: function(e8) {
          l2.before = e8;
        }, after: function(e8) {
          l2.after = e8;
        }, pre: function(e8) {
          l2.pre = e8;
        }, post: function(e8) {
          l2.post = e8;
        }, stop: function() {
          a2 = false;
        }, block: function() {
          c3 = false;
        } };
        if (!a2)
          return p2;
        function d2() {
          if ("object" == typeof p2.node && null !== p2.node) {
            p2.keys && p2.node_ === p2.node || (p2.keys = oC(p2.node)), p2.isLeaf = 0 == p2.keys.length;
            for (var e8 = 0; e8 < o5.length; e8++)
              if (o5[e8].node_ === i4) {
                p2.circular = o5[e8];
                break;
              }
          } else
            p2.isLeaf = true, p2.keys = null;
          p2.notLeaf = !p2.isLeaf, p2.notRoot = !p2.isRoot;
        }
        d2();
        var u3 = t5.call(p2, p2.node);
        return void 0 !== u3 && p2.update && p2.update(u3), l2.before && l2.before.call(p2, p2.node), c3 ? ("object" != typeof p2.node || null === p2.node || p2.circular || (o5.push(p2), d2(), sC(p2.keys, function(t6, o6) {
          n6.push(t6), l2.pre && l2.pre.call(p2, p2.node[t6], t6);
          var a3 = e7(p2.node[t6]);
          r6 && lC.call(p2.node, t6) && (p2.node[t6] = a3.node), a3.isLast = o6 == p2.keys.length - 1, a3.isFirst = 0 == o6, l2.post && l2.post.call(p2, a3), n6.pop();
        }), o5.pop()), l2.after && l2.after.call(p2, p2.node), p2) : p2;
      }(e6).node;
    }
    function nC(e6) {
      if ("object" == typeof e6 && null !== e6) {
        var t5;
        if (iC(e6))
          t5 = [];
        else if ("[object Date]" === aC(e6))
          t5 = new Date(e6.getTime ? e6.getTime() : e6);
        else if ("[object RegExp]" === aC(e6))
          t5 = new RegExp(e6);
        else if (function(e7) {
          return "[object Error]" === aC(e7);
        }(e6))
          t5 = { message: e6.message };
        else if (function(e7) {
          return "[object Boolean]" === aC(e7);
        }(e6))
          t5 = new Boolean(e6);
        else if (function(e7) {
          return "[object Number]" === aC(e7);
        }(e6))
          t5 = new Number(e6);
        else if (function(e7) {
          return "[object String]" === aC(e7);
        }(e6))
          t5 = new String(e6);
        else if (Object.create && Object.getPrototypeOf)
          t5 = Object.create(Object.getPrototypeOf(e6));
        else if (e6.constructor === Object)
          t5 = {};
        else {
          var r6 = e6.constructor && e6.constructor.prototype || e6.__proto__ || {}, n6 = function() {
          };
          n6.prototype = r6, t5 = new n6();
        }
        return sC(oC(e6), function(r7) {
          t5[r7] = e6[r7];
        }), t5;
      }
      return e6;
    }
    tC.prototype.get = function(e6) {
      for (var t5 = this.value, r6 = 0; r6 < e6.length; r6++) {
        var n6 = e6[r6];
        if (!t5 || !lC.call(t5, n6)) {
          t5 = void 0;
          break;
        }
        t5 = t5[n6];
      }
      return t5;
    }, tC.prototype.has = function(e6) {
      for (var t5 = this.value, r6 = 0; r6 < e6.length; r6++) {
        var n6 = e6[r6];
        if (!t5 || !lC.call(t5, n6))
          return false;
        t5 = t5[n6];
      }
      return true;
    }, tC.prototype.set = function(e6, t5) {
      for (var r6 = this.value, n6 = 0; n6 < e6.length - 1; n6++) {
        var o5 = e6[n6];
        lC.call(r6, o5) || (r6[o5] = {}), r6 = r6[o5];
      }
      return r6[e6[n6]] = t5, t5;
    }, tC.prototype.map = function(e6) {
      return rC(this.value, e6, true);
    }, tC.prototype.forEach = function(e6) {
      return this.value = rC(this.value, e6, false), this.value;
    }, tC.prototype.reduce = function(e6, t5) {
      var r6 = 1 === arguments.length, n6 = r6 ? this.value : t5;
      return this.forEach(function(t6) {
        this.isRoot && r6 || (n6 = e6.call(this, n6, t6));
      }), n6;
    }, tC.prototype.paths = function() {
      var e6 = [];
      return this.forEach(function(t5) {
        e6.push(this.path);
      }), e6;
    }, tC.prototype.nodes = function() {
      var e6 = [];
      return this.forEach(function(t5) {
        e6.push(this.node);
      }), e6;
    }, tC.prototype.clone = function() {
      var e6 = [], t5 = [];
      return function r6(n6) {
        for (var o5 = 0; o5 < e6.length; o5++)
          if (e6[o5] === n6)
            return t5[o5];
        if ("object" == typeof n6 && null !== n6) {
          var a2 = nC(n6);
          return e6.push(n6), t5.push(a2), sC(oC(n6), function(e7) {
            a2[e7] = r6(n6[e7]);
          }), e6.pop(), t5.pop(), a2;
        }
        return n6;
      }(this.value);
    };
    var oC = Object.keys || function(e6) {
      var t5 = [];
      for (var r6 in e6)
        t5.push(r6);
      return t5;
    };
    function aC(e6) {
      return Object.prototype.toString.call(e6);
    }
    var iC = Array.isArray || function(e6) {
      return "[object Array]" === Object.prototype.toString.call(e6);
    }, sC = function(e6, t5) {
      if (e6.forEach)
        return e6.forEach(t5);
      for (var r6 = 0; r6 < e6.length; r6++)
        t5(e6[r6], r6, e6);
    };
    sC(oC(tC.prototype), function(e6) {
      eC[e6] = function(t5) {
        var r6 = [].slice.call(arguments, 1), n6 = new tC(t5);
        return n6[e6].apply(n6, r6);
      };
    });
    var lC = Object.hasOwnProperty || function(e6, t5) {
      return t5 in e6;
    }, cC = ["properties"], pC = ["properties"], dC = ["definitions", "parameters", "responses", "securityDefinitions", "components/schemas", "components/responses", "components/parameters", "components/securitySchemes"], uC = ["schema/example", "items/example"];
    function hC(e6) {
      var t5 = e6[e6.length - 1], r6 = e6[e6.length - 2], n6 = e6.join("/");
      return cC.indexOf(t5) > -1 && -1 === pC.indexOf(r6) || dC.indexOf(n6) > -1 || uC.some(function(e7) {
        return n6.indexOf(e7) > -1;
      });
    }
    function fC(e6, t5) {
      var r6, n6 = Pf(e6.split("#"), 2), o5 = n6[0], a2 = n6[1], i4 = hu.resolve(o5 || "", t5 || "");
      return a2 ? Rb(r6 = "".concat(i4, "#")).call(r6, a2) : i4;
    }
    var mC = /^([a-z]+:\/\/|\/\/)/i, yC = QT("JSONRefError", function(e6, t5, r6) {
      this.originalError = r6, Hd(this, t5 || {});
    }), gC = {}, vC = new PO(), bC = [function(e6) {
      return "paths" === e6[0] && "responses" === e6[3] && "examples" === e6[5];
    }, function(e6) {
      return "paths" === e6[0] && "responses" === e6[3] && "content" === e6[5] && "example" === e6[7];
    }, function(e6) {
      return "paths" === e6[0] && "responses" === e6[3] && "content" === e6[5] && "examples" === e6[7] && "value" === e6[9];
    }, function(e6) {
      return "paths" === e6[0] && "requestBody" === e6[3] && "content" === e6[4] && "example" === e6[6];
    }, function(e6) {
      return "paths" === e6[0] && "requestBody" === e6[3] && "content" === e6[4] && "examples" === e6[6] && "value" === e6[8];
    }, function(e6) {
      return "paths" === e6[0] && "parameters" === e6[2] && "example" === e6[4];
    }, function(e6) {
      return "paths" === e6[0] && "parameters" === e6[3] && "example" === e6[5];
    }, function(e6) {
      return "paths" === e6[0] && "parameters" === e6[2] && "examples" === e6[4] && "value" === e6[6];
    }, function(e6) {
      return "paths" === e6[0] && "parameters" === e6[3] && "examples" === e6[5] && "value" === e6[7];
    }, function(e6) {
      return "paths" === e6[0] && "parameters" === e6[2] && "content" === e6[4] && "example" === e6[6];
    }, function(e6) {
      return "paths" === e6[0] && "parameters" === e6[2] && "content" === e6[4] && "examples" === e6[6] && "value" === e6[8];
    }, function(e6) {
      return "paths" === e6[0] && "parameters" === e6[3] && "content" === e6[4] && "example" === e6[7];
    }, function(e6) {
      return "paths" === e6[0] && "parameters" === e6[3] && "content" === e6[5] && "examples" === e6[7] && "value" === e6[9];
    }], xC = { key: "$ref", plugin: function(e6, t5, r6, n6) {
      var o5, a2 = n6.getInstance(), i4 = mS(r6).call(r6, 0, -1);
      if (!hC(i4) && (o5 = i4, !bC.some(function(e7) {
        return e7(o5);
      }))) {
        var s6 = n6.getContext(r6).baseDoc;
        if ("string" != typeof e6)
          return new yC("$ref: must be a string (JSON-Ref)", { $ref: e6, baseDoc: s6, fullPath: r6 });
        var l2, c3, p2, d2 = SC(e6), u3 = d2[0], h2 = d2[1] || "";
        try {
          l2 = s6 || u3 ? $C(u3, s6) : null;
        } catch (t6) {
          return kC(t6, { pointer: h2, $ref: e6, basePath: l2, fullPath: r6 });
        }
        if (function(e7, t6, r7, n7) {
          var o6, a3, i5 = vC.get(n7);
          i5 || (i5 = {}, vC.set(n7, i5));
          var s7, l3 = 0 === (s7 = r7).length ? "" : "/".concat(Tb(s7).call(s7, jC).join("/")), c4 = Rb(o6 = "".concat(t6 || "<specmap-base>", "#")).call(o6, e7), p3 = l3.replace(/allOf\/\d+\/?/g, "");
          if (t6 === n7.contextTree.get([]).baseDoc && IC(p3, e7))
            return true;
          var d3 = "", u4 = r7.some(function(e8) {
            var t7;
            return d3 = Rb(t7 = "".concat(d3, "/")).call(t7, jC(e8)), i5[d3] && i5[d3].some(function(e9) {
              return IC(e9, c4) || IC(c4, e9);
            });
          });
          if (u4)
            return true;
          i5[p3] = Rb(a3 = i5[p3] || []).call(a3, c4);
        }(h2, l2, i4, n6) && !a2.useCircularStructures) {
          var f3 = fC(e6, l2);
          return e6 === f3 ? null : YA.replace(r6, f3);
        }
        if (null == l2 ? (p2 = TC(h2), void 0 === (c3 = n6.get(p2)) && (c3 = new yC("Could not resolve reference: ".concat(e6), { pointer: h2, $ref: e6, baseDoc: s6, fullPath: r6 }))) : c3 = null != (c3 = AC(l2, h2)).l ? c3.l : c3.catch(function(t6) {
          throw kC(t6, { pointer: h2, $ref: e6, baseDoc: s6, fullPath: r6 });
        }), c3 instanceof Error)
          return [YA.remove(r6), c3];
        var m2 = fC(e6, l2), y2 = YA.replace(i4, c3, { $$ref: m2 });
        if (l2 && l2 !== s6)
          return [y2, YA.context(i4, { baseDoc: l2 })];
        try {
          if (!function(e7, t6) {
            var r7 = [e7];
            return t6.path.reduce(function(e8, t7) {
              return r7.push(e8[t7]), e8[t7];
            }, e7), function e8(t7) {
              return YA.isObject(t7) && (r7.indexOf(t7) >= 0 || Cb(t7).some(function(r8) {
                return e8(t7[r8]);
              }));
            }(t6.value);
          }(n6.state, y2) || a2.useCircularStructures)
            return y2;
        } catch (o6) {
          return null;
        }
      }
    } }, wC = Hd(xC, { docCache: gC, absoluteify: $C, clearCache: function(e6) {
      void 0 !== e6 ? delete gC[e6] : Cb(gC).forEach(function(e7) {
        delete gC[e7];
      });
    }, JSONRefError: yC, wrapError: kC, getDoc: EC, split: SC, extractFromDoc: AC, fetchJSON: function(e6) {
      return fetch(e6, { headers: { Accept: "application/json, application/yaml" }, loadSpec: true }).then(function(e7) {
        return e7.text();
      }).then(function(e7) {
        return cS.load(e7);
      });
    }, extract: OC, jsonPointerToArray: TC, unescapeJsonPointerToken: CC });
    function $C(e6, t5) {
      if (!mC.test(e6)) {
        var r6;
        if (!t5)
          throw new yC(Rb(r6 = "Tried to resolve a relative URL, without having a basePath. path: '".concat(e6, "' basePath: '")).call(r6, t5, "'"));
        return hu.resolve(t5, e6);
      }
      return e6;
    }
    function kC(e6, t5) {
      var r6, n6;
      return r6 = e6 && e6.response && e6.response.body ? Rb(n6 = "".concat(e6.response.body.code, " ")).call(n6, e6.response.body.message) : e6.message, new yC("Could not resolve reference: ".concat(r6), t5, e6);
    }
    function SC(e6) {
      return (e6 + "").split("#");
    }
    function AC(e6, t5) {
      var r6 = gC[e6];
      if (r6 && !YA.isPromise(r6))
        try {
          var n6 = OC(t5, r6);
          return Hd(JS.resolve(n6), { l: n6 });
        } catch (e7) {
          return JS.reject(e7);
        }
      return EC(e6).then(function(e7) {
        return OC(t5, e7);
      });
    }
    function EC(e6) {
      var t5 = gC[e6];
      return t5 ? YA.isPromise(t5) ? t5 : JS.resolve(t5) : (gC[e6] = wC.fetchJSON(e6).then(function(t6) {
        return gC[e6] = t6, t6;
      }), gC[e6]);
    }
    function OC(e6, t5) {
      var r6 = TC(e6);
      if (r6.length < 1)
        return t5;
      var n6 = YA.getIn(t5, r6);
      if (void 0 === n6)
        throw new yC("Could not resolve pointer: ".concat(e6, " does not exist in document"), { pointer: e6 });
      return n6;
    }
    function TC(e6) {
      var t5;
      if ("string" != typeof e6)
        throw new TypeError("Expected a string, got a ".concat(_f(e6)));
      return "/" === e6[0] && (e6 = e6.substr(1)), "" === e6 ? [] : Tb(t5 = e6.split("/")).call(t5, CC);
    }
    function CC(e6) {
      return "string" != typeof e6 ? e6 : new ZT("=".concat(e6.replace(/~1/g, "/").replace(/~0/g, "~"))).get("");
    }
    function jC(e6) {
      var t5, r6 = new ZT([["", e6.replace(/~/g, "~0").replace(/\//g, "~1")]]);
      return mS(t5 = r6.toString()).call(t5, 1);
    }
    function IC(e6, t5) {
      if (!(r6 = t5) || "/" === r6 || "#" === r6)
        return true;
      var r6, n6 = e6.charAt(t5.length), o5 = mS(t5).call(t5, -1);
      return 0 === e6.indexOf(t5) && (!n6 || "/" === n6 || "#" === n6) && "#" !== o5;
    }
    const _C = { key: "allOf", plugin: function(e6, t5, r6, n6, o5) {
      if (!o5.meta || !o5.meta.$$ref) {
        var a2 = mS(r6).call(r6, 0, -1);
        if (!hC(a2)) {
          if (!Array.isArray(e6)) {
            var i4 = new TypeError("allOf must be an array");
            return i4.fullPath = r6, i4;
          }
          var s6 = false, l2 = o5.value;
          if (a2.forEach(function(e7) {
            l2 && (l2 = l2[e7]);
          }), l2 = Td({}, l2), 0 !== Cb(l2).length) {
            delete l2.allOf;
            var c3, p2, d2 = [];
            return d2.push(n6.replace(a2, {})), e6.forEach(function(e7, t6) {
              if (!n6.isObject(e7)) {
                if (s6)
                  return null;
                s6 = true;
                var o6 = new TypeError("Elements in allOf must be objects");
                return o6.fullPath = r6, d2.push(o6);
              }
              d2.push(n6.mergeDeep(a2, e7));
              var i5 = function(e8, t7) {
                var r7 = arguments.length > 2 && void 0 !== arguments[2] ? arguments[2] : {}, n7 = r7.specmap, o7 = r7.getBaseUrlForNodePath, a3 = void 0 === o7 ? function(e9) {
                  var r8;
                  return n7.getContext(Rb(r8 = []).call(r8, fS(t7), fS(e9))).baseDoc;
                } : o7, i6 = r7.targetKeys, s7 = void 0 === i6 ? ["$ref", "$$ref"] : i6, l3 = [];
                return XT.exports(e8).forEach(function() {
                  if (Gv(s7).call(s7, this.key) && "string" == typeof this.node) {
                    var e9 = this.path, r8 = Rb(t7).call(t7, this.path), o8 = fC(this.node, a3(e9));
                    l3.push(n7.replace(r8, o8));
                  }
                }), l3;
              }(e7, mS(r6).call(r6, 0, -1), { getBaseUrlForNodePath: function(e8) {
                var o7;
                return n6.getContext(Rb(o7 = []).call(o7, fS(r6), [t6], fS(e8))).baseDoc;
              }, specmap: n6 });
              d2.push.apply(d2, fS(i5));
            }), l2.example && d2.push(n6.remove(Rb(c3 = []).call(c3, a2, "example"))), d2.push(n6.mergeDeep(a2, l2)), l2.$$ref || d2.push(n6.remove(Rb(p2 = []).call(p2, a2, "$$ref"))), d2;
          }
        }
      }
    } }, PC = { key: "parameters", plugin: function(e6, t5, r6, n6) {
      if (Array.isArray(e6) && e6.length) {
        var o5 = Hd([], e6), a2 = mS(r6).call(r6, 0, -1), i4 = Td({}, YA.getIn(n6.spec, a2));
        return e6.forEach(function(e7, t6) {
          try {
            o5[t6].default = n6.parameterMacro(i4, e7);
          } catch (e8) {
            var a3 = new Error(e8);
            return a3.fullPath = r6, a3;
          }
        }), YA.replace(r6, o5);
      }
      return YA.replace(r6, e6);
    } }, RC = { key: "properties", plugin: function(e6, t5, r6, n6) {
      var o5 = Td({}, e6);
      for (var a2 in e6)
        try {
          o5[a2].default = n6.modelPropertyMacro(o5[a2]);
        } catch (e7) {
          var i4 = new Error(e7);
          return i4.fullPath = r6, i4;
        }
      return YA.replace(r6, o5);
    } };
    var LC = function() {
      function e6(t5) {
        BS(this, e6), this.root = FC(t5 || {});
      }
      return qS(e6, [{ key: "set", value: function(e7, t5) {
        var r6 = this.getParent(e7, true);
        if (r6) {
          var n6 = e7[e7.length - 1], o5 = r6.children;
          o5[n6] ? DC(o5[n6], t5, r6) : o5[n6] = FC(t5, r6);
        } else
          DC(this.root, t5, null);
      } }, { key: "get", value: function(e7) {
        if ((e7 = e7 || []).length < 1)
          return this.root.value;
        for (var t5, r6, n6 = this.root, o5 = 0; o5 < e7.length && (r6 = e7[o5], (t5 = n6.children)[r6]); o5 += 1)
          n6 = t5[r6];
        return n6 && n6.protoValue;
      } }, { key: "getParent", value: function(e7, t5) {
        return !e7 || e7.length < 1 ? null : e7.length < 2 ? this.root : mS(e7).call(e7, 0, -1).reduce(function(e8, r6) {
          if (!e8)
            return e8;
          var n6 = e8.children;
          return !n6[r6] && t5 && (n6[r6] = FC(null, e8)), n6[r6];
        }, this.root);
      } }]), e6;
    }();
    function FC(e6, t5) {
      return DC({ children: {} }, e6, t5);
    }
    function DC(e6, t5, r6) {
      return e6.value = t5 || {}, e6.protoValue = r6 ? Td(Td({}, r6.protoValue), e6.value) : e6.value, Cb(e6.children).forEach(function(t6) {
        var r7 = e6.children[t6];
        e6.children[t6] = DC(r7, r7.value, e6);
      }), e6;
    }
    var BC = function() {
    }, NC = function() {
      function e6(t5) {
        var r6, n6, o5 = this;
        BS(this, e6), Hd(this, { spec: "", debugLevel: "info", plugins: [], pluginHistory: {}, errors: [], mutations: [], promisedPatches: [], state: {}, patches: [], context: {}, contextTree: new LC(), showDebug: false, allPatches: [], pluginProp: "specMap", libMethods: Hd(Object.create(this), YA, { getInstance: function() {
          return o5;
        } }), allowMetaPatches: false }, t5), this.get = this._get.bind(this), this.getContext = this._getContext.bind(this), this.hasRun = this._hasRun.bind(this), this.wrappedPlugins = Wb(r6 = Tb(n6 = this.plugins).call(n6, this.wrapPlugin.bind(this))).call(r6, YA.isFunction), this.patches.push(YA.add([], this.spec)), this.patches.push(YA.context([], this.context)), this.updatePatches(this.patches);
      }
      return qS(e6, [{ key: "debug", value: function(e7) {
        if (this.debugLevel === e7) {
          for (var t5, r6 = arguments.length, n6 = new Array(r6 > 1 ? r6 - 1 : 0), o5 = 1; o5 < r6; o5++)
            n6[o5 - 1] = arguments[o5];
          (t5 = console).log.apply(t5, n6);
        }
      } }, { key: "verbose", value: function(e7) {
        if ("verbose" === this.debugLevel) {
          for (var t5, r6, n6 = arguments.length, o5 = new Array(n6 > 1 ? n6 - 1 : 0), a2 = 1; a2 < n6; a2++)
            o5[a2 - 1] = arguments[a2];
          (t5 = console).log.apply(t5, Rb(r6 = ["[".concat(e7, "]   ")]).call(r6, o5));
        }
      } }, { key: "wrapPlugin", value: function(e7, t5) {
        var r6, n6, o5, a2 = this.pathDiscriminator, i4 = null;
        return e7[this.pluginProp] ? (i4 = e7, r6 = e7[this.pluginProp]) : YA.isFunction(e7) ? r6 = e7 : YA.isObject(e7) && (n6 = e7, o5 = function(e8, t6) {
          return !Array.isArray(e8) || e8.every(function(e9, r7) {
            return e9 === t6[r7];
          });
        }, r6 = _v.mark(function e8(t6, r7) {
          var i5, s6, l2, c3, p2, d2;
          return _v.wrap(function(e9) {
            for (; ; )
              switch (e9.prev = e9.next) {
                case 0:
                  d2 = function(e10, t7, l3) {
                    var c4, p3, u3, h2, f3, m2, y2, g2, v2, b2, x3, w2, $2;
                    return _v.wrap(function(i6) {
                      for (; ; )
                        switch (i6.prev = i6.next) {
                          case 0:
                            if (YA.isObject(e10)) {
                              i6.next = 6;
                              break;
                            }
                            if (n6.key !== t7[t7.length - 1]) {
                              i6.next = 4;
                              break;
                            }
                            return i6.next = 4, n6.plugin(e10, n6.key, t7, r7);
                          case 4:
                            i6.next = 30;
                            break;
                          case 6:
                            c4 = t7.length - 1, p3 = t7[c4], u3 = t7.indexOf("properties"), h2 = "properties" === p3 && c4 === u3, f3 = r7.allowMetaPatches && s6[e10.$$ref], m2 = 0, y2 = Cb(e10);
                          case 12:
                            if (!(m2 < y2.length)) {
                              i6.next = 30;
                              break;
                            }
                            if (g2 = y2[m2], v2 = e10[g2], b2 = Rb(t7).call(t7, g2), x3 = YA.isObject(v2), w2 = e10.$$ref, f3) {
                              i6.next = 22;
                              break;
                            }
                            if (!x3) {
                              i6.next = 22;
                              break;
                            }
                            return r7.allowMetaPatches && w2 && (s6[w2] = true), i6.delegateYield(d2(v2, b2, l3), "t0", 22);
                          case 22:
                            if (h2 || g2 !== n6.key) {
                              i6.next = 27;
                              break;
                            }
                            if ($2 = o5(a2, t7), a2 && !$2) {
                              i6.next = 27;
                              break;
                            }
                            return i6.next = 27, n6.plugin(v2, g2, b2, r7, l3);
                          case 27:
                            m2++, i6.next = 12;
                            break;
                          case 30:
                          case "end":
                            return i6.stop();
                        }
                    }, i5);
                  }, i5 = _v.mark(d2), s6 = {}, l2 = Cf(Wb(t6).call(t6, YA.isAdditiveMutation)), e9.prev = 4, l2.s();
                case 6:
                  if ((c3 = l2.n()).done) {
                    e9.next = 11;
                    break;
                  }
                  return p2 = c3.value, e9.delegateYield(d2(p2.value, p2.path, p2), "t0", 9);
                case 9:
                  e9.next = 6;
                  break;
                case 11:
                  e9.next = 16;
                  break;
                case 13:
                  e9.prev = 13, e9.t1 = e9.catch(4), l2.e(e9.t1);
                case 16:
                  return e9.prev = 16, l2.f(), e9.finish(16);
                case 19:
                case "end":
                  return e9.stop();
              }
          }, e8, null, [[4, 13, 16, 19]]);
        })), Hd(r6.bind(i4), { pluginName: e7.name || t5, isGenerator: YA.isGenerator(r6) });
      } }, { key: "nextPlugin", value: function() {
        var e7, t5 = this;
        return KS(e7 = this.wrappedPlugins).call(e7, function(e8) {
          return t5.getMutationsForPlugin(e8).length > 0;
        });
      } }, { key: "nextPromisedPatch", value: function() {
        var e7;
        if (this.promisedPatches.length > 0)
          return JS.race(Tb(e7 = this.promisedPatches).call(e7, function(e8) {
            return e8.value;
          }));
      } }, { key: "getPluginHistory", value: function(e7) {
        var t5 = this.constructor.getPluginName(e7);
        return this.pluginHistory[t5] || [];
      } }, { key: "getPluginRunCount", value: function(e7) {
        return this.getPluginHistory(e7).length;
      } }, { key: "getPluginHistoryTip", value: function(e7) {
        var t5 = this.getPluginHistory(e7);
        return t5 && t5[t5.length - 1] || {};
      } }, { key: "getPluginMutationIndex", value: function(e7) {
        var t5 = this.getPluginHistoryTip(e7).mutationIndex;
        return "number" != typeof t5 ? -1 : t5;
      } }, { key: "updatePluginHistory", value: function(e7, t5) {
        var r6 = this.constructor.getPluginName(e7);
        this.pluginHistory[r6] = this.pluginHistory[r6] || [], this.pluginHistory[r6].push(t5);
      } }, { key: "updatePatches", value: function(e7) {
        var t5 = this;
        YA.normalizeArray(e7).forEach(function(e8) {
          if (e8 instanceof Error)
            t5.errors.push(e8);
          else
            try {
              if (!YA.isObject(e8))
                return void t5.debug("updatePatches", "Got a non-object patch", e8);
              if (t5.showDebug && t5.allPatches.push(e8), YA.isPromise(e8.value))
                return t5.promisedPatches.push(e8), void t5.promisedPatchThen(e8);
              if (YA.isContextPatch(e8))
                return void t5.setContext(e8.path, e8.value);
              if (YA.isMutation(e8))
                return void t5.updateMutations(e8);
            } catch (e9) {
              console.error(e9), t5.errors.push(e9);
            }
        });
      } }, { key: "updateMutations", value: function(e7) {
        "object" === _f(e7.value) && !Array.isArray(e7.value) && this.allowMetaPatches && (e7.value = Td({}, e7.value));
        var t5 = YA.applyPatch(this.state, e7, { allowMetaPatches: this.allowMetaPatches });
        t5 && (this.mutations.push(e7), this.state = t5);
      } }, { key: "removePromisedPatch", value: function(e7) {
        var t5, r6 = this.promisedPatches.indexOf(e7);
        r6 < 0 ? this.debug("Tried to remove a promisedPatch that isn't there!") : uA(t5 = this.promisedPatches).call(t5, r6, 1);
      } }, { key: "promisedPatchThen", value: function(e7) {
        var t5 = this;
        return e7.value = e7.value.then(function(r6) {
          var n6 = Td(Td({}, e7), {}, { value: r6 });
          t5.removePromisedPatch(e7), t5.updatePatches(n6);
        }).catch(function(r6) {
          t5.removePromisedPatch(e7), t5.updatePatches(r6);
        }), e7.value;
      } }, { key: "getMutations", value: function(e7, t5) {
        var r6;
        return e7 = e7 || 0, "number" != typeof t5 && (t5 = this.mutations.length), mS(r6 = this.mutations).call(r6, e7, t5);
      } }, { key: "getCurrentMutations", value: function() {
        return this.getMutationsForPlugin(this.getCurrentPlugin());
      } }, { key: "getMutationsForPlugin", value: function(e7) {
        var t5 = this.getPluginMutationIndex(e7);
        return this.getMutations(t5 + 1);
      } }, { key: "getCurrentPlugin", value: function() {
        return this.currentPlugin;
      } }, { key: "getLib", value: function() {
        return this.libMethods;
      } }, { key: "_get", value: function(e7) {
        return YA.getIn(this.state, e7);
      } }, { key: "_getContext", value: function(e7) {
        return this.contextTree.get(e7);
      } }, { key: "setContext", value: function(e7, t5) {
        return this.contextTree.set(e7, t5);
      } }, { key: "_hasRun", value: function(e7) {
        return this.getPluginRunCount(this.getCurrentPlugin()) > (e7 || 0);
      } }, { key: "dispatch", value: function() {
        var e7, t5 = this, r6 = this, n6 = this.nextPlugin();
        if (!n6) {
          var o5 = this.nextPromisedPatch();
          if (o5)
            return o5.then(function() {
              return t5.dispatch();
            }).catch(function() {
              return t5.dispatch();
            });
          var a2 = { spec: this.state, errors: this.errors };
          return this.showDebug && (a2.patches = this.allPatches), JS.resolve(a2);
        }
        if (r6.pluginCount = r6.pluginCount || {}, r6.pluginCount[n6] = (r6.pluginCount[n6] || 0) + 1, r6.pluginCount[n6] > 100)
          return JS.resolve({ spec: r6.state, errors: Rb(e7 = r6.errors).call(e7, new Error("We've reached a hard limit of ".concat(100, " plugin runs"))) });
        if (n6 !== this.currentPlugin && this.promisedPatches.length) {
          var i4, s6 = Tb(i4 = this.promisedPatches).call(i4, function(e8) {
            return e8.value;
          });
          return JS.all(Tb(s6).call(s6, function(e8) {
            return e8.then(BC, BC);
          })).then(function() {
            return t5.dispatch();
          });
        }
        return function() {
          r6.currentPlugin = n6;
          var e8 = r6.getCurrentMutations(), t6 = r6.mutations.length - 1;
          try {
            if (n6.isGenerator) {
              var o6, a3 = Cf(n6(e8, r6.getLib()));
              try {
                for (a3.s(); !(o6 = a3.n()).done; )
                  l2(o6.value);
              } catch (e9) {
                a3.e(e9);
              } finally {
                a3.f();
              }
            } else
              l2(n6(e8, r6.getLib()));
          } catch (e9) {
            console.error(e9), l2([Hd(Object.create(e9), { plugin: n6 })]);
          } finally {
            r6.updatePluginHistory(n6, { mutationIndex: t6 });
          }
          return r6.dispatch();
        }();
        function l2(e8) {
          e8 && (e8 = YA.fullyNormalizeArray(e8), r6.updatePatches(e8, n6));
        }
      } }], [{ key: "getPluginName", value: function(e7) {
        return e7.pluginName;
      } }, { key: "getPatchesOfType", value: function(e7, t5) {
        return Wb(e7).call(e7, t5);
      } }]), e6;
    }(), qC = { refs: wC, allOf: _C, parameters: PC, properties: RC }, UC = function(e6) {
      return String.prototype.toLowerCase.call(e6);
    }, zC = function(e6) {
      return e6.replace(/[^\w]/gi, "_");
    };
    function MC(e6) {
      var t5 = e6.openapi;
      return !!t5 && uu(t5).call(t5, "3");
    }
    function HC(e6, t5) {
      var r6 = arguments.length > 2 && void 0 !== arguments[2] ? arguments[2] : "", n6 = arguments.length > 3 && void 0 !== arguments[3] ? arguments[3] : {}, o5 = n6.v2OperationIdCompatibilityMode;
      if (!e6 || "object" !== _f(e6))
        return null;
      var a2 = (e6.operationId || "").replace(/\s/g, "");
      return a2.length ? zC(e6.operationId) : WC(t5, r6, { v2OperationIdCompatibilityMode: o5 });
    }
    function WC(e6, t5) {
      var r6, n6 = arguments.length > 2 && void 0 !== arguments[2] ? arguments[2] : {}, o5 = n6.v2OperationIdCompatibilityMode;
      if (o5) {
        var a2, i4, s6 = Rb(a2 = "".concat(t5.toLowerCase(), "_")).call(a2, e6).replace(/[\s!@#$%^&*()_+=[{\]};:<>|./?,\\'""-]/g, "_");
        return (s6 = s6 || Rb(i4 = "".concat(e6.substring(1), "_")).call(i4, t5)).replace(/((_){2,})/g, "_").replace(/^(_)*/g, "").replace(/([_])*$/g, "");
      }
      return Rb(r6 = "".concat(UC(t5))).call(r6, zC(e6));
    }
    function VC(e6, t5) {
      var r6;
      return Rb(r6 = "".concat(UC(t5), "-")).call(r6, e6);
    }
    function GC(e6, t5) {
      return e6 && e6.paths ? KC(e6, function(e7) {
        var r6 = e7.pathName, n6 = e7.method, o5 = e7.operation;
        if (!o5 || "object" !== _f(o5))
          return false;
        var a2 = o5.operationId;
        return [HC(o5, r6, n6), VC(r6, n6), a2].some(function(e8) {
          return e8 && e8 === t5;
        });
      }, true) || null : null;
    }
    function KC(e6, t5, r6) {
      if (!e6 || "object" !== _f(e6) || !e6.paths || "object" !== _f(e6.paths))
        return null;
      var n6 = e6.paths;
      for (var o5 in n6)
        for (var a2 in n6[o5])
          if ("PARAMETERS" !== a2.toUpperCase()) {
            var i4 = n6[o5][a2];
            if (i4 && "object" === _f(i4)) {
              var s6 = { spec: e6, pathName: o5, method: a2.toUpperCase(), operation: i4 }, l2 = t5(s6);
              if (r6 && l2)
                return s6;
            }
          }
    }
    function JC(e6) {
      var t5 = e6.spec, r6 = t5.paths, n6 = {};
      if (!r6 || t5.$$normalized)
        return e6;
      for (var o5 in r6) {
        var a2, i4 = r6[o5];
        if (null != i4 && Gv(a2 = ["object", "function"]).call(a2, _f(i4))) {
          var s6 = i4.parameters, l2 = function(e7) {
            var r7, a3 = i4[e7];
            if (null == a3 || !Gv(r7 = ["object", "function"]).call(r7, _f(a3)))
              return "continue";
            var l3 = HC(a3, o5, e7);
            if (l3) {
              n6[l3] ? n6[l3].push(a3) : n6[l3] = [a3];
              var c4 = n6[l3];
              if (c4.length > 1)
                c4.forEach(function(e8, t6) {
                  var r8;
                  e8.p = e8.p || e8.operationId, e8.operationId = Rb(r8 = "".concat(l3)).call(r8, t6 + 1);
                });
              else if (void 0 !== a3.operationId) {
                var p2 = c4[0];
                p2.p = p2.p || a3.operationId, p2.operationId = l3;
              }
            }
            if ("parameters" !== e7) {
              var d2 = [], u3 = {};
              for (var h2 in t5)
                "produces" !== h2 && "consumes" !== h2 && "security" !== h2 || (u3[h2] = t5[h2], d2.push(u3));
              if (s6 && (u3.parameters = s6, d2.push(u3)), d2.length) {
                var f3, m2 = Cf(d2);
                try {
                  for (m2.s(); !(f3 = m2.n()).done; ) {
                    var y2 = f3.value;
                    for (var g2 in y2)
                      if (a3[g2]) {
                        if ("parameters" === g2) {
                          var v2, b2 = Cf(y2[g2]);
                          try {
                            var x3 = function() {
                              var e8 = v2.value;
                              a3[g2].some(function(t6) {
                                return t6.name && t6.name === e8.name || t6.$ref && t6.$ref === e8.$ref || t6.$$ref && t6.$$ref === e8.$$ref || t6 === e8;
                              }) || a3[g2].push(e8);
                            };
                            for (b2.s(); !(v2 = b2.n()).done; )
                              x3();
                          } catch (e8) {
                            b2.e(e8);
                          } finally {
                            b2.f();
                          }
                        }
                      } else
                        a3[g2] = y2[g2];
                  }
                } catch (e8) {
                  m2.e(e8);
                } finally {
                  m2.f();
                }
              }
            }
          };
          for (var c3 in i4)
            l2(c3);
        }
      }
      return t5.$$normalized = true, e6;
    }
    function YC(e6) {
      var t5 = arguments.length > 1 && void 0 !== arguments[1] ? arguments[1] : {}, r6 = t5.requestInterceptor, n6 = t5.responseInterceptor, o5 = e6.withCredentials ? "include" : "same-origin";
      return function(t6) {
        return e6({ url: t6, loadSpec: true, requestInterceptor: r6, responseInterceptor: n6, headers: { Accept: "application/json, application/yaml" }, credentials: o5 }).then(function(e7) {
          return e7.body;
        });
      };
    }
    function ZC(e6) {
      var t5 = e6.fetch, r6 = e6.spec, n6 = e6.url, o5 = e6.mode, a2 = e6.allowMetaPatches, i4 = void 0 === a2 || a2, s6 = e6.pathDiscriminator, l2 = e6.modelPropertyMacro, c3 = e6.parameterMacro, p2 = e6.requestInterceptor, d2 = e6.responseInterceptor, u3 = e6.skipNormalization, h2 = e6.useCircularStructures, f3 = e6.http, m2 = e6.baseDoc;
      return m2 = m2 || n6, f3 = t5 || f3 || $S, r6 ? y2(r6) : YC(f3, { requestInterceptor: p2, responseInterceptor: d2 })(m2).then(y2);
      function y2(e7) {
        m2 && (qC.refs.docCache[m2] = e7), qC.refs.fetchJSON = YC(f3, { requestInterceptor: p2, responseInterceptor: d2 });
        var t6, r7, n7 = [qC.refs];
        return "function" == typeof c3 && n7.push(qC.parameters), "function" == typeof l2 && n7.push(qC.properties), "strict" !== o5 && n7.push(qC.allOf), (t6 = { spec: e7, context: { baseDoc: m2 }, plugins: n7, allowMetaPatches: i4, pathDiscriminator: s6, parameterMacro: c3, modelPropertyMacro: l2, useCircularStructures: h2 }, new NC(t6).dispatch()).then(u3 ? (r7 = jv(_v.mark(function e8(t7) {
          return _v.wrap(function(e9) {
            for (; ; )
              switch (e9.prev = e9.next) {
                case 0:
                  return e9.abrupt("return", t7);
                case 1:
                case "end":
                  return e9.stop();
              }
          }, e8);
        })), function(e8) {
          return r7.apply(this, arguments);
        }) : JC);
      }
    }
    var QC = Array.isArray, XC = "object" == typeof global && global && global.Object === Object && global, ej = "object" == typeof self && self && self.Object === Object && self, tj = XC || ej || Function("return this")(), rj = tj.Symbol, nj = rj, oj = Object.prototype, aj = oj.hasOwnProperty, ij = oj.toString, sj = nj ? nj.toStringTag : void 0, lj = Object.prototype.toString, cj = function(e6) {
      var t5 = aj.call(e6, sj), r6 = e6[sj];
      try {
        e6[sj] = void 0;
        var n6 = true;
      } catch (e7) {
      }
      var o5 = ij.call(e6);
      return n6 && (t5 ? e6[sj] = r6 : delete e6[sj]), o5;
    }, pj = rj ? rj.toStringTag : void 0, dj = function(e6) {
      return null == e6 ? void 0 === e6 ? "[object Undefined]" : "[object Null]" : pj && pj in Object(e6) ? cj(e6) : function(e7) {
        return lj.call(e7);
      }(e6);
    }, uj = dj, hj = function(e6) {
      return "symbol" == typeof e6 || function(e7) {
        return null != e7 && "object" == typeof e7;
      }(e6) && "[object Symbol]" == uj(e6);
    }, fj = QC, mj = hj, yj = /\.|\[(?:[^[\]]*|(["'])(?:(?!\1)[^\\]|\\.)*?\1)\]/, gj = /^\w*$/, vj = function(e6) {
      var t5 = typeof e6;
      return null != e6 && ("object" == t5 || "function" == t5);
    }, bj = dj, xj = vj, wj = tj.i, $j = function() {
      var e6 = /[^.]+$/.exec(wj && wj.keys && wj.keys.IE_PROTO || "");
      return e6 ? "Symbol(src)_1." + e6 : "";
    }(), kj = Function.prototype.toString, Sj = function(e6) {
      if (!xj(e6))
        return false;
      var t5 = bj(e6);
      return "[object Function]" == t5 || "[object GeneratorFunction]" == t5 || "[object AsyncFunction]" == t5 || "[object Proxy]" == t5;
    }, Aj = function(e6) {
      return !!$j && $j in e6;
    }, Ej = vj, Oj = /^\[object .+?Constructor\]$/, Tj = Function.prototype, Cj = Object.prototype, jj = Tj.toString, Ij = Cj.hasOwnProperty, _j = RegExp("^" + jj.call(Ij).replace(/[\\^$.*+?()[\]{}|]/g, "\\$&").replace(/hasOwnProperty|(function).*?(?=\\\()| for .+?(?=\\\])/g, "$1.*?") + "$"), Pj = function(e6) {
      return !(!Ej(e6) || Aj(e6)) && (Sj(e6) ? _j : Oj).test(function(e7) {
        if (null != e7) {
          try {
            return kj.call(e7);
          } catch (e8) {
          }
          try {
            return e7 + "";
          } catch (e8) {
          }
        }
        return "";
      }(e6));
    }, Rj = function(e6, t5) {
      var r6 = function(e7, t6) {
        return null == e7 ? void 0 : e7[t6];
      }(e6, t5);
      return Pj(r6) ? r6 : void 0;
    }, Lj = Rj(Object, "create"), Fj = Lj, Dj = Lj, Bj = Object.prototype.hasOwnProperty, Nj = Lj, qj = Object.prototype.hasOwnProperty, Uj = Lj, zj = function() {
      this.v = Fj ? Fj(null) : {}, this.size = 0;
    }, Mj = function(e6) {
      var t5 = this.has(e6) && delete this.v[e6];
      return this.size -= t5 ? 1 : 0, t5;
    }, Hj = function(e6) {
      var t5 = this.v;
      if (Dj) {
        var r6 = t5[e6];
        return "__lodash_hash_undefined__" === r6 ? void 0 : r6;
      }
      return Bj.call(t5, e6) ? t5[e6] : void 0;
    }, Wj = function(e6) {
      var t5 = this.v;
      return Nj ? void 0 !== t5[e6] : qj.call(t5, e6);
    }, Vj = function(e6, t5) {
      var r6 = this.v;
      return this.size += this.has(e6) ? 0 : 1, r6[e6] = Uj && void 0 === t5 ? "__lodash_hash_undefined__" : t5, this;
    };
    function Gj(e6) {
      var t5 = -1, r6 = null == e6 ? 0 : e6.length;
      for (this.clear(); ++t5 < r6; ) {
        var n6 = e6[t5];
        this.set(n6[0], n6[1]);
      }
    }
    Gj.prototype.clear = zj, Gj.prototype.delete = Mj, Gj.prototype.get = Hj, Gj.prototype.has = Wj, Gj.prototype.set = Vj;
    var Kj = Gj, Jj = function(e6, t5) {
      return e6 === t5 || e6 != e6 && t5 != t5;
    }, Yj = function(e6, t5) {
      for (var r6 = e6.length; r6--; )
        if (Jj(e6[r6][0], t5))
          return r6;
      return -1;
    }, Zj = Yj, Qj = Array.prototype.splice, Xj = Yj, eI = Yj, tI = Yj, rI = function() {
      this.v = [], this.size = 0;
    }, nI = function(e6) {
      var t5 = this.v, r6 = Zj(t5, e6);
      return !(r6 < 0 || (r6 == t5.length - 1 ? t5.pop() : Qj.call(t5, r6, 1), --this.size, 0));
    }, oI = function(e6) {
      var t5 = this.v, r6 = Xj(t5, e6);
      return r6 < 0 ? void 0 : t5[r6][1];
    }, aI = function(e6, t5) {
      var r6 = this.v, n6 = tI(r6, e6);
      return n6 < 0 ? (++this.size, r6.push([e6, t5])) : r6[n6][1] = t5, this;
    };
    function iI(e6) {
      var t5 = -1, r6 = null == e6 ? 0 : e6.length;
      for (this.clear(); ++t5 < r6; ) {
        var n6 = e6[t5];
        this.set(n6[0], n6[1]);
      }
    }
    iI.prototype.clear = rI, iI.prototype.delete = nI, iI.prototype.get = oI, iI.prototype.has = function(e6) {
      return eI(this.v, e6) > -1;
    }, iI.prototype.set = aI;
    var sI = iI, lI = Rj(tj, "Map"), cI = Kj, pI = sI, dI = lI, uI = function(e6) {
      var t5 = typeof e6;
      return "string" == t5 || "number" == t5 || "symbol" == t5 || "boolean" == t5 ? "__proto__" !== e6 : null === e6;
    }, hI = function(e6, t5) {
      var r6 = e6.v;
      return uI(t5) ? r6["string" == typeof t5 ? "string" : "hash"] : r6.map;
    }, fI = hI, mI = hI, yI = hI, gI = hI, vI = function(e6, t5) {
      var r6 = gI(this, e6), n6 = r6.size;
      return r6.set(e6, t5), this.size += r6.size == n6 ? 0 : 1, this;
    };
    function bI(e6) {
      var t5 = -1, r6 = null == e6 ? 0 : e6.length;
      for (this.clear(); ++t5 < r6; ) {
        var n6 = e6[t5];
        this.set(n6[0], n6[1]);
      }
    }
    bI.prototype.clear = function() {
      this.size = 0, this.v = { hash: new cI(), map: new (dI || pI)(), string: new cI() };
    }, bI.prototype.delete = function(e6) {
      var t5 = fI(this, e6).delete(e6);
      return this.size -= t5 ? 1 : 0, t5;
    }, bI.prototype.get = function(e6) {
      return mI(this, e6).get(e6);
    }, bI.prototype.has = function(e6) {
      return yI(this, e6).has(e6);
    }, bI.prototype.set = vI;
    var xI = bI;
    function wI(e6, t5) {
      if ("function" != typeof e6 || null != t5 && "function" != typeof t5)
        throw new TypeError("Expected a function");
      var r6 = function() {
        var n6 = arguments, o5 = t5 ? t5.apply(this, n6) : n6[0], a2 = r6.cache;
        if (a2.has(o5))
          return a2.get(o5);
        var i4 = e6.apply(this, n6);
        return r6.cache = a2.set(o5, i4) || a2, i4;
      };
      return r6.cache = new (wI.Cache || xI)(), r6;
    }
    wI.Cache = xI;
    var $I = wI, kI = /[^.[\]]+|\[(?:(-?\d+(?:\.\d+)?)|(["'])((?:(?!\2)[^\\]|\\.)*?)\2)\]|(?=(?:\.|\[\])(?:\.|\[\]|$))/g, SI = /\\(\\)?/g, AI = function(e6) {
      var t5 = $I(function(e7) {
        var t6 = [];
        return 46 === e7.charCodeAt(0) && t6.push(""), e7.replace(kI, function(e8, r7, n6, o5) {
          t6.push(n6 ? o5.replace(SI, "$1") : r7 || e8);
        }), t6;
      }, function(e7) {
        return 500 === r6.size && r6.clear(), e7;
      }), r6 = t5.cache;
      return t5;
    }(), EI = AI, OI = function(e6, t5) {
      for (var r6 = -1, n6 = null == e6 ? 0 : e6.length, o5 = Array(n6); ++r6 < n6; )
        o5[r6] = t5(e6[r6], r6, e6);
      return o5;
    }, TI = QC, CI = hj, jI = rj ? rj.prototype : void 0, II = jI ? jI.toString : void 0, _I = function e6(t5) {
      if ("string" == typeof t5)
        return t5;
      if (TI(t5))
        return OI(t5, e6) + "";
      if (CI(t5))
        return II ? II.call(t5) : "";
      var r6 = t5 + "";
      return "0" == r6 && 1 / t5 == -1 / 0 ? "-0" : r6;
    }, PI = QC, RI = function(e6, t5) {
      if (fj(e6))
        return false;
      var r6 = typeof e6;
      return !("number" != r6 && "symbol" != r6 && "boolean" != r6 && null != e6 && !mj(e6)) || gj.test(e6) || !yj.test(e6) || null != t5 && e6 in Object(t5);
    }, LI = EI, FI = hj, DI = function(e6, t5) {
      return PI(e6) ? e6 : RI(e6, t5) ? [e6] : LI(function(e7) {
        return null == e7 ? "" : _I(e7);
      }(e6));
    }, BI = function(e6) {
      if ("string" == typeof e6 || FI(e6))
        return e6;
      var t5 = e6 + "";
      return "0" == t5 && 1 / e6 == -1 / 0 ? "-0" : t5;
    }, NI = function(e6, t5) {
      for (var r6 = 0, n6 = (t5 = DI(t5, e6)).length; null != e6 && r6 < n6; )
        e6 = e6[BI(t5[r6++])];
      return r6 && r6 == n6 ? e6 : void 0;
    }, qI = function(e6, t5, r6) {
      var n6 = null == e6 ? void 0 : NI(e6, t5);
      return void 0 === n6 ? r6 : n6;
    };
    function UI() {
      return UI = jv(_v.mark(function e6(t5, r6) {
        var n6, o5, a2, i4, s6, l2, c3, p2, d2, u3, h2, f3, m2 = arguments;
        return _v.wrap(function(e7) {
          for (; ; )
            switch (e7.prev = e7.next) {
              case 0:
                return n6 = m2.length > 2 && void 0 !== m2[2] ? m2[2] : {}, o5 = n6.returnEntireTree, a2 = n6.baseDoc, i4 = n6.requestInterceptor, s6 = n6.responseInterceptor, l2 = n6.parameterMacro, c3 = n6.modelPropertyMacro, p2 = n6.useCircularStructures, d2 = { pathDiscriminator: r6, baseDoc: a2, requestInterceptor: i4, responseInterceptor: s6, parameterMacro: l2, modelPropertyMacro: c3, useCircularStructures: p2 }, u3 = JC({ spec: t5 }), h2 = u3.spec, e7.next = 6, ZC(Td(Td({}, d2), {}, { spec: h2, allowMetaPatches: true, skipNormalization: true }));
              case 6:
                return f3 = e7.sent, !o5 && Array.isArray(r6) && r6.length && (f3.spec = qI(f3.spec, r6) || null), e7.abrupt("return", f3);
              case 9:
              case "end":
                return e7.stop();
            }
        }, e6);
      })), UI.apply(this, arguments);
    }
    var zI = function() {
      return null;
    }, MI = function(e6) {
      var t5 = e6.spec, r6 = e6.cb, n6 = void 0 === r6 ? zI : r6, o5 = e6.defaultTag, a2 = void 0 === o5 ? "default" : o5, i4 = e6.v2OperationIdCompatibilityMode, s6 = {}, l2 = {};
      return KC(t5, function(e7) {
        var r7, o6 = e7.pathName, c3 = e7.method, p2 = e7.operation;
        (p2.tags ? (r7 = p2.tags, Array.isArray(r7) ? r7 : [r7]) : [a2]).forEach(function(e8) {
          if ("string" == typeof e8) {
            l2[e8] = l2[e8] || {};
            var r8, a3 = l2[e8], d2 = HC(p2, o6, c3, { v2OperationIdCompatibilityMode: i4 }), u3 = n6({ spec: t5, pathName: o6, method: c3, operation: p2, operationId: d2 });
            if (s6[d2])
              s6[d2] += 1, a3[Rb(r8 = "".concat(d2)).call(r8, s6[d2])] = u3;
            else if (void 0 !== a3[d2]) {
              var h2, f3, m2 = s6[d2] || 1;
              s6[d2] = m2 + 1, a3[Rb(h2 = "".concat(d2)).call(h2, s6[d2])] = u3;
              var y2 = a3[d2];
              delete a3[d2], a3[Rb(f3 = "".concat(d2)).call(f3, m2)] = y2;
            } else
              a3[d2] = u3;
          }
        });
      }), l2;
    }, HI = function() {
      var e6 = arguments.length > 0 && void 0 !== arguments[0] ? arguments[0] : {};
      return function(t5) {
        var r6 = t5.pathName, n6 = t5.method, o5 = t5.operationId;
        return function(t6) {
          var a2 = arguments.length > 1 && void 0 !== arguments[1] ? arguments[1] : {}, i4 = e6.requestInterceptor, s6 = e6.responseInterceptor, l2 = e6.userFetch;
          return e6.execute(Td({ spec: e6.spec, requestInterceptor: i4, responseInterceptor: s6, userFetch: l2, pathName: r6, method: n6, parameters: t6, operationId: o5 }, a2));
        };
      };
    }, WI = Co, VI = Vo.indexOf, GI = Up, KI = Ot([].indexOf), JI = !!KI && 1 / KI([1], 1, -0) < 0, YI = GI("indexOf");
    WI({ target: "Array", proto: true, forced: JI || !YI }, { indexOf: function(e6) {
      var t5 = arguments.length > 1 ? arguments[1] : void 0;
      return JI ? KI(this, e6, t5) || 0 : VI(this, e6, t5);
    } });
    var ZI = sc("Array").indexOf, QI = pr, XI = ZI, e_ = Array.prototype;
    const t_ = ut({ exports: {} }.exports = function(e6) {
      var t5 = e6.indexOf;
      return e6 === e_ || QI(e_, e6) && t5 === e_.indexOf ? XI : t5;
    });
    var r_ = function(e6, t5, r6) {
      var n6 = r6 || {}, o5 = n6.encode || a_;
      if ("function" != typeof o5)
        throw new TypeError("option encode is invalid");
      if (!o_.test(e6))
        throw new TypeError("argument name is invalid");
      var a2 = o5(t5);
      if (a2 && !o_.test(a2))
        throw new TypeError("argument val is invalid");
      var i4, s6 = e6 + "=" + a2;
      if (null != n6.maxAge) {
        var l2 = n6.maxAge - 0;
        if (isNaN(l2) || !isFinite(l2))
          throw new TypeError("option maxAge is invalid");
        s6 += "; Max-Age=" + Math.floor(l2);
      }
      if (n6.domain) {
        if (!o_.test(n6.domain))
          throw new TypeError("option domain is invalid");
        s6 += "; Domain=" + n6.domain;
      }
      if (n6.path) {
        if (!o_.test(n6.path))
          throw new TypeError("option path is invalid");
        s6 += "; Path=" + n6.path;
      }
      if (n6.expires) {
        var c3 = n6.expires;
        if (i4 = c3, !("[object Date]" === n_.call(i4) || i4 instanceof Date) || isNaN(c3.valueOf()))
          throw new TypeError("option expires is invalid");
        s6 += "; Expires=" + c3.toUTCString();
      }
      if (n6.httpOnly && (s6 += "; HttpOnly"), n6.secure && (s6 += "; Secure"), n6.priority)
        switch ("string" == typeof n6.priority ? n6.priority.toLowerCase() : n6.priority) {
          case "low":
            s6 += "; Priority=Low";
            break;
          case "medium":
            s6 += "; Priority=Medium";
            break;
          case "high":
            s6 += "; Priority=High";
            break;
          default:
            throw new TypeError("option priority is invalid");
        }
      if (n6.sameSite)
        switch ("string" == typeof n6.sameSite ? n6.sameSite.toLowerCase() : n6.sameSite) {
          case true:
            s6 += "; SameSite=Strict";
            break;
          case "lax":
            s6 += "; SameSite=Lax";
            break;
          case "strict":
            s6 += "; SameSite=Strict";
            break;
          case "none":
            s6 += "; SameSite=None";
            break;
          default:
            throw new TypeError("option sameSite is invalid");
        }
      return s6;
    }, n_ = Object.prototype.toString, o_ = /^[\u0009\u0020-\u007e\u0080-\u00ff]+$/;
    function a_(e6) {
      return encodeURIComponent(e6);
    }
    function i_(e6) {
      return "[object Object]" === Object.prototype.toString.call(e6);
    }
    function s_(e6) {
      var t5, r6;
      return false !== i_(e6) && (void 0 === (t5 = e6.constructor) || false !== i_(r6 = t5.prototype) && false !== r6.hasOwnProperty("isPrototypeOf"));
    }
    const l_ = { body: function(e6) {
      var t5 = e6.req, r6 = e6.value;
      t5.body = r6;
    }, header: function(e6) {
      var t5 = e6.req, r6 = e6.parameter, n6 = e6.value;
      t5.headers = t5.headers || {}, void 0 !== n6 && (t5.headers[r6.name] = n6);
    }, query: function(e6) {
      var t5 = e6.req, r6 = e6.value, n6 = e6.parameter;
      if (t5.query = t5.query || {}, false === r6 && "boolean" === n6.type && (r6 = "false"), 0 === r6 && ["number", "integer"].indexOf(n6.type) > -1 && (r6 = "0"), r6)
        t5.query[n6.name] = { collectionFormat: n6.collectionFormat, value: r6 };
      else if (n6.allowEmptyValue && void 0 !== r6) {
        var o5 = n6.name;
        t5.query[o5] = t5.query[o5] || {}, t5.query[o5].allowEmptyValue = true;
      }
    }, path: function(e6) {
      var t5 = e6.req, r6 = e6.value, n6 = e6.parameter;
      t5.url = t5.url.split("{".concat(n6.name, "}")).join(encodeURIComponent(r6));
    }, formData: function(e6) {
      var t5 = e6.req, r6 = e6.value, n6 = e6.parameter;
      (r6 || n6.allowEmptyValue) && (t5.form = t5.form || {}, t5.form[n6.name] = { value: r6, allowEmptyValue: n6.allowEmptyValue, collectionFormat: n6.collectionFormat });
    } };
    function c_(e6, t5) {
      return Gv(t5).call(t5, "application/json") ? "string" == typeof e6 ? e6 : $b(e6) : e6.toString();
    }
    var p_ = ["accept", "authorization", "content-type"];
    const d_ = Object.freeze(Object.defineProperty({ __proto__: null, path: function(e6) {
      var t5 = e6.req, r6 = e6.value, n6 = e6.parameter, o5 = n6.name, a2 = n6.style, i4 = n6.explode, s6 = n6.content;
      if (s6) {
        var l2 = Cb(s6)[0];
        t5.url = t5.url.split("{".concat(o5, "}")).join(vS(c_(r6, l2), { escape: true }));
      } else {
        var c3 = bS({ key: n6.name, value: r6, style: a2 || "simple", explode: i4 || false, escape: true });
        t5.url = t5.url.split("{".concat(o5, "}")).join(c3);
      }
    }, query: function(e6) {
      var t5 = e6.req, r6 = e6.value, n6 = e6.parameter;
      if (t5.query = t5.query || {}, n6.content) {
        var o5 = Cb(n6.content)[0];
        t5.query[n6.name] = c_(r6, o5);
      } else if (false === r6 && (r6 = "false"), 0 === r6 && (r6 = "0"), r6) {
        var a2 = n6.style, i4 = n6.explode, s6 = n6.allowReserved;
        t5.query[n6.name] = { value: r6, serializationOption: { style: a2, explode: i4, allowReserved: s6 } };
      } else if (n6.allowEmptyValue && void 0 !== r6) {
        var l2 = n6.name;
        t5.query[l2] = t5.query[l2] || {}, t5.query[l2].allowEmptyValue = true;
      }
    }, header: function(e6) {
      var t5 = e6.req, r6 = e6.parameter, n6 = e6.value;
      if (t5.headers = t5.headers || {}, !(p_.indexOf(r6.name.toLowerCase()) > -1))
        if (r6.content) {
          var o5 = Cb(r6.content)[0];
          t5.headers[r6.name] = c_(n6, o5);
        } else
          void 0 !== n6 && (t5.headers[r6.name] = bS({ key: r6.name, value: n6, style: r6.style || "simple", explode: void 0 !== r6.explode && r6.explode, escape: false }));
    }, cookie: function(e6) {
      var t5 = e6.req, r6 = e6.parameter, n6 = e6.value;
      t5.headers = t5.headers || {};
      var o5 = _f(n6);
      if (r6.content) {
        var a2, i4 = Cb(r6.content)[0];
        t5.headers.Cookie = Rb(a2 = "".concat(r6.name, "=")).call(a2, c_(n6, i4));
      } else if ("undefined" !== o5) {
        var s6 = "object" === o5 && !Array.isArray(n6) && r6.explode ? "" : "".concat(r6.name, "=");
        t5.headers.Cookie = s6 + bS({ key: r6.name, value: n6, escape: false, style: r6.style || "form", explode: void 0 !== r6.explode && r6.explode });
      }
    } }, Symbol.toStringTag, { value: "Module" }));
    Co({ global: true }, { globalThis: ft });
    const u_ = ut({ exports: {} }.exports = { exports: {} }.exports = ft);
    var h_ = (void 0 !== u_ ? u_ : "undefined" != typeof self ? self : window).btoa;
    var f_ = ["http", "fetch", "spec", "operationId", "pathName", "method", "parameters", "securities"], m_ = function(e6) {
      return Array.isArray(e6) ? e6 : [];
    }, y_ = QT("OperationNotFoundError", function(e6, t5, r6) {
      this.originalError = r6, Hd(this, t5 || {});
    }), g_ = { buildRequest: v_ };
    function v_(e6) {
      var t5, r6, n6 = e6.spec, o5 = e6.operationId, a2 = e6.responseContentType, i4 = e6.scheme, s6 = e6.requestInterceptor, l2 = e6.responseInterceptor, c3 = e6.contextUrl, p2 = e6.userFetch, d2 = e6.server, u3 = e6.serverVariables, h2 = e6.http, f3 = e6.signal, m2 = e6.parameters, y2 = e6.parameterBuilders, g2 = MC(n6);
      y2 || (y2 = g2 ? d_ : l_);
      var v2 = { url: "", credentials: h2 && h2.withCredentials ? "include" : "same-origin", headers: {}, cookies: {} };
      f3 && (v2.signal = f3), s6 && (v2.requestInterceptor = s6), l2 && (v2.responseInterceptor = l2), p2 && (v2.userFetch = p2);
      var b2 = GC(n6, o5);
      if (!b2)
        throw new y_("Operation ".concat(o5, " not found"));
      var x3 = b2.operation, w2 = void 0 === x3 ? {} : x3, $2 = b2.method, k2 = b2.pathName;
      if (v2.url += x_({ spec: n6, scheme: i4, contextUrl: c3, server: d2, serverVariables: u3, pathName: k2, method: $2 }), !o5)
        return delete v2.cookies, v2;
      v2.url += k2, v2.method = "".concat($2).toUpperCase(), m2 = m2 || {};
      var S2 = n6.paths[k2] || {};
      a2 && (v2.headers.accept = a2);
      var A2 = function(e7) {
        var t6 = {};
        e7.forEach(function(e8) {
          t6[e8.in] || (t6[e8.in] = {}), t6[e8.in][e8.name] = e8;
        });
        var r7 = [];
        return Cb(t6).forEach(function(e8) {
          Cb(t6[e8]).forEach(function(n7) {
            r7.push(t6[e8][n7]);
          });
        }), r7;
      }(Rb(t5 = Rb(r6 = []).call(r6, m_(w2.parameters))).call(t5, m_(S2.parameters)));
      A2.forEach(function(e7) {
        var t6, r7, o6, a3, i5 = y2[e7.in];
        if ("body" === e7.in && e7.schema && e7.schema.properties && (t6 = m2), void 0 === (t6 = e7 && e7.name && m2[e7.name]))
          t6 = e7 && e7.name && m2[Rb(r7 = "".concat(e7.in, ".")).call(r7, e7.name)];
        else if ((o6 = e7.name, a3 = A2, Wb(a3).call(a3, function(e8) {
          return e8.name === o6;
        })).length > 1) {
          var s7;
          console.warn(Rb(s7 = "Parameter '".concat(e7.name, "' is ambiguous because the defined spec has more than one parameter with the name: '")).call(s7, e7.name, "' and the passed-in parameter values did not define an 'in' value."));
        }
        if (null !== t6) {
          if (void 0 !== e7.default && void 0 === t6 && (t6 = e7.default), void 0 === t6 && e7.required && !e7.allowEmptyValue)
            throw new Error("Required parameter ".concat(e7.name, " is not provided"));
          if (g2 && e7.schema && "object" === e7.schema.type && "string" == typeof t6)
            try {
              t6 = JSON.parse(t6);
            } catch (o7) {
              throw new Error("Could not parse object parameter value string as JSON");
            }
          i5 && i5({ req: v2, parameter: e7, value: t6, operation: w2, spec: n6 });
        }
      });
      var E2 = Td(Td({}, e6), {}, { operation: w2 });
      if ((v2 = g2 ? function(e7, t6) {
        var r7, n7, o6, a3, i5, s7, l3, c4, p3, d3, u4, h3, f4, m3 = e7.operation, y3 = e7.requestBody, g3 = e7.securities, v3 = e7.spec, b3 = e7.attachContentTypeForEmptyPayload, x4 = e7.requestContentType;
        a3 = void 0 === (o6 = (r7 = { request: t6, securities: g3, operation: m3, spec: v3 }).securities) ? {} : o6, s7 = void 0 === (i5 = r7.operation) ? {} : i5, l3 = r7.spec, c4 = Td({}, n7 = r7.request), p3 = a3.authorized, d3 = void 0 === p3 ? {} : p3, u4 = s7.security || l3.security || [], h3 = d3 && !!Cb(d3).length, f4 = qI(l3, ["components", "securitySchemes"]) || {}, c4.headers = c4.headers || {}, c4.query = c4.query || {}, t6 = Cb(a3).length && h3 && u4 && (!Array.isArray(s7.security) || s7.security.length) ? (u4.forEach(function(e8) {
          Cb(e8).forEach(function(e9) {
            var t7 = d3[e9], r8 = f4[e9];
            if (t7) {
              var n8 = t7.value || t7, o7 = r8.type;
              if (t7) {
                if ("apiKey" === o7)
                  "query" === r8.in && (c4.query[r8.name] = n8), "header" === r8.in && (c4.headers[r8.name] = n8), "cookie" === r8.in && (c4.cookies[r8.name] = n8);
                else if ("http" === o7) {
                  if (/^basic$/i.test(r8.scheme)) {
                    var a4, i6 = n8.username || "", s8 = n8.password || "", l4 = h_(Rb(a4 = "".concat(i6, ":")).call(a4, s8));
                    c4.headers.Authorization = "Basic ".concat(l4);
                  }
                  /^bearer$/i.test(r8.scheme) && (c4.headers.Authorization = "Bearer ".concat(n8));
                } else if ("oauth2" === o7 || "openIdConnect" === o7) {
                  var p4, u5 = t7.token || {}, h4 = u5[r8["x-tokenName"] || "access_token"], m4 = u5.token_type;
                  m4 && "bearer" !== m4.toLowerCase() || (m4 = "Bearer"), c4.headers.Authorization = Rb(p4 = "".concat(m4, " ")).call(p4, h4);
                }
              }
            }
          });
        }), c4) : n7;
        var w3 = m3.requestBody || {}, $3 = Cb(w3.content || {}), k3 = x4 && $3.indexOf(x4) > -1;
        if (y3 || b3) {
          if (x4 && k3)
            t6.headers["Content-Type"] = x4;
          else if (!x4) {
            var S3 = $3[0];
            S3 && (t6.headers["Content-Type"] = S3, x4 = S3);
          }
        } else
          x4 && k3 && (t6.headers["Content-Type"] = x4);
        if (!e7.responseContentType && m3.responses) {
          var A3, E3 = Wb(A3 = Hb(m3.responses)).call(A3, function(e8) {
            var t7 = Pf(e8, 2), r8 = t7[0], n8 = t7[1], o7 = parseInt(r8, 10);
            return o7 >= 200 && o7 < 300 && s_(n8.content);
          }).reduce(function(e8, t7) {
            var r8 = Pf(t7, 2)[1];
            return Rb(e8).call(e8, Cb(r8.content));
          }, []);
          E3.length > 0 && (t6.headers.accept = E3.join(", "));
        }
        if (y3)
          if (x4) {
            if ($3.indexOf(x4) > -1)
              if ("application/x-www-form-urlencoded" === x4 || "multipart/form-data" === x4)
                if ("object" === _f(y3)) {
                  var O3 = (w3.content[x4] || {}).encoding || {};
                  t6.form = {}, Cb(y3).forEach(function(e8) {
                    t6.form[e8] = { value: y3[e8], encoding: O3[e8] || {} };
                  });
                } else
                  t6.form = y3;
              else
                t6.body = y3;
          } else
            t6.body = y3;
        return t6;
      }(E2, v2) : function(e7, t6) {
        var r7, n7, o6, a3, i5, s7, l3, c4, p3, d3, u4, h3, f4, m3, y3, g3, v3, b3 = e7.spec, x4 = e7.operation, w3 = e7.securities, $3 = e7.requestContentType, k3 = e7.responseContentType, S3 = e7.attachContentTypeForEmptyPayload;
        if (s7 = void 0 === (i5 = (o6 = { request: t6, securities: w3, operation: x4, spec: b3 }).securities) ? {} : i5, c4 = void 0 === (l3 = o6.operation) ? {} : l3, p3 = o6.spec, d3 = Td({}, a3 = o6.request), u4 = s7.authorized, h3 = void 0 === u4 ? {} : u4, f4 = s7.specSecurity, m3 = void 0 === f4 ? [] : f4, y3 = c4.security || m3, g3 = h3 && !!Cb(h3).length, v3 = p3.securityDefinitions, d3.headers = d3.headers || {}, d3.query = d3.query || {}, (t6 = Cb(s7).length && g3 && y3 && (!Array.isArray(c4.security) || c4.security.length) ? (y3.forEach(function(e8) {
          Cb(e8).forEach(function(e9) {
            var t7 = h3[e9];
            if (t7) {
              var r8 = t7.token, n8 = t7.value || t7, o7 = v3[e9], a4 = o7.type, i6 = o7["x-tokenName"] || "access_token", s8 = r8 && r8[i6], l4 = r8 && r8.token_type;
              if (t7) {
                if ("apiKey" === a4) {
                  var c5 = "query" === o7.in ? "query" : "headers";
                  d3[c5] = d3[c5] || {}, d3[c5][o7.name] = n8;
                } else if ("basic" === a4)
                  if (n8.header)
                    d3.headers.authorization = n8.header;
                  else {
                    var p4, u5 = n8.username || "", f5 = n8.password || "";
                    n8.base64 = h_(Rb(p4 = "".concat(u5, ":")).call(p4, f5)), d3.headers.authorization = "Basic ".concat(n8.base64);
                  }
                else if ("oauth2" === a4 && s8) {
                  var m4;
                  l4 = l4 && "bearer" !== l4.toLowerCase() ? l4 : "Bearer", d3.headers.authorization = Rb(m4 = "".concat(l4, " ")).call(m4, s8);
                }
              }
            }
          });
        }), d3) : a3).body || t6.form || S3)
          if ($3)
            t6.headers["Content-Type"] = $3;
          else if (Array.isArray(x4.consumes)) {
            var A3 = Pf(x4.consumes, 1);
            t6.headers["Content-Type"] = A3[0];
          } else if (Array.isArray(b3.consumes)) {
            var E3 = Pf(b3.consumes, 1);
            t6.headers["Content-Type"] = E3[0];
          } else
            x4.parameters && Wb(r7 = x4.parameters).call(r7, function(e8) {
              return "file" === e8.type;
            }).length ? t6.headers["Content-Type"] = "multipart/form-data" : x4.parameters && Wb(n7 = x4.parameters).call(n7, function(e8) {
              return "formData" === e8.in;
            }).length && (t6.headers["Content-Type"] = "application/x-www-form-urlencoded");
        else if ($3) {
          var O3, T3, C2 = x4.parameters && Wb(O3 = x4.parameters).call(O3, function(e8) {
            return "body" === e8.in;
          }).length > 0, j2 = x4.parameters && Wb(T3 = x4.parameters).call(T3, function(e8) {
            return "formData" === e8.in;
          }).length > 0;
          (C2 || j2) && (t6.headers["Content-Type"] = $3);
        }
        return !k3 && Array.isArray(x4.produces) && x4.produces.length > 0 && (t6.headers.accept = x4.produces.join(", ")), t6;
      }(E2, v2)).cookies && Cb(v2.cookies).length) {
        var O2 = Cb(v2.cookies).reduce(function(e7, t6) {
          var r7 = v2.cookies[t6];
          return e7 + (e7 ? "&" : "") + r_(t6, r7);
        }, "");
        v2.headers.Cookie = O2;
      }
      return v2.cookies && delete v2.cookies, DS(v2), v2;
    }
    var b_ = function(e6) {
      return e6 ? e6.replace(/\W/g, "") : null;
    };
    function x_(e6) {
      return MC(e6.spec) ? function(e7) {
        var t5 = e7.spec, r6 = e7.pathName, n6 = e7.method, o5 = e7.server, a2 = e7.contextUrl, i4 = e7.serverVariables, s6 = void 0 === i4 ? {} : i4, l2 = qI(t5, ["paths", r6, (n6 || "").toLowerCase(), "servers"]) || qI(t5, ["paths", r6, "servers"]) || qI(t5, ["servers"]), c3 = "", p2 = null;
        if (o5 && l2 && l2.length) {
          var d2 = Tb(l2).call(l2, function(e8) {
            return e8.url;
          });
          d2.indexOf(o5) > -1 && (c3 = o5, p2 = l2[d2.indexOf(o5)]);
        }
        if (!c3 && l2 && l2.length) {
          c3 = l2[0].url;
          var u3 = Pf(l2, 1);
          p2 = u3[0];
        }
        c3.indexOf("{") > -1 && function(e8) {
          for (var t6, r7 = [], n7 = /{([^}]+)}/g; t6 = n7.exec(e8); )
            r7.push(t6[1]);
          return r7;
        }(c3).forEach(function(e8) {
          if (p2.variables && p2.variables[e8]) {
            var t6 = p2.variables[e8], r7 = s6[e8] || t6.default, n7 = new RegExp("{".concat(e8, "}"), "g");
            c3 = c3.replace(n7, r7);
          }
        });
        return function() {
          var e8, t6, r7 = arguments.length > 0 && void 0 !== arguments[0] ? arguments[0] : "", n7 = arguments.length > 1 && void 0 !== arguments[1] ? arguments[1] : "", o6 = r7 && n7 ? hu.parse(hu.resolve(n7, r7)) : hu.parse(r7), a3 = hu.parse(n7), i5 = b_(o6.protocol) || b_(a3.protocol) || "", s7 = o6.host || a3.host, l3 = o6.pathname || "";
          return "/" === (e8 = i5 && s7 ? Rb(t6 = "".concat(i5, "://")).call(t6, s7 + l3) : l3)[e8.length - 1] ? mS(e8).call(e8, 0, -1) : e8;
        }(c3, a2);
      }(e6) : function(e7) {
        var t5, r6, n6 = e7.spec, o5 = e7.scheme, a2 = e7.contextUrl, i4 = void 0 === a2 ? "" : a2, s6 = hu.parse(i4), l2 = Array.isArray(n6.schemes) ? n6.schemes[0] : null, c3 = o5 || l2 || b_(s6.protocol) || "http", p2 = n6.host || s6.host || "", d2 = n6.basePath || "";
        return "/" === (t5 = c3 && p2 ? Rb(r6 = "".concat(c3, "://")).call(r6, p2 + d2) : d2)[t5.length - 1] ? mS(t5).call(t5, 0, -1) : t5;
      }(e6);
    }
    function w_(e6) {
      var t5 = this, r6 = arguments.length > 1 && void 0 !== arguments[1] ? arguments[1] : {};
      if ("string" == typeof e6 ? r6.url = e6 : r6 = e6, !(this instanceof w_))
        return new w_(r6);
      Hd(this, r6);
      var n6 = this.resolve().then(function() {
        return t5.disableInterfaces || Hd(t5, w_.makeApisTagOperation(t5)), t5;
      });
      return n6.client = this, n6;
    }
    function $_(e6) {
      const t5 = (e6 = e6.replace("[]", "Array")).split("/");
      return t5[0] = t5[0].replace(/[^A-Za-z0-9_\-\.]+|\s+/gm, "_"), t5.join("/");
    }
    w_.http = $S, w_.makeHttp = function(e6, t5, r6) {
      return r6 = r6 || function(e7) {
        return e7;
      }, t5 = t5 || function(e7) {
        return e7;
      }, function(n6) {
        return "string" == typeof n6 && (n6 = { url: n6 }), wS.mergeInQueryOrForm(n6), n6 = t5(n6), r6(e6(n6));
      };
    }.bind(null, w_.http), w_.resolve = ZC, w_.resolveSubtree = function(e6, t5) {
      return UI.apply(this, arguments);
    }, w_.execute = function(e6) {
      var t5 = e6.http, r6 = e6.fetch, n6 = e6.spec, o5 = e6.operationId, a2 = e6.pathName, i4 = e6.method, s6 = e6.parameters, l2 = e6.securities, c3 = function(e7, t6) {
        if (null == e7)
          return {};
        var r7, n7, o6 = function(e8, t7) {
          if (null == e8)
            return {};
          var r8, n8, o7 = {}, a4 = sa(e8);
          for (n8 = 0; n8 < a4.length; n8++)
            r8 = a4[n8], t_(t7).call(t7, r8) >= 0 || (o7[r8] = e8[r8]);
          return o7;
        }(e7, t6);
        if (ec) {
          var a3 = ec(e7);
          for (n7 = 0; n7 < a3.length; n7++)
            r7 = a3[n7], t_(t6).call(t6, r7) >= 0 || Object.prototype.propertyIsEnumerable.call(e7, r7) && (o6[r7] = e7[r7]);
        }
        return o6;
      }(e6, f_), p2 = t5 || r6 || $S;
      a2 && i4 && !o5 && (o5 = VC(a2, i4));
      var d2 = g_.buildRequest(Td({ spec: n6, operationId: o5, parameters: s6, securities: l2, http: p2 }, c3));
      return d2.body && (s_(d2.body) || Array.isArray(d2.body)) && (d2.body = $b(d2.body)), p2(d2);
    }, w_.serializeRes = ES, w_.serializeHeaders = TS, w_.clearCache = function() {
      qC.refs.clearCache();
    }, w_.makeApisTagOperation = function() {
      var e6 = arguments.length > 0 && void 0 !== arguments[0] ? arguments[0] : {}, t5 = HI(e6);
      return { apis: MI({ v2OperationIdCompatibilityMode: e6.v2OperationIdCompatibilityMode, spec: e6.spec, cb: t5 }) };
    }, w_.buildRequest = v_, w_.helpers = { opId: HC }, w_.getBaseUrl = x_, w_.prototype = { http: $S, execute: function(e6) {
      return this.applyDefaults(), w_.execute(Td({ spec: this.spec, http: this.http, securities: { authorized: this.authorizations }, contextUrl: "string" == typeof this.url ? this.url : void 0, requestInterceptor: this.requestInterceptor || null, responseInterceptor: this.responseInterceptor || null }, e6));
    }, resolve: function() {
      var e6 = this, t5 = arguments.length > 0 && void 0 !== arguments[0] ? arguments[0] : {};
      return w_.resolve(Td({ spec: this.spec, url: this.url, http: this.http || this.fetch, allowMetaPatches: this.allowMetaPatches, useCircularStructures: this.useCircularStructures, requestInterceptor: this.requestInterceptor || null, responseInterceptor: this.responseInterceptor || null, skipNormalization: this.skipNormalization || false }, t5)).then(function(t6) {
        return e6.originalSpec = e6.spec, e6.spec = t6.spec, e6.errors = t6.errors, e6;
      });
    } }, w_.prototype.applyDefaults = function() {
      var e6 = this.spec, t5 = this.url;
      if (t5 && uu(t5).call(t5, "http")) {
        var r6 = hu.parse(t5);
        e6.host || (e6.host = r6.host), e6.schemes || (e6.schemes = [r6.protocol.replace(":", "")]), e6.basePath || (e6.basePath = "/");
      }
    }, w_.helpers;
    const k_ = { parameterTypeProperties: ["format", "minimum", "maximum", "exclusiveMinimum", "exclusiveMaximum", "minLength", "maxLength", "multipleOf", "minItems", "maxItems", "uniqueItems", "minProperties", "maxProperties", "additionalProperties", "pattern", "enum", "default"], arrayProperties: ["items", "minItems", "maxItems", "uniqueItems"], httpMethods: ["get", "post", "put", "delete", "patch", "head", "options", "trace"], uniqueOnly: function(e6, t5, r6) {
      return r6.indexOf(e6) === t5;
    }, createHash: function(e6) {
      let t5, r6 = 0;
      if (0 === e6.length)
        return r6;
      for (let n6 = 0; n6 < e6.length; n6++)
        t5 = e6.charCodeAt(n6), r6 = (r6 << 5) - r6 + t5, r6 |= 0;
      return r6;
    }, sanitise: $_, sanitiseAll: function(e6) {
      return $_(e6.split("/").join("_"));
    }, camelize: function(e6) {
      return e6.toLowerCase().replace(/[-_ \/\.](.)/g, (e7, t5) => t5.toUpperCase());
    }, clone: function(e6) {
      return JSON.parse(JSON.stringify(e6));
    }, circularClone: function e6(t5, r6 = null) {
      if (r6 || (r6 = /* @__PURE__ */ new WeakMap()), Object(t5) !== t5 || t5 instanceof Function)
        return t5;
      if (r6.has(t5))
        return r6.get(t5);
      let n6;
      try {
        n6 = new t5.constructor();
      } catch (e7) {
        n6 = Object.create(Object.getPrototypeOf(t5));
      }
      return r6.set(t5, n6), Object.assign(n6, ...Object.keys(t5).map((n7) => ({ [n7]: e6(t5[n7], r6) })));
    } };
    function S_() {
      return { depth: 0, seen: /* @__PURE__ */ new WeakMap(), top: true, combine: false, allowRefSiblings: false };
    }
    const A_ = function e6(t5, r6, n6, o5) {
      if (void 0 === n6.depth && (n6 = S_()), null == t5)
        return t5;
      if (n6.combine && (t5.allOf && Array.isArray(t5.allOf) && 1 === t5.allOf.length && delete (t5 = { ...t5.allOf[0], ...t5 })?.allOf, t5?.anyOf && Array.isArray(t5.anyOf) && 1 === t5.anyOf.length && delete (t5 = { ...t5.anyOf[0], ...t5 })?.anyOf, t5?.oneOf && Array.isArray(t5.oneOf) && 1 === t5.oneOf.length && delete (t5 = { ...t5.oneOf[0], ...t5 })?.oneOf), o5(t5, r6, n6), n6.seen.has(t5))
        return t5;
      if ("object" == typeof t5 && null !== t5 && n6.seen.set(t5, true), n6.top = false, n6.depth++, void 0 !== t5?.items && (n6.property = "items", e6(t5.items, t5, n6, o5)), t5?.additionalItems && "object" == typeof t5.additionalItems && (n6.property = "additionalItems", e6(t5.additionalItems, t5, n6, o5)), t5?.additionalProperties && "object" == typeof t5.additionalProperties && (n6.property = "additionalProperties", e6(t5.additionalProperties, t5, n6, o5)), t5?.properties)
        for (const r7 in t5.properties) {
          const a2 = t5.properties[r7];
          n6.property = `properties/${r7}`, e6(a2, t5, n6, o5);
        }
      if (t5?.patternProperties)
        for (const r7 in t5.patternProperties) {
          const a2 = t5.patternProperties[r7];
          n6.property = `patternProperties/${r7}`, e6(a2, t5, n6, o5);
        }
      if (t5?.allOf)
        for (const r7 in t5.allOf) {
          const a2 = t5.allOf[r7];
          n6.property = `allOf/${r7}`, e6(a2, t5, n6, o5);
        }
      if (t5?.anyOf)
        for (const r7 in t5.anyOf) {
          const a2 = t5.anyOf[r7];
          n6.property = `anyOf/${r7}`, e6(a2, t5, n6, o5);
        }
      if (t5?.oneOf)
        for (const r7 in t5.oneOf) {
          const a2 = t5.oneOf[r7];
          n6.property = `oneOf/${r7}`, e6(a2, t5, n6, o5);
        }
      return t5?.not && (n6.property = "not", e6(t5.not, t5, n6, o5)), n6.depth--, t5;
    };
    function E_(e6, t5, r6) {
      if (t5 || (t5 = { depth: 0 }), t5.depth || (t5 = { path: "#", depth: 0, pkey: "", parent: {}, payload: {}, seen: /* @__PURE__ */ new WeakMap(), identity: false, identityDetection: false, ...t5 }), "object" != typeof e6)
        return;
      const n6 = t5.path;
      for (const o5 in e6) {
        if (t5.key = o5, t5.path = `${t5.path}/${encodeURIComponent(o5)}`, t5.identityPath = t5.seen.get(e6[o5]), t5.identity = void 0 !== t5.identityPath, e6.hasOwnProperty(o5) && r6(e6, o5, t5), "object" == typeof e6[o5] && !t5.identity) {
          t5.identityDetection && !Array.isArray(e6[o5]) && null !== e6[o5] && t5.seen.set(e6[o5], t5.path);
          const n7 = {};
          n7.parent = e6, n7.path = t5.path, n7.depth = t5.depth ? t5.depth + 1 : 1, n7.pkey = o5, n7.payload = t5.payload, n7.seen = t5.seen, n7.identity = false, n7.identityDetection = t5.identityDetection, E_(e6[o5], n7, r6);
        }
        t5.path = n6;
      }
    }
    let O_;
    function T_(e6, t5) {
      for (const r6 in e6)
        r6.startsWith("x-") && !r6.startsWith("x-s2o") && (t5[r6] = e6[r6]);
    }
    function C_(e6, t5) {
      A_(e6, {}, {}, (e7, r6) => {
        !function(e8) {
          if (e8["x-required"] && Array.isArray(e8["x-required"]) && (e8.required || (e8.required = []), e8.required = e8.required.concat(e8["x-required"]), delete e8["x-required"]), e8["x-anyOf"] && (e8.anyOf = e8["x-anyOf"], delete e8["x-anyOf"]), e8["x-oneOf"] && (e8.oneOf = e8["x-oneOf"], delete e8["x-oneOf"]), e8["x-not"] && (e8.not = e8["x-not"], delete e8["x-not"]), "boolean" == typeof e8["x-nullable"] && (e8.nullable = e8["x-nullable"], delete e8["x-nullable"]), "object" == typeof e8["x-discriminator"] && "string" == typeof e8["x-discriminator"].propertyName) {
            e8.discriminator = e8["x-discriminator"], delete e8["x-discriminator"];
            for (const t6 in e8.discriminator.mapping) {
              const r7 = e8.discriminator.mapping[t6];
              r7.startsWith("#/definitions/") && (e8.discriminator.mapping[t6] = r7.replace("#/definitions/", "#/components/schemas/"));
            }
          }
        }(e7), function(e8, t6, r7) {
          if (e8.nullable && r7.patches++, e8.discriminator && "string" == typeof e8.discriminator && (e8.discriminator = { propertyName: e8.discriminator }), e8.items && Array.isArray(e8.items) && (0 === e8.items.length ? e8.items = {} : 1 === e8.items.length ? e8.items = e8.items[0] : e8.items = { anyOf: e8.items }), e8.type && Array.isArray(e8.type)) {
            if (r7.patches++, r7.warnings.push("(Patchable) schema type must not be an array"), 0 === e8.type.length)
              delete e8.type;
            else {
              e8.oneOf || (e8.oneOf = []);
              for (const t7 of e8.type) {
                const r8 = {};
                if ("null" === t7)
                  e8.nullable = true;
                else {
                  r8.type = t7;
                  for (const t8 of k_.arrayProperties)
                    void 0 !== e8.prop && (r8[t8] = e8[t8], delete e8[t8]);
                }
                r8.type && e8.oneOf.push(r8);
              }
              delete e8.type, 0 === e8.oneOf.length ? delete e8.oneOf : e8.oneOf.length < 2 && (e8.type = e8.oneOf[0].type, Object.keys(e8.oneOf[0]).length > 1 && (r7.patches++, r7.warnings.push("Lost properties from oneOf")), delete e8.oneOf);
            }
            e8.type && Array.isArray(e8.type) && 1 === e8.type.length && (e8.type = e8.type[0]);
          }
          e8.type && "null" === e8.type && (delete e8.type, e8.nullable = true), "array" !== e8.type || e8.items || (e8.items = {}), "file" === e8.type && (e8.type = "string", e8.format = "binary"), "boolean" == typeof e8.required && (e8.required && e8.name && (void 0 === t6.required && (t6.required = []), Array.isArray(t6.required) && t6.required.push(e8.name)), delete e8.required), e8.xml && "string" == typeof e8.xml.namespace && (e8.xml.namespace || delete e8.xml.namespace), e8.allowEmptyValue && (delete e8.allowEmptyValue, r7.patches++, r7.warnings.push("(Patchable): deleted schema.allowEmptyValue"));
        }(e7, r6, t5);
      });
    }
    function j_(e6) {
      for (const t5 in e6)
        for (const r6 in e6[t5]) {
          const n6 = k_.sanitise(r6);
          r6 !== n6 && (e6[t5][n6] = e6[t5][r6], delete e6[t5][r6]);
        }
    }
    function I_(e6, t5) {
      if ("basic" === e6.type && (e6.type = "http", e6.scheme = "basic"), "oauth2" === e6.type) {
        const r6 = {};
        let n6 = e6.flow;
        "application" === e6.flow && (n6 = "clientCredentials"), "accessCode" === e6.flow && (n6 = "authorizationCode"), "string" == typeof e6.authorizationUrl && (r6.authorizationUrl = e6.authorizationUrl.split("?")[0].trim() || "/"), "string" == typeof e6.tokenUrl && (r6.tokenUrl = e6.tokenUrl.split("?")[0].trim() || "/"), r6.scopes = e6.scopes || {}, e6.flows = {}, e6.flows[n6] = r6, delete e6.flow, delete e6.authorizationUrl, delete e6.tokenUrl, delete e6.scopes, e6.name && (delete e6.name, t5.patches++, t5.warnings.push("(Patchable) oauth2 securitySchemes should not have name property"));
      }
    }
    function __(e6) {
      return e6 && !e6["x-s2o-delete"];
    }
    function P_(e6, t5) {
      if (e6.type && !e6.schema && (e6.schema = {}), e6.type && (e6.schema.type = e6.type), e6.items && "array" !== e6.items.type) {
        if (e6.items.collectionFormat !== e6.collectionFormat)
          return t5.errCount++, void t5.errors.push({ message: "Nested collectionFormats are not supported", pointer: "/.../responses/header" });
        delete e6.items.collectionFormat;
      }
      "array" === e6.type ? ("ssv" === e6.collectionFormat ? (t5.patches++, t5.warnings.push("collectionFormat:ssv is no longer supported for headers")) : "pipes" === e6.collectionFormat ? (t5.patches++, t5.warnings.push("collectionFormat:pipes is no longer supported for headers")) : "multi" === e6.collectionFormat ? e6.explode = true : "tsv" === e6.collectionFormat ? (e6["x-collectionFormat"] = "tsv", t5.patches++, t5.warnings.push("collectionFormat:tsv is no longer supported")) : e6.style = "simple", delete e6.collectionFormat) : e6.collectionFormat && (delete e6.collectionFormat, t5.patches++, t5.warnings.push("(Patchable) collectionFormat is only applicable to header.type array")), delete e6.type;
      for (const t6 of k_.parameterTypeProperties)
        void 0 !== e6[t6] && (e6.schema[t6] = e6[t6], delete e6[t6]);
      for (const t6 of k_.arrayProperties)
        void 0 !== e6[t6] && (e6.schema[t6] = e6[t6], delete e6[t6]);
    }
    function R_(e6, t5, r6, n6, o5, a2, i4) {
      const s6 = {};
      let l2, c3 = true;
      t5 && t5.consumes && "string" == typeof t5.consumes && (t5.consumes = [t5.consumes], i4.patches++, i4.warnings.push("(Patchable) operation.consumes must be an array")), Array.isArray(a2.consumes) || delete a2.consumes;
      const p2 = ((t5 ? t5.consumes : null) || a2.consumes || []).filter(k_.uniqueOnly);
      if (e6 && (e6.name || e6.in)) {
        "boolean" == typeof e6["x-deprecated"] && (e6.deprecated = e6["x-deprecated"], delete e6["x-deprecated"]), void 0 !== e6["x-example"] && (e6.example = e6["x-example"], delete e6["x-example"]), "body" === e6.in || e6.type || (e6.type = "string", i4.patches++, i4.warnings.push("(Patchable) parameter.type is mandatory for non-body parameters")), "file" === e6.type && (e6["x-s2o-originalType"] = e6.type, l2 = e6.type), null === e6.description && delete e6.description;
        let t6 = e6.collectionFormat;
        if ("array" !== e6.type || t6 || (t6 = "csv"), t6 && ("array" !== e6.type && (delete e6.collectionFormat, i4.patches++, i4.warnings.push("(Patchable) collectionFormat is only applicable to param.type array")), "csv" !== t6 || "query" !== e6.in && "cookie" !== e6.in || (e6.style = "form", e6.explode = false), "csv" !== t6 || "path" !== e6.in && "header" !== e6.in || (e6.style = "simple"), "ssv" === t6 && ("query" === e6.in ? e6.style = "spaceDelimited" : i4.warnings.push(`${e6.name} collectionFormat:ssv is no longer supported except for in:query parameters`)), "pipes" === t6 && ("query" === e6.in ? e6.style = "pipeDelimited" : i4.warnings.push(`${e6.name} collectionFormat:pipes is no longer supported except for in:query parameters`)), "multi" === t6 && (e6.explode = true), "tsv" === t6 && (i4.warnings.push("collectionFormat:tsv is no longer supported"), e6["x-collectionFormat"] = "tsv"), delete e6.collectionFormat), e6.type && "body" !== e6.type && "formData" !== e6.in)
          if (e6.items && e6.schema)
            i4.warnings.push(`${e6.name} parameter has array,items and schema`);
          else {
            e6.schema && i4.patches++, e6.schema && "object" == typeof e6.schema || (e6.schema = {}), e6.schema.type = e6.type, e6.items && (e6.schema.items = e6.items, delete e6.items, E_(e6.schema.items, null, (r7, n7) => {
              "collectionFormat" === n7 && "string" == typeof r7[n7] && (t6 && r7[n7] !== t6 && i4.warnings.push(`${e6.name} Nested collectionFormats are not supported`), delete r7[n7]);
            }));
            for (const t7 of k_.parameterTypeProperties)
              void 0 !== e6[t7] && (e6.schema[t7] = e6[t7]), delete e6[t7];
          }
        e6.schema && C_(e6.schema, i4), e6["x-ms-skip-url-encoding"] && "query" === e6.in && (e6.allowReserved = true, delete e6["x-ms-skip-url-encoding"]);
      }
      if (e6 && "formData" === e6.in) {
        c3 = false, s6.content = {};
        let t6 = "application/x-www-form-urlencoded";
        if (p2.length && p2.indexOf("multipart/form-data") >= 0 && (t6 = "multipart/form-data"), s6.content[t6] = {}, e6.schema)
          s6.content[t6].schema = e6.schema;
        else {
          s6.content[t6].schema = {}, s6.content[t6].schema.type = "object", s6.content[t6].schema.properties = {}, s6.content[t6].schema.properties[e6.name] = {};
          const r7 = s6.content[t6].schema, n7 = s6.content[t6].schema.properties[e6.name];
          e6.description && (n7.description = e6.description), e6.example && (n7.example = e6.example), e6.type && (n7.type = e6.type);
          for (const t7 of k_.parameterTypeProperties)
            void 0 !== e6[t7] && (n7[t7] = e6[t7]);
          true === e6.required && (r7.required || (r7.required = []), r7.required.push(e6.name), s6.required = true), void 0 !== e6.default && (n7.default = e6.default), n7.properties && (n7.properties = e6.properties), e6.allOf && (n7.allOf = e6.allOf), "array" === e6.type && e6.items && (n7.items = e6.items, n7.items.collectionFormat && delete n7.items.collectionFormat), "file" !== l2 && "file" !== e6["x-s2o-originalType"] || (n7.type = "string", n7.format = "binary"), T_(e6, n7);
        }
      } else
        e6 && "file" === e6.type && (e6.required && (s6.required = e6.required), s6.content = {}, s6.content["application/octet-stream"] = {}, s6.content["application/octet-stream"].schema = {}, s6.content["application/octet-stream"].schema.type = "string", s6.content["application/octet-stream"].schema.format = "binary", T_(e6, s6));
      if (e6 && "body" === e6.in) {
        s6.content = {}, e6.name && (s6["x-s2o-name"] = (t5 && t5.operationId ? k_.sanitiseAll(t5.operationId) : "") + k_.camelize(`_${e6.name}`)), e6.description && (s6.description = e6.description), e6.required && (s6.required = e6.required), p2.length || p2.push("application/json");
        for (const t6 of p2)
          s6.content[t6] = {}, s6.content[t6].schema = k_.clone(e6.schema || {}), C_(s6.content[t6].schema, i4);
        T_(e6, s6);
      }
      if (Object.keys(s6).length > 0 && (e6["x-s2o-delete"] = true, t5))
        if (t5.requestBody && c3) {
          t5.requestBody["x-s2o-overloaded"] = true;
          const e7 = t5.operationId || o5;
          i4.warnings.push(`Operation ${e7} has multiple requestBodies`);
        } else
          t5.requestBody || (t5 = function(e7, t6) {
            const r7 = {};
            for (const n7 of Object.keys(e7))
              r7[n7] = e7[n7], "parameters" === n7 && (r7.requestBody = {}, t6.rbname && (r7[t6.rbname] = ""));
            return r7.requestBody = {}, r7;
          }(t5, i4), r6[n6] = t5), t5.requestBody.content && t5.requestBody.content["multipart/form-data"] && t5.requestBody.content["multipart/form-data"].schema && t5.requestBody.content["multipart/form-data"].schema.properties && s6.content["multipart/form-data"] && s6.content["multipart/form-data"].schema && s6.content["multipart/form-data"].schema.properties ? (t5.requestBody.content["multipart/form-data"].schema.properties = Object.assign(t5.requestBody.content["multipart/form-data"].schema.properties, s6.content["multipart/form-data"].schema.properties), t5.requestBody.content["multipart/form-data"].schema.required = (t5.requestBody.content["multipart/form-data"].schema.required || []).concat(s6.content["multipart/form-data"].schema.required || []), t5.requestBody.content["multipart/form-data"].schema.required.length || delete t5.requestBody.content["multipart/form-data"].schema.required) : t5.requestBody.content && t5.requestBody.content["application/x-www-form-urlencoded"] && t5.requestBody.content["application/x-www-form-urlencoded"].schema && t5.requestBody.content["application/x-www-form-urlencoded"].schema.properties && s6.content["application/x-www-form-urlencoded"] && s6.content["application/x-www-form-urlencoded"].schema && s6.content["application/x-www-form-urlencoded"].schema.properties ? (t5.requestBody.content["application/x-www-form-urlencoded"].schema.properties = Object.assign(t5.requestBody.content["application/x-www-form-urlencoded"].schema.properties, s6.content["application/x-www-form-urlencoded"].schema.properties), t5.requestBody.content["application/x-www-form-urlencoded"].schema.required = (t5.requestBody.content["application/x-www-form-urlencoded"].schema.required || []).concat(s6.content["application/x-www-form-urlencoded"].schema.required || []), t5.requestBody.content["application/x-www-form-urlencoded"].schema.required.length || delete t5.requestBody.content["application/x-www-form-urlencoded"].schema.required) : (t5.requestBody = Object.assign(t5.requestBody, s6), t5.requestBody["x-s2o-name"] || t5.operationId && (t5.requestBody["x-s2o-name"] = k_.sanitiseAll(t5.operationId)));
      if (e6 && !e6["x-s2o-delete"]) {
        delete e6.type;
        for (const t6 of k_.parameterTypeProperties)
          delete e6[t6];
        "path" !== e6.in || void 0 !== e6.required && true === e6.required || (e6.required = true, i4.patches++, i4.warnings.push(`(Patchable) path parameters must be required:true [${e6.name} in ${o5}]`));
      }
      return t5;
    }
    function L_(e6, t5, r6, n6) {
      if (!e6)
        return false;
      if (e6.description || "object" != typeof e6 || Array.isArray(e6) || (n6.patches++, n6.warnings.push("(Patchable) response.description is mandatory")), void 0 !== e6.schema) {
        C_(e6.schema, n6), t5 && t5.produces && "string" == typeof t5.produces && (t5.produces = [t5.produces], n6.patches++, n6.warnings.push("(Patchable) operation.produces must be an array")), r6.produces && !Array.isArray(r6.produces) && delete r6.produces;
        const o5 = ((t5 ? t5.produces : null) || r6.produces || []).filter(k_.uniqueOnly);
        o5.length || o5.push("*/*"), e6.content = {};
        for (const t6 of o5) {
          if (e6.content[t6] = {}, e6.content[t6].schema = k_.clone(e6.schema), e6.examples && e6.examples[t6]) {
            const r7 = {};
            r7.value = e6.examples[t6], e6.content[t6].examples = {}, e6.content[t6].examples.response = r7, delete e6.examples[t6];
          }
          "file" === e6.content[t6].schema.type && (e6.content[t6].schema = { type: "string", format: "binary" });
        }
        delete e6.schema;
      }
      for (const t6 in e6.examples)
        e6.content || (e6.content = {}), e6.content[t6] || (e6.content[t6] = {}), e6.content[t6].examples = {}, e6.content[t6].examples.response = {}, e6.content[t6].examples.response.value = e6.examples[t6];
      if (delete e6.examples, e6.headers)
        for (const t6 in e6.headers)
          "status code" === t6.toLowerCase() ? (delete e6.headers[t6], n6.patches++, n6.warnings.push('(Patchable) "Status Code" is not a valid header')) : P_(e6.headers[t6], n6);
    }
    function F_(e6, t5, r6, n6, o5) {
      for (const a2 in e6) {
        const i4 = e6[a2];
        i4 && i4["x-trace"] && "object" == typeof i4["x-trace"] && (i4.trace = i4["x-trace"], delete i4["x-trace"]), i4 && i4["x-summary"] && "string" == typeof i4["x-summary"] && (i4.summary = i4["x-summary"], delete i4["x-summary"]), i4 && i4["x-description"] && "string" == typeof i4["x-description"] && (i4.description = i4["x-description"], delete i4["x-description"]), i4 && i4["x-servers"] && Array.isArray(i4["x-servers"]) && (i4.servers = i4["x-servers"], delete i4["x-servers"]);
        for (const e7 in i4)
          if (k_.httpMethods.indexOf(e7) >= 0 || "x-amazon-apigateway-any-method" === e7) {
            let s6 = i4[e7];
            if (s6 && s6.parameters && Array.isArray(s6.parameters)) {
              if (i4.parameters)
                for (const t6 of i4.parameters)
                  s6.parameters.find((e8) => e8.name === t6.name && e8.in === t6.in) || "formData" !== t6.in && "body" !== t6.in && "file" !== t6.type || (s6 = R_(t6, s6, i4, e7, a2, o5, r6));
              for (const t6 of s6.parameters)
                s6 = R_(t6, s6, i4, e7, `${e7}: ${a2}`, o5, r6);
              s6.parameters && (s6.parameters = s6.parameters.filter(__));
            }
            if (s6 && s6.security && j_(s6.security), "object" == typeof s6) {
              if (!s6.responses) {
                const e8 = { description: "Default response" };
                s6.responses = { default: e8 };
              }
              for (const e8 in s6.responses)
                L_(s6.responses[e8], s6, o5, r6);
            }
            if (s6 && s6["x-servers"] && Array.isArray(s6["x-servers"]))
              s6.servers = s6["x-servers"], delete s6["x-servers"];
            else if (s6 && s6.schemes && s6.schemes.length) {
              for (const e8 of s6.schemes)
                if ((!o5.schemes || o5.schemes.indexOf(e8) < 0) && (s6.servers || (s6.servers = []), Array.isArray(o5.servers)))
                  for (const e9 of o5.servers) {
                    const t6 = k_.clone(e9);
                    s6.servers.push(t6);
                  }
            }
            if (s6) {
              if (delete s6.consumes, delete s6.produces, delete s6.schemes, s6["x-ms-examples"]) {
                for (const e8 in s6["x-ms-examples"]) {
                  const t6 = s6["x-ms-examples"][e8], r7 = k_.sanitiseAll(e8);
                  if (t6.parameters)
                    for (const r8 in t6.parameters) {
                      const n7 = t6.parameters[r8];
                      for (const t7 of (s6.parameters || []).concat(i4.parameters || []))
                        t7.name !== r8 || t7.example || (t7.examples || (t7.examples = {}), t7.examples[e8] = { value: n7 });
                    }
                  if (t6.responses)
                    for (const n7 in t6.responses) {
                      if (t6.responses[n7].headers)
                        for (const e9 in t6.responses[n7].headers) {
                          const r8 = t6.responses[n7].headers[e9];
                          for (const t7 in s6.responses[n7].headers)
                            t7 === e9 && (s6.responses[n7].headers[t7].example = r8);
                        }
                      if (t6.responses[n7].body && (o5.components.examples[r7] = { value: k_.clone(t6.responses[n7].body) }, s6.responses[n7] && s6.responses[n7].content))
                        for (const t7 in s6.responses[n7].content) {
                          const o6 = s6.responses[n7].content[t7];
                          o6.examples || (o6.examples = {}), o6.examples[e8] = { $ref: `#/components/examples/${r7}` };
                        }
                    }
                }
                delete s6["x-ms-examples"];
              }
              if (s6.parameters && 0 === s6.parameters.length && delete s6.parameters, s6.requestBody) {
                const r7 = s6.operationId ? k_.sanitiseAll(s6.operationId) : k_.camelize(k_.sanitiseAll(e7 + a2)), o6 = k_.sanitise(s6.requestBody["x-s2o-name"] || r7 || "");
                delete s6.requestBody["x-s2o-name"];
                const i5 = JSON.stringify(s6.requestBody), l2 = k_.createHash(i5);
                if (!n6[l2]) {
                  const e8 = {};
                  e8.name = o6, e8.body = s6.requestBody, e8.refs = [], n6[l2] = e8;
                }
                const c3 = `#/${t5}/${encodeURIComponent(a2)}/${e7}/requestBody`;
                n6[l2].refs.push(c3);
              }
            }
          }
        if (i4 && i4.parameters) {
          for (const e7 in i4.parameters)
            R_(i4.parameters[e7], null, i4, null, a2, o5, r6);
          Array.isArray(i4.parameters) && (i4.parameters = i4.parameters.filter(__));
        }
      }
    }
    function D_(e6) {
      return e6 && e6.url && "string" == typeof e6.url ? (e6.url = e6.url.split("{{").join("{"), e6.url = e6.url.split("}}").join("}"), e6.url.replace(/\{(.+?)\}/g, (t5, r6) => {
        e6.variables || (e6.variables = {}), e6.variables[r6] = { default: "unknown" };
      }), e6) : e6;
    }
    function B_(e6, t5) {
      void 0 !== e6.info && null !== e6.info || (e6.info = { version: "", title: "" }, t5.patches++, t5.warnings.push("(Patchable) info object is mandatory")), ("object" != typeof e6.info || Array.isArray(e6.info)) && (t5.errCount++, t5.errors.push({ message: "info must be an object", pointer: "/info" })), e6.info && (void 0 === e6.info.title && (t5.patches++, e6.info.title = "", t5.warnings.push({ message: "(Patchable) info.title cannot be null", pointer: "/info/title", patchable: true })), void 0 === e6.info.version ? (t5.patches++, e6.info.version = "", t5.warnings.push("(Patchable) info.version cannot be null")) : "string" != typeof e6.info.version && (t5.patches++, e6.info.version = e6.info.version.toString(), t5.warnings.push("(Patchable) info.version must be a string")));
    }
    function N_(e6, t5) {
      e6.paths || (t5.patches++, e6.paths = {}, t5.warnings.push("(Patchable) paths object is mandatory"));
    }
    function q_(e6 = {}) {
      const t5 = { original: e6, openapi: {}, patches: 0, warnings: [], errCount: 0, errors: [] };
      if (e6.openapi && "string" == typeof e6.openapi && e6.openapi.startsWith("3."))
        return t5.openapi = k_.circularClone(e6), B_(t5.openapi, t5), N_(t5.openapi, t5), t5;
      if ("2.0" !== e6.swagger)
        return t5.errCount++, t5.errors.push({ message: `Unsupported swagger/OpenAPI version: ${e6.openapi ? e6.openapi : e6.swagger}`, pointer: "/swagger" }), t5;
      if (t5.openapi = k_.circularClone(e6), t5.openapi.openapi = "3.0.0", delete t5.openapi.swagger, E_(t5.openapi, {}, (e7, t6, r6) => {
        null === e7[t6] && !t6.startsWith("x-") && "default" !== t6 && r6.path.indexOf("/example") < 0 && delete e7[t6];
      }), e6.host)
        (e6.schemes || []).forEach((r6) => {
          const n6 = {}, o5 = (e6.basePath || "").replace(/\/$/, "");
          n6.url = `${r6 ? `${r6}:` : ""}//${e6.host}${o5}`, D_(n6), t5.openapi.servers || (t5.openapi.servers = []), t5.openapi.servers.push(n6);
        });
      else if (e6.basePath) {
        const r6 = {};
        r6.url = e6.basePath, D_(r6), t5.openapi.servers || (t5.openapi.servers = []), t5.openapi.servers.push(r6);
      }
      if (delete t5.openapi.host, delete t5.openapi.basePath, e6["x-ms-parameterized-host"]) {
        const r6 = e6["x-ms-parameterized-host"], n6 = {};
        n6.url = r6.hostTemplate + (e6.basePath ? e6.basePath : ""), n6.variables = {};
        const o5 = n6.url.match(/\{\w+\}/g);
        for (const e7 in r6.parameters) {
          const t6 = r6.parameters[e7];
          e7.startsWith("x-") || (delete t6.required, delete t6.type, delete t6.in, void 0 === t6.default && (t6.enum ? t6.default = t6.enum[0] : t6.default = "none"), t6.name || (t6.name = o5[e7].replace("{", "").replace("}", "")), n6.variables[t6.name] = t6, delete t6.name);
        }
        t5.openapi.servers || (t5.openapi.servers = []), false === r6.useSchemePrefix ? t5.openapi.servers.push(n6) : e6.schemes.forEach((e7) => {
          t5.openapi.servers.push({ ...n6, url: `${e7}://${n6.url}` });
        }), delete t5.openapi["x-ms-parameterized-host"];
      }
      return B_(t5.openapi, t5), N_(t5.openapi, t5), "string" == typeof t5.openapi.consumes && (t5.openapi.consumes = [t5.openapi.consumes]), "string" == typeof t5.openapi.produces && (t5.openapi.produces = [t5.openapi.produces]), t5.openapi.components = {}, t5.openapi["x-callbacks"] && (t5.openapi.components.callbacks = t5.openapi["x-callbacks"], delete t5.openapi["x-callbacks"]), t5.openapi.components.examples = {}, t5.openapi.components.headers = {}, t5.openapi["x-links"] && (t5.openapi.components.links = t5.openapi["x-links"], delete t5.openapi["x-links"]), t5.openapi.components.parameters = t5.openapi.parameters || {}, t5.openapi.components.responses = t5.openapi.responses || {}, t5.openapi.components.requestBodies = {}, t5.openapi.components.securitySchemes = t5.openapi.securityDefinitions || {}, t5.openapi.components.schemas = t5.openapi.definitions || {}, delete t5.openapi.definitions, delete t5.openapi.responses, delete t5.openapi.parameters, delete t5.openapi.securityDefinitions, function(e7) {
        const t6 = e7.openapi, r6 = {};
        O_ = { schemas: {} }, t6.security && j_(t6.security);
        for (const r7 in t6.components.securitySchemes) {
          const n6 = k_.sanitise(r7);
          if (r7 !== n6) {
            if (t6.components.securitySchemes[n6])
              return e7.errCount++, e7.errors.push({ message: `Duplicate sanitised securityScheme name ${n6}`, pointer: `/components/securitySchemes/${n6}` }), e7;
            t6.components.securitySchemes[n6] = t6.components.securitySchemes[r7], delete t6.components.securitySchemes[r7];
          }
          I_(t6.components.securitySchemes[n6], e7);
        }
        for (const r7 in t6.components.schemas) {
          const n6 = k_.sanitiseAll(r7);
          let o5 = 0;
          if (r7 !== n6) {
            for (; t6.components.schemas[n6 + o5]; )
              o5 = o5 ? ++o5 : 2;
            t6.components.schemas[n6 + o5] = t6.components.schemas[r7], delete t6.components.schemas[r7];
          }
          O_.schemas[r7] = n6 + o5, C_(t6.components.schemas[`${n6}${o5}`], e7);
        }
        for (const r7 in t6.components.parameters) {
          const n6 = k_.sanitise(r7);
          if (r7 !== n6) {
            if (t6.components.parameters[n6])
              return e7.errCount++, e7.errors.push({ message: `Duplicate sanitised parameter name ${n6}`, pointer: `/components/parameters/${n6}` }), e7;
            t6.components.parameters[n6] = t6.components.parameters[r7], delete t6.components.parameters[r7];
          }
          R_(t6.components.parameters[n6], null, null, null, n6, t6, e7);
        }
        for (const r7 in t6.components.responses) {
          const n6 = k_.sanitise(r7);
          if (r7 !== n6) {
            if (t6.components.responses[n6])
              return e7.errCount++, e7.errors.push({ message: `Duplicate sanitised response name ${n6}`, pointer: `/components/responses/${n6}` }), e7;
            t6.components.responses[n6] = t6.components.responses[r7], delete t6.components.responses[r7];
          }
          const o5 = t6.components.responses[n6];
          if (L_(o5, null, t6, e7), o5.headers)
            for (const t7 in o5.headers)
              "status code" === t7.toLowerCase() ? (delete o5.headers[t7], e7.patches++, e7.warnings.push('(Patchable) "Status Code" is not a valid header')) : P_(o5.headers[t7], e7);
        }
        for (const e8 in t6.components.requestBodies) {
          const n6 = t6.components.requestBodies[e8], o5 = JSON.stringify(n6), a2 = k_.createHash(o5), i4 = {};
          i4.name = e8, i4.body = n6, i4.refs = [], r6[a2] = i4;
        }
        F_(t6.paths, "paths", e7, r6, t6), t6["x-ms-paths"] && F_(t6["x-ms-paths"], "x-ms-paths", e7, r6, t6);
        for (const e8 in t6.components.parameters)
          t6.components.parameters[e8]["x-s2o-delete"] && delete t6.components.parameters[e8];
        return delete t6.consumes, delete t6.produces, delete t6.schemes, t6.components.requestBodies = {}, t6.components.responses && 0 === Object.keys(t6.components.responses).length && delete t6.components.responses, t6.components.parameters && 0 === Object.keys(t6.components.parameters).length && delete t6.components.parameters, t6.components.examples && 0 === Object.keys(t6.components.examples).length && delete t6.components.examples, t6.components.requestBodies && 0 === Object.keys(t6.components.requestBodies).length && delete t6.components.requestBodies, t6.components.securitySchemes && 0 === Object.keys(t6.components.securitySchemes).length && delete t6.components.securitySchemes, t6.components.headers && 0 === Object.keys(t6.components.headers).length && delete t6.components.headers, t6.components.schemas && 0 === Object.keys(t6.components.schemas).length && delete t6.components.schemas, t6.components && 0 === Object.keys(t6.components).length && delete t6.components, e7;
      }(t5);
    }
    function U_(e6) {
      return e6.ok && e6.text && e6.parseError && "YAMLException" === e6.parseError.name && (!e6.headers["content-type"] || e6.headers["content-type"].match("text/plain")) && (e6.body = e6.text), e6;
    }
    const z_ = function(e6) {
      return new Promise(async (t5) => {
        try {
          const r6 = await w_.resolve(e6, U_);
          if (r6.errors && r6.errors.length > 0)
            t5(r6);
          else {
            r6.spec.openapi && (r6.resolvedSpec = r6.spec, t5(r6));
            const e7 = q_(r6.spec);
            e7.errors && e7.errors.length > 0 && (Array.isArray(r6.errors) ? r6.errors.concat(r6.errors) : r6.errors = e7.errors), e7.warnings && e7.warnings.length > 0 && (r6.warnings = e7.warnings), r6.resolvedSpec = r6.spec, r6.spec = e7.openapi, t5(r6);
          }
        } catch (e7) {
          t5(e7);
        }
      });
    };
    async function M_(e6, t5 = false, r6 = false, n6 = "", o5 = "", a2 = "", i4 = "", s6 = "") {
      var l2, c3;
      let p2;
      try {
        var d2, u3;
        let t6;
        if (this.requestUpdate(), t6 = "string" == typeof e6 ? await z_({ url: e6, allowMetaPatches: false }) : await z_({ spec: e6, allowMetaPatches: false }), await it(0), null !== (d2 = t6.resolvedSpec) && void 0 !== d2 && d2.jsonSchemaViewer && null !== (u3 = t6.resolvedSpec) && void 0 !== u3 && u3.schemaAndExamples) {
          this.dispatchEvent(new CustomEvent("before-render", { detail: { spec: t6.resolvedSpec } }));
          const e7 = Object.entries(t6.resolvedSpec.schemaAndExamples).map((e8) => ({ show: true, expanded: true, selectedExample: null, name: e8[0], elementId: e8[0].replace(ot, "-"), ...e8[1] }));
          return { specLoadError: false, isSpecLoading: false, info: t6.resolvedSpec.info, schemaAndExamples: e7 };
        }
        var h2, f3, m2, y2;
        if (!t6.spec || !(t6.spec.components || t6.spec.info || t6.spec.servers || t6.spec.tags || t6.spec.paths))
          return console.info("RapiDoc: %c There was an issue while parsing the spec %o ", "color:orangered", t6), { specLoadError: true, isSpecLoading: false, info: { title: "Error loading the spec", description: null !== (h2 = t6.response) && void 0 !== h2 && h2.url ? `${null === (f3 = t6.response) || void 0 === f3 ? void 0 : f3.url} \u2503 ${null === (m2 = t6.response) || void 0 === m2 ? void 0 : m2.status}  ${null === (y2 = t6.response) || void 0 === y2 ? void 0 : y2.statusText}` : "Unable to load the Spec", version: " " }, tags: [] };
        p2 = t6.spec, this.dispatchEvent(new CustomEvent("before-render", { detail: { spec: p2 } }));
      } catch (e7) {
        console.info("RapiDoc: %c There was an issue while parsing the spec %o ", "color:orangered", e7);
      }
      const g2 = function(e7, t6, r7 = false, n7 = false) {
        const o6 = ["get", "put", "post", "delete", "patch", "head", "options"], a3 = e7.tags && Array.isArray(e7.tags) ? e7.tags.map((e8) => ({ show: true, elementId: `tag--${e8.name.replace(ot, "-")}`, name: e8.name, description: e8.description || "", headers: e8.description ? H_(e8.description) : [], paths: [], expanded: false !== e8["x-tag-expanded"] })) : [], i5 = e7.paths || {};
        if (e7.webhooks)
          for (const [t7, r8] of Object.entries(e7.webhooks))
            r8._type = "webhook", i5[t7] = r8;
        for (const t7 in i5) {
          const n8 = i5[t7].parameters, s8 = { servers: i5[t7].servers || [], parameters: i5[t7].parameters || [] }, l3 = "webhook" === i5[t7]._type;
          o6.forEach((o7) => {
            if (i5[t7][o7]) {
              const i6 = e7.paths[t7][o7], c4 = i6.tags || [];
              if (0 === c4.length)
                if (r7) {
                  const e8 = t7.replace(/^\/+|\/+$/g, ""), r8 = e8.indexOf("/");
                  -1 === r8 ? c4.push(e8) : c4.push(e8.substr(0, r8));
                } else
                  c4.push("General \u2982");
              c4.forEach((r8) => {
                let c5, p3;
                var d3, u4;
                (e7.tags && (p3 = e7.tags.find((e8) => e8.name.toLowerCase() === r8.toLowerCase())), c5 = a3.find((e8) => e8.name === r8), c5) || (c5 = { show: true, elementId: `tag--${r8.replace(ot, "-")}`, name: r8, description: (null === (d3 = p3) || void 0 === d3 ? void 0 : d3.description) || "", headers: null !== (u4 = p3) && void 0 !== u4 && u4.description ? H_(p3.description) : [], paths: [], expanded: !p3 || false !== p3["x-tag-expanded"] }, a3.push(c5));
                let h3 = (i6.summary || i6.description || `${o7.toUpperCase()} ${t7}`).trim();
                h3.length > 100 && ([h3] = h3.split(/[.|!|?]\s|[\r?\n]/));
                let f4 = [];
                if (f4 = n8 ? i6.parameters ? n8.filter((e8) => {
                  if (!i6.parameters.some((t8) => e8.name === t8.name && e8.in === t8.in))
                    return e8;
                }).concat(i6.parameters) : n8.slice(0) : i6.parameters ? i6.parameters.slice(0) : [], i6.callbacks)
                  for (const [e8, t8] of Object.entries(i6.callbacks)) {
                    const r9 = Object.entries(t8).filter((e9) => "object" == typeof e9[1]) || [];
                    i6.callbacks[e8] = Object.fromEntries(r9);
                  }
                c5.paths.push({ show: true, expanded: false, isWebhook: l3, expandedAtLeastOnce: false, summary: i6.summary || "", description: i6.description || "", externalDocs: i6.externalDocs, shortSummary: h3, method: o7, path: t7, operationId: i6.operationId, elementId: `${o7}-${t7.replace(ot, "-")}`, servers: i6.servers ? s8.servers.concat(i6.servers) : s8.servers, parameters: f4, requestBody: i6.requestBody, responses: i6.responses, callbacks: i6.callbacks, deprecated: i6.deprecated, security: i6.security, xBadges: i6["x-badges"] || void 0, xCodeSamples: i6["x-codeSamples"] || i6["x-code-samples"] || "" });
              });
            }
          });
        }
        const s7 = a3.filter((e8) => e8.paths && e8.paths.length > 0);
        return s7.forEach((e8) => {
          "method" === t6 ? e8.paths.sort((e9, t7) => o6.indexOf(e9.method).toString().localeCompare(o6.indexOf(t7.method))) : "summary" === t6 ? e8.paths.sort((e9, t7) => e9.shortSummary.localeCompare(t7.shortSummary)) : "path" === t6 && e8.paths.sort((e9, t7) => e9.path.localeCompare(t7.path)), e8.firstPathId = e8.paths[0].elementId;
        }), n7 ? s7.sort((e8, t7) => e8.name.localeCompare(t7.name)) : s7;
      }(p2, n6, t5, r6), v2 = function(e7) {
        if (!e7.components)
          return [];
        const t6 = [];
        for (const r7 in e7.components) {
          const n7 = [];
          for (const t7 in e7.components[r7]) {
            const o7 = { show: true, id: `${r7.toLowerCase()}-${t7.toLowerCase()}`.replace(ot, "-"), name: t7, component: e7.components[r7][t7] };
            n7.push(o7);
          }
          let o6 = r7, a3 = r7;
          switch (r7) {
            case "schemas":
              a3 = "Schemas", o6 = "Schemas allows the definition of input and output data types. These types can be objects, but also primitives and arrays.";
              break;
            case "responses":
              a3 = "Responses", o6 = "Describes responses from an API Operation, including design-time, static links to operations based on the response.";
              break;
            case "parameters":
              a3 = "Parameters", o6 = "Describes operation parameters. A unique parameter is defined by a combination of a name and location.";
              break;
            case "examples":
              a3 = "Examples", o6 = "List of Examples for operations, can be requests, responses and objects examples.";
              break;
            case "requestBodies":
              a3 = "Request Bodies", o6 = "Describes common request bodies that are used across the API operations.";
              break;
            case "headers":
              a3 = "Headers", o6 = 'Headers follows the structure of the Parameters but they are explicitly in "header"';
              break;
            case "securitySchemes":
              a3 = "Security Schemes", o6 = "Defines a security scheme that can be used by the operations. Supported schemes are HTTP authentication, an API key (either as a header, a cookie parameter or as a query parameter), OAuth2's common flows(implicit, password, client credentials and authorization code) as defined in RFC6749, and OpenID Connect Discovery.";
              break;
            case "links":
              a3 = "Links", o6 = "Links represent a possible design-time link for a response. The presence of a link does not guarantee the caller's ability to successfully invoke it, rather it provides a known relationship and traversal mechanism between responses and other operations.";
              break;
            case "callbacks":
              a3 = "Callbacks", o6 = "A map of possible out-of band callbacks related to the parent operation. Each value in the map is a Path Item Object that describes a set of requests that may be initiated by the API provider and the expected responses. The key value used to identify the path item object is an expression, evaluated at runtime, that identifies a URL to use for the callback operation.";
              break;
            default:
              a3 = r7, o6 = r7;
          }
          const i5 = { show: true, name: a3, description: o6, subComponents: n7 };
          t6.push(i5);
        }
        return t6 || [];
      }(p2), b2 = null !== (l2 = p2.info) && void 0 !== l2 && l2.description ? H_(p2.info.description) : [], x3 = [];
      if (null !== (c3 = p2.components) && void 0 !== c3 && c3.securitySchemes) {
        const e7 = /* @__PURE__ */ new Set();
        Object.entries(p2.components.securitySchemes).forEach((t6) => {
          if (!e7.has(t6[0])) {
            e7.add(t6[0]);
            const r7 = { securitySchemeId: t6[0], ...t6[1] };
            r7.value = "", r7.finalKeyValue = "", "apiKey" === t6[1].type || "http" === t6[1].type ? (r7.in = t6[1].in || "header", r7.name = t6[1].name || "Authorization", r7.user = "", r7.password = "") : "oauth2" === t6[1].type && (r7.in = "header", r7.name = "Authorization", r7.clientId = "", r7.clientSecret = ""), x3.push(r7);
          }
        });
      }
      o5 && a2 && i4 && x3.push({ securitySchemeId: at, description: "api-key provided in rapidoc element attributes", type: "apiKey", oAuthFlow: "", name: o5, in: a2, value: i4, finalKeyValue: i4 }), x3.forEach((e7) => {
        "http" === e7.type ? e7.typeDisplay = "basic" === e7.scheme ? "HTTP Basic" : "HTTP Bearer" : "apiKey" === e7.type ? e7.typeDisplay = `API Key (${e7.name})` : "oauth2" === e7.type ? e7.typeDisplay = `OAuth (${e7.securitySchemeId})` : e7.typeDisplay = e7.type || "None";
      });
      let w2 = [];
      p2.servers && Array.isArray(p2.servers) ? (p2.servers.forEach((e7) => {
        let t6 = e7.url.trim();
        t6.startsWith("http") || t6.startsWith("//") || t6.startsWith("{") || window.location.origin.startsWith("http") && (e7.url = window.location.origin + e7.url, t6 = e7.url), e7.variables && Object.entries(e7.variables).forEach((e8) => {
          const r7 = new RegExp(`{${e8[0]}}`, "g");
          t6 = t6.replace(r7, e8[1].default || ""), e8[1].value = e8[1].default || "";
        }), e7.computedUrl = t6;
      }), s6 && p2.servers.push({ url: s6, computedUrl: s6 })) : s6 ? p2.servers = [{ url: s6, computedUrl: s6 }] : window.location.origin.startsWith("http") ? p2.servers = [{ url: window.location.origin, computedUrl: window.location.origin }] : p2.servers = [{ url: "http://localhost", computedUrl: "http://localhost" }], w2 = p2.servers;
      return { specLoadError: false, isSpecLoading: false, info: p2.info, infoDescriptionHeaders: b2, tags: g2, components: v2, externalDocs: p2.externalDocs, securitySchemes: x3, servers: w2 };
    }
    function H_(e6) {
      const t5 = We.lexer(e6).filter((e7) => "heading" === e7.type && e7.depth <= 2);
      return t5 || [];
    }
    const W_ = 1, V_ = 2, G_ = 3, K_ = 4, J_ = (e6) => (...t5) => ({ _$litDirective$: e6, values: t5 });
    class Y_ {
      constructor(e6) {
      }
      get _$AU() {
        return this._$AM._$AU;
      }
      _$AT(e6, t5, r6) {
        this._$Ct = e6, this._$AM = t5, this._$Ci = r6;
      }
      _$AS(e6, t5) {
        return this.update(e6, t5);
      }
      update(e6, t5) {
        return this.render(...t5);
      }
    }
    class Z_ extends Y_ {
      constructor(e6) {
        if (super(e6), this.it = z, e6.type !== V_)
          throw Error(this.constructor.directiveName + "() can only be used in child bindings");
      }
      render(e6) {
        if (e6 === z || null == e6)
          return this._t = void 0, this.it = e6;
        if (e6 === U)
          return e6;
        if ("string" != typeof e6)
          throw Error(this.constructor.directiveName + "() called with a non-string value");
        if (e6 === this.it)
          return this._t;
        this.it = e6;
        const t5 = [e6];
        return t5.raw = t5, this._t = { _$litType$: this.constructor.resultType, strings: t5, values: [] };
      }
    }
    Z_.directiveName = "unsafeHTML", Z_.resultType = 1;
    const Q_ = J_(Z_);
    var X_ = r5(764).lW;
    const eP = "rapidoc";
    function tP(e6, t5 = "", r6 = "", n6 = "") {
      var o5, a2;
      const i4 = null === (o5 = this.resolvedSpec.securitySchemes) || void 0 === o5 ? void 0 : o5.find((t6) => t6.securitySchemeId === e6);
      if (!i4)
        return false;
      let s6 = "";
      if ("basic" === (null === (a2 = i4.scheme) || void 0 === a2 ? void 0 : a2.toLowerCase()))
        t5 && (s6 = `Basic ${X_.from(`${t5}:${r6}`, "utf8").toString("base64")}`);
      else if (n6) {
        var l2;
        i4.value = n6, s6 = `${"bearer" === (null === (l2 = i4.scheme) || void 0 === l2 ? void 0 : l2.toLowerCase()) ? "Bearer " : ""}${n6}`;
      }
      return !!s6 && (i4.finalKeyValue = s6, this.requestUpdate(), true);
    }
    function rP() {
      var e6;
      null === (e6 = this.resolvedSpec.securitySchemes) || void 0 === e6 || e6.forEach((e7) => {
        e7.user = "", e7.password = "", e7.value = "", e7.finalKeyValue = "";
      }), this.requestUpdate();
    }
    function nP() {
      return JSON.parse(localStorage.getItem(eP)) || {};
    }
    function oP(e6) {
      localStorage.setItem(eP, JSON.stringify(e6));
    }
    function aP() {
      const e6 = nP.call(this);
      Object.values(e6).forEach((e7) => {
        tP.call(this, e7.securitySchemeId, e7.username, e7.password, e7.value);
      });
    }
    function iP(e6) {
      let t5 = "";
      const r6 = this.resolvedSpec.securitySchemes.find((t6) => t6.securitySchemeId === e6);
      if (r6) {
        const n6 = this.shadowRoot.getElementById(`security-scheme-${e6}`);
        if (n6) {
          if (r6.type && r6.scheme && "http" === r6.type && "basic" === r6.scheme.toLowerCase()) {
            const t6 = n6.querySelector(".api-key-user").value.trim(), r7 = n6.querySelector(".api-key-password").value.trim();
            tP.call(this, e6, t6, r7);
          } else
            t5 = n6.querySelector(".api-key-input").value.trim(), tP.call(this, e6, "", "", t5);
          if ("true" === this.persistAuth) {
            const t6 = nP.call(this);
            t6[e6] = r6, oP.call(this, t6);
          }
        }
      }
    }
    function sP(e6, t5, r6 = "Bearer") {
      const n6 = this.resolvedSpec.securitySchemes.find((t6) => t6.securitySchemeId === e6);
      n6.finalKeyValue = `${"bearer" === r6.toLowerCase() ? "Bearer" : "mac" === r6.toLowerCase() ? "MAC" : r6} ${t5}`, this.requestUpdate();
    }
    async function lP(e6, t5, r6, n6, o5, a2, i4, s6, l2 = "header", c3 = null, p2 = null, d2 = null) {
      const u3 = s6 ? s6.querySelector(".oauth-resp-display") : void 0, h2 = new URLSearchParams(), f3 = new Headers();
      h2.append("grant_type", o5), "authorization_code" === o5 && (h2.append("client_id", t5), h2.append("client_secret", r6)), "client_credentials" !== o5 && "password" !== o5 && h2.append("redirect_uri", n6), a2 && (h2.append("code", a2), h2.append("code_verifier", "731DB1C3F7EA533B85E29492D26AA-1234567890-1234567890")), "header" === l2 ? f3.set("Authorization", `Basic ${X_.from(`${t5}:${r6}`, "utf8").toString("base64")}`) : (h2.append("client_id", t5), h2.append("client_secret", r6)), "password" === o5 && (h2.append("username", p2), h2.append("password", d2)), c3 && h2.append("scope", c3);
      try {
        const t6 = await fetch(e6, { method: "POST", headers: f3, body: h2 }), r7 = await t6.json();
        if (!t6.ok)
          return u3 && (u3.innerHTML = `<span style="color:var(--red)">${r7.error_description || r7.error_description || "Unable to get access token"}</span>`), false;
        if (r7.token_type && r7.access_token)
          return sP.call(this, i4, r7.access_token, r7.token_type), u3 && (u3.innerHTML = '<span style="color:var(--green)">Access Token Received</span>'), true;
      } catch (e7) {
        return u3 && (u3.innerHTML = '<span style="color:var(--red)">Failed to get access token</span>'), false;
      }
    }
    async function cP(e6, t5, r6, n6, o5, a2, i4, s6, l2, c3) {
      sessionStorage.removeItem("winMessageEventActive"), t5.close(), e6.data.fake || (e6.data || console.warn("RapiDoc: Received no data with authorization message"), e6.data.error && console.warn("RapiDoc: Error while receiving data"), e6.data && ("code" === e6.data.responseType ? lP.call(this, r6, n6, o5, a2, i4, e6.data.code, l2, c3, s6) : "token" === e6.data.responseType && sP.call(this, l2, e6.data.access_token, e6.data.token_type)));
    }
    async function pP(e6, t5, r6, n6, o5) {
      const a2 = o5.target.closest(".oauth-flow"), i4 = a2.querySelector(".oauth-client-id") ? a2.querySelector(".oauth-client-id").value.trim() : "", s6 = a2.querySelector(".oauth-client-secret") ? a2.querySelector(".oauth-client-secret").value.trim() : "", l2 = a2.querySelector(".api-key-user") ? a2.querySelector(".api-key-user").value.trim() : "", c3 = a2.querySelector(".api-key-password") ? a2.querySelector(".api-key-password").value.trim() : "", p2 = a2.querySelector(".oauth-send-client-secret-in") ? a2.querySelector(".oauth-send-client-secret-in").value.trim() : "header", d2 = [...a2.querySelectorAll(".scope-checkbox:checked")], u3 = a2.querySelector(`#${e6}-pkce`), h2 = `${Math.random().toString(36).slice(2, 9)}random${Math.random().toString(36).slice(2, 9)}`, f3 = `${Math.random().toString(36).slice(2, 9)}random${Math.random().toString(36).slice(2, 9)}`, m2 = new URL(`${window.location.origin}${window.location.pathname.substring(0, window.location.pathname.lastIndexOf("/"))}/${this.oauthReceiver}`);
      let y2, g2 = "", v2 = "";
      if ([...a2.parentNode.querySelectorAll(".oauth-resp-display")].forEach((e7) => {
        e7.innerHTML = "";
      }), "authorizationCode" === t5 || "implicit" === t5) {
        const o6 = new URL(r6);
        "authorizationCode" === t5 ? (g2 = "authorization_code", v2 = "code") : "implicit" === t5 && (v2 = "token");
        const l3 = new URLSearchParams(o6.search), c4 = d2.map((e7) => e7.value).join(" ");
        c4 && l3.set("scope", c4), l3.set("client_id", i4), l3.set("redirect_uri", m2.toString()), l3.set("response_type", v2), l3.set("state", h2), l3.set("nonce", f3), u3 && u3.checked && (l3.set("code_challenge", "4FatVDBJKPAo4JgLLaaQFMUcQPn5CrPRvLlaob9PTYc"), l3.set("code_challenge_method", "S256")), l3.set("show_dialog", true), o6.search = l3.toString(), "true" === sessionStorage.getItem("winMessageEventActive") && window.postMessage({ fake: true }, this), setTimeout(() => {
          y2 = window.open(o6.toString()), y2 ? (sessionStorage.setItem("winMessageEventActive", "true"), window.addEventListener("message", (t6) => cP.call(this, t6, y2, n6, i4, s6, m2.toString(), g2, p2, e6, a2), { once: true })) : console.error(`RapiDoc: Unable to open ${o6.toString()} in a new window`);
        }, 10);
      } else if ("clientCredentials" === t5) {
        g2 = "client_credentials";
        const t6 = d2.map((e7) => e7.value).join(" ");
        lP.call(this, n6, i4, s6, m2.toString(), g2, "", e6, a2, p2, t6);
      } else if ("password" === t5) {
        g2 = "password";
        const t6 = d2.map((e7) => e7.value).join(" ");
        lP.call(this, n6, i4, s6, m2.toString(), g2, "", e6, a2, p2, t6, l2, c3);
      }
    }
    function dP(e6, t5, r6, n6, o5, a2 = [], i4 = "header") {
      let { authorizationUrl: s6, tokenUrl: l2, refreshUrl: c3 } = o5;
      const p2 = o5["x-pkce-only"] || false, d2 = (e7) => e7.indexOf("://") > 0 || 0 === e7.indexOf("//"), u3 = new URL(this.selectedServer.computedUrl).origin;
      let h2;
      return c3 && !d2(c3) && (c3 = `${u3}/${c3.replace(/^\//, "")}`), l2 && !d2(l2) && (l2 = `${u3}/${l2.replace(/^\//, "")}`), s6 && !d2(s6) && (s6 = `${u3}/${s6.replace(/^\//, "")}`), h2 = "authorizationCode" === e6 ? "Authorization Code Flow" : "clientCredentials" === e6 ? "Client Credentials Flow" : "implicit" === e6 ? "Implicit Flow" : "password" === e6 ? "Password Flow" : e6, q`
    <div class="oauth-flow ${e6}" style="padding: 12px 0; margin-bottom:12px;">
      <div class="tiny-title upper" style="margin-bottom:8px;">${h2}</div>
      ${s6 ? q`<div style="margin-bottom:5px"><span style="width:75px; display: inline-block;">Auth URL</span> <span class="mono-font"> ${s6} </span></div>` : ""}
      ${l2 ? q`<div style="margin-bottom:5px"><span style="width:75px; display: inline-block;">Token URL</span> <span class="mono-font">${l2}</span></div>` : ""}
      ${c3 ? q`<div style="margin-bottom:5px"><span style="width:75px; display: inline-block;">Refresh URL</span> <span class="mono-font">${c3}</span></div>` : ""}
      ${"authorizationCode" === e6 || "clientCredentials" === e6 || "implicit" === e6 || "password" === e6 ? q`
          ${o5.scopes ? q`
              <span> Scopes </span>
              <div class= "oauth-scopes" part="section-auth-scopes" style = "width:100%; display:flex; flex-direction:column; flex-wrap:wrap; margin:0 0 10px 24px">
                ${Object.entries(o5.scopes).map((t6, r7) => q`
                  <div class="m-checkbox" style="display:inline-flex; align-items:center">
                    <input type="checkbox" part="checkbox checkbox-auth-scope" class="scope-checkbox" id="${n6}${e6}${r7}" ?checked="${a2.includes(t6[0])}" value="${t6[0]}">
                    <label for="${n6}${e6}${r7}" style="margin-left:5px; cursor:pointer">
                      <span class="mono-font">${t6[0]}</span>
                        ${t6[0] !== t6[1] ? ` - ${t6[1] || ""}` : ""}
                    </label>
                  </div>
                `)}
              </div>
            ` : ""}
          ${"password" === e6 ? q`
              <div style="margin:5px 0">
                <input type="text" value = "" placeholder="username" spellcheck="false" class="oauth2 ${e6} ${n6} api-key-user" part="textbox textbox-username">
                <input type="password" value = "" placeholder="password" spellcheck="false" class="oauth2 ${e6} ${n6} api-key-password" style = "margin:0 5px;" part="textbox textbox-password">
              </div>` : ""}
          <div>
            ${"authorizationCode" === e6 ? q`
                <div style="margin: 16px 0 4px">
                  <input type="checkbox" part="checkbox checkbox-auth-scope" id="${n6}-pkce" checked ?disabled=${p2}>
                  <label for="${n6}-pkce" style="margin:0 16px 0 4px; line-height:24px; cursor:pointer">
                   Send Proof Key for Code Exchange (PKCE)
                  </label>
                </div>
              ` : ""}
            <input type="text" part="textbox textbox-auth-client-id" value = "${t5 || ""}" placeholder="client-id" spellcheck="false" class="oauth2 ${e6} ${n6} oauth-client-id">
            ${"authorizationCode" === e6 || "clientCredentials" === e6 || "password" === e6 ? q`
                <input
                  type="password" part="textbox textbox-auth-client-secret"
                  value = "${r6 || ""}" placeholder="client-secret" spellcheck="false"
                  class="oauth2 ${e6} ${n6}
                  oauth-client-secret"
                  style = "margin:0 5px;${p2 ? "display:none;" : ""}"
                >
                <select style="margin-right:5px;${p2 ? "display:none;" : ""}" class="${e6} ${n6} oauth-send-client-secret-in">
                  <option value = 'header' .selected = ${"header" === i4} > Authorization Header </option>
                  <option value = 'request-body' .selected = ${"request-body" === i4}> Request Body </option>
                </select>` : ""}
            ${"authorizationCode" === e6 || "clientCredentials" === e6 || "implicit" === e6 || "password" === e6 ? q`
                <button class="m-btn thin-border" part="btn btn-outline"
                  @click="${(t6) => {
        pP.call(this, n6, e6, s6, l2, t6);
      }}"
                > GET TOKEN </button>` : ""}
          </div>
          <div class="oauth-resp-display red-text small-font-size"></div>
          ` : ""}
    </div>
  `;
    }
    function uP(e6) {
      var t5;
      const r6 = null === (t5 = this.resolvedSpec.securitySchemes) || void 0 === t5 ? void 0 : t5.find((t6) => t6.securitySchemeId === e6);
      if (r6.user = "", r6.password = "", r6.value = "", r6.finalKeyValue = "", "true" === this.persistAuth) {
        const e7 = nP.call(this);
        delete e7[r6.securitySchemeId], oP.call(this, e7);
      }
      this.requestUpdate();
    }
    function hP() {
      var e6;
      if (!this.resolvedSpec)
        return "";
      const t5 = null === (e6 = this.resolvedSpec.securitySchemes) || void 0 === e6 ? void 0 : e6.filter((e7) => e7.finalKeyValue);
      return t5 ? q`
  <section id='auth' part="section-auth" style="text-align:left; direction:ltr; margin-top:24px; margin-bottom:24px;" class = 'observe-me ${"read focused".includes(this.renderStyle) ? "section-gap--read-mode" : "section-gap "}'>
    <div class='sub-title regular-font'> AUTHENTICATION </div>

    <div class="small-font-size" style="display:flex; align-items: center; min-height:30px">
      ${t5.length > 0 ? q`
          <div class="blue-text"> ${t5.length} API key applied </div>
          <div style="flex:1"></div>
          <button class="m-btn thin-border" part="btn btn-outline" @click=${() => {
        rP.call(this);
      }}>CLEAR ALL API KEYS</button>` : q`<div class="red-text">No API key applied</div>`}
    </div>
    ${this.resolvedSpec.securitySchemes && this.resolvedSpec.securitySchemes.length > 0 ? q`
        <table role="presentation" id="auth-table" class='m-table padded-12' style="width:100%;">
          ${this.resolvedSpec.securitySchemes.map((e7) => q`
            <tr id="security-scheme-${e7.securitySchemeId}" class="${e7.type.toLowerCase()}">
              <td style="max-width:500px; overflow-wrap: break-word;">
                <div style="line-height:28px; margin-bottom:5px;">
                  <span style="font-weight:bold; font-size:var(--font-size-regular)">${e7.typeDisplay}</span>
                  ${e7.finalKeyValue ? q`
                      <span class='blue-text'>  ${e7.finalKeyValue ? "Key Applied" : ""} </span>
                      <button class="m-btn thin-border small" part="btn btn-outline" @click=${() => {
        uP.call(this, e7.securitySchemeId);
      }}>REMOVE</button>
                      ` : ""}
                </div>
                ${e7.description ? q`
                    <div class="m-markdown">
                      ${Q_(We(e7.description || ""))}
                    </div>` : ""}

                ${"apikey" === e7.type.toLowerCase() || "http" === e7.type.toLowerCase() && "bearer" === e7.scheme.toLowerCase() ? q`
                    <div style="margin-bottom:5px">
                      ${"apikey" === e7.type.toLowerCase() ? q`Send <code>${e7.name}</code> in <code>${e7.in}</code>` : q`Send <code>Authorization</code> in <code>header</code> containing the word <code>Bearer</code> followed by a space and a Token String.`}
                    </div>
                    <div style="max-height:28px;">
                      ${"cookie" !== e7.in ? q`
                          <input type = "text" value = "${e7.value}" class="${e7.type} ${e7.securitySchemeId} api-key-input" placeholder = "api-token" spellcheck = "false">
                          <button class="m-btn thin-border" style = "margin-left:5px;"
                            part = "btn btn-outline"
                            @click="${(t6) => {
        iP.call(this, e7.securitySchemeId, t6);
      }}">
                            ${e7.finalKeyValue ? "UPDATE" : "SET"}
                          </button>` : q`<span class="gray-text" style="font-size::var(--font-size-small)"> cookies cannot be set from here</span>`}
                    </div>` : ""}
                ${"http" === e7.type.toLowerCase() && "basic" === e7.scheme.toLowerCase() ? q`
                    <div style="margin-bottom:5px">
                      Send <code>Authorization</code> in <code>header</code> containing the word <code>Basic</code> followed by a space and a base64 encoded string of <code>username:password</code>.
                    </div>
                    <div>
                      <input type="text" value = "${e7.user}" placeholder="username" spellcheck="false" class="${e7.type} ${e7.securitySchemeId} api-key-user" style="width:100px">
                      <input type="password" value = "${e7.password}" placeholder="password" spellcheck="false" class="${e7.type} ${e7.securitySchemeId} api-key-password" style = "width:100px; margin:0 5px;">
                      <button class="m-btn thin-border"
                        @click="${(t6) => {
        iP.call(this, e7.securitySchemeId, t6);
      }}"
                        part = "btn btn-outline"
                      >
                        ${e7.finalKeyValue ? "UPDATE" : "SET"}
                      </button>
                    </div>` : ""}
              </td>
            </tr>
            ${"oauth2" === e7.type.toLowerCase() ? q`
                <tr>
                  <td style="border:none; padding-left:48px">
                    ${Object.keys(e7.flows).map((t6) => dP.call(this, t6, e7.flows[t6]["x-client-id"] || e7["x-client-id"] || "", e7.flows[t6]["x-client-secret"] || e7["x-client-secret"] || "", e7.securitySchemeId, e7.flows[t6], e7.flows[t6]["x-default-scopes"] || e7["x-default-scopes"], e7.flows[t6]["x-receive-token-in"] || e7["x-receive-token-in"]))}
                  </td>
                </tr>
                ` : ""}
          `)}
        </table>` : ""}
    <slot name="auth"></slot>
  </section>
` : void 0;
    }
    function fP(e6) {
      if (this.resolvedSpec.securitySchemes && e6) {
        const t5 = [];
        return Array.isArray(e6) ? 0 === e6.length ? "" : (e6.forEach((e7) => {
          const r6 = [], n6 = [];
          0 === Object.keys(e7).length ? t5.push({ securityTypes: "None", securityDefs: [] }) : (Object.keys(e7).forEach((t6) => {
            let o5 = "";
            const a2 = this.resolvedSpec.securitySchemes.find((e8) => e8.securitySchemeId === t6);
            e7[t6] && Array.isArray(e7[t6]) && (o5 = e7[t6].join(", ")), a2 && (n6.push(a2.typeDisplay), r6.push({ ...a2, scopes: o5 }));
          }), t5.push({ securityTypes: n6.length > 1 ? `${n6[0]} + ${n6.length - 1} more` : n6[0], securityDefs: r6 }));
        }), q`<div style="position:absolute; top:3px; right:2px; font-size:var(--font-size-small); line-height: 1.5;">
      <div style="position:relative; display:flex; min-width:350px; max-width:700px; justify-content: flex-end;">
        <svg width="24" height="24" viewBox="0 0 24 24" stroke-width="1.5" fill="none" style="stroke:var(--fg3)"> <rect x="5" y="11" width="14" height="10" rx="2" /> <circle cx="12" cy="16" r="1" /> <path d="M8 11v-4a4 4 0 0 1 8 0v4" /></svg>
          ${t5.map((e7, t6) => q`
          ${e7.securityTypes ? q`
              ${0 !== t6 ? q`<div style="padding:3px 4px;"> OR </div>` : ""}
              <div class="tooltip">
                <div style = "padding:2px 4px; white-space:nowrap; text-overflow:ellipsis;max-width:150px; overflow:hidden;">
                  ${"true" === this.updateRoute && "true" === this.allowAuthentication ? q`<a part="anchor anchor-operation-security" href="#auth"> ${e7.securityTypes} </a>` : q`${e7.securityTypes}`}
                </div>
                <div class="tooltip-text" style="position:absolute; color: var(--fg); top:26px; right:0; border:1px solid var(--border-color);padding:2px 4px; display:block;">
                  ${e7.securityDefs.length > 1 ? q`<div>Requires <b>all</b> of the following </div>` : ""}
                  <div style="padding-left: 8px">
                    ${e7.securityDefs.map((t7, r6) => {
          const n6 = q`${"" !== t7.scopes ? q`
                          <div>
                            <b>Required scopes:</b>
                            <br/>
                            <div style="margin-left:8px">
                              ${t7.scopes.split(",").map((e8, t8) => q`${0 === t8 ? "" : "\u2503"}<span>${e8}</span>`)}
                            </div>
                          </div>` : ""}`;
          return q`
                      ${"oauth2" === t7.type ? q`
                          <div>
                            ${e7.securityDefs.length > 1 ? q`<b>${r6 + 1}.</b> &nbsp;` : "Needs"}
                            OAuth Token <span style="font-family:var(--font-mono); color:var(--primary-color);">${t7.securitySchemeId}</span> in <b>Authorization header</b>
                            ${n6}
                          </div>` : "http" === t7.type ? q`
                            <div>
                              ${e7.securityDefs.length > 1 ? q`<b>${r6 + 1}.</b> &nbsp;` : q`Requires`}
                              ${"basic" === t7.scheme ? "Base 64 encoded username:password" : "Bearer Token"} in <b>Authorization header</b>
                              ${n6}
                            </div>` : q`
                            <div>
                              ${e7.securityDefs.length > 1 ? q`<b>${r6 + 1}.</b> &nbsp;` : q`Requires`}
                              Token in <b>${t7.name} ${t7.in}</b>
                              ${n6}
                            </div>`}`;
        })}
                  </div>
                </div>
              </div>
            ` : ""}
        `)}
      </div>
    `) : "";
      }
      return "";
    }
    function mP(e6) {
      return q`
  <section class="table-title" style="margin-top:24px;">CODE SAMPLES</div>
  <div class="tab-panel col"
    @click="${(e7) => {
        if (!e7.target.classList.contains("tab-btn"))
          return;
        const t5 = e7.target.dataset.tab, r6 = [...e7.currentTarget.querySelectorAll(".tab-btn")], n6 = [...e7.currentTarget.querySelectorAll(".tab-content")];
        r6.forEach((e8) => e8.classList[e8.dataset.tab === t5 ? "add" : "remove"]("active")), n6.forEach((e8) => {
          e8.style.display = e8.dataset.tab === t5 ? "block" : "none";
        });
      }}">
    <div class="tab-buttons row" style="width:100; overflow">
      ${e6.map((e7, t5) => q`<button class="tab-btn ${0 === t5 ? "active" : ""}" data-tab = '${e7.lang}${t5}'> ${e7.label || e7.lang} </button>`)}
    </div>
    ${e6.map((e7, t5) => {
        var r6, n6, o5;
        return q`
      <div class="tab-content m-markdown" style= "display:${0 === t5 ? "block" : "none"}" data-tab = '${e7.lang}${t5}'>
        <button class="toolbar-btn" style = "position:absolute; top:12px; right:8px" @click='${(t6) => {
          st(e7.source, t6);
        }}'> Copy </button>
        <pre><code class="language">${Ge().languages[null === (r6 = e7.lang) || void 0 === r6 ? void 0 : r6.toLowerCase()] ? Q_(Ge().highlight(e7.source, Ge().languages[null === (n6 = e7.lang) || void 0 === n6 ? void 0 : n6.toLowerCase()], null === (o5 = e7.lang) || void 0 === o5 ? void 0 : o5.toLowerCase())) : e7.source}</code></pre>
      </div>`;
      })}
  </div>  
  </section>`;
    }
    function yP(e6) {
      return q`
    <div class="req-res-title" style="margin-top:12px">CALLBACKS</div>
    ${Object.entries(e6).map((e7) => q`
      <div class="tiny-title" style="padding: 12px; border:1px solid var(--light-border-color)"> 
        ${e7[0]}
        ${Object.entries(e7[1]).map((e8) => q`
          <div class="mono-font small-font-size" style="display:flex; margin-left:16px;">
            <div style="width:100%"> 
              ${Object.entries(e8[1]).map((t5) => {
        var r6, n6, o5;
        return q`
                <div>
                  <div style="margin-top:12px;">
                    <div class="method method-fg ${t5[0]}" style="width:70px; border:none; margin:0; padding:0; line-height:20px; vertical-align: baseline;text-align:left"> 
                      <span style="font-size:20px;"> &#x2944; </span> 
                      ${t5[0]} 
                    </div>
                    <span style="line-height:20px; vertical-align: baseline;">${e8[0]} </span>
                  </div>  
                  <div class='expanded-req-resp-container'>
                    <api-request
                      class = "${this.renderStyle}-mode callback"  
                      style = "width:100%;"
                      callback = "true"
                      method = "${t5[0] || ""}", 
                      path = "${e8[0] || ""}" 
                      .parameters = "${(null === (r6 = t5[1]) || void 0 === r6 ? void 0 : r6.parameters) || ""}" 
                      .request_body = "${(null === (n6 = t5[1]) || void 0 === n6 ? void 0 : n6.requestBody) || ""}"
                      fill-request-fields-with-example = "${this.fillRequestFieldsWithExample}"
                      allow-try = "false"
                      render-style="${this.renderStyle}" 
                      schema-style = "${this.schemaStyle}"
                      active-schema-tab = "${this.defaultSchemaTab}"
                      schema-expand-level = "${this.schemaExpandLevel}"
                      schema-description-expanded = "${this.schemaDescriptionExpanded}"
                      allow-schema-description-expand-toggle = "${this.allowSchemaDescriptionExpandToggle}"
                      schema-hide-read-only = "false"
                      schema-hide-write-only = "${"never" === this.schemaHideWriteOnly ? "false" : "true"}"
                      fetch-credentials = "${this.fetchCredentials}"
                      exportparts = "wrap-request-btn:wrap-request-btn, btn:btn, btn-fill:btn-fill, btn-outline:btn-outline, btn-try:btn-try, btn-clear:btn-clear, btn-clear-resp:btn-clear-resp,
                        file-input:file-input, textbox:textbox, textbox-param:textbox-param, textarea:textarea, textarea-param:textarea-param, 
                        anchor:anchor, anchor-param-example:anchor-param-example, schema-description:schema-description, schema-multiline-toggle:schema-multiline-toggle"
                      > </api-request>

                    <api-response
                      style = "width:100%;"
                      class = "${this.renderStyle}-mode"
                      callback = "true"
                      .responses="${null === (o5 = t5[1]) || void 0 === o5 ? void 0 : o5.responses}"
                      render-style="${this.renderStyle}"
                      schema-style="${this.schemaStyle}"
                      active-schema-tab = "${this.defaultSchemaTab}"
                      schema-expand-level = "${this.schemaExpandLevel}"
                      schema-description-expanded = "${this.schemaDescriptionExpanded}"
                      allow-schema-description-expand-toggle = "${this.allowSchemaDescriptionExpandToggle}"
                      schema-hide-read-only = "${"never" === this.schemaHideReadOnly ? "false" : "true"}"
                      schema-hide-write-only = "false"
                      exportparts = "btn:btn, btn-response-status:btn-response-status, btn-selected-response-status:btn-selected-response-status, btn-fill:btn-fill, btn-copy:btn-copy,
                      schema-description:schema-description, schema-multiline-toggle:schema-multiline-toggle"
                    > </api-response>
                  </div>
                </div>  
              `;
      })}
            </div>  
          </div>  
        `)}
      </div>  
    `)}
  `;
    }
    const gP = {}, vP = J_(class extends Y_ {
      constructor() {
        super(...arguments), this.ot = gP;
      }
      render(e6, t5) {
        return t5();
      }
      update(e6, [t5, r6]) {
        if (Array.isArray(t5)) {
          if (Array.isArray(this.ot) && this.ot.length === t5.length && t5.every((e7, t6) => e7 === this.ot[t6]))
            return U;
        } else if (this.ot === t5)
          return U;
        return this.ot = Array.isArray(t5) ? Array.from(t5) : t5, this.render(t5, r6);
      }
    }), { I: bP } = re, xP = {}, wP = J_(class extends Y_ {
      constructor(e6) {
        if (super(e6), e6.type !== G_ && e6.type !== W_ && e6.type !== K_)
          throw Error("The `live` directive is not allowed on child or event bindings");
        if (!((e7) => void 0 === e7.strings)(e6))
          throw Error("`live` bindings can only contain a single expression");
      }
      render(e6) {
        return e6;
      }
      update(e6, [t5]) {
        if (t5 === U || t5 === z)
          return t5;
        const r6 = e6.element, n6 = e6.name;
        if (e6.type === G_) {
          if (t5 === r6[n6])
            return U;
        } else if (e6.type === K_) {
          if (!!t5 === r6.hasAttribute(n6))
            return U;
        } else if (e6.type === W_ && r6.getAttribute(n6) === t5 + "")
          return U;
        return ((e7, t6 = xP) => {
          e7._$AH = t6;
        })(e6), t5;
      }
    });
    var $P = r5(131), kP = r5.n($P);
    const SP = c2`
.border-top {
  border-top:1px solid var(--border-color);
}
.border{
  border:1px solid var(--border-color);
  border-radius: var(--border-radius);
}
.light-border{
  border:1px solid var(--light-border-color);
  border-radius: var(--border-radius);
}
.pad-8-16{
  padding: 8px 16px;
}
.pad-top-8{
  padding-top: 8px;
}
.mar-top-8{
  margin-top: 8px;
}
`;
    function AP(e6) {
      return void 0 === e6 ? "" : null === e6 ? "null" : "" === e6 ? "\u2205" : "boolean" == typeof e6 || "number" == typeof e6 ? `${e6}` : Array.isArray(e6) ? e6.map((e7) => null === e7 ? "null" : "" === e7 ? "\u2205" : e7.toString().replace(/^ +| +$/g, (e8) => "\u25CF".repeat(e8.length)) || "").join(", ") : e6.toString().replace(/^ +| +$/g, (e7) => "\u25CF".repeat(e7.length)) || "";
    }
    function EP(e6) {
      if (!e6)
        return;
      let t5 = "", r6 = "";
      if (e6.$ref) {
        const r7 = e6.$ref.lastIndexOf("/");
        t5 = `{recursive: ${e6.$ref.substring(r7 + 1)}} `;
      } else
        e6.type ? (t5 = Array.isArray(e6.type) ? e6.type.join(2 === e6.length ? " or " : "\u2503") : e6.type, (e6.format || e6.enum || e6.const) && (t5 = t5.replace("string", e6.enum ? "enum" : e6.const ? "const" : e6.format)), e6.nullable && (t5 += "\u2503null")) : t5 = e6.const ? "const" : 0 === Object.keys(e6).length ? "any" : "{missing-type-info}";
      const n6 = { type: t5, format: e6.format || "", pattern: e6.pattern && !e6.enum ? e6.pattern : "", readOrWriteOnly: e6.readOnly ? "\u{1F181}" : e6.writeOnly ? "\u{1F186}" : "", deprecated: e6.deprecated ? "\u274C" : "", examples: e6.examples || e6.example, default: AP(e6.default), description: e6.description || "", constrain: "", allowedValues: "", arrayType: "", html: "" };
      if ("{recursive}" === n6.type ? n6.description = e6.$ref.substring(e6.$ref.lastIndexOf("/") + 1) : "{missing-type-info}" !== n6.type && "any" !== n6.type || (n6.description = n6.description || ""), n6.allowedValues = e6.const ? e6.const : Array.isArray(e6.enum) ? e6.enum.map((e7) => AP(e7)).join("\u2503") : "", "array" === t5 && e6.items) {
        var o5, a2;
        const t6 = null === (o5 = e6.items) || void 0 === o5 ? void 0 : o5.type, r7 = AP(e6.items.default);
        n6.arrayType = `${e6.type} of ${Array.isArray(t6) ? t6.join("") : t6}`, n6.default = r7, n6.allowedValues = e6.items.const ? e6.const : Array.isArray(null === (a2 = e6.items) || void 0 === a2 ? void 0 : a2.enum) ? e6.items.enum.map((e7) => AP(e7)).join("\u2503") : "";
      }
      return t5.match(/integer|number/g) && (void 0 === e6.minimum && void 0 === e6.exclusiveMinimum || (r6 += void 0 !== e6.minimum ? `Min ${e6.minimum}` : `More than ${e6.exclusiveMinimum}`), void 0 === e6.maximum && void 0 === e6.exclusiveMaximum || (r6 += void 0 !== e6.maximum ? `${r6 ? "\u2503" : ""}Max ${e6.maximum}` : `${r6 ? "\u2503" : ""}Less than ${e6.exclusiveMaximum}`), void 0 !== e6.multipleOf && (r6 += `${r6 ? "\u2503" : ""} multiple of ${e6.multipleOf}`)), t5.match(/string/g) && (void 0 !== e6.minLength && void 0 !== e6.maxLength ? r6 += `${r6 ? "\u2503" : ""}${e6.minLength} to ${e6.maxLength} chars` : void 0 !== e6.minLength ? r6 += `${r6 ? "\u2503" : ""}Min ${e6.minLength} chars` : void 0 !== e6.maxLength && (r6 += `Max ${r6 ? "\u2503" : ""}${e6.maxLength} chars`)), n6.constrain = r6, n6.html = `${n6.type}~|~${n6.readOrWriteOnly}~|~${n6.constrain}~|~${n6.default}~|~${n6.allowedValues}~|~${n6.pattern}~|~${n6.description}~|~${e6.title || ""}~|~${n6.deprecated ? "deprecated" : ""}`, n6;
    }
    function OP(e6) {
      return "boolean" == typeof e6 || "number" == typeof e6 ? { Example: { value: `${e6}` } } : "" === e6 ? { Example: { value: "" } } : e6 ? { Example: { value: e6 } } : e6;
    }
    function TP(e6, t5 = "string") {
      if (!e6)
        return { exampleVal: "", exampleList: [] };
      if (e6.constructor === Object) {
        const t6 = Object.values(e6).filter((e7) => false !== e7["x-example-show-value"]).map((e7) => ({ value: "boolean" == typeof e7.value || "number" == typeof e7.value ? `${e7.value}` : e7.value || "", printableValue: AP(e7.value), summary: e7.summary || "", description: e7.description || "" }));
        return { exampleVal: t6.length > 0 ? t6[0].value.toString() : "", exampleList: t6 };
      }
      if (Array.isArray(e6) || (e6 = e6 ? [e6] : []), 0 === e6.length)
        return { exampleVal: "", exampleList: [] };
      if ("array" === t5) {
        const [t6] = e6, r7 = e6.map((e7) => ({ value: e7, printableValue: AP(e7) }));
        return { exampleVal: t6, exampleList: r7 };
      }
      const r6 = e6[0].toString(), n6 = e6.map((e7) => ({ value: e7.toString(), printableValue: AP(e7) }));
      return { exampleVal: r6, exampleList: n6 };
    }
    function CP(e6) {
      const t5 = e6.examples ? e6.examples[0] : null === e6.example ? null : e6.example || void 0;
      if ("" === t5)
        return "";
      if (null === t5)
        return null;
      if (0 === t5)
        return 0;
      if (false === t5)
        return false;
      if (t5 instanceof Date)
        switch (e6.format.toLowerCase()) {
          case "date":
            return t5.toISOString().split("T")[0];
          case "time":
            return t5.toISOString().split("T")[1];
          default:
            return t5.toISOString();
        }
      if (t5)
        return t5;
      if (0 === Object.keys(e6).length)
        return null;
      if (e6.$ref)
        return e6.$ref;
      if (false === e6.const || 0 === e6.const || null === e6.const || "" === e6.const)
        return e6.const;
      if (e6.const)
        return e6.const;
      const r6 = Array.isArray(e6.type) ? e6.type[0] : e6.type;
      if (!r6)
        return "?";
      if (r6.match(/^integer|^number/g)) {
        const t6 = Number.isNaN(Number(e6.multipleOf)) ? void 0 : Number(e6.multipleOf), n6 = Number.isNaN(Number(e6.maximum)) ? void 0 : Number(e6.maximum), o5 = Number.isNaN(Number(e6.minimum)) ? Number.isNaN(Number(e6.exclusiveMinimum)) ? n6 || 0 : Number(e6.exclusiveMinimum) + (r6.startsWith("integer") ? 1 : 1e-3) : Number(e6.minimum);
        return t6 ? t6 >= o5 ? t6 : o5 % t6 == 0 ? o5 : Math.ceil(o5 / t6) * t6 : o5;
      }
      if (r6.match(/^boolean/g))
        return false;
      if (r6.match(/^null/g))
        return null;
      if (r6.match(/^string/g)) {
        if (e6.enum)
          return e6.enum[0];
        if (e6.const)
          return e6.const;
        if (e6.pattern)
          return e6.pattern;
        if (!e6.format) {
          const t6 = Number.isNaN(e6.minLength) ? void 0 : Number(e6.minLength), r7 = Number.isNaN(e6.maxLength) ? void 0 : Number(e6.maxLength), n6 = t6 || (r7 > 6 ? 6 : r7 || void 0);
          return n6 ? "A".repeat(n6) : "string";
        }
        {
          const t6 = `${Date.now().toString(16)}${Math.random().toString(16)}0`.repeat(16);
          switch (e6.format.toLowerCase()) {
            case "url":
            case "uri":
              return "http://example.com";
            case "date":
              return (/* @__PURE__ */ new Date(0)).toISOString().split("T")[0];
            case "time":
              return (/* @__PURE__ */ new Date(0)).toISOString().split("T")[1];
            case "date-time":
              return (/* @__PURE__ */ new Date(0)).toISOString();
            case "duration":
              return "P3Y6M4DT12H30M5S";
            case "email":
            case "idn-email":
              return "user@example.com";
            case "hostname":
            case "idn-hostname":
              return "www.example.com";
            case "ipv4":
              return "198.51.100.42";
            case "ipv6":
              return "2001:0db8:5b96:0000:0000:426f:8e17:642a";
            case "uuid":
              return [t6.substr(0, 8), t6.substr(8, 4), `4000-8${t6.substr(13, 3)}`, t6.substr(16, 12)].join("-");
            default:
              return "";
          }
        }
      }
      return "?";
    }
    function jP(e6, t5 = 1) {
      const r6 = "  ".repeat(t5);
      let n6 = "";
      if (1 === t5 && "object" != typeof e6)
        return `
${r6}${e6.toString()}`;
      for (const o5 in e6) {
        const a2 = e6[o5]["::XML_TAG"] || o5;
        let i4 = "";
        i4 = Array.isArray(e6[o5]) ? a2[0]["::XML_TAG"] || `${o5}` : a2, o5.startsWith("::") || (n6 = Array.isArray(e6[o5]) || "object" == typeof e6[o5] ? `${n6}
${r6}<${i4}>${jP(e6[o5], t5 + 1)}
${r6}</${i4}>` : `${n6}
${r6}<${i4}>${e6[o5].toString()}</${i4}>`);
      }
      return n6;
    }
    function IP(e6, t5) {
      var r6, n6;
      if ("object" == typeof t5 && null !== t5) {
        var o5, a2;
        if (e6.title && (t5["::TITLE"] = e6.title), e6.description && (t5["::DESCRIPTION"] = e6.description), null !== (r6 = e6.xml) && void 0 !== r6 && r6.name)
          t5["::XML_TAG"] = null === (o5 = e6.xml) || void 0 === o5 ? void 0 : o5.name;
        if (null !== (n6 = e6.xml) && void 0 !== n6 && n6.wrapped)
          t5["::XML_WRAP"] = null === (a2 = e6.xml) || void 0 === a2 ? void 0 : a2.wrapped.toString();
      }
    }
    function _P(e6) {
      if ("object" == typeof e6 && null !== e6) {
        delete e6["::TITLE"], delete e6["::DESCRIPTION"], delete e6["::XML_TAG"], delete e6["::XML_WRAP"];
        for (const t5 in e6)
          _P(e6[t5]);
      }
    }
    function PP(e6, t5, r6) {
      for (const n6 in t5)
        t5[n6][r6] = e6;
    }
    function RP(e6, t5, r6) {
      let n6 = 0;
      const o5 = {};
      for (const a2 in e6) {
        for (const i4 in r6)
          if (o5[`example-${n6}`] = { ...e6[a2] }, o5[`example-${n6}`][t5] = r6[i4], n6++, n6 >= 10)
            break;
        if (n6 >= 10)
          break;
      }
      return o5;
    }
    function LP(e6, t5 = {}) {
      let r6 = {};
      if (e6) {
        if (e6.allOf) {
          var n6, o5;
          const a3 = {};
          if (!(1 !== e6.allOf.length || null !== (n6 = e6.allOf[0]) && void 0 !== n6 && n6.properties || null !== (o5 = e6.allOf[0]) && void 0 !== o5 && o5.items)) {
            if (e6.allOf[0].$ref)
              return "{  }";
            if (e6.allOf[0].readOnly && t5.includeReadOnly) {
              return CP(e6.allOf[0]);
            }
            return;
          }
          e6.allOf.forEach((e7) => {
            if ("object" === e7.type || e7.properties || e7.allOf || e7.anyOf || e7.oneOf) {
              const r7 = LP(e7, t5);
              Object.assign(a3, r7);
            } else if ("array" === e7.type || e7.items) {
              const r7 = [LP(e7, t5)];
              Object.assign(a3, r7);
            } else {
              if (!e7.type)
                return "";
              {
                const t6 = `prop${Object.keys(a3).length}`;
                a3[t6] = CP(e7);
              }
            }
          }), r6 = a3;
        } else if (e6.oneOf) {
          const n7 = {};
          if (e6.properties)
            for (const r7 in e6.properties) {
              var a2;
              e6.properties[r7].properties || null !== (a2 = e6.properties[r7].properties) && void 0 !== a2 && a2.items ? n7[r7] = LP(e6.properties[r7], t5) : n7[r7] = CP(e6.properties[r7]);
            }
          if (e6.oneOf.length > 0) {
            let o6 = 0;
            for (const a3 in e6.oneOf) {
              const i5 = LP(e6.oneOf[a3], t5);
              for (const t6 in i5) {
                let s7;
                if (Object.keys(n7).length > 0) {
                  if (null === i5[t6] || "object" != typeof i5[t6])
                    continue;
                  s7 = Object.assign(i5[t6], n7);
                } else
                  s7 = i5[t6];
                r6[`example-${o6}`] = s7, IP(e6.oneOf[a3], r6[`example-${o6}`]), o6++;
              }
            }
          }
        } else if (e6.anyOf) {
          let n7;
          if ("object" === e6.type || e6.properties) {
            n7 = { "example-0": {} };
            for (const r7 in e6.properties) {
              if (e6.example) {
                n7 = e6;
                break;
              }
              e6.properties[r7].deprecated && !t5.includeDeprecated || (e6.properties[r7].readOnly && !t5.includeReadOnly || e6.properties[r7].writeOnly && !t5.includeWriteOnly || (n7 = RP(n7, r7, LP(e6.properties[r7], t5))));
            }
          }
          let o6 = 0;
          for (const a3 in e6.anyOf) {
            const i5 = LP(e6.anyOf[a3], t5);
            for (const t6 in i5) {
              if (void 0 !== n7)
                for (const e7 in n7)
                  r6[`example-${o6}`] = { ...n7[e7], ...i5[t6] };
              else
                r6[`example-${o6}`] = i5[t6];
              IP(e6.anyOf[a3], r6[`example-${o6}`]), o6++;
            }
          }
        } else if ("object" === e6.type || e6.properties)
          if (r6["example-0"] = {}, IP(e6, r6["example-0"]), e6.example)
            r6["example-0"] = e6.example;
          else
            for (const n7 in e6.properties) {
              var i4, s6, l2, c3, p2, d2, u3;
              if (null === (i4 = e6.properties[n7]) || void 0 === i4 || !i4.deprecated || t5.includeDeprecated) {
                if (null === (s6 = e6.properties[n7]) || void 0 === s6 || !s6.readOnly || t5.includeReadOnly) {
                  if (null === (l2 = e6.properties[n7]) || void 0 === l2 || !l2.writeOnly || t5.includeWriteOnly)
                    if ("array" === (null === (c3 = e6.properties[n7]) || void 0 === c3 ? void 0 : c3.type) || null !== (p2 = e6.properties[n7]) && void 0 !== p2 && p2.items)
                      if (e6.properties[n7].example)
                        PP(e6.properties[n7].example, r6, n7);
                      else if (null !== (d2 = e6.properties[n7]) && void 0 !== d2 && null !== (u3 = d2.items) && void 0 !== u3 && u3.example)
                        PP([e6.properties[n7].items.example], r6, n7);
                      else {
                        const o6 = LP(e6.properties[n7].items, t5);
                        if (t5.useXmlTagForProp) {
                          var h2, f3;
                          const t6 = (null === (h2 = e6.properties[n7].xml) || void 0 === h2 ? void 0 : h2.name) || n7;
                          if (null !== (f3 = e6.properties[n7].xml) && void 0 !== f3 && f3.wrapped) {
                            r6 = RP(r6, t6, JSON.parse(`{ "${t6}" : { "${t6}" : ${JSON.stringify(o6["example-0"])} } }`));
                          } else
                            r6 = RP(r6, t6, o6);
                        } else {
                          const e7 = [];
                          for (const t6 in o6)
                            e7[t6] = [o6[t6]];
                          r6 = RP(r6, n7, e7);
                        }
                      }
                    else
                      r6 = RP(r6, n7, LP(e6.properties[n7], t5));
                }
              }
            }
        else {
          if ("array" !== e6.type && !e6.items)
            return { "example-0": CP(e6) };
          var m2;
          if (e6.items || e6.example)
            if (e6.example)
              r6["example-0"] = e6.example;
            else if (null !== (m2 = e6.items) && void 0 !== m2 && m2.example)
              r6["example-0"] = [e6.items.example];
            else {
              const n7 = LP(e6.items, t5);
              let o6 = 0;
              for (const t6 in n7)
                r6[`example-${o6}`] = [n7[t6]], IP(e6.items, r6[`example-${o6}`]), o6++;
            }
          else
            r6["example-0"] = [];
        }
        return r6;
      }
    }
    function FP(e6, t5 = 0) {
      var r6;
      let n6 = (e6.description || e6.title) && (e6.minItems || e6.maxItems) ? '<span class="descr-expand-toggle">\u2794</span>' : "";
      if (e6.title ? n6 = e6.description ? `${n6} <b>${e6.title}:</b> ${e6.description}<br/>` : `${n6} ${e6.title}<br/>` : e6.description && (n6 = `${n6} ${e6.description}<br/>`), e6.minItems && (n6 = `${n6} <b>Min Items:</b> ${e6.minItems}`), e6.maxItems && (n6 = `${n6} <b>Max Items:</b> ${e6.maxItems}`), t5 > 0 && null !== (r6 = e6.items) && void 0 !== r6 && r6.description) {
        let t6 = "";
        e6.items.minProperties && (t6 = `<b>Min Properties:</b> ${e6.items.minProperties}`), e6.items.maxProperties && (t6 = `${t6} <b>Max Properties:</b> ${e6.items.maxProperties}`), n6 = `${n6} \u2B95 ${t6} [ ${e6.items.description} ] `;
      }
      return n6;
    }
    function DP(e6, t5, r6 = 0, n6 = "") {
      if (e6) {
        if (e6.allOf) {
          const n7 = {};
          if (1 === e6.allOf.length && !e6.allOf[0].properties && !e6.allOf[0].items) {
            return `${EP(e6.allOf[0]).html}`;
          }
          e6.allOf.map((e7, t6) => {
            if ("object" === e7.type || e7.properties || e7.allOf || e7.anyOf || e7.oneOf) {
              const o6 = (e7.anyOf || e7.oneOf) && t6 > 0 ? t6 : "", a3 = DP(e7, {}, r6 + 1, o6);
              Object.assign(n7, a3);
            } else if ("array" === e7.type || e7.items) {
              const t7 = DP(e7, {}, r6 + 1);
              Object.assign(n7, t7);
            } else {
              if (!e7.type)
                return "";
              {
                const t7 = `prop${Object.keys(n7).length}`, r7 = EP(e7);
                n7[t7] = `${r7.html}`;
              }
            }
          }), t5 = n7;
        } else if (e6.anyOf || e6.oneOf) {
          if (t5["::description"] = e6.description || "", "object" === e6.type || e6.properties) {
            t5["::description"] = e6.description || "", t5["::type"] = "object";
            for (const n7 in e6.properties)
              e6.required && e6.required.includes(n7) ? t5[`${n7}*`] = DP(e6.properties[n7], {}, r6 + 1) : t5[n7] = DP(e6.properties[n7], {}, r6 + 1);
          }
          const o6 = {}, a3 = e6.anyOf ? "anyOf" : "oneOf";
          e6[a3].forEach((e7, t6) => {
            if ("object" === e7.type || e7.properties || e7.allOf || e7.anyOf || e7.oneOf) {
              const r7 = DP(e7, {});
              o6[`::OPTION~${t6 + 1}${e7.title ? `~${e7.title}` : ""}`] = r7, o6[`::OPTION~${t6 + 1}${e7.title ? `~${e7.title}` : ""}`]["::readwrite"] = "", o6["::type"] = "xxx-of-option";
            } else if ("array" === e7.type || e7.items) {
              const r7 = DP(e7, {});
              o6[`::OPTION~${t6 + 1}${e7.title ? `~${e7.title}` : ""}`] = r7, o6[`::OPTION~${t6 + 1}${e7.title ? `~${e7.title}` : ""}`]["::readwrite"] = "", o6["::type"] = "xxx-of-array";
            } else {
              const r7 = `::OPTION~${t6 + 1}${e7.title ? `~${e7.title}` : ""}`;
              o6[r7] = `${EP(e7).html}`, o6["::type"] = "xxx-of-option";
            }
          }), t5[e6.anyOf ? `::ANY~OF ${n6}` : `::ONE~OF ${n6}`] = o6, t5["::type"] = "object";
        } else if (Array.isArray(e6.type)) {
          const n7 = JSON.parse(JSON.stringify(e6)), i5 = [], s6 = [];
          let l2;
          var o5;
          if (n7.type.forEach((e7) => {
            var t6, r7;
            e7.match(/integer|number|string|null|boolean/g) ? i5.push(e7) : "array" === e7 && "string" == typeof (null === (t6 = n7.items) || void 0 === t6 ? void 0 : t6.type) && null !== (r7 = n7.items) && void 0 !== r7 && r7.type.match(/integer|number|string|null|boolean/g) ? "string" === n7.items.type && n7.items.format ? i5.push(`[${n7.items.format}]`) : i5.push(`[${n7.items.type}]`) : s6.push(e7);
          }), i5.length > 0) {
            if (n7.type = i5.join(2 === i5.length ? " or " : "\u2503"), l2 = EP(n7), 0 === s6.length)
              return `${(null === (o5 = l2) || void 0 === o5 ? void 0 : o5.html) || ""}`;
          }
          if (s6.length > 0) {
            var a2;
            t5["::type"] = "object";
            const o6 = { "::type": "xxx-of-option" };
            s6.forEach((t6, a3) => {
              if ("null" === t6)
                o6[`::OPTION~${a3 + 1}`] = "NULL~|~~|~~|~~|~~|~~|~~|~~|~";
              else if ("integer, number, string, boolean,".includes(`${t6},`)) {
                n7.type = Array.isArray(t6) ? t6.join("\u2503") : t6;
                const e7 = EP(n7);
                o6[`::OPTION~${a3 + 1}`] = e7.html;
              } else if ("object" === t6) {
                const t7 = { "::title": e6.title || "", "::description": e6.description || "", "::type": "object", "::deprecated": e6.deprecated || false };
                for (const n8 in e6.properties)
                  e6.required && e6.required.includes(n8) ? t7[`${n8}*`] = DP(e6.properties[n8], {}, r6 + 1) : t7[n8] = DP(e6.properties[n8], {}, r6 + 1);
                o6[`::OPTION~${a3 + 1}`] = t7;
              } else
                "array" === t6 && (o6[`::OPTION~${a3 + 1}`] = { "::title": e6.title || "", "::description": e6.description || "", "::type": "array", "::props": DP(e6.items, {}, r6 + 1) });
            }), o6[`::OPTION~${s6.length + 1}`] = (null === (a2 = l2) || void 0 === a2 ? void 0 : a2.html) || "", t5["::ONE~OF"] = o6;
          }
        } else if ("object" === e6.type || e6.properties) {
          t5["::title"] = e6.title || "", t5["::description"] = FP(e6, r6), t5["::type"] = "object", (Array.isArray(e6.type) && e6.type.includes("null") || e6.nullable) && (t5["::dataTypeLabel"] = "object or null"), t5["::deprecated"] = e6.deprecated || false, t5["::readwrite"] = e6.readOnly ? "readonly" : e6.writeOnly ? "writeonly" : "";
          for (const n7 in e6.properties)
            e6.required && e6.required.includes(n7) ? t5[`${n7}*`] = DP(e6.properties[n7], {}, r6 + 1) : t5[n7] = DP(e6.properties[n7], {}, r6 + 1);
          for (const n7 in e6.patternProperties)
            t5[`[pattern: ${n7}]`] = DP(e6.patternProperties[n7], t5, r6 + 1);
          e6.additionalProperties && (t5["[any-key]"] = DP(e6.additionalProperties, {}));
        } else {
          if ("array" !== e6.type && !e6.items) {
            const t6 = EP(e6);
            return null != t6 && t6.html ? `${t6.html}` : "";
          }
          var i4;
          t5["::title"] = e6.title || "", t5["::description"] = FP(e6, r6), t5["::type"] = "array", (Array.isArray(e6.type) && e6.type.includes("null") || e6.nullable) && (t5["::dataTypeLabel"] = "array or null"), t5["::deprecated"] = e6.deprecated || false, t5["::readwrite"] = e6.readOnly ? "readonly" : e6.writeOnly ? "writeonly" : "", null !== (i4 = e6.items) && void 0 !== i4 && i4.items && (t5["::array-type"] = e6.items.items.type), t5["::props"] = DP(e6.items, {}, r6 + 1);
        }
        return t5;
      }
    }
    function BP(e6, t5, r6 = "", n6 = "", o5 = true, a2 = true, i4 = "json", s6 = false) {
      const l2 = [];
      if (r6)
        for (const e7 in r6) {
          let n7 = "", o6 = "json";
          if (null != t5 && t5.toLowerCase().includes("json")) {
            if ("text" === i4)
              n7 = "string" == typeof r6[e7].value ? r6[e7].value : JSON.stringify(r6[e7].value, void 0, 2), o6 = "text";
            else if (n7 = r6[e7].value, "string" == typeof r6[e7].value)
              try {
                const t6 = r6[e7].value;
                n7 = JSON.parse(t6), o6 = "json";
              } catch (t6) {
                o6 = "text", n7 = r6[e7].value;
              }
          } else
            n7 = r6[e7].value, o6 = "text";
          l2.push({ exampleId: e7, exampleSummary: r6[e7].summary || e7, exampleDescription: r6[e7].description || "", exampleType: t5, exampleValue: n7, exampleFormat: o6 });
        }
      else if (n6) {
        let e7 = "", r7 = "json";
        if (null != t5 && t5.toLowerCase().includes("json")) {
          if ("text" === i4)
            e7 = "string" == typeof n6 ? n6 : JSON.stringify(n6, void 0, 2), r7 = "text";
          else if ("object" == typeof n6)
            e7 = n6, r7 = "json";
          else if ("string" == typeof n6)
            try {
              e7 = JSON.parse(n6), r7 = "json";
            } catch (t6) {
              r7 = "text", e7 = n6;
            }
        } else
          e7 = n6, r7 = "text";
        l2.push({ exampleId: "Example", exampleSummary: "", exampleDescription: "", exampleType: t5, exampleValue: e7, exampleFormat: r7 });
      }
      if (0 === l2.length || true === s6)
        if (e6)
          if (e6.example)
            l2.push({ exampleId: "Example", exampleSummary: "", exampleDescription: "", exampleType: t5, exampleValue: e6.example, exampleFormat: null != t5 && t5.toLowerCase().includes("json") && "object" == typeof e6.example ? "json" : "text" });
          else if (null != t5 && t5.toLowerCase().includes("json") || null != t5 && t5.toLowerCase().includes("text") || null != t5 && t5.toLowerCase().includes("*/*") || null != t5 && t5.toLowerCase().includes("xml")) {
            let r7 = "", n7 = "", s7 = "", d2 = "";
            var c3, p2;
            if (null != t5 && t5.toLowerCase().includes("xml"))
              r7 = null !== (c3 = e6.xml) && void 0 !== c3 && c3.name ? `<${e6.xml.name} ${e6.xml.namespace ? `xmlns="${e6.xml.namespace}"` : ""}>` : "<root>", n7 = null !== (p2 = e6.xml) && void 0 !== p2 && p2.name ? `</${e6.xml.name}>` : "</root>", s7 = "text";
            else
              s7 = i4;
            const u3 = LP(e6, { includeReadOnly: o5, includeWriteOnly: a2, deprecated: true, useXmlTagForProp: null == t5 ? void 0 : t5.toLowerCase().includes("xml") });
            let h2 = 0;
            for (const e7 in u3) {
              if (!u3[e7])
                continue;
              const o6 = u3[e7]["::TITLE"] || "Example " + ++h2, a3 = u3[e7]["::DESCRIPTION"] || "";
              null != t5 && t5.toLowerCase().includes("xml") ? d2 = `<?xml version="1.0" encoding="UTF-8"?>
${r7}${jP(u3[e7], 1)}
${n7}` : (_P(u3[e7]), d2 = "text" === i4 ? JSON.stringify(u3[e7], null, 2) : u3[e7]), l2.push({ exampleId: e7, exampleSummary: o6, exampleDescription: a3, exampleType: t5, exampleFormat: s7, exampleValue: d2 });
            }
          } else
            null != t5 && t5.toLowerCase().includes("jose") ? l2.push({ exampleId: "Example", exampleSummary: "Base64 Encoded", exampleDescription: "", exampleType: t5, exampleValue: e6.pattern || "bXJpbg==", exampleFormat: "text" }) : l2.push({ exampleId: "Example", exampleSummary: "", exampleDescription: "", exampleType: t5, exampleValue: "", exampleFormat: "text" });
        else
          l2.push({ exampleId: "Example", exampleSummary: "", exampleDescription: "", exampleType: t5, exampleValue: "", exampleFormat: "text" });
      return l2;
    }
    function NP(e6) {
      return "application/json" === e6 ? "json" : "application/xml" === e6 ? "xml" : null;
    }
    function qP(e6) {
      if (e6.schema)
        return [e6.schema, null, null];
      if (e6.content) {
        for (const t5 of Object.keys(e6.content))
          if (e6.content[t5].schema)
            return [e6.content[t5].schema, NP(t5), e6.content[t5]];
      }
      return [null, null, null];
    }
    customElements.define("json-tree", class extends ie {
      static get properties() {
        return { data: { type: Object }, renderStyle: { type: String, attribute: "render-style" } };
      }
      static get styles() {
        return [Ke, SP, Je, c2`
      :host{
        display:flex;
      }
      :where(button, input[type="checkbox"], [tabindex="0"]):focus-visible { box-shadow: var(--focus-shadow); }
      :where(input[type="text"], input[type="password"], select, textarea):focus-visible { border-color: var(--primary-color); }
      .json-tree {
        position: relative;
        font-family: var(--font-mono);
        font-size: var(--font-size-small);
        display:inline-block;
        overflow:hidden;
        word-break: break-all;
        flex:1;
        line-height: calc(var(--font-size-small) + 6px);
        min-height: 40px;
        direction: ltr; 
        text-align: left;
      }

      .open-bracket {
        display:inline-block;
        padding: 0 20px 0 0;
        cursor:pointer;
        border: 1px solid transparent;
        border-radius:3px;
      }
      .close-bracket {
        border: 1px solid transparent;
        border-radius:3px;
        display:inline-block;
      }
      .open-bracket:hover {
        color:var(--primary-color);
        background-color:var(--hover-color);
        border: 1px solid var(--border-color);
      }
      .open-bracket.expanded:hover ~ .inside-bracket {
        border-left: 1px solid var(--fg3);
      }
      .open-bracket.expanded:hover ~ .close-bracket {
        color:var(--primary-color);
      }
      .inside-bracket {
        padding-left:12px;
        overflow: hidden;
        border-left:1px dotted var(--border-color);
      }
      .open-bracket.collapsed + .inside-bracket,
      .open-bracket.collapsed + .inside-bracket + .close-bracket {
        display:none;
      }

      .string{color:var(--green);}
      .number{color:var(--blue);}
      .null{color:var(--red);}
      .boolean{color:var(--purple);}
      .object{color:var(--fg)}
      .toolbar {
        position: absolute;
        top:5px;
        right:6px;
        display:flex;
        padding:2px;
        align-items: center;
      }`, nt];
      }
      render() {
        return q`
      <div class = "json-tree"  @click='${(e6) => {
          e6.target.classList.contains("btn-copy") ? st(JSON.stringify(this.data, null, 2), e6) : this.toggleExpand(e6);
        }}'>
        <div class='toolbar'> 
          <button class="toolbar-btn btn-copy" part="btn btn-fill btn-copy"> Copy </button>
        </div>
          ${this.generateTree(this.data, true)}
      </div>  
    `;
      }
      generateTree(e6, t5 = false) {
        if (null === e6)
          return q`<div class="null" style="display:inline;">null</div>`;
        if ("object" == typeof e6 && e6 instanceof Date == false) {
          const r6 = Array.isArray(e6) ? "array" : "pure_object";
          return 0 === Object.keys(e6).length ? q`${Array.isArray(e6) ? "[ ]," : "{ },"}` : q`
      <div class="open-bracket expanded ${"array" === r6 ? "array" : "object"}" > ${"array" === r6 ? "[" : "{"}</div>
      <div class="inside-bracket">
        ${Object.keys(e6).map((t6, n6, o5) => q`
          <div class="item"> 
            ${"pure_object" === r6 ? q`"${t6}":` : ""}
            ${this.generateTree(e6[t6], n6 === o5.length - 1)}
          </div>`)}
      </div>
      <div class="close-bracket">${"array" === r6 ? "]" : "}"}${t5 ? "" : ","}</div>
      `;
        }
        return "string" == typeof e6 || e6 instanceof Date ? q`<span class="${typeof e6}">"${e6}"</span>${t5 ? "" : ","}` : q`<span class="${typeof e6}">${e6}</span>${t5 ? "" : ","}`;
      }
      toggleExpand(e6) {
        const t5 = e6.target;
        e6.target.classList.contains("open-bracket") && (t5.classList.contains("expanded") ? (t5.classList.replace("expanded", "collapsed"), e6.target.innerHTML = e6.target.classList.contains("array") ? "[...]" : "{...}") : (t5.classList.replace("collapsed", "expanded"), e6.target.innerHTML = e6.target.classList.contains("array") ? "[" : "{"));
      }
    });
    const UP = c2`

*, *:before, *:after { box-sizing: border-box; }

.tr {
  display: flex;
  flex: none;
  width: 100%;
  box-sizing: content-box;
  border-bottom: 1px dotted transparent;
  transition: max-height 0.3s ease-out;
}
.td {
  display: block;
  flex: 0 0 auto;
}
.key {
  font-family: var(--font-mono);
  white-space: normal;
  word-break: break-all;
}

.collapsed-all-descr .key {
  overflow:hidden;
}
.expanded-all-descr .key-descr .descr-expand-toggle {
  display:none;
}

.key-descr .descr-expand-toggle {
  display:inline-block;
  user-select:none;
  color: var(--fg);
  cursor: pointer;
  transform: rotate(45deg);
  transition: transform .2s ease;
}

.expanded-descr .key-descr .descr-expand-toggle {
  transform: rotate(270deg)
}

.key-descr .descr-expand-toggle:hover {
  color: var(--primary-color);
}

.expanded-descr .more-content { display:none; }

.key-descr {
  font-family:var(--font-regular);
  color:var(--light-fg);
  flex-shrink: 1;
  text-overflow: ellipsis;
  overflow: hidden;
  display: none;
}
.expanded-descr .key-descr{
  max-height:auto;
  overflow:hidden;
  display: none;
}

.xxx-of-key {
  font-size: calc(var(--font-size-small) - 2px); 
  font-weight:bold; 
  background-color:var(--primary-color); 
  color:var(--primary-color-invert); 
  border-radius:2px;
  line-height:calc(var(--font-size-small) + 6px);
  padding:0px 5px; 
  margin-bottom:1px; 
  display:inline-block;
}

.xxx-of-descr {
  font-family: var(--font-regular);
  color: var(--primary-color);
  font-size: calc(var(--font-size-small) - 1px);
  margin-left: 2px;
}

.stri, .string, .uri, .url, .byte, .bina, .date, .pass, .ipv4, .ipv4, .uuid, .emai, .host {color:var(--green);}
.inte, .numb, .number, .int6, .int3, .floa, .doub, .deci .blue {color:var(--blue);}
.null {color:var(--red);}
.bool, .boolean{color:var(--orange)}
.enum {color:var(--purple)}
.cons {color:var(--purple)}
.recu {color:var(--brown)}
.toolbar {
  display:flex;
  width:100%;
  padding: 2px 0;
  color:var(--primary-color);
}
.toolbar-item {
  cursor:pointer;
  padding:5px 0;
  margin:0 2px;
}
.schema-root-type {
  cursor:auto;
  color:var(--fg2);
  font-weight: bold;
  text-transform: uppercase;
}
.toolbar-item:first-of-type { margin:0 2px 0 0;}

@media only screen and (min-width: 500px) {
  .key-descr {
    display: block;
  }
  .expanded-descr .key-descr{
    display: block;
  }
}
`;
    customElements.define("schema-tree", class extends ie {
      static get properties() {
        return { data: { type: Object }, schemaExpandLevel: { type: Number, attribute: "schema-expand-level" }, schemaDescriptionExpanded: { type: String, attribute: "schema-description-expanded" }, allowSchemaDescriptionExpandToggle: { type: String, attribute: "allow-schema-description-expand-toggle" }, schemaHideReadOnly: { type: String, attribute: "schema-hide-read-only" }, schemaHideWriteOnly: { type: String, attribute: "schema-hide-write-only" } };
      }
      connectedCallback() {
        super.connectedCallback(), (!this.schemaExpandLevel || this.schemaExpandLevel < 1) && (this.schemaExpandLevel = 99999), this.schemaDescriptionExpanded && "true false".includes(this.schemaDescriptionExpanded) || (this.schemaDescriptionExpanded = "false"), this.schemaHideReadOnly && "true false".includes(this.schemaHideReadOnly) || (this.schemaHideReadOnly = "true"), this.schemaHideWriteOnly && "true false".includes(this.schemaHideWriteOnly) || (this.schemaHideWriteOnly = "true");
      }
      static get styles() {
        return [Ke, UP, SP, c2`
      .tree {
        font-size:var(--font-size-small);
        text-align: left;
        direction: ltr;
        line-height:calc(var(--font-size-small) + 6px);
      }
      .tree .tr:hover{
        background-color:var(--hover-color);
      }
      .collapsed-all-descr .tr:not(.expanded-descr) {
        overflow: hidden;
        max-height:calc(var(--font-size-small) + 8px);
      }
      .tree .key {
        max-width: 300px;
      }
      .key.deprecated .key-label {
        color: var(--red);
      }
      .tr.expanded:hover > .td.key > .open-bracket {
        color: var(--primary-color);
      }
      .tr.expanded:hover + .inside-bracket {
        border-left: 1px solid var(--fg3);
      }
      .tr.expanded:hover + .inside-bracket + .close-bracket {
        color: var(--primary-color);
      }
      .inside-bracket.xxx-of-option {
        border-left: 1px solid transparent;
      }
      .open-bracket{
        display:inline-block;
        padding: 0 20px 0 0;
        cursor:pointer;
        border: 1px solid transparent;
        border-radius:3px;
      }
      .open-bracket:hover {
        color:var(--primary-color);
        background-color:var(--hover-color);
        border: 1px solid var(--border-color);
      }
      .close-bracket{
        display:inline-block;
        font-family: var(--font-mono);
      }
      .tr.collapsed + .inside-bracket,
      .tr.collapsed + .inside-bracket + .close-bracket{
        overflow: hidden;
        display:none;
      }
      .inside-bracket.object,
      .inside-bracket.array {
        border-left: 1px dotted var(--border-color);
      }`, nt];
      }
      render() {
        var e6, t5, r6;
        return q`
      <div class="tree ${"true" === this.schemaDescriptionExpanded ? "expanded-all-descr" : "collapsed-all-descr"}" @click="${(e7) => this.handleAllEvents(e7)}">
        <div class="toolbar">
          <div class="toolbar-item schema-root-type ${(null === (e6 = this.data) || void 0 === e6 ? void 0 : e6["::type"]) || ""} "> ${(null === (t5 = this.data) || void 0 === t5 ? void 0 : t5["::type"]) || ""} </div>
          ${"true" === this.allowSchemaDescriptionExpandToggle ? q`
              <div style="flex:1"></div>
              <div part="schema-toolbar-item schema-multiline-toggle" class='toolbar-item schema-multiline-toggle'> 
                ${"true" === this.schemaDescriptionExpanded ? "Single line description" : "Multiline description"}
              </div>` : ""}
        </div>
        <span part="schema-description" class='m-markdown'> ${Q_(We((null === (r6 = this.data) || void 0 === r6 ? void 0 : r6["::description"]) || ""))}</span>
        ${this.data ? q`
            ${this.generateTree("array" === this.data["::type"] ? this.data["::props"] : this.data, this.data["::type"], this.data["::array-type"] || "")}` : q`<span class='mono-font' style='color:var(--red)'> Schema not found </span>`}
      </div>  
    `;
      }
      generateTree(e6, t5 = "object", r6 = "", n6 = "", o5 = "", a2 = 0, i4 = 0, s6 = "") {
        var l2;
        if ("true" === this.schemaHideReadOnly) {
          if ("array" === t5 && "readonly" === s6)
            return;
          if ("readonly" === (null == e6 ? void 0 : e6["::readwrite"]))
            return;
        }
        if ("true" === this.schemaHideWriteOnly) {
          if ("array" === t5 && "writeonly" === s6)
            return;
          if ("writeonly" === (null == e6 ? void 0 : e6["::readwrite"]))
            return;
        }
        if (!e6)
          return q`<div class="null" style="display:inline;">
        <span class="key-label xxx-of-key"> ${n6.replace("::OPTION~", "")}</span>
        ${"array" === t5 ? q`<span class='mono-font'> [ ] </span>` : "object" === t5 ? q`<span class='mono-font'> { } </span>` : q`<span class='mono-font'> schema undefined </span>`}
      </div>`;
        if (0 === Object.keys(e6).length)
          return q`<span class="key object">${n6}:{ }</span>`;
        let c3 = "", p2 = "";
        if (n6.startsWith("::ONE~OF") || n6.startsWith("::ANY~OF"))
          c3 = n6.replace("::", "").replace("~", " ");
        else if (n6.startsWith("::OPTION")) {
          const e7 = n6.split("~");
          [, c3, p2] = e7;
        } else
          c3 = n6;
        const d2 = 400 - 12 * i4;
        let u3 = "", h2 = "";
        const f3 = null !== (l2 = e6["::type"]) && void 0 !== l2 && l2.startsWith("xxx-of") ? a2 : a2 + 1, m2 = "xxx-of-option" === t5 || "xxx-of-option" === e6["::type"] || n6.startsWith("::OPTION") ? i4 : i4 + 1;
        if ("object" === e6["::type"])
          "array" === t5 ? (u3 = a2 < this.schemaExpandLevel ? q`<span class="open-bracket array-of-object" >[{</span>` : q`<span class="open-bracket array-of-object">[{...}]</span>`, h2 = "}]") : (u3 = a2 < this.schemaExpandLevel ? q`<span class="open-bracket object">{</span>` : q`<span class="open-bracket object">{...}</span>`, h2 = "}");
        else if ("array" === e6["::type"])
          if ("array" === t5) {
            const e7 = "object" !== r6 ? r6 : "";
            u3 = a2 < this.schemaExpandLevel ? q`<span class="open-bracket array-of-array" data-array-type="${e7}">[[ ${e7} </span>` : q`<span class="open-bracket array-of-array"  data-array-type="${e7}">[[...]]</span>`, h2 = "]]";
          } else
            u3 = a2 < this.schemaExpandLevel ? q`<span class="open-bracket array">[</span>` : q`<span class="open-bracket array">[...]</span>`, h2 = "]";
        var y2;
        if ("object" == typeof e6)
          return q`
        <div class="tr ${a2 < this.schemaExpandLevel || null !== (y2 = e6["::type"]) && void 0 !== y2 && y2.startsWith("xxx-of") ? "expanded" : "collapsed"} ${e6["::type"] || "no-type-info"}" title="${e6["::deprecated"] ? "Deprecated" : ""}">
          <div class="td key ${e6["::deprecated"] ? "deprecated" : ""}" style='min-width:${d2}px'>
            ${"xxx-of-option" === e6["::type"] || "xxx-of-array" === e6["::type"] || n6.startsWith("::OPTION") ? q`<span class='key-label xxx-of-key'> ${c3}</span><span class="xxx-of-descr">${p2}</span>` : "::props" === c3 || "::ARRAY~OF" === c3 ? "" : a2 > 0 ? q`<span class="key-label" title="${"readonly" === s6 ? "Read-Only" : "writeonly" === s6 ? "Write-Only" : ""}">
                      ${e6["::deprecated"] ? "\u2717" : ""}
                      ${c3.replace(/\*$/, "")}${c3.endsWith("*") ? q`<span style="color:var(--red)">*</span>` : ""}${"readonly" === s6 ? q` 🆁` : "writeonly" === s6 ? q` 🆆` : s6}:
                    </span>` : ""}
            ${u3}
          </div>
          <div class='td key-descr m-markdown-small'>${Q_(We(o5 || ""))}</div>
        </div>
        <div class='inside-bracket ${e6["::type"] || "no-type-info"}' style='padding-left:${"xxx-of-option" === e6["::type"] || "xxx-of-array" === e6["::type"] ? 0 : 12}px;'>
          ${Array.isArray(e6) && e6[0] ? q`${this.generateTree(e6[0], "xxx-of-option", "", "::ARRAY~OF", "", f3, m2, e6[0]["::readwrite"])}` : q`
              ${Object.keys(e6).map((t6) => {
            var r7;
            return q`
                ${["::title", "::description", "::type", "::props", "::deprecated", "::array-type", "::readwrite", "::dataTypeLabel"].includes(t6) ? "array" === e6[t6]["::type"] || "object" === e6[t6]["::type"] ? q`${this.generateTree("array" === e6[t6]["::type"] ? e6[t6]["::props"] : e6[t6], e6[t6]["::type"], e6[t6]["::array-type"] || "", t6, e6[t6]["::description"], f3, m2, e6[t6]["::readwrite"] ? e6[t6]["::readwrite"] : "")}` : "" : q`${this.generateTree("array" === e6[t6]["::type"] ? e6[t6]["::props"] : e6[t6], e6[t6]["::type"], e6[t6]["::array-type"] || "", t6, (null === (r7 = e6[t6]) || void 0 === r7 ? void 0 : r7["::description"]) || "", f3, m2, e6[t6]["::readwrite"] ? e6[t6]["::readwrite"] : "")}`}
              `;
          })}
            `}
        </div>
        ${e6["::type"] && e6["::type"].includes("xxx-of") ? "" : q`<div class='close-bracket'> ${h2} </div>`}
      `;
        const [g2, v2, b2, x3, w2, $2, k2, S2, A2] = e6.split("~|~");
        if ("\u{1F181}" === v2 && "true" === this.schemaHideReadOnly)
          return;
        if ("\u{1F186}" === v2 && "true" === this.schemaHideWriteOnly)
          return;
        const E2 = g2.replace(/┃.*/g, "").replace(/[^a-zA-Z0-9+]/g, "").substring(0, 4).toLowerCase(), O2 = b2 || x3 || w2 || $2 ? `<span class="descr-expand-toggle ${"true" === this.schemaDescriptionExpanded ? "expanded-descr" : ""}">\u2794</span>` : "";
        let T3 = "", C2 = "";
        return "array" === t5 ? "readonly" === s6 ? (T3 = "\u{1F181}", C2 = "Read-Only") : "writeonly" === s6 && (T3 = "\u{1F186}", C2 = "Write-Only") : "\u{1F181}" === v2 ? (T3 = "\u{1F181}", C2 = "Read-Only") : "\u{1F186}" === v2 && (T3 = "\u{1F186}", C2 = "Write-Only"), q`
      <div class = "tr primitive" title="${A2 ? "Deprecated" : ""}">
        <div class="td key ${A2}" style='min-width:${d2}px'>
          ${A2 ? q`<span style='color:var(--red);'>✗</span>` : ""}
          ${c3.endsWith("*") ? q`<span class="key-label">${c3.substring(0, c3.length - 1)}</span><span style='color:var(--red);'>*</span>:` : n6.startsWith("::OPTION") ? q`<span class='key-label xxx-of-key'>${c3}</span><span class="xxx-of-descr">${p2}</span>` : q`<span class="key-label">${c3}:</span>`}
          <span class="${E2}" title="${C2}"> 
            ${"array" === t5 ? `[${g2}]` : `${g2}`}
            ${T3}
          </span>
        </div>
        <div class='td key-descr'>
          ${o5 || S2 || k2 ? q`${q`<span class="m-markdown-small">
                ${Q_(We("array" === t5 ? `${O2} ${o5}` : S2 ? `${O2} <b>${S2}:</b> ${k2}` : `${O2} ${k2}`))}
              </span>`}` : ""}  
          ${b2 ? q`<div style='display:inline-block; line-break:anywhere; margin-right:8px'><span class='bold-text'>Constraints: </span>${b2}</div>` : ""}
          ${x3 ? q`<div style='display:inline-block; line-break:anywhere; margin-right:8px'><span class='bold-text'>Default: </span>${x3}</div>` : ""}
          ${w2 ? q`<div style='display:inline-block; line-break:anywhere; margin-right:8px'><span class='bold-text'>${"const" === g2 ? "Value" : "Allowed"}: </span>${w2}</div>` : ""}
          ${$2 ? q`<div style='display:inline-block; line-break: anywhere; margin-right:8px'><span class='bold-text'>Pattern: </span>${$2}</div>` : ""}
        </div>
      </div>
    `;
      }
      handleAllEvents(e6) {
        if (e6.target.classList.contains("open-bracket"))
          this.toggleObjectExpand(e6);
        else if (e6.target.classList.contains("schema-multiline-toggle"))
          this.schemaDescriptionExpanded = "true" === this.schemaDescriptionExpanded ? "false" : "true";
        else if (e6.target.classList.contains("descr-expand-toggle")) {
          const t5 = e6.target.closest(".tr");
          t5 && (t5.classList.toggle("expanded-descr"), t5.style.maxHeight = t5.scrollHeight);
        }
      }
      toggleObjectExpand(e6) {
        const t5 = e6.target.closest(".tr");
        t5.classList.contains("expanded") ? (t5.classList.replace("expanded", "collapsed"), e6.target.innerHTML = e6.target.classList.contains("array-of-object") ? "[{...}]" : e6.target.classList.contains("array-of-array") ? "[[...]]" : e6.target.classList.contains("array") ? "[...]" : "{...}") : (t5.classList.replace("collapsed", "expanded"), e6.target.innerHTML = e6.target.classList.contains("array-of-object") ? "[{" : e6.target.classList.contains("array-of-array") ? `[[ ${e6.target.dataset.arrayType}` : e6.target.classList.contains("object") ? "{" : "[");
      }
    });
    customElements.define("tag-input", class extends ie {
      render() {
        let e6 = "";
        return Array.isArray(this.value) && (e6 = q`${this.value.filter((e7) => "string" == typeof e7 && "" !== e7.trim()).map((e7) => q`<span class='tag'>${e7}</span>`)}`), q`
      <div class='tags'>
        ${e6}
        <input type="text" class='editor' @paste="${(e7) => this.afterPaste(e7)}" @keydown="${this.afterKeyDown}" @blur="${this.onBlur}" placeholder="${this.placeholder || ""}">
      </div>
    `;
      }
      static get properties() {
        return { placeholder: { type: String }, value: { type: Array, attribute: "value" } };
      }
      attributeChangedCallback(e6, t5, r6) {
        "value" === e6 && r6 && t5 !== r6 && (this.value = r6.split(",").filter((e7) => "" !== e7.trim())), super.attributeChangedCallback(e6, t5, r6);
      }
      afterPaste(e6) {
        const t5 = (e6.clipboardData || window.clipboardData).getData("Text"), r6 = t5 ? t5.split(",").filter((e7) => "" !== e7.trim()) : "";
        r6 && (Array.isArray(this.value) ? this.value = [...this.value, ...r6] : this.value = r6), e6.preventDefault();
      }
      afterKeyDown(e6) {
        13 === e6.keyCode ? (e6.stopPropagation(), e6.preventDefault(), e6.target.value && (Array.isArray(this.value) ? this.value = [...this.value, e6.target.value] : this.value = [e6.target.value], e6.target.value = "")) : 8 === e6.keyCode && 0 === e6.target.value.length && Array.isArray(this.value) && this.value.length > 0 && (this.value.splice(-1), this.value = [...this.value]);
      }
      onBlur(e6) {
        e6.target.value && (Array.isArray(this.value) ? this.value = [...this.value, e6.target.value] : this.value = [e6.target.value], e6.target.value = "");
      }
      static get styles() {
        return [c2`
      .tags {
        display:flex;
        flex-wrap: wrap;
        outline: none;
        padding:0;
        border-radius:var(--border-radius);
        border:1px solid var(--border-color);
        cursor:text;
        overflow:hidden;
        background:var(--input-bg);
      }
      .tag, .editor {
        padding:3px;
        margin:2px;
      }
      .tag{
        border:1px solid var(--border-color);
        background-color:var(--bg3);
        color:var(--fg3);
        border-radius:var(--border-radius);
        word-break: break-all;
        font-size: var(--font-size-small);
      }
      .tag:hover ~ #cursor {
        display: block;
      }
      .editor {
        flex:1;
        border:1px solid transparent;
        color:var(--fg);
        min-width:60px;
        outline: none;
        line-height: inherit;
        font-family:inherit;
        background:transparent;
        font-size: calc(var(--font-size-small) + 1px);
      }
      .editor:focus-visible {
        outline: 1px solid;
      }
      .editor::placeholder {
        color: var(--placeholder-color);
        opacity:1;
      }
    `];
      }
    });
    customElements.define("api-request", class extends ie {
      constructor() {
        super(), this.responseMessage = "", this.responseStatus = "success", this.responseHeaders = "", this.responseText = "", this.responseUrl = "", this.curlSyntax = "", this.activeResponseTab = "response", this.selectedRequestBodyType = "", this.selectedRequestBodyExample = "", this.activeParameterSchemaTabs = {};
      }
      static get properties() {
        return { serverUrl: { type: String, attribute: "server-url" }, servers: { type: Array }, method: { type: String }, path: { type: String }, security: { type: Array }, parameters: { type: Array }, request_body: { type: Object }, api_keys: { type: Array }, parser: { type: Object }, accept: { type: String }, callback: { type: String }, webhook: { type: String }, responseMessage: { type: String, attribute: false }, responseText: { type: String, attribute: false }, responseHeaders: { type: String, attribute: false }, responseStatus: { type: String, attribute: false }, responseUrl: { type: String, attribute: false }, curlSyntax: { type: String, attribute: false }, fillRequestFieldsWithExample: { type: String, attribute: "fill-request-fields-with-example" }, allowTry: { type: String, attribute: "allow-try" }, showCurlBeforeTry: { type: String, attribute: "show-curl-before-try" }, renderStyle: { type: String, attribute: "render-style" }, schemaStyle: { type: String, attribute: "schema-style" }, activeSchemaTab: { type: String, attribute: "active-schema-tab" }, activeParameterSchemaTabs: { type: Object, converter: { fromAttribute: (e6) => JSON.parse(e6), toAttribute: (e6) => JSON.stringify(e6) }, attribute: "active-parameter-schema-tabs" }, schemaExpandLevel: { type: Number, attribute: "schema-expand-level" }, schemaDescriptionExpanded: { type: String, attribute: "schema-description-expanded" }, allowSchemaDescriptionExpandToggle: { type: String, attribute: "allow-schema-description-expand-toggle" }, schemaHideReadOnly: { type: String, attribute: "schema-hide-read-only" }, schemaHideWriteOnly: { type: String, attribute: "schema-hide-write-only" }, fetchCredentials: { type: String, attribute: "fetch-credentials" }, activeResponseTab: { type: String }, selectedRequestBodyType: { type: String, attribute: "selected-request-body-type" }, selectedRequestBodyExample: { type: String, attribute: "selected-request-body-example" } };
      }
      static get styles() {
        return [Ze, Je, Ke, Ye, SP, et, Xe, c2`
        *, *:before, *:after { box-sizing: border-box; }
        :where(button, input[type="checkbox"], [tabindex="0"]):focus-visible { box-shadow: var(--focus-shadow); }
        :where(input[type="text"], input[type="password"], select, textarea):focus-visible { border-color: var(--primary-color); }
        tag-input:focus-within { outline: 1px solid;}
        .read-mode {
          margin-top: 24px;
        }
        .param-name,
        .param-type {
          margin: 1px 0;
          text-align: right;
          line-height: var(--font-size-small);
        }
        .param-name {
          color: var(--fg); 
          font-family: var(--font-mono);
        }
        .param-name.deprecated { 
          color: var(--red);
        }
        .param-type{
          color: var(--light-fg); 
          font-family: var(--font-regular);
        }
        .param-constraint{
          min-width:100px;
        }
        .param-constraint:empty{
          display:none;
        }
        .top-gap{margin-top:24px;}

        .textarea {
          min-height:220px; 
          padding:5px;
          resize:vertical;
          direction: ltr;
        }
        .example:first-child {
          margin-top: -9px;
        }

        .response-message{
          font-weight:bold;
          text-overflow: ellipsis;
        }
        .response-message.error {
          color:var(--red);
        }
        .response-message.success {
          color:var(--blue);
        }

        .file-input-container {
          align-items:flex-end;
        }
        .file-input-container .input-set:first-child .file-input-remove-btn{
          visibility:hidden;
        }

        .file-input-remove-btn{
          font-size:16px;
          color:var(--red);
          outline: none;
          border: none;
          background:none;
          cursor:pointer;
        }

        .v-tab-btn {
          font-size: var(--smal-font-size);
          height:24px; 
          border:none; 
          background:none; 
          opacity: 0.3;
          cursor: pointer;
          padding: 4px 8px;
        }
        .v-tab-btn.active {
          font-weight: bold;
          background: var(--bg);
          opacity: 1;
        }

        @media only screen and (min-width: 768px) {
          .textarea {
            padding:8px;
          }
        }

        @media only screen and (max-width: 470px) {
          .hide-in-small-screen {
            display:none;
          }
        }
      `, nt];
      }
      render() {
        return q`
    <div class="col regular-font request-panel ${"read focused".includes(this.renderStyle) || "true" === this.callback ? "read-mode" : "view-mode"}">
      <div class=" ${"true" === this.callback ? "tiny-title" : "req-res-title"} "> 
        ${"true" === this.callback ? "CALLBACK REQUEST" : "REQUEST"}
      </div>
      <div>
        ${vP([this.method, this.path, this.allowTry, this.parameters, this.activeParameterSchemaTabs], () => this.inputParametersTemplate("path"))}
        ${vP([this.method, this.path, this.allowTry, this.parameters, this.activeParameterSchemaTabs], () => this.inputParametersTemplate("query"))}
        ${this.requestBodyTemplate()}
        ${vP([this.method, this.path, this.allowTry, this.parameters, this.activeParameterSchemaTabs], () => this.inputParametersTemplate("header"))}
        ${vP([this.method, this.path, this.allowTry, this.parameters, this.activeParameterSchemaTabs], () => this.inputParametersTemplate("cookie"))}
        ${"false" === this.allowTry ? "" : q`${this.apiCallTemplate()}`}
      </div>  
    </div>
    `;
      }
      async updated() {
        "true" === this.showCurlBeforeTry && this.applyCURLSyntax(this.shadowRoot), "true" === this.webhook && (this.allowTry = "false");
      }
      async saveExampleState() {
        if ("focused" === this.renderStyle) {
          [...this.shadowRoot.querySelectorAll("textarea.request-body-param-user-input")].forEach((e6) => {
            e6.dataset.user_example = e6.value;
          });
          [...this.shadowRoot.querySelectorAll('textarea[data-ptype="form-data"]')].forEach((e6) => {
            e6.dataset.user_example = e6.value;
          }), this.requestUpdate();
        }
      }
      async updateExamplesFromDataAttr() {
        if ("focused" === this.renderStyle) {
          [...this.shadowRoot.querySelectorAll("textarea.request-body-param-user-input")].forEach((e6) => {
            e6.value = e6.dataset.user_example || e6.dataset.example;
          });
          [...this.shadowRoot.querySelectorAll('textarea[data-ptype="form-data"]')].forEach((e6) => {
            e6.value = e6.dataset.user_example || e6.dataset.example;
          }), this.requestUpdate();
        }
      }
      renderExample(e6, t5, r6) {
        var n6;
        return q`
      ${"array" === t5 ? "[" : ""}
      <a
        part="anchor anchor-param-example"
        style="display:inline-block; min-width:24px; text-align:center"
        class="${"true" === this.allowTry ? "" : "inactive-link"}"
        data-example-type="${"array" === t5 ? t5 : "string"}"
        data-example="${e6.value && Array.isArray(e6.value) ? null === (n6 = e6.value) || void 0 === n6 ? void 0 : n6.join("~|~") : e6.value || ""}"
        @click="${(e7) => {
          const t6 = e7.target.closest("table").querySelector(`[data-pname="${r6}"]`);
          t6 && (t6.value = "array" === e7.target.dataset.exampleType ? e7.target.dataset.example.split("~|~") : e7.target.dataset.example);
        }}"
      > ${e6.printableValue || e6.value} </a>
      ${"array" === t5 ? "] " : ""}
    `;
      }
      renderShortFormatExamples(e6, t5, r6) {
        return q`${e6.map((e7, n6) => q`
      ${0 === n6 ? "" : "\u2503"}
      ${this.renderExample(e7, t5, r6)}`)}`;
      }
      renderLongFormatExamples(e6, t5, r6) {
        return q` <ul style="list-style-type: disclosure-closed;">
      ${e6.map((e7) => {
          var n6, o5;
          return q`
          <li>
            ${this.renderExample(e7, t5, r6)}
            ${(null === (n6 = e7.summary) || void 0 === n6 ? void 0 : n6.length) > 0 ? q`<span>&lpar;${e7.summary}&rpar;</span>` : ""}
            ${(null === (o5 = e7.description) || void 0 === o5 ? void 0 : o5.length) > 0 ? q`<p>${Q_(We(e7.description))}</p>` : ""}
          </li>
        `;
        })}
    </ul>`;
      }
      exampleListTemplate(e6, t5, r6 = []) {
        return q` ${r6.length > 0 ? q`<span style="font-weight:bold">Examples: </span>
          ${n6 = r6, n6.some((e7) => {
          var t6, r7;
          return (null === (t6 = e7.summary) || void 0 === t6 ? void 0 : t6.length) > 0 || (null === (r7 = e7.description) || void 0 === r7 ? void 0 : r7.length) > 0;
        }) ? this.renderLongFormatExamples(r6, t5, e6) : this.renderShortFormatExamples(r6, t5, e6)}` : ""}`;
        var n6;
      }
      inputParametersTemplate(e6) {
        const t5 = this.parameters ? this.parameters.filter((t6) => t6.in === e6) : [];
        if (0 === t5.length)
          return "";
        let r6 = "";
        "path" === e6 ? r6 = "PATH PARAMETERS" : "query" === e6 ? r6 = "QUERY-STRING PARAMETERS" : "header" === e6 ? r6 = "REQUEST HEADERS" : "cookie" === e6 && (r6 = "COOKIES");
        const n6 = [];
        for (const r7 of t5) {
          const [t6, o5, a2] = qP(r7);
          if (!t6)
            continue;
          const i4 = EP(t6);
          if (!i4)
            continue;
          const s6 = DP(t6, {});
          let l2 = "form", c3 = true, p2 = false;
          "query" === e6 && (r7.style && "form spaceDelimited pipeDelimited".includes(r7.style) ? l2 = r7.style : o5 && (l2 = o5), "boolean" == typeof r7.explode && (c3 = r7.explode), "boolean" == typeof r7.allowReserved && (p2 = r7.allowReserved));
          const d2 = TP(r7.examples || OP(r7.example) || OP(null == a2 ? void 0 : a2.example) || (null == a2 ? void 0 : a2.examples) || OP(i4.examples) || OP(i4.example), i4.type);
          d2.exampleVal || "object" !== i4.type || (d2.exampleVal = BP(t6, o5 || "json", "", "", "true" === this.callback || "true" === this.webhook, "true" !== this.callback && "true" !== this.webhook, true, "text")[0].exampleValue);
          const u3 = "read focused".includes(this.renderStyle) ? "200px" : "160px";
          n6.push(q`
      <tr title="${r7.deprecated ? "Deprecated" : ""}"> 
        <td rowspan="${"true" === this.allowTry ? "1" : "2"}" style="width:${u3}; min-width:100px;">
          <div class="param-name ${r7.deprecated ? "deprecated" : ""}" >
            ${r7.deprecated ? q`<span style='color:var(--red);'>✗</span>` : ""}
            ${r7.required ? q`<span style='color:var(--red)'>*</span>` : ""}
            ${r7.name}
          </div>
          <div class="param-type">
            ${"array" === i4.type ? `${i4.arrayType}` : `${i4.format ? i4.format : i4.type}`}
          </div>
        </td>  
        ${"true" === this.allowTry ? q`
            <td style="min-width:100px;" colspan="${i4.default || i4.constrain || i4.allowedValues || i4.pattern ? "1" : "2"}">
              ${"array" === i4.type ? q`
                  <tag-input class="request-param" 
                    style = "width:100%" 
                    data-ptype = "${e6}"
                    data-pname = "${r7.name}"
                    data-example = "${Array.isArray(d2.exampleVal) ? d2.exampleVal.join("~|~") : d2.exampleVal}"
                    data-param-serialize-style = "${l2}"
                    data-param-serialize-explode = "${c3}"
                    data-param-allow-reserved = "${p2}"
                    data-x-fill-example = "${r7["x-fill-example"] || "yes"}"
                    data-array = "true"
                    placeholder = "add-multiple &#x21a9;"
                    .value="${"no" === r7["x-fill-example"] ? [] : wP("true" === this.fillRequestFieldsWithExample ? Array.isArray(d2.exampleVal) ? d2.exampleVal : [d2.exampleVal] : [])}"
                  >
                  </tag-input>` : "object" === i4.type ? q`
                    <div class="tab-panel col" style="border-width:0 0 1px 0;">
                      <div class="tab-buttons row" @click="${(e7) => {
            if ("button" === e7.target.tagName.toLowerCase()) {
              const t7 = { ...this.activeParameterSchemaTabs };
              t7[r7.name] = e7.target.dataset.tab, this.activeParameterSchemaTabs = t7;
            }
          }}">
                        <button class="tab-btn ${"example" === this.activeParameterSchemaTabs[r7.name] ? "active" : ""}" data-tab = 'example'>EXAMPLE </button>
                        <button class="tab-btn ${"example" !== this.activeParameterSchemaTabs[r7.name] ? "active" : ""}" data-tab = 'schema'>SCHEMA</button>
                      </div>
                      ${"example" === this.activeParameterSchemaTabs[r7.name] ? q`<div class="tab-content col">
                          <textarea 
                            class = "textarea request-param"
                            part = "textarea textarea-param"
                            data-ptype = "${e6}-object"
                            data-pname = "${r7.name}"
                            data-example = "${d2.exampleVal}"
                            data-param-serialize-style = "${l2}"
                            data-param-serialize-explode = "${c3}"
                            data-param-allow-reserved = "${p2}"
                            data-x-fill-example = "${r7["x-fill-example"] || "yes"}"
                            spellcheck = "false"
                            .textContent="${"no" === r7["x-fill-example"] ? "" : wP("true" === this.fillRequestFieldsWithExample ? d2.exampleVal : "")}"
                            style = "resize:vertical; width:100%; height: ${"read focused".includes(this.renderStyle) ? "180px" : "120px"};"
                            @input=${(e7) => {
            const t7 = this.getRequestPanel(e7);
            this.liveCURLSyntaxUpdate(t7);
          }}
                          ></textarea>
                        </div>` : q`
                          <div class="tab-content col">
                            <schema-tree
                              class = 'json'
                              style = 'display: block'
                              .data = '${s6}'
                              schema-expand-level = "${this.schemaExpandLevel}"
                              schema-description-expanded = "${this.schemaDescriptionExpanded}"
                              allow-schema-description-expand-toggle = "${this.allowSchemaDescriptionExpandToggle}"
                              schema-hide-read-only = "${this.schemaHideReadOnly.includes(this.method)}"
                              schema-hide-write-only = "${this.schemaHideWriteOnly.includes(this.method)}"
                              exportparts = "wrap-request-btn:wrap-request-btn, btn:btn, btn-fill:btn-fill, btn-outline:btn-outline, btn-try:btn-try, btn-clear:btn-clear, btn-clear-resp:btn-clear-resp,
                                file-input:file-input, textbox:textbox, textbox-param:textbox-param, textarea:textarea, textarea-param:textarea-param, 
                                anchor:anchor, anchor-param-example:anchor-param-example"
                            > </schema-tree>
                          </div>`}
                    </div>` : q`
                    <input type="${"password" === i4.format ? "password" : "text"}" spellcheck="false" style="width:100%" 
                      class="request-param"
                      part="textbox textbox-param"
                      data-ptype="${e6}"
                      data-pname="${r7.name}" 
                      data-example="${Array.isArray(d2.exampleVal) ? d2.exampleVal.join("~|~") : d2.exampleVal}"
                      data-param-allow-reserved = "${p2}"
                      data-x-fill-example = "${r7["x-fill-example"] || "yes"}"
                      data-array="false"
                      .value="${"no" === r7["x-fill-example"] ? "" : wP("true" === this.fillRequestFieldsWithExample ? d2.exampleVal : "")}"
                      @input=${(e7) => {
            const t7 = this.getRequestPanel(e7);
            this.liveCURLSyntaxUpdate(t7);
          }}
                    />`}
            </td>` : ""}
        ${i4.default || i4.constrain || i4.allowedValues || i4.pattern ? q`
            <td colspan="${"true" === this.allowTry ? "1" : "2"}">
              <div class="param-constraint">
                ${i4.default ? q`<span style="font-weight:bold">Default: </span>${i4.default}<br/>` : ""}
                ${i4.pattern ? q`<span style="font-weight:bold">Pattern: </span>${i4.pattern}<br/>` : ""}
                ${i4.constrain ? q`${i4.constrain}<br/>` : ""}
                ${i4.allowedValues && i4.allowedValues.split("\u2503").map((e7, t7) => q`
                  ${t7 > 0 ? "\u2503" : q`<span style="font-weight:bold">Allowed: </span>`}
                  ${q`
                    <a part="anchor anchor-param-constraint" class = "${"true" === this.allowTry ? "" : "inactive-link"}"
                      data-type="${"array" === i4.type ? i4.type : "string"}"
                      data-enum="${e7.trim()}"
                      @click="${(e8) => {
            const t8 = e8.target.closest("table").querySelector(`[data-pname="${r7.name}"]`);
            t8 && ("array" === e8.target.dataset.type ? t8.value = [e8.target.dataset.enum] : t8.value = e8.target.dataset.enum);
          }}"
                    >${e7}</a>`}`)}
              </div>
            </td>` : q`<td></td>`}
      </tr>
      <tr>
        ${"true" === this.allowTry ? q`<td style="border:none"> </td>` : ""}
        <td colspan="2" style="border:none">
          <span class="m-markdown-small">${Q_(We(r7.description || ""))}</span>
          ${this.exampleListTemplate.call(this, r7.name, i4.type, d2.exampleList)}
        </td>
      </tr>
    `);
        }
        return q`
    <div class="table-title top-gap">${r6}</div>
    <div style="display:block; overflow-x:auto; max-width:100%;">
      <table role="presentation" class="m-table" style="width:100%; word-break:break-word;">
        ${n6}
      </table>
    </div>`;
      }
      async beforeNavigationFocusedMode() {
      }
      async afterNavigationFocusedMode() {
        this.selectedRequestBodyType = "", this.selectedRequestBodyExample = "", this.updateExamplesFromDataAttr(), this.clearResponseData();
      }
      onSelectExample(e6) {
        this.selectedRequestBodyExample = e6.target.value;
        const t5 = e6.target;
        window.setTimeout((e7) => {
          const t6 = e7.closest(".example-panel").querySelector(".request-body-param");
          e7.closest(".example-panel").querySelector(".request-body-param-user-input").value = t6.innerText;
          const r6 = this.getRequestPanel({ target: e7 });
          this.liveCURLSyntaxUpdate(r6);
        }, 0, t5);
      }
      onMimeTypeChange(e6) {
        this.selectedRequestBodyType = e6.target.value;
        const t5 = e6.target;
        this.selectedRequestBodyExample = "", window.setTimeout((e7) => {
          const t6 = e7.closest(".request-body-container").querySelector(".request-body-param");
          if (t6) {
            e7.closest(".request-body-container").querySelector(".request-body-param-user-input").value = t6.innerText;
          }
        }, 0, t5);
      }
      requestBodyTemplate() {
        if (!this.request_body)
          return "";
        if (0 === Object.keys(this.request_body).length)
          return "";
        let e6 = "", t5 = "", r6 = "", n6 = "", o5 = "";
        const a2 = [], { content: i4 } = this.request_body;
        for (const e7 in i4)
          a2.push({ mimeType: e7, schema: i4[e7].schema, example: i4[e7].example, examples: i4[e7].examples }), this.selectedRequestBodyType || (this.selectedRequestBodyType = e7);
        return e6 = 1 === a2.length ? "" : q`
        <select style="min-width:100px; max-width:100%;  margin-bottom:-1px;" @change = '${(e7) => this.onMimeTypeChange(e7)}'>
          ${a2.map((e7) => q`
            <option value = '${e7.mimeType}' ?selected = '${e7.mimeType === this.selectedRequestBodyType}'>
              ${e7.mimeType}
            </option> `)}
        </select>
      `, a2.forEach((e7) => {
          let a3, i5 = [];
          if (this.selectedRequestBodyType.includes("json") || this.selectedRequestBodyType.includes("xml") || this.selectedRequestBodyType.includes("text") || this.selectedRequestBodyType.includes("jose"))
            e7.mimeType === this.selectedRequestBodyType && (i5 = BP(e7.schema, e7.mimeType, e7.examples, e7.example, "true" === this.callback || "true" === this.webhook, "true" !== this.callback && "true" !== this.webhook, "text", false), this.selectedRequestBodyExample || (this.selectedRequestBodyExample = i5.length > 0 ? i5[0].exampleId : ""), o5 = q`
            ${o5}
            <div class = 'example-panel border-top pad-top-8'>
              ${1 === i5.length ? "" : q`
                  <select style="min-width:100px; max-width:100%;  margin-bottom:-1px;" @change='${(e8) => this.onSelectExample(e8)}'>
                    ${i5.map((e8) => q`<option value="${e8.exampleId}" ?selected=${e8.exampleId === this.selectedRequestBodyExample} > 
                      ${e8.exampleSummary.length > 80 ? e8.exampleId : e8.exampleSummary ? e8.exampleSummary : e8.exampleId} 
                    </option>`)}
                  </select>
                `}
              ${i5.filter((e8) => e8.exampleId === this.selectedRequestBodyExample).map((t6) => q`
                <div class="example ${t6.exampleId === this.selectedRequestBodyExample ? "example-selected" : ""}" data-example = '${t6.exampleId}'>
                  ${t6.exampleSummary && t6.exampleSummary.length > 80 ? q`<div style="padding: 4px 0"> ${t6.exampleSummary} </div>` : ""}
                  ${t6.exampleDescription ? q`<div class="m-markdown-small" style="padding: 4px 0"> ${Q_(We(t6.exampleDescription || ""))} </div>` : ""}
                  <!-- This pre(hidden) is to store the original example value, this will remain unchanged when users switches from one example to another, its is used to populate the editable textarea -->
                  <pre 
                    class = "textarea is-hidden request-body-param ${e7.mimeType.substring(e7.mimeType.indexOf("/") + 1)}" 
                    spellcheck = "false"
                    data-ptype = "${e7.mimeType}" 
                    style="width:100%; resize:vertical; display:none"
                  >${"text" === t6.exampleFormat ? t6.exampleValue : JSON.stringify(t6.exampleValue, null, 2)}</pre>

                  <!-- this textarea is for user to edit the example -->
                  <textarea 
                    class = "textarea request-body-param-user-input"
                    part = "textarea textarea-param"
                    spellcheck = "false"
                    data-ptype = "${e7.mimeType}" 
                    data-example = "${"text" === t6.exampleFormat ? t6.exampleValue : JSON.stringify(t6.exampleValue, null, 2)}"
                    data-example-format = "${t6.exampleFormat}"
                    style="width:100%; resize:vertical;"
                    .textContent = "${"true" === this.fillRequestFieldsWithExample ? "text" === t6.exampleFormat ? t6.exampleValue : JSON.stringify(t6.exampleValue, null, 2) : ""}"
                    @input=${(e8) => {
              const t7 = this.getRequestPanel(e8);
              this.liveCURLSyntaxUpdate(t7);
            }}
                  ></textarea>
                </div>  
              `)}

            </div>
          `);
          else if (this.selectedRequestBodyType.includes("form-urlencoded") || this.selectedRequestBodyType.includes("form-data")) {
            if (e7.mimeType === this.selectedRequestBodyType) {
              const t6 = BP(e7.schema, e7.mimeType, e7.examples, e7.example, "true" === this.callback || "true" === this.webhook, "true" !== this.callback && "true" !== this.webhook, "text", false);
              e7.schema && (r6 = this.formDataTemplate(e7.schema, e7.mimeType, t6[0] ? t6[0].exampleValue : ""));
            }
          } else
            /^audio\/|^image\/|^video\/|^font\/|tar$|zip$|7z$|rtf$|msword$|excel$|\/pdf$|\/octet-stream$/.test(this.selectedRequestBodyType) && e7.mimeType === this.selectedRequestBodyType && (t5 = q`
            <div class = "small-font-size bold-text row">
              <input type="file" part="file-input" style="max-width:100%" class="request-body-param-file" data-ptype="${e7.mimeType}" spellcheck="false" />
            </div>  
          `);
          (e7.mimeType.includes("json") || e7.mimeType.includes("xml") || e7.mimeType.includes("text") || this.selectedRequestBodyType.includes("jose")) && (a3 = DP(e7.schema, {}), "table" === this.schemaStyle ? n6 = q`
            ${n6}
            <schema-table
              class = '${e7.mimeType.substring(e7.mimeType.indexOf("/") + 1)}'
              style = 'display: ${this.selectedRequestBodyType === e7.mimeType ? "block" : "none"};'
              .data = '${a3}'
              schema-expand-level = "${this.schemaExpandLevel}"
              schema-description-expanded = "${this.schemaDescriptionExpanded}"
              allow-schema-description-expand-toggle = "${this.allowSchemaDescriptionExpandToggle}"
              schema-hide-read-only = "${this.schemaHideReadOnly}"
              schema-hide-write-only = "${this.schemaHideWriteOnly}"
              exportparts = "schema-description:schema-description, schema-multiline-toggle:schema-multiline-toggle"
            > </schema-table>
          ` : "tree" === this.schemaStyle && (n6 = q`
            ${n6}
            <schema-tree
              class = "${e7.mimeType.substring(e7.mimeType.indexOf("/") + 1)}"
              style = "display: ${this.selectedRequestBodyType === e7.mimeType ? "block" : "none"};"
              .data = "${a3}"
              schema-expand-level = "${this.schemaExpandLevel}"
              schema-description-expanded = "${this.schemaDescriptionExpanded}"
              allow-schema-description-expand-toggle = "${this.allowSchemaDescriptionExpandToggle}"
              schema-hide-read-only = "${this.schemaHideReadOnly}"
              schema-hide-write-only = "${this.schemaHideWriteOnly}"
              exportparts = "schema-description:schema-description, schema-multiline-toggle:schema-multiline-toggle"
            > </schema-tree>
          `));
        }), q`
      <div class='request-body-container' data-selected-request-body-type="${this.selectedRequestBodyType}">
        <div class="table-title top-gap row">
          REQUEST BODY ${this.request_body.required ? q`<span class="mono-font" style='color:var(--red)'>*</span>` : ""} 
          <span style = "font-weight:normal; margin-left:5px"> ${this.selectedRequestBodyType}</span>
          <span style="flex:1"></span>
          ${e6}
        </div>
        ${this.request_body.description ? q`<div class="m-markdown" style="margin-bottom:12px">${Q_(We(this.request_body.description))}</div>` : ""}
        
        ${this.selectedRequestBodyType.includes("json") || this.selectedRequestBodyType.includes("xml") || this.selectedRequestBodyType.includes("text") || this.selectedRequestBodyType.includes("jose") ? q`
            <div class="tab-panel col" style="border-width:0 0 1px 0;">
              <div class="tab-buttons row" @click="${(e7) => {
          "button" === e7.target.tagName.toLowerCase() && (this.activeSchemaTab = e7.target.dataset.tab);
        }}">
                <button class="tab-btn ${"example" === this.activeSchemaTab ? "active" : ""}" data-tab = 'example'>EXAMPLE</button>
                <button class="tab-btn ${"example" !== this.activeSchemaTab ? "active" : ""}" data-tab = 'schema'>SCHEMA</button>
              </div>
              ${q`<div class="tab-content col" style="display:${"example" === this.activeSchemaTab ? "block" : "none"};"> ${o5}</div>`}
              ${q`<div class="tab-content col" style="display:${"example" === this.activeSchemaTab ? "none" : "block"};"> ${n6}</div>`}
            </div>` : q`  
            ${t5}
            ${r6}`}
      </div>  
    `;
      }
      formDataParamAsObjectTemplate(e6, t5, r6) {
        var n6;
        const o5 = DP(t5, {}), a2 = BP(t5, "json", t5.examples, t5.example, "true" === this.callback || "true" === this.webhook, "true" !== this.callback && "true" !== this.webhook, "text", false);
        return q`
      <div class="tab-panel row" style="min-height:220px; border-left: 6px solid var(--light-border-color); align-items: stretch;">
        <div style="width:24px; background-color:var(--light-border-color)">
          <div class="row" style="flex-direction:row-reverse; width:160px; height:24px; transform:rotate(270deg) translateX(-160px); transform-origin:top left; display:block;" @click="${(e7) => {
          if (e7.target.classList.contains("v-tab-btn")) {
            const { tab: t6 } = e7.target.dataset;
            if (t6) {
              const r7 = e7.target.closest(".tab-panel"), n7 = r7.querySelector(`.v-tab-btn[data-tab="${t6}"]`), o6 = [...r7.querySelectorAll(`.v-tab-btn:not([data-tab="${t6}"])`)], a3 = r7.querySelector(`.tab-content[data-tab="${t6}"]`), i4 = [...r7.querySelectorAll(`.tab-content:not([data-tab="${t6}"])`)];
              n7.classList.add("active"), a3.style.display = "block", o6.forEach((e8) => {
                e8.classList.remove("active");
              }), i4.forEach((e8) => {
                e8.style.display = "none";
              });
            }
          }
          "button" === e7.target.tagName.toLowerCase() && (this.activeSchemaTab = e7.target.dataset.tab);
        }}">
          <button class="v-tab-btn ${"example" === this.activeSchemaTab ? "active" : ""}" data-tab = 'example'>EXAMPLE</button>
          <button class="v-tab-btn ${"example" !== this.activeSchemaTab ? "active" : ""}" data-tab = 'schema'>SCHEMA</button>
        </div>
      </div>
      ${q`
        <div class="tab-content col" data-tab = 'example' style="display:${"example" === this.activeSchemaTab ? "block" : "none"}; padding-left:5px; width:100%"> 
          <textarea 
            class = "textarea"
            part = "textarea textarea-param"
            style = "width:100%; border:none; resize:vertical;" 
            data-array = "false" 
            data-ptype = "${r6.includes("form-urlencode") ? "form-urlencode" : "form-data"}"
            data-pname = "${e6}"
            data-example = "${(null === (n6 = a2[0]) || void 0 === n6 ? void 0 : n6.exampleValue) || ""}"
            .textContent = "${"true" === this.fillRequestFieldsWithExample ? a2[0].exampleValue : ""}"
            spellcheck = "false"
          ></textarea>
        </div>`}
      ${q`
        <div class="tab-content col" data-tab = 'schema' style="display:${"example" !== this.activeSchemaTab ? "block" : "none"}; padding-left:5px; width:100%;"> 
          <schema-tree
            .data = '${o5}'
            schema-expand-level = "${this.schemaExpandLevel}"
            schema-description-expanded = "${this.schemaDescriptionExpanded}"
            allow-schema-description-expand-toggle = "${this.allowSchemaDescriptionExpandToggle}",
          > </schema-tree>
        </div>`}
      </div>
    `;
      }
      formDataTemplate(e6, t5, r6 = "") {
        const n6 = [];
        if (e6.properties) {
          for (const r7 in e6.properties) {
            var o5, a2;
            const i4 = e6.properties[r7];
            if (i4.readOnly)
              continue;
            const s6 = i4.examples || i4.example || "", l2 = i4.type, c3 = EP(i4), p2 = "read focused".includes(this.renderStyle) ? "200px" : "160px", d2 = TP(c3.examples || c3.example, c3.type);
            n6.push(q`
        <tr title="${i4.deprecated ? "Deprecated" : ""}"> 
          <td style="width:${p2}; min-width:100px;">
            <div class="param-name ${i4.deprecated ? "deprecated" : ""}">
              ${r7}${null !== (o5 = e6.required) && void 0 !== o5 && o5.includes(r7) || i4.required ? q`<span style='color:var(--red);'>*</span>` : ""}
            </div>
            <div class="param-type">${c3.type}</div>
          </td>  
          <td 
            style="${"object" === l2 ? "width:100%; padding:0;" : "true" === this.allowTry ? "" : "display:none;"} min-width:100px;" 
            colspan="${"object" === l2 ? 2 : 1}">
            ${"array" === l2 ? "binary" === (null === (a2 = i4.items) || void 0 === a2 ? void 0 : a2.format) ? q`
                <div class="file-input-container col" style='align-items:flex-end;' @click="${(e7) => this.onAddRemoveFileInput(e7, r7, t5)}">
                  <div class='input-set row'>
                    <input 
                      type = "file"
                      part = "file-input"
                      style = "width:100%" 
                      data-pname = "${r7}" 
                      data-ptype = "${t5.includes("form-urlencode") ? "form-urlencode" : "form-data"}"
                      data-array = "false" 
                      data-file-array = "true" 
                    />
                    <button class="file-input-remove-btn"> &#x2715; </button>
                  </div>  
                  <button class="m-btn primary file-input-add-btn" part="btn btn-fill" style="margin:2px 25px 0 0; padding:2px 6px;">ADD</button>
                </div>  
                ` : q`
                  <tag-input
                    style = "width:100%" 
                    data-ptype = "${t5.includes("form-urlencode") ? "form-urlencode" : "form-data"}"
                    data-pname = "${r7}"
                    data-example = "${Array.isArray(s6) ? s6.join("~|~") : s6}"
                    data-array = "true"
                    placeholder = "add-multiple &#x21a9;"
                    .value = "${Array.isArray(s6) ? Array.isArray(s6[0]) ? s6[0] : [s6[0]] : [s6]}"
                  >
                  </tag-input>
                ` : q`
                ${"object" === l2 ? this.formDataParamAsObjectTemplate.call(this, r7, i4, t5) : q`
                    ${"true" === this.allowTry ? q`<input
                          .value = "${"true" === this.fillRequestFieldsWithExample ? d2.exampleVal : ""}"
                          spellcheck = "false"
                          type = "${"binary" === i4.format ? "file" : "password" === i4.format ? "password" : "text"}"
                          part = "textbox textbox-param"
                          style = "width:100%"
                          data-ptype = "${t5.includes("form-urlencode") ? "form-urlencode" : "form-data"}"
                          data-pname = "${r7}"
                          data-example = "${Array.isArray(s6) ? s6[0] : s6}"
                          data-array = "false"
                        />` : ""}
                    `}`}
          </td>
          ${"object" === l2 ? "" : q`
              <td>
                ${c3.default || c3.constrain || c3.allowedValues || c3.pattern ? q`
                    <div class="param-constraint">
                      ${c3.default ? q`<span style="font-weight:bold">Default: </span>${c3.default}<br/>` : ""}
                      ${c3.pattern ? q`<span style="font-weight:bold">Pattern: </span>${c3.pattern}<br/>` : ""}
                      ${c3.constrain ? q`${c3.constrain}<br/>` : ""}
                      ${c3.allowedValues && c3.allowedValues.split("\u2503").map((e7, t6) => q`
                        ${t6 > 0 ? "\u2503" : q`<span style="font-weight:bold">Allowed: </span>`}
                        ${q`
                          <a part="anchor anchor-param-constraint" class = "${"true" === this.allowTry ? "" : "inactive-link"}"
                            data-type="${"array" === c3.type ? c3.type : "string"}"
                            data-enum="${e7.trim()}"
                            @click="${(e8) => {
              const t7 = e8.target.closest("table").querySelector(`[data-pname="${r7}"]`);
              t7 && ("array" === e8.target.dataset.type ? t7.value = [e8.target.dataset.enum] : t7.value = e8.target.dataset.enum);
            }}"
                          > 
                            ${e7} 
                          </a>`}`)}
                    </div>` : ""}
              </td>`}
        </tr>
        ${"object" === l2 ? "" : q`
            <tr>
              <td style="border:none"> </td>
              <td colspan="2" style="border:none; margin-top:0; padding:0 5px 8px 5px;"> 
                <span class="m-markdown-small">${Q_(We(i4.description || ""))}</span>
                ${this.exampleListTemplate.call(this, r7, c3.type, d2.exampleList)}
              </td>
            </tr>
          `}`);
          }
          return q`
        <table role="presentation" style="width:100%;" class="m-table">
          ${n6}
        </table>
      `;
        }
        return q`
      <textarea
        class = "textarea dynamic-form-param ${t5}"
        part = "textarea textarea-param"
        spellcheck = "false"
        data-pname="dynamic-form" 
        data-ptype="${t5}"
        .textContent = "${r6}"
        style="width:100%"
      ></textarea>
      ${e6.description ? q`<span class="m-markdown-small">${Q_(We(e6.description))}</span>` : ""}
    `;
      }
      curlSyntaxTemplate(e6 = "flex") {
        return q`
      <div class="col m-markdown" style="flex:1; display:${e6}; position:relative; max-width: 100%;">
        <button  class="toolbar-btn" style = "position:absolute; top:12px; right:8px" @click='${(e7) => {
          st(this.curlSyntax.replace(/\\$/, ""), e7);
        }}' part="btn btn-fill"> Copy </button>
        <pre style="white-space:pre"><code>${Q_(Ge().highlight(this.curlSyntax.trim().replace(/\\$/, ""), Ge().languages.shell, "shell"))}</code></pre>
      </div>
      `;
      }
      apiResponseTabTemplate() {
        let e6 = "", t5 = "";
        if (!this.responseIsBlob)
          if (this.responseHeaders.includes("application/x-ndjson")) {
            e6 = "json";
            const r6 = this.responseText.split("\n").map((t6) => Ge().highlight(t6, Ge().languages[e6], e6)).join("\n");
            t5 = q`<code>${Q_(r6)}</code>`;
          } else
            this.responseHeaders.includes("json") ? (e6 = "json", t5 = q`<code>${Q_(Ge().highlight(this.responseText, Ge().languages[e6], e6))}</code>`) : this.responseHeaders.includes("html") || this.responseHeaders.includes("xml") ? (e6 = "html", t5 = q`<code>${Q_(Ge().highlight(this.responseText, Ge().languages[e6], e6))}</code>`) : (e6 = "text", t5 = q`<code>${this.responseText}</code>`);
        return q`
      <div class="row" style="font-size:var(--font-size-small); margin:5px 0">
        <div class="response-message ${this.responseStatus}">Response Status: ${this.responseMessage}</div>
        <div style="flex:1"></div>
        <button class="m-btn" part="btn btn-outline btn-clear-response" @click="${this.clearResponseData}">CLEAR RESPONSE</button>
      </div>
      <div class="tab-panel col" style="border-width:0 0 1px 0;">
        <div id="tab_buttons" class="tab-buttons row" @click="${(e7) => {
          false !== e7.target.classList.contains("tab-btn") && (this.activeResponseTab = e7.target.dataset.tab);
        }}">
          <button class="tab-btn ${"response" === this.activeResponseTab ? "active" : ""}" data-tab = 'response' > RESPONSE</button>
          <button class="tab-btn ${"headers" === this.activeResponseTab ? "active" : ""}"  data-tab = 'headers' > RESPONSE HEADERS</button>
          ${"true" === this.showCurlBeforeTry ? "" : q`<button class="tab-btn ${"curl" === this.activeResponseTab ? "active" : ""}" data-tab = 'curl'>CURL</button>`}
        </div>
        ${this.responseIsBlob ? q`
            <div class="tab-content col" style="flex:1; display:${"response" === this.activeResponseTab ? "flex" : "none"};">
              <button class="m-btn thin-border mar-top-8" style="width:135px" @click='${(e7) => {
          pt(this.responseBlobUrl, this.respContentDisposition);
        }}' part="btn btn-outline">
                DOWNLOAD
              </button>
              ${"view" === this.responseBlobType ? q`<button class="m-btn thin-border mar-top-8" style="width:135px"  @click='${(e7) => {
          dt(this.responseBlobUrl);
        }}' part="btn btn-outline">VIEW (NEW TAB)</button>` : ""}
            </div>` : q`
            <div class="tab-content col m-markdown" style="flex:1; display:${"response" === this.activeResponseTab ? "flex" : "none"};" >
              <button class="toolbar-btn" style="position:absolute; top:12px; right:8px" @click='${(e7) => {
          st(this.responseText, e7);
        }}' part="btn btn-fill"> Copy </button>
              <pre style="white-space:pre; min-height:50px; height:var(--resp-area-height, 400px); resize:vertical; overflow:auto">${t5}</pre>
            </div>`}
        <div class="tab-content col m-markdown" style="flex:1; display:${"headers" === this.activeResponseTab ? "flex" : "none"};" >
          <button  class="toolbar-btn" style = "position:absolute; top:12px; right:8px" @click='${(e7) => {
          st(this.responseHeaders, e7);
        }}' part="btn btn-fill"> Copy </button>
          <pre style="white-space:pre"><code>${Q_(Ge().highlight(this.responseHeaders, Ge().languages.css, "css"))}</code></pre>
        </div>
        ${"true" === this.showCurlBeforeTry ? "" : this.curlSyntaxTemplate("curl" === this.activeResponseTab ? "flex" : "none")}
      </div>`;
      }
      apiCallTemplate() {
        var e6, t5;
        let r6 = "";
        this.servers && this.servers.length > 0 && (r6 = q`
        <select style="min-width:100px;" @change='${(e7) => {
          this.serverUrl = e7.target.value;
        }}'>
          ${this.servers.map((e7) => q`<option value = "${e7.url}"> ${e7.url} - ${e7.description} </option>`)}
        </select>
      `);
        const n6 = q`
      <div style="display:flex; flex-direction:column;">
        ${r6}
        ${this.serverUrl ? q`
            <div style="display:flex; align-items:baseline;">
              <div style="font-weight:bold; padding-right:5px;">API Server</div> 
              <span class = "gray-text"> ${this.serverUrl} </span>
            </div>
          ` : ""}
      </div>  
    `;
        return q`
    <div style="display:flex; align-items:flex-end; margin:16px 0; font-size:var(--font-size-small);" part="wrap-request-btn">
      <div class="hide-in-small-screen" style="flex-direction:column; margin:0; width:calc(100% - 60px);">
        <div style="display:flex; flex-direction:row; align-items:center; overflow:hidden;"> 
          ${n6}
        </div>
        <div style="display:flex;">
          <div style="font-weight:bold; padding-right:5px;">Authentication</div>
          ${(null === (e6 = this.security) || void 0 === e6 ? void 0 : e6.length) > 0 ? q`
              ${this.api_keys.length > 0 ? q`<div style="color:var(--blue); overflow:hidden;"> 
                    ${1 === this.api_keys.length ? `${null === (t5 = this.api_keys[0]) || void 0 === t5 ? void 0 : t5.typeDisplay} in ${this.api_keys[0].in}` : `${this.api_keys.length} API keys applied`} 
                  </div>` : q`<div class="gray-text">Required  <span style="color:var(--red)">(None Applied)</span>`}` : q`<span class="gray-text"> Not Required </span>`}
        </div>
      </div>
      ${this.parameters.length > 0 || this.request_body ? q`
            <button class="m-btn thin-border" part="btn btn-outline btn-fill" style="margin-right:5px;" @click="${this.onFillRequestData}" title="Fills with example data (if provided)">
              FILL EXAMPLE
            </button>
            <button class="m-btn thin-border" part="btn btn-outline btn-clear" style="margin-right:5px;" @click="${this.onClearRequestData}">
              CLEAR
            </button>` : ""}
      <button class="m-btn primary thin-border" part="btn btn-try" @click="${this.onTryClick}">TRY</button>
    </div>
    <div class="row" style="font-size:var(--font-size-small); margin:5px 0">
      ${"true" === this.showCurlBeforeTry ? this.curlSyntaxTemplate() : ""}
    </div>
    ${"" === this.responseMessage ? "" : this.apiResponseTabTemplate()}
    `;
      }
      async onFillRequestData(e6) {
        [...e6.target.closest(".request-panel").querySelectorAll("input, tag-input, textarea:not(.is-hidden)")].forEach((e7) => {
          e7.dataset.example && ("TAG-INPUT" === e7.tagName.toUpperCase() ? e7.value = e7.dataset.example.split("~|~") : e7.value = e7.dataset.example);
        });
      }
      async onClearRequestData(e6) {
        [...e6.target.closest(".request-panel").querySelectorAll("input, tag-input, textarea:not(.is-hidden)")].forEach((e7) => {
          e7.value = "";
        });
      }
      buildFetchURL(e6) {
        let t5;
        const r6 = [...e6.querySelectorAll("[data-ptype='path']")], n6 = [...e6.querySelectorAll("[data-ptype='query']")], o5 = [...e6.querySelectorAll("[data-ptype='query-object']")];
        t5 = this.path, r6.map((e7) => {
          t5 = t5.replace(`{${e7.dataset.pname}}`, encodeURIComponent(e7.value));
        });
        const a2 = /* @__PURE__ */ new Map(), i4 = [];
        n6.length > 0 && n6.forEach((e7) => {
          const t6 = new URLSearchParams();
          if ("true" === e7.dataset.paramAllowReserved && i4.push(e7.dataset.pname), "false" === e7.dataset.array)
            "" !== e7.value && t6.append(e7.dataset.pname, e7.value);
          else {
            const { paramSerializeStyle: r7, paramSerializeExplode: n7 } = e7.dataset;
            let o6 = e7.value && Array.isArray(e7.value) ? e7.value : [];
            o6 = Array.isArray(o6) ? o6.filter((e8) => "" !== e8) : [], o6.length > 0 && ("spaceDelimited" === r7 ? t6.append(e7.dataset.pname, o6.join(" ").replace(/^\s|\s$/g, "")) : "pipeDelimited" === r7 ? t6.append(e7.dataset.pname, o6.join("|").replace(/^\||\|$/g, "")) : "true" === n7 ? o6.forEach((r8) => {
              t6.append(e7.dataset.pname, r8);
            }) : t6.append(e7.dataset.pname, o6.join(",").replace(/^,|,$/g, "")));
          }
          t6.toString() && a2.set(e7.dataset.pname, t6);
        }), o5.length > 0 && o5.map((e7) => {
          const t6 = new URLSearchParams();
          try {
            let r7 = {};
            const { paramSerializeStyle: n7, paramSerializeExplode: o6 } = e7.dataset;
            if (r7 = Object.assign(r7, JSON.parse(e7.value.replace(/\s+/g, " "))), "true" === e7.dataset.paramAllowReserved && i4.push(e7.dataset.pname), "json xml".includes(n7))
              "json" === n7 ? t6.append(e7.dataset.pname, JSON.stringify(r7)) : "xml" === n7 && t6.append(e7.dataset.pname, jP(r7));
            else
              for (const e8 in r7)
                "object" == typeof r7[e8] ? Array.isArray(r7[e8]) && ("spaceDelimited" === n7 ? t6.append(e8, r7[e8].join(" ")) : "pipeDelimited" === n7 ? t6.append(e8, r7[e8].join("|")) : "true" === o6 ? r7[e8].forEach((r8) => {
                  t6.append(e8, r8);
                }) : t6.append(e8, r7[e8])) : t6.append(e8, r7[e8]);
          } catch (t7) {
            console.error("RapiDoc: unable to parse %s into object", e7.value);
          }
          t6.toString() && a2.set(e7.dataset.pname, t6);
        });
        let s6 = "";
        return a2.size && (a2.forEach((e7, t6) => {
          i4.includes(t6) ? (s6 += `${t6}=`, s6 += e7.getAll(t6).join(`&${t6}=`), s6 += "&") : s6 += `${e7.toString()}&`;
        }), s6 = s6.slice(0, -1)), 0 !== s6.length && (t5 = `${t5}${t5.includes("?") ? "&" : "?"}${s6}`), this.api_keys.filter((e7) => "query" === e7.in).forEach((e7) => {
          t5 = `${t5}${t5.includes("?") ? "&" : "?"}${e7.name}=${encodeURIComponent(e7.finalKeyValue)}`;
        }), t5 = `${this.serverUrl.replace(/\/$/, "")}${t5}`, t5;
      }
      buildFetchHeaders(e6) {
        var t5;
        const r6 = null === (t5 = this.closest(".expanded-req-resp-container, .req-resp-container")) || void 0 === t5 ? void 0 : t5.getElementsByTagName("api-response")[0], n6 = [...e6.querySelectorAll("[data-ptype='header']")], o5 = e6.querySelector(".request-body-container"), a2 = null == r6 ? void 0 : r6.selectedMimeType, i4 = new Headers();
        if (a2 ? i4.append("Accept", a2) : this.accept && i4.append("Accept", this.accept), this.api_keys.filter((e7) => "header" === e7.in).forEach((e7) => {
          i4.append(e7.name, e7.finalKeyValue);
        }), n6.map((e7) => {
          e7.value && i4.append(e7.dataset.pname, e7.value);
        }), o5) {
          const e7 = o5.dataset.selectedRequestBodyType;
          e7.includes("form-data") || i4.append("Content-Type", e7);
        }
        return i4;
      }
      buildFetchBodyOptions(e6) {
        const t5 = e6.querySelector(".request-body-container"), r6 = { method: this.method.toUpperCase() };
        if (t5) {
          const n6 = t5.dataset.selectedRequestBodyType;
          if (n6.includes("form-urlencoded")) {
            const t6 = e6.querySelector("[data-ptype='dynamic-form']");
            if (t6) {
              const e7 = t6.value, n7 = new URLSearchParams();
              let o5, a2 = true;
              if (e7)
                try {
                  o5 = JSON.parse(e7);
                } catch (e8) {
                  a2 = false, console.warn("RapiDoc: Invalid JSON provided", e8);
                }
              else
                a2 = false;
              if (a2) {
                for (const e8 in o5)
                  n7.append(e8, JSON.stringify(o5[e8]));
                r6.body = n7;
              }
            } else {
              const t7 = [...e6.querySelectorAll("[data-ptype='form-urlencode']")], n7 = new URLSearchParams();
              t7.filter((e7) => "file" !== e7.type).forEach((e7) => {
                if ("false" === e7.dataset.array)
                  e7.value && n7.append(e7.dataset.pname, e7.value);
                else {
                  const t8 = e7.value && Array.isArray(e7.value) ? e7.value.join(",") : "";
                  n7.append(e7.dataset.pname, t8);
                }
              }), r6.body = n7;
            }
          } else if (n6.includes("form-data")) {
            const t6 = new FormData();
            [...e6.querySelectorAll("[data-ptype='form-data']")].forEach((e7) => {
              "false" === e7.dataset.array ? "file" === e7.type && e7.files[0] ? t6.append(e7.dataset.pname, e7.files[0], e7.files[0].name) : e7.value && t6.append(e7.dataset.pname, e7.value) : e7.value && Array.isArray(e7.value) && t6.append(e7.dataset.pname, e7.value.join(","));
            }), r6.body = t6;
          } else if (/^audio\/|^image\/|^video\/|^font\/|tar$|zip$|7z$|rtf$|msword$|excel$|\/pdf$|\/octet-stream$/.test(n6)) {
            const t6 = e6.querySelector(".request-body-param-file");
            null != t6 && t6.files[0] && (r6.body = t6.files[0]);
          } else if (n6.includes("json") || n6.includes("xml") || n6.includes("text")) {
            const t6 = e6.querySelector(".request-body-param-user-input");
            null != t6 && t6.value && (r6.body = t6.value);
          }
        }
        return r6;
      }
      async onTryClick(e6) {
        const t5 = e6.target, r6 = t5.closest(".request-panel"), n6 = this.buildFetchURL(r6), o5 = this.buildFetchBodyOptions(r6), a2 = this.buildFetchHeaders(r6);
        this.responseUrl = "", this.responseHeaders = [], this.curlSyntax = this.generateCURLSyntax(n6, a2, o5, r6), this.responseStatus = "success", this.responseIsBlob = false, this.respContentDisposition = "", this.responseBlobUrl && (URL.revokeObjectURL(this.responseBlobUrl), this.responseBlobUrl = ""), this.fetchCredentials && (o5.credentials = this.fetchCredentials);
        const i4 = new AbortController(), { signal: s6 } = i4;
        o5.headers = a2;
        const l2 = { url: n6, ...o5 };
        this.dispatchEvent(new CustomEvent("before-try", { bubbles: true, composed: true, detail: { request: l2, controller: i4 } }));
        const c3 = { method: l2.method, headers: l2.headers, credentials: l2.credentials, body: l2.body }, p2 = new Request(l2.url, c3);
        let d2, u3;
        try {
          let e7, r7, n7;
          t5.disabled = true, this.responseText = "\u231B", this.responseMessage = "", this.requestUpdate();
          const o6 = performance.now();
          d2 = await fetch(p2, { signal: s6 });
          const a3 = performance.now();
          u3 = d2.clone(), t5.disabled = false, this.responseMessage = q`${d2.statusText ? `${d2.statusText}:${d2.status}` : d2.status} <div style="color:var(--light-fg)"> Took ${Math.round(a3 - o6)} milliseconds </div>`, this.responseUrl = d2.url;
          const i5 = {};
          d2.headers.forEach((e8, t6) => {
            i5[t6] = e8, this.responseHeaders = `${this.responseHeaders}${t6}: ${e8}
`;
          });
          const l3 = d2.headers.get("content-type");
          if (0 === (await d2.clone().text()).length)
            this.responseText = "";
          else if (l3) {
            if ("application/x-ndjson" === l3)
              this.responseText = await d2.text();
            else if (l3.includes("json"))
              if (/charset=[^"']+/.test(l3)) {
                const e8 = l3.split("charset=")[1], t6 = await d2.arrayBuffer();
                try {
                  n7 = new TextDecoder(e8).decode(t6);
                } catch {
                  n7 = new TextDecoder("utf-8").decode(t6);
                }
                try {
                  r7 = JSON.parse(n7), this.responseText = JSON.stringify(r7, null, 2);
                } catch {
                  this.responseText = n7;
                }
              } else
                r7 = await d2.json(), this.responseText = JSON.stringify(r7, null, 2);
            else
              /^font\/|tar$|zip$|7z$|rtf$|msword$|excel$|\/pdf$|\/octet-stream$|^application\/vnd\./.test(l3) ? (this.responseIsBlob = true, this.responseBlobType = "download") : /^audio|^image|^video/.test(l3) ? (this.responseIsBlob = true, this.responseBlobType = "view") : (n7 = await d2.text(), l3.includes("xml") ? this.responseText = kP()(n7, { textNodesOnSameLine: true, indentor: "  " }) : this.responseText = n7);
            if (this.responseIsBlob) {
              const t6 = d2.headers.get("content-disposition");
              this.respContentDisposition = t6 ? t6.split("filename=")[1].replace(/"|'/g, "") : "filename", e7 = await d2.blob(), this.responseBlobUrl = URL.createObjectURL(e7);
            }
          } else
            n7 = await d2.text(), this.responseText = n7;
          this.dispatchEvent(new CustomEvent("after-try", { bubbles: true, composed: true, detail: { request: p2, response: u3, responseHeaders: i5, responseBody: r7 || n7 || e7, responseStatus: u3.ok } }));
        } catch (e7) {
          t5.disabled = false, "AbortError" === e7.name ? (this.dispatchEvent(new CustomEvent("request-aborted", { bubbles: true, composed: true, detail: { err: e7, request: p2 } })), this.responseMessage = "Request Aborted", this.responseText = "Request Aborted") : (this.dispatchEvent(new CustomEvent("after-try", { bubbles: true, composed: true, detail: { err: e7, request: p2 } })), this.responseMessage = `${e7.message} (CORS or Network Issue)`);
        }
        this.requestUpdate();
      }
      liveCURLSyntaxUpdate(e6) {
        this.applyCURLSyntax(e6), this.requestUpdate();
      }
      onGenerateCURLClick(e6) {
        const t5 = this.getRequestPanel(e6);
        this.applyCURLSyntax(t5);
      }
      getRequestPanel(e6) {
        return e6.target.closest(".request-panel");
      }
      applyCURLSyntax(e6) {
        const t5 = this.buildFetchURL(e6), r6 = this.buildFetchBodyOptions(e6), n6 = this.buildFetchHeaders(e6);
        this.curlSyntax = this.generateCURLSyntax(t5, n6, r6, e6);
      }
      generateCURLSyntax(e6, t5, r6, n6) {
        let o5, a2 = "", i4 = "", s6 = "", l2 = "";
        const c3 = n6.querySelector(".request-body-container");
        if (false === e6.startsWith("http")) {
          o5 = new URL(e6, window.location.href).href;
        } else
          o5 = e6;
        if (a2 = `curl -X ${this.method.toUpperCase()} "${o5}" \\
`, i4 = Array.from(t5).map(([e7, t6]) => ` -H "${e7}: ${t6}"`).join("\\\n"), i4 && (i4 = `${i4} \\
`), r6.body instanceof URLSearchParams)
          s6 = ` -d ${r6.body.toString()} \\
`;
        else if (r6.body instanceof File)
          s6 = ` --data-binary @${r6.body.name} \\
`;
        else if (r6.body instanceof FormData)
          l2 = Array.from(r6.body).reduce((e7, [t6, r7]) => {
            if (r7 instanceof File)
              return [...e7, ` -F "${t6}=@${r7.name}"`];
            const n7 = r7.match(/([^,],)/gm);
            if (n7) {
              const r8 = n7.map((e8) => `-F "${t6}[]=${e8}"`);
              return [...e7, ...r8];
            }
            return [...e7, ` -F "${t6}=${r7}"`];
          }, []).join("\\\n");
        else if (c3 && c3.dataset.selectedRequestBodyType) {
          const e7 = c3.dataset.selectedRequestBodyType, t6 = n6.querySelector(".request-body-param-user-input");
          if (null != t6 && t6.value) {
            if (r6.body = t6.value, e7.includes("json"))
              try {
                s6 = ` -d '${JSON.stringify(JSON.parse(t6.value))}' \\
`;
              } catch (e8) {
              }
            s6 || (s6 = ` -d '${t6.value.replace(/'/g, `'"'"'`)}' \\
`);
          }
        }
        return `${a2}${i4}${s6}${l2}`;
      }
      onAddRemoveFileInput(e6, t5, r6) {
        if ("button" !== e6.target.tagName.toLowerCase())
          return;
        if (e6.target.classList.contains("file-input-remove-btn")) {
          return void e6.target.closest(".input-set").remove();
        }
        const n6 = e6.target.closest(".file-input-container"), o5 = document.createElement("div");
        o5.setAttribute("class", "input-set row");
        const a2 = document.createElement("input");
        a2.type = "file", a2.style = "width:200px; margin-top:2px;", a2.setAttribute("data-pname", t5), a2.setAttribute("data-ptype", r6.includes("form-urlencode") ? "form-urlencode" : "form-data"), a2.setAttribute("data-array", "false"), a2.setAttribute("data-file-array", "true");
        const i4 = document.createElement("button");
        i4.setAttribute("class", "file-input-remove-btn"), i4.innerHTML = "&#x2715;", o5.appendChild(a2), o5.appendChild(i4), n6.insertBefore(o5, e6.target);
      }
      clearResponseData() {
        this.responseUrl = "", this.responseHeaders = "", this.responseText = "", this.responseStatus = "success", this.responseMessage = "", this.responseIsBlob = false, this.responseBlobType = "", this.respContentDisposition = "", this.responseBlobUrl && (URL.revokeObjectURL(this.responseBlobUrl), this.responseBlobUrl = "");
      }
      disconnectedCallback() {
        this.curlSyntax = "", this.responseBlobUrl && (URL.revokeObjectURL(this.responseBlobUrl), this.responseBlobUrl = ""), super.disconnectedCallback();
      }
    });
    customElements.define("schema-table", class extends ie {
      static get properties() {
        return { schemaExpandLevel: { type: Number, attribute: "schema-expand-level" }, schemaDescriptionExpanded: { type: String, attribute: "schema-description-expanded" }, allowSchemaDescriptionExpandToggle: { type: String, attribute: "allow-schema-description-expand-toggle" }, schemaHideReadOnly: { type: String, attribute: "schema-hide-read-only" }, schemaHideWriteOnly: { type: String, attribute: "schema-hide-write-only" }, data: { type: Object } };
      }
      connectedCallback() {
        super.connectedCallback(), (!this.schemaExpandLevel || this.schemaExpandLevel < 1) && (this.schemaExpandLevel = 99999), this.schemaDescriptionExpanded && "true false".includes(this.schemaDescriptionExpanded) || (this.schemaDescriptionExpanded = "false"), this.schemaHideReadOnly && "true false".includes(this.schemaHideReadOnly) || (this.schemaHideReadOnly = "true"), this.schemaHideWriteOnly && "true false".includes(this.schemaHideWriteOnly) || (this.schemaHideWriteOnly = "true");
      }
      static get styles() {
        return [Ke, UP, c2`
      .table {
        font-size: var(--font-size-small);
        text-align: left;
        line-height: calc(var(--font-size-small) + 6px);
      }
      .table .tr {
        width: calc(100% - 5px);
        padding: 0 0 0 5px;
        border-bottom: 1px dotted var(--light-border-color);
      }
      .table .td {
        padding: 4px 0;
      }
      .table .key {
        width: 240px;
      }
      .key .key-label {
        font-size: var(--font-size-mono);
      }
      .key.deprecated .key-label {
        color: var(--red);
      }

      .table .key-type {
        white-space: normal;
        width: 150px;
      }
      .collapsed-all-descr .tr:not(.expanded-descr) {
        max-height: calc(var(--font-size-small) + var(--font-size-small));
      }

      .obj-toggle {
        padding: 0 2px;
        border-radius:2px;
        border: 1px solid transparent;
        display: inline-block;
        margin-left: -16px;
        color:var(--primary-color);
        cursor:pointer;
        font-size: calc(var(--font-size-small) + 4px);
        font-family: var(--font-mono);
        background-clip: border-box;
      }
      .obj-toggle:hover {
        border-color: var(--primary-color);
      }
      .tr.expanded + .object-body {
        display:block;
      }
      .tr.collapsed + .object-body {
        display:none;
      }`, nt];
      }
      render() {
        var e6, t5, r6;
        return q`
      <div class="table ${"true" === this.schemaDescriptionExpanded ? "expanded-all-descr" : "collapsed-all-descr"}" @click="${(e7) => this.handleAllEvents(e7)}">
        <div class='toolbar'>
          <div class="toolbar-item schema-root-type ${(null === (e6 = this.data) || void 0 === e6 ? void 0 : e6["::type"]) || ""} "> ${(null === (t5 = this.data) || void 0 === t5 ? void 0 : t5["::type"]) || ""} </div>
          ${"true" === this.allowSchemaDescriptionExpandToggle ? q`
              <div style="flex:1"></div>
              <div part="schema-multiline-toggle" class='toolbar-item schema-multiline-toggle' > 
                ${"true" === this.schemaDescriptionExpanded ? "Single line description" : "Multiline description"}
              </div>
            ` : ""}
        </div>
        <span part="schema-description" class='m-markdown'> ${Q_(We((null === (r6 = this.data) || void 0 === r6 ? void 0 : r6["::description"]) || ""))} </span>
        <div style = 'border:1px solid var(--light-border-color)'>
          <div style='display:flex; background-color: var(--bg2); padding:8px 4px; border-bottom:1px solid var(--light-border-color);'>
            <div class='key' style='font-family:var(--font-regular); font-weight:bold; color:var(--fg);'> Field </div>
            <div class='key-type' style='font-family:var(--font-regular); font-weight:bold; color:var(--fg);'> Type </div>
            <div class='key-descr' style='font-family:var(--font-regular); font-weight:bold; color:var(--fg);'> Description </div>
          </div>
          ${this.data ? q`
              ${this.generateTree("array" === this.data["::type"] ? this.data["::props"] : this.data, this.data["::type"], this.data["::array-type"])}` : ""}  
        </div>
      </div>  
    `;
      }
      generateTree(e6, t5 = "object", r6 = "", n6 = "", o5 = "", a2 = 0, i4 = 0, s6 = "") {
        var l2, c3;
        if ("true" === this.schemaHideReadOnly) {
          if ("array" === t5 && "readonly" === s6)
            return;
          if (e6 && "readonly" === e6["::readwrite"])
            return;
        }
        if ("true" === this.schemaHideWriteOnly) {
          if ("array" === t5 && "writeonly" === s6)
            return;
          if (e6 && "writeonly" === e6["::readwrite"])
            return;
        }
        if (!e6)
          return q`<div class="null" style="display:inline;">
        <span style='margin-left:${16 * (a2 + 1)}px'> &nbsp; </span>
        <span class="key-label xxx-of-key"> ${n6.replace("::OPTION~", "")}</span>
        ${"array" === t5 ? q`<span class='mono-font'> [ ] </span>` : "object" === t5 ? q`<span class='mono-font'> { } </span>` : q`<span class='mono-font'> schema undefined </span>`}
      </div>`;
        const p2 = null !== (l2 = e6["::type"]) && void 0 !== l2 && l2.startsWith("xxx-of") ? a2 : a2 + 1, d2 = "xxx-of-option" === t5 || "xxx-of-option" === e6["::type"] || n6.startsWith("::OPTION") ? i4 : i4 + 1, u3 = 16 * d2;
        if (0 === Object.keys(e6).length)
          return q`<span class="td key object" style='padding-left:${u3}px'>${n6}</span>`;
        let h2 = "", f3 = "", m2 = false;
        if (n6.startsWith("::ONE~OF") || n6.startsWith("::ANY~OF"))
          h2 = n6.replace("::", "").replace("~", " "), m2 = true;
        else if (n6.startsWith("::OPTION")) {
          const e7 = n6.split("~");
          h2 = e7[1], f3 = e7[2];
        } else
          h2 = n6;
        let y2 = "";
        if ("object" === e6["::type"] ? y2 = "array" === t5 ? "array of object" : e6["::dataTypeLabel"] || e6["::type"] : "array" === e6["::type"] && (y2 = "array" === t5 ? "array of array " + ("object" !== r6 ? `of ${r6}` : "") : e6["::dataTypeLabel"] || e6["::type"]), "object" == typeof e6)
          return q`
        ${p2 >= 0 && n6 ? q`
            <div class='tr ${p2 <= this.schemaExpandLevel ? "expanded" : "collapsed"} ${e6["::type"]}' data-obj='${h2}' title="${e6["::deprecated"] ? "Deprecated" : ""}">
              <div class="td key ${e6["::deprecated"] ? "deprecated" : ""}" style='padding-left:${u3}px'>
                ${h2 || f3 ? q`
                    <span class='obj-toggle ${p2 < this.schemaExpandLevel ? "expanded" : "collapsed"}' data-obj='${h2}'>
                      ${a2 < this.schemaExpandLevel ? "-" : "+"}
                    </span>` : ""}
                ${"xxx-of-option" === e6["::type"] || "xxx-of-array" === e6["::type"] || n6.startsWith("::OPTION") ? q`<span class="xxx-of-key" style="margin-left:-6px">${h2}</span><span class="${m2 ? "xxx-of-key" : "xxx-of-descr"}">${f3}</span>` : h2.endsWith("*") ? q`<span class="key-label" style="display:inline-block; margin-left:-6px;">${e6["::deprecated"] ? "\u2717" : ""} ${h2.substring(0, h2.length - 1)}</span><span style='color:var(--red);'>*</span>` : q`<span class="key-label" style="display:inline-block; margin-left:-6px;">${e6["::deprecated"] ? "\u2717" : ""} ${"::props" === h2 ? "" : h2}</span>`}
                ${"xxx-of" === e6["::type"] && "array" === t5 ? q`<span style="color:var(--primary-color)">ARRAY</span>` : ""} 
              </div>
              <div class='td key-type' title="${"readonly" === e6["::readwrite"] ? "Read-Only" : "writeonly" === e6["::readwrite"] ? "Write-Only" : ""}">
                ${(e6["::type"] || "").includes("xxx-of") ? "" : y2}
                ${"readonly" === e6["::readwrite"] ? " \u{1F181}" : "writeonly" === e6["::readwrite"] ? " \u{1F186}" : ""}
              </div>
              <div class='td key-descr m-markdown-small' style='line-height:1.7'>${Q_(We(o5 || ""))}</div>
            </div>` : q`
            ${"array" === e6["::type"] && "array" === t5 ? q`
                <div class='tr'> 
                  <div class='td key'></div> 
                  <div class='td key-type'>
                    ${r6 && "object" !== r6 ? `${t5} of ${r6}` : t5}
                  </div> 
                  <div class='td key-descr'></div> 
                </div>` : ""}`}
        <div class='object-body'>
        ${Array.isArray(e6) && e6[0] ? q`${this.generateTree(e6[0], "xxx-of-option", "", "::ARRAY~OF", "", p2, d2, "")}` : q`
            ${Object.keys(e6).map((t6) => {
            var r7;
            return q`
              ${["::title", "::description", "::type", "::props", "::deprecated", "::array-type", "::readwrite", "::dataTypeLabel"].includes(t6) ? "array" === e6[t6]["::type"] || "object" === e6[t6]["::type"] ? q`${this.generateTree("array" === e6[t6]["::type"] ? e6[t6]["::props"] : e6[t6], e6[t6]["::type"], e6[t6]["::array-type"] || "", t6, e6[t6]["::description"], p2, d2, e6[t6]["::readwrite"] ? e6[t6]["::readwrite"] : "")}` : "" : q`${this.generateTree("array" === e6[t6]["::type"] ? e6[t6]["::props"] : e6[t6], e6[t6]["::type"], e6[t6]["::array-type"] || "", t6, (null === (r7 = e6[t6]) || void 0 === r7 ? void 0 : r7["::description"]) || "", p2, d2, e6[t6]["::readwrite"] ? e6[t6]["::readwrite"] : "")}`}
            `;
          })}
          `}
        <div>
      `;
        const [g2, v2, b2, x3, w2, $2, k2, S2, A2] = e6.split("~|~");
        if ("\u{1F181}" === v2 && "true" === this.schemaHideReadOnly)
          return;
        if ("\u{1F186}" === v2 && "true" === this.schemaHideWriteOnly)
          return;
        const E2 = g2.replace(/┃.*/g, "").replace(/[^a-zA-Z0-9+]/g, "").substring(0, 4).toLowerCase(), O2 = b2 || x3 || w2 || $2 ? '<span class="descr-expand-toggle">\u2794</span>' : "";
        let T3 = "";
        return T3 = "array" === t5 ? q` 
        <div class='td key-type ${E2}' title="${"readonly" === s6 ? "Read-Only" : "writeonly" === v2 ? "Write-Only" : ""}">
          [${g2}] ${"readonly" === s6 ? "\u{1F181}" : "writeonly" === s6 ? "\u{1F186}" : ""}
        </div>` : q` 
        <div class='td key-type ${E2}' title="${"\u{1F181}" === v2 ? "Read-Only" : "\u{1F186}" === v2 ? "Write-Only" : ""}">
          ${g2} ${v2}
        </div>`, q`
      <div class = "tr primitive" title="${A2 ? "Deprecated" : ""}">
        <div class="td key ${A2}" style='padding-left:${u3}px'>
          ${A2 ? q`<span style='color:var(--red);'>✗</span>` : ""}
          ${null !== (c3 = h2) && void 0 !== c3 && c3.endsWith("*") ? q`
              <span class="key-label">${h2.substring(0, h2.length - 1)}</span>
              <span style='color:var(--red);'>*</span>` : n6.startsWith("::OPTION") ? q`<span class='xxx-of-key'>${h2}</span><span class="xxx-of-descr">${f3}</span>` : q`${h2 ? q`<span class="key-label"> ${h2}</span>` : q`<span class="xxx-of-descr">${S2}</span>`}`}
        </div>
        ${T3}
        <div class='td key-descr' style='font-size: var(--font-size-small)'>
          ${q`<span class="m-markdown-small">
            ${Q_(We("array" === t5 ? `${O2} ${o5}` : S2 ? `${O2} <b>${S2}:</b> ${k2}` : `${O2} ${k2}`))}
          </span>`}
          ${b2 ? q`<div class='' style='display:inline-block; line-break:anywhere; margin-right:8px;'> <span class='bold-text'>Constraints: </span> ${b2}</div>` : ""}
          ${x3 ? q`<div style='display:inline-block; line-break:anywhere; margin-right:8px;'> <span class='bold-text'>Default: </span>${x3}</div>` : ""}
          ${w2 ? q`<div style='display:inline-block; line-break:anywhere; margin-right:8px;'> <span class='bold-text'>${"const" === g2 ? "Value" : "Allowed"}: </span>${w2}</div>` : ""}
          ${$2 ? q`<div style='display:inline-block; line-break:anywhere; margin-right:8px;'> <span class='bold-text'>Pattern: </span>${$2}</div>` : ""}
        </div>
      </div>
    `;
      }
      handleAllEvents(e6) {
        if (e6.target.classList.contains("obj-toggle"))
          this.toggleObjectExpand(e6);
        else if (e6.target.classList.contains("schema-multiline-toggle"))
          this.schemaDescriptionExpanded = "true" === this.schemaDescriptionExpanded ? "false" : "true";
        else if (e6.target.classList.contains("descr-expand-toggle")) {
          const t5 = e6.target.closest(".tr");
          t5 && (t5.classList.toggle("expanded-descr"), t5.style.maxHeight = t5.scrollHeight);
        }
      }
      toggleObjectExpand(e6) {
        const t5 = e6.target.closest(".tr");
        t5.classList.contains("expanded") ? (t5.classList.add("collapsed"), t5.classList.remove("expanded"), e6.target.innerText = "+") : (t5.classList.remove("collapsed"), t5.classList.add("expanded"), e6.target.innerText = "-");
      }
    });
    function zP(e6) {
      const t5 = new We.Renderer();
      return t5.heading = (t6, r6, n6, o5) => `<h${r6} class="observe-me" id="${e6}--${o5.slug(n6)}">${t6}</h${r6}>`, t5;
    }
    function MP(e6) {
      const t5 = e6.target.closest(".tag-container").querySelector(".tag-description"), r6 = e6.target.closest(".tag-container").querySelector(".tag-icon");
      if (t5 && r6) {
        t5.classList.contains("expanded") ? (t5.style.maxHeight = 0, t5.classList.replace("expanded", "collapsed"), r6.classList.replace("expanded", "collapsed")) : (t5.style.maxHeight = `${t5.scrollHeight}px`, t5.classList.replace("collapsed", "expanded"), r6.classList.replace("collapsed", "expanded"));
      }
    }
    function HP(e6, t5 = "", r6 = "") {
      var n6, o5, a2, i4, s6, l2, c3, p2, d2;
      const u3 = /* @__PURE__ */ new Set();
      for (const t6 in e6.responses)
        for (const r7 in null === (h2 = e6.responses[t6]) || void 0 === h2 ? void 0 : h2.content) {
          var h2;
          u3.add(r7.trim());
        }
      const f3 = [...u3].join(", "), m2 = this.resolvedSpec.securitySchemes.filter((t6) => {
        var r7;
        return t6.finalKeyValue && (null === (r7 = e6.security) || void 0 === r7 ? void 0 : r7.some((e7) => t6.securitySchemeId in e7));
      }) || [], y2 = this.resolvedSpec.securitySchemes.find((e7) => e7.securitySchemeId === at && "-" !== e7.value);
      y2 && m2.push(y2);
      const g2 = e6.xCodeSamples ? mP.call(this, e6.xCodeSamples) : "";
      return q`
    ${"read" === this.renderStyle ? q`<div class='divider' part="operation-divider"></div>` : ""}
    <div class='expanded-endpoint-body observe-me ${e6.method} ${e6.deprecated ? "deprecated" : ""} ' part="section-operation ${e6.elementId}" id='${e6.elementId}'>
      ${"focused" === this.renderStyle && "General \u2982" !== t5 ? q`
          <div class="tag-container" part="section-operation-tag"> 
            <span class="upper" style="font-weight:bold; font-size:18px;"> ${t5} </span>
            ${r6 ? q`
                <svg class="tag-icon collapsed" width="24" height="24" viewBox="0 0 24 24" stroke-width="2" fill="none" style="stroke:var(--primary-color); vertical-align:top; cursor:pointer"
                @click="${(e7) => {
        MP.call(this, e7);
      }}"
                >
                  <path d="M12 20h-6a2 2 0 0 1 -2 -2v-12a2 2 0 0 1 2 -2h8"></path><path d="M18 4v17"></path><path d="M15 18l3 3l3 -3"></path>
                </svg>
                <div class="tag-description collapsed" style="max-height:0px; overflow:hidden; margin-top:16px; border:1px solid var(--border-color)"> 
                  <div class="m-markdown" style="padding:8px"> ${Q_(We(r6))}</div>  
                </div>` : ""}  
          </div>
        ` : ""}
      ${e6.deprecated ? q`<div class="bold-text red-text"> DEPRECATED </div>` : ""}
      ${q`
        ${e6.xBadges && (null === (n6 = e6.xBadges) || void 0 === n6 ? void 0 : n6.length) > 0 ? q`
            <div style="display:flex; flex-wrap:wrap; margin-bottom: -24px; font-size: var(--font-size-small);">
              ${e6.xBadges.map((e7) => q`<span style="margin:1px; margin-right:5px; padding:1px 8px; font-weight:bold; border-radius:12px;  background-color: var(--light-${e7.color}, var(--input-bg)); color:var(--${e7.color}); border:1px solid var(--${e7.color})">${e7.label}</span>`)}
            </div>
            ` : ""}
        <h2 part="section-operation-summary"> ${e6.shortSummary || `${e6.method.toUpperCase()} ${e6.path}`}</h2>
        ${e6.isWebhook ? q`<span part="section-operation-webhook" style="color:var(--primary-color); font-weight:bold; font-size: var(--font-size-regular);"> WEBHOOK </span>` : q`
            <div part="section-operation-webhook-method" class="mono-font regular-font-size" style="text-align:left; direction:ltr; padding: 8px 0; color:var(--fg3)"> 
              <span part="label-operation-method" class="regular-font upper method-fg bold-text ${e6.method}">${e6.method}</span> 
              <span part="label-operation-path">${e6.path}</span>
            </div>
          `}
        <slot name="${e6.elementId}"></slot>`}
      ${e6.description ? q`<div class="m-markdown"> ${Q_(We(e6.description))}</div>` : ""}
      ${fP.call(this, e6.security)}
      ${null !== (o5 = e6.externalDocs) && void 0 !== o5 && o5.url || null !== (a2 = e6.externalDocs) && void 0 !== a2 && a2.description ? q`<div style="background-color:var(--bg3); padding:2px 8px 8px 8px; margin:8px 0; border-radius:var(--border-radius)"> 
            <div class="m-markdown"> ${Q_(We((null === (i4 = e6.externalDocs) || void 0 === i4 ? void 0 : i4.description) || ""))} </div>
            ${null !== (s6 = e6.externalDocs) && void 0 !== s6 && s6.url ? q`<a style="font-family:var(--font-mono); font-size:var(--font-size-small)" href="${null === (l2 = e6.externalDocs) || void 0 === l2 ? void 0 : l2.url}" target="_blank">
                  ${null === (c3 = e6.externalDocs) || void 0 === c3 ? void 0 : c3.url} <div style="transform: rotate(270deg) scale(1.5); display: inline-block; margin-left:5px">⇲</div>
                </a>` : ""}
          </div>` : ""}
      ${g2}
      <div class='expanded-req-resp-container'>
        <api-request
          class = "${this.renderStyle}-mode"
          style = "width:100%;"
          webhook = "${e6.isWebhook}"
          method = "${e6.method}"
          path = "${e6.path}"
          .security = "${e6.security}"
          .parameters = "${e6.parameters}"
          .request_body = "${e6.requestBody}"
          .api_keys = "${m2}"
          .servers = "${e6.servers}"
          server-url = "${(null === (p2 = e6.servers) || void 0 === p2 || null === (d2 = p2[0]) || void 0 === d2 ? void 0 : d2.url) || this.selectedServer.computedUrl}"
          fill-request-fields-with-example = "${this.fillRequestFieldsWithExample}"
          allow-try = "${this.allowTry}"
          show-curl-before-try = "${this.showCurlBeforeTry}"
          accept = "${f3}"
          render-style="${this.renderStyle}" 
          schema-style = "${this.schemaStyle}"
          active-schema-tab = "${this.defaultSchemaTab}"
          schema-expand-level = "${this.schemaExpandLevel}"
          schema-description-expanded = "${this.schemaDescriptionExpanded}"
          allow-schema-description-expand-toggle = "${this.allowSchemaDescriptionExpandToggle}"
          schema-hide-read-only = "${"never" === this.schemaHideReadOnly || e6.isWebhook ? "false" : "true"}"
          schema-hide-write-only = "${"never" === this.schemaHideWriteOnly ? "false" : e6.isWebhook ? "true" : "false"}"
          fetch-credentials = "${this.fetchCredentials}"
          exportparts = "wrap-request-btn:wrap-request-btn, btn:btn, btn-fill:btn-fill, btn-outline:btn-outline, btn-try:btn-try, btn-clear:btn-clear, btn-clear-resp:btn-clear-resp,
            file-input:file-input, textbox:textbox, textbox-param:textbox-param, textarea:textarea, textarea-param:textarea-param, 
            anchor:anchor, anchor-param-example:anchor-param-example, schema-description:schema-description, schema-multiline-toggle:schema-multiline-toggle"
        > </api-request>

        ${e6.callbacks ? yP.call(this, e6.callbacks) : ""}

        <api-response
          class = "${this.renderStyle}-mode"
          style = "width:100%;"
          webhook = "${e6.isWebhook}"
          .responses = "${e6.responses}"
          render-style = "${this.renderStyle}"
          schema-style = "${this.schemaStyle}"
          active-schema-tab = "${this.defaultSchemaTab}"
          schema-expand-level = "${this.schemaExpandLevel}"
          schema-description-expanded = "${this.schemaDescriptionExpanded}"
          allow-schema-description-expand-toggle = "${this.allowSchemaDescriptionExpandToggle}"
          schema-hide-read-only = "${"never" === this.schemaHideReadOnly ? "false" : e6.isWebhook ? "true" : "false"}"
          schema-hide-write-only = "${"never" === this.schemaHideWriteOnly || e6.isWebhook ? "false" : "true"}"
          selected-status = "${Object.keys(e6.responses || {})[0] || ""}"
          exportparts = "btn:btn, btn-response-status:btn-response-status, btn-selected-response-status:btn-selected-response-status, btn-fill:btn-fill, btn-copy:btn-copy,
          schema-description:schema-description, schema-multiline-toggle:schema-multiline-toggle"
        > </api-response>
      </div>
    </div>
  `;
    }
    function WP() {
      return this.resolvedSpec ? q`
  ${this.resolvedSpec.tags.map((e6) => q`
    <section id="${e6.elementId}" part="section-tag" class="regular-font section-gap--read-mode observe-me" style="border-top:1px solid var(--primary-color);">
      <div class="title tag" part="section-tag-title label-tag-title">${e6.name}</div>
      <slot name="${e6.elementId}"></slot>
      <div class="regular-font-size">
      ${Q_(`
          <div class="m-markdown regular-font">
          ${We(e6.description || "", "true" === this.infoDescriptionHeadingsInNavBar ? { renderer: zP(e6.elementId) } : void 0)}
        </div>`)}
      </div>
    </section>
    <section class="regular-font section-gap--read-mode" part="section-operations-in-tag">
      ${e6.paths.map((e7) => HP.call(this, e7))}
    </section>
    `)}
` : "";
    }
    function VP(e6) {
      return q`
  <div class='divider'></div>
  <div class='expanded-endpoint-body observe-me ${e6.name}' id='cmp--${e6.id}' >
    <div style="font-weight:bold"> ${e6.name} <span style="color:var(--light-fg); font-size:var(--font-size-small); font-weight:400;"> Schema </span></div>
  ${"table" === this.schemaStyle ? q`
      <schema-table
        .data = '${DP(e6.component, {})}'
        schema-expand-level = "${this.schemaExpandLevel}"
        schema-description-expanded = "${this.schemaDescriptionExpanded}"
        allow-schema-description-expand-toggle = "${this.allowSchemaDescriptionExpandToggle}"
        schema-hide-read-only = "false"
        schema-hide-write-only = "${this.schemaHideWriteOnly}"
        exportparts = "schema-description:schema-description, schema-multiline-toggle:schema-multiline-toggle"
      > </schema-table>` : q`
      <schema-tree
        .data = '${DP(e6.component, {})}'
        schema-expand-level = "${this.schemaExpandLevel}"
        schema-description-expanded = "${this.schemaDescriptionExpanded}"
        allow-schema-description-expand-toggle = "${this.allowSchemaDescriptionExpandToggle}"
        schema-hide-read-only = "false"
        schema-hide-write-only = "${this.schemaHideWriteOnly}"
        exportparts = "schema-description:schema-description, schema-multiline-toggle:schema-multiline-toggle"
      > </schema-tree>`}
  </div>`;
    }
    function GP(e6, t5) {
      return -1 !== e6.id.indexOf("schemas-") ? VP.call(this, e6) : q`
  <div class='divider'></div>
  <div class='expanded-endpoint-body observe-me ${e6.name}' id='cmp--${e6.id}' >
    ${q`
      <div style="font-weight:bold"> ${e6.name} <span style="color:var(--light-fg); font-size:var(--font-size-small); font-weight:400"> ${t5} </span> </div>
      ${e6.component ? q`
      <div class='mono-font regular-font-size' style='padding: 8px 0; color:var(--fg2)'> 
        <json-tree class="border tree" render-style='${this.renderStyle}' .data="${e6.component}"> </json-tree>
      </div>` : ""}
    `}
  </div>
  `;
    }
    function KP() {
      return this.resolvedSpec ? q`
  ${this.resolvedSpec.components.map((e6) => q`
    <div id="cmp--${e6.name.toLowerCase()}" class='regular-font section-gap--read-mode observe-me' style="border-top:1px solid var(--primary-color);">
      <div class="title tag">${e6.name}</div>
      <div class="regular-font-size">
        ${Q_(`<div class='m-markdown regular-font'>${We(e6.description ? e6.description : "")}</div>`)}
      </div>
    </div>
    <div class='regular-font section-gap--read-mode'>
      ${e6.subComponents.filter((e7) => false !== e7.expanded).map((t5) => GP.call(this, t5, e6.name))}
    </div>
    `)}
` : "";
    }
    function JP() {
      const e6 = new We.Renderer();
      return e6.heading = (e7, t5, r6, n6) => `<h${t5} class="observe-me" id="overview--${n6.slug(r6)}">${e7}</h${t5}>`, e6;
    }
    function YP() {
      var e6, t5, r6, n6;
      return q`
    <section id="overview" part="section-overview"
      class="observe-me ${"view" === this.renderStyle ? "section-gap" : "section-gap--read-mode"}">
      ${null !== (e6 = this.resolvedSpec) && void 0 !== e6 && e6.info ? q`
          <div id="api-title" part="section-overview-title" style="font-size:32px">
            ${this.resolvedSpec.info.title}
            ${this.resolvedSpec.info.version ? q`
              <span style = 'font-size:var(--font-size-small);font-weight:bold'>
                ${this.resolvedSpec.info.version}
              </span>` : ""}
          </div>
          <div id="api-info" style="font-size:calc(var(--font-size-regular) - 1px); margin-top:8px;">
            ${null !== (t5 = this.resolvedSpec.info.contact) && void 0 !== t5 && t5.email ? q`<span>${this.resolvedSpec.info.contact.name || "Email"}: 
                <a href="mailto:${this.resolvedSpec.info.contact.email}" part="anchor anchor-overview">${this.resolvedSpec.info.contact.email}</a>
              </span>` : ""}
            ${null !== (r6 = this.resolvedSpec.info.contact) && void 0 !== r6 && r6.url ? q`<span>URL: <a href="${this.resolvedSpec.info.contact.url}" part="anchor anchor-overview">${this.resolvedSpec.info.contact.url}</a></span>` : ""}
            ${this.resolvedSpec.info.license ? q`<span>License: 
                ${this.resolvedSpec.info.license.url ? q`<a href="${this.resolvedSpec.info.license.url}" part="anchor anchor-overview">${this.resolvedSpec.info.license.name}</a>` : this.resolvedSpec.info.license.name} </span>` : ""}
            ${this.resolvedSpec.info.termsOfService ? q`<span><a href="${this.resolvedSpec.info.termsOfService}" part="anchor anchor-overview">Terms of Service</a></span>` : ""}
            ${this.specUrl && "true" === this.allowSpecFileDownload ? q`
                <div style="display:flex; margin:12px 0; gap:8px; justify-content: start;">
                  <button class="m-btn thin-border" style="min-width:170px" part="btn btn-outline" @click='${(e7) => {
        pt(this.specUrl, "openapi-spec");
      }}'>Download OpenAPI spec</button>
                  ${null !== (n6 = this.specUrl) && void 0 !== n6 && n6.trim().toLowerCase().endsWith("json") ? q`<button class="m-btn thin-border" style="width:200px" part="btn btn-outline" @click='${(e7) => {
        dt(this.specUrl);
      }}'>View OpenAPI spec (New Tab)</button>` : ""}
                </div>` : ""}
          </div>
          <slot name="overview"></slot>
          <div id="api-description">
          ${this.resolvedSpec.info.description ? q`${Q_(`
                <div class="m-markdown regular-font">
                ${We(this.resolvedSpec.info.description, "true" === this.infoDescriptionHeadingsInNavBar ? { renderer: JP() } : void 0)}
              </div>`)}` : ""}
          </div>
        ` : ""}
    </section>
  `;
    }
    function ZP(e6) {
      var t5;
      const r6 = null === (t5 = this.resolvedSpec) || void 0 === t5 ? void 0 : t5.servers.find((t6) => t6.url === e6);
      return !!r6 && (this.selectedServer = r6, this.requestUpdate(), this.dispatchEvent(new CustomEvent("api-server-change", { bubbles: true, composed: true, detail: { selectedServer: r6 } })), true);
    }
    function QP(e6, t5) {
      const r6 = [...e6.currentTarget.closest("table").querySelectorAll("input, select")];
      let n6 = t5.url;
      r6.forEach((e7) => {
        const t6 = new RegExp(`{${e7.dataset.var}}`, "g");
        n6 = n6.replace(t6, e7.value);
      }), t5.computedUrl = n6, this.requestUpdate();
    }
    function XP() {
      return this.selectedServer && this.selectedServer.variables ? q`
    <div class="table-title">SERVER VARIABLES</div>
    <table class='m-table' role='presentation'>
      ${Object.entries(this.selectedServer.variables).map((e6) => q`
        <tr>
          <td style="vertical-align: middle;" >${e6[0]}</td>
          <td>
            ${e6[1].enum ? q`
            <select
              data-var = "${e6[0]}"
              @input = ${(e7) => {
        QP.call(this, e7, this.selectedServer);
      }}
            >
            ${Object.entries(e6[1].enum).map((t5) => e6[1].default === t5[1] ? q`
              <option
                selected
                label = ${t5[1]}
                value = ${t5[1]}
              />` : q`
              <option
                label = ${t5[1]}
                value = ${t5[1]}
              />`)}
            </select>` : q`
            <input
              type = "text"
              part="textbox textbox-server-var"
              spellcheck = "false"
              data-var = "${e6[0]}"
              value = "${e6[1].default}"
              @input = ${(e7) => {
        QP.call(this, e7, this.selectedServer);
      }}
            />`}
          </td>
        </tr>
        ${e6[1].description ? q`<tr><td colspan="2" style="border:none"><span class="m-markdown-small"> ${Q_(We(e6[1].description))} </span></td></tr>` : ""}
      `)}
    </table>
    ` : "";
    }
    function eR() {
      var e6, t5, r6;
      return !this.resolvedSpec || this.resolvedSpec.specLoadError ? "" : q`
  <section id = 'servers' part="section-servers" style="text-align:left; direction:ltr; margin-top:24px; margin-bottom:24px;" class='regular-font observe-me ${"read focused".includes(this.renderStyle) ? "section-gap--read-mode" : "section-gap"}'>
    <div part = "section-servers-title" class = "sub-title">API SERVER</div>
    <div class = 'mono-font' style='margin: 12px 0; font-size:calc(var(--font-size-small) + 1px);'>
      ${this.resolvedSpec.servers && 0 !== (null === (e6 = this.resolvedSpec.servers) || void 0 === e6 ? void 0 : e6.length) ? q`
          ${null === (t5 = this.resolvedSpec) || void 0 === t5 ? void 0 : t5.servers.map((e7, t6) => q`
            <input type = 'radio'
              name = 'api_server'
              id = 'srvr-opt-${t6}'
              value = '${e7.url}'
              @change = ${() => {
        ZP.call(this, e7.url);
      }}
              .checked = '${this.selectedServer.url === e7.url}'
              style = 'margin:4px 0; cursor:pointer'
            />
              <label style='cursor:pointer' for='srvr-opt-${t6}'>
                ${e7.url} ${e7.description ? q`- <span class='regular-font'>${e7.description} </span>` : ""}
              </label>
            <br/>
          `)}
      ` : ""}
      <div class="table-title primary-text" part="label-selected-server"> SELECTED: ${(null === (r6 = this.selectedServer) || void 0 === r6 ? void 0 : r6.computedUrl) || "none"}</div>
    </div>
    <slot name="servers"></slot>
    ${XP.call(this)}
  </section>`;
    }
    function tR(e6, t5 = "toggle") {
      const r6 = null == e6 ? void 0 : e6.closest(".nav-bar-tag-and-paths"), n6 = null == r6 ? void 0 : r6.querySelector(".nav-bar-paths-under-tag");
      if (r6) {
        const e7 = r6.classList.contains("expanded");
        !e7 || "toggle" !== t5 && "collapse" !== t5 ? e7 || "toggle" !== t5 && "expand" !== t5 || (r6.classList.replace("collapsed", "expanded"), n6.style.maxHeight = `${n6.scrollHeight}px`) : (n6.style.maxHeight = 0, r6.classList.replace("expanded", "collapsed"));
      }
    }
    function rR(e6) {
      var t5, r6, n6, o5;
      if ("click" !== e6.type && ("keyup" !== e6.type || 13 !== e6.keyCode))
        return;
      const a2 = e6.target;
      e6.stopPropagation(), "navigate" === (null === (t5 = a2.dataset) || void 0 === t5 ? void 0 : t5.action) ? this.scrollToEventTarget(e6, false) : "expand-all" === (null === (r6 = a2.dataset) || void 0 === r6 ? void 0 : r6.action) || "collapse-all" === (null === (n6 = a2.dataset) || void 0 === n6 ? void 0 : n6.action) ? function(e7, t6 = "expand-all") {
        if ("click" !== e7.type && ("keyup" !== e7.type || 13 !== e7.keyCode))
          return;
        const r7 = [...e7.target.closest(".nav-scroll").querySelectorAll(".nav-bar-tag-and-paths")];
        "expand-all" === t6 ? r7.forEach((e8) => {
          const t7 = e8.querySelector(".nav-bar-paths-under-tag");
          e8.classList.replace("collapsed", "expanded"), t7.style.maxHeight = `${null == t7 ? void 0 : t7.scrollHeight}px`;
        }) : r7.forEach((e8) => {
          e8.classList.replace("expanded", "collapsed"), e8.querySelector(".nav-bar-paths-under-tag").style.maxHeight = 0;
        });
      }(e6, a2.dataset.action) : "expand-collapse-tag" === (null === (o5 = a2.dataset) || void 0 === o5 ? void 0 : o5.action) && tR(a2, "toggle");
    }
    function nR() {
      var e6, t5, r6, n6;
      return !this.resolvedSpec || this.resolvedSpec.specLoadError ? q`
      <nav class='nav-bar' part='section-navbar'>
        <slot name='nav-logo' class='logo'></slot>
      </nav>
    ` : q`
  <nav class='nav-bar ${this.renderStyle}' part='section-navbar'>
    <slot name='nav-logo' class='logo'></slot>
    ${"false" === this.allowSearch && "false" === this.allowAdvancedSearch ? "" : q`
        <div style='display:flex; flex-direction:row; justify-content:center; align-items:stretch; padding:8px 24px 12px 24px; ${"false" === this.allowAdvancedSearch ? "border-bottom: 1px solid var(--nav-hover-bg-color)" : ""}' part='section-navbar-search'>
          ${"false" === this.allowSearch ? "" : q`
              <div style = 'display:flex; flex:1; line-height:22px;'>
                <input id = 'nav-bar-search' 
                  part = 'textbox textbox-nav-filter'
                  style = 'width:100%; padding-right:20px; color:var(--nav-hover-text-color); border-color:var(--nav-accent-color); background-color:var(--nav-hover-bg-color)'
                  type = 'text'
                  placeholder = 'Filter' 
                  @change = '${this.onSearchChange}'
                  spellcheck = 'false'
                >
                <div style='margin: 6px 5px 0 -24px; font-size:var(--font-size-regular); cursor:pointer;'>&#x21a9;</div>
              </div>  
              ${this.matchPaths ? q`
                  <button @click = '${this.onClearSearch}' class='m-btn thin-border' style='margin-left:5px; color:var(--nav-text-color); width:75px; padding:6px 8px;' part='btn btn-outline btn-clear-filter'>
                    CLEAR
                  </button>` : ""}
            `}
          ${"false" === this.allowAdvancedSearch || this.matchPaths ? "" : q`
              <button class='m-btn primary' part='btn btn-fill btn-search' style='margin-left:5px; padding:6px 8px; width:75px' @click='${this.onShowSearchModalClicked}'>
                SEARCH
              </button>
            `}
        </div>
      `}
    ${q`<nav class='nav-scroll' tabindex='-1' part='section-navbar-scroll' @click='${(e7) => rR.call(this, e7)}' @keyup='${(e7) => rR.call(this, e7)}' >
      ${"false" !== this.showInfo && this.resolvedSpec.info ? q`
          ${"true" === this.infoDescriptionHeadingsInNavBar ? q`
              ${this.resolvedSpec.infoDescriptionHeaders.length > 0 ? q`<div class='nav-bar-info ${this.navActiveItemMarker}' id='link-overview' data-content-id='overview' data-action='navigate' tabindex='0' part='section-navbar-item section-navbar-overview'> 
                    ${(null === (e6 = this.resolvedSpec.info) || void 0 === e6 || null === (t5 = e6.title) || void 0 === t5 ? void 0 : t5.trim()) || "Overview"}
                  </div>` : ""}
              <div class='overview-headers'>
                ${this.resolvedSpec.infoDescriptionHeaders.map((e7) => q`
                  <div
                    class='nav-bar-h${e7.depth} ${this.navActiveItemMarker}' 
                    id='link-overview--${new We.Slugger().slug(e7.text)}'
                    data-action='navigate' 
                    data-content-id='overview--${new We.Slugger().slug(e7.text)}' 
                  >
                    ${e7.text}
                  </div>`)}
              </div>
              ${this.resolvedSpec.infoDescriptionHeaders.length > 0 ? q`<hr style='border-top: 1px solid var(--nav-hover-bg-color); border-width:1px 0 0 0; margin: 15px 0 0 0'/>` : ""}
            ` : q`<div class='nav-bar-info ${this.navActiveItemMarker}' id='link-overview' data-action='navigate' data-content-id='overview' tabindex='0'> 
              ${(null === (r6 = this.resolvedSpec.info) || void 0 === r6 || null === (n6 = r6.title) || void 0 === n6 ? void 0 : n6.trim()) || "Overview"}
            </div>`}
        ` : ""}
    
      ${"false" === this.allowServerSelection ? "" : q`<div class='nav-bar-info ${this.navActiveItemMarker}' id='link-servers' data-action='navigate' data-content-id='servers' tabindex='0' part='section-navbar-item section-navbar-servers'> API Servers </div>`}
      ${"false" !== this.allowAuthentication && this.resolvedSpec.securitySchemes ? q`<div class='nav-bar-info ${this.navActiveItemMarker}' id='link-auth' data-action='navigate' data-content-id='auth' tabindex='0' part='section-navbar-item section-navbar-auth'> Authentication </div>` : ""}

      <div id='link-operations-top' class='nav-bar-section operations' data-action='navigate' data-content-id='${"focused" === this.renderStyle ? "" : "operations-top"}' part='section-navbar-item section-navbar-operations-top'>
        <div style='font-size:16px; display:flex; margin-left:10px;'>
          ${"focused" === this.renderStyle ? q`
              <div class='nav-bar-expand-all'
                data-action='expand-all'
                tabindex='0' 
                title='Expand all'
              >▸</div>
              <div class='nav-bar-collapse-all'
                data-action='collapse-all'
                tabindex='0' 
                title='Collapse all'
              >▸</div>` : ""}  
        </div>
        <div class='nav-bar-section-title'> OPERATIONS </div>
      </div>

      <!-- TAGS AND PATHS-->
      ${this.resolvedSpec.tags.filter((e7) => e7.paths.filter((e8) => lt(this.matchPaths, e8, this.matchType)).length).map((e7) => {
        var t6;
        return q`
          <div class='nav-bar-tag-and-paths ${"read" === this.renderStyle || e7.expanded ? "expanded" : "collapsed"}' >
            ${"General \u2982" === e7.name ? q`<hr style='border:none; border-top: 1px dotted var(--nav-text-color); opacity:0.3; margin:-1px 0 0 0;'/>` : q`
                <div 
                  class='nav-bar-tag ${this.navActiveItemMarker}'
                  part='section-navbar-item section-navbar-tag'
                  id='link-${e7.elementId}'
                  data-action='${"read" === this.renderStyle || "show-description" === this.onNavTagClick ? "navigate" : "expand-collapse-tag"}'
                  data-content-id='${("read" === this.renderStyle ? `${e7.elementId}` : "show-description" === this.onNavTagClick) ? `${e7.elementId}` : ""}'
                  data-first-path-id='${e7.firstPathId}'
                  tabindex='0'
                >
                  <div style="pointer-events:none;">${e7.name}</div>
                  <div class='nav-bar-tag-icon' tabindex='0' data-action='expand-collapse-tag'></div>
                </div>
              `}
            ${"true" === this.infoDescriptionHeadingsInNavBar ? q`
                ${"focused" === this.renderStyle && "expand-collapse" === this.onNavTagClick ? "" : q`
                    <div class='tag-headers'>
                      ${e7.headers.map((t7) => q`
                      <div
                        class='nav-bar-h${t7.depth} ${this.navActiveItemMarker}'
                        part='section-navbar-item section-navbar-h${t7.depth}'
                        id='link-${e7.elementId}--${new We.Slugger().slug(t7.text)}'
                        data-action='navigate'
                        data-content-id='${e7.elementId}--${new We.Slugger().slug(t7.text)}'
                        tabindex='0'
                      > ${t7.text}</div>`)}
                    </div>`}` : ""}
            <div class='nav-bar-paths-under-tag' style='max-height:${e7.expanded || "read" === this.renderStyle ? 50 * ((null === (t6 = e7.paths) || void 0 === t6 ? void 0 : t6.length) || 1) : 0}px;'>
              <!-- Paths in each tag (endpoints) -->
              ${e7.paths.filter((e8) => !this.matchPaths || lt(this.matchPaths, e8, this.matchType)).map((e8) => q`
              <div 
                class='nav-bar-path ${this.navActiveItemMarker} ${"true" === this.usePathInNavBar ? "small-font" : ""}'
                part='section-navbar-item section-navbar-path'
                data-action='navigate'
                data-content-id='${e8.elementId}'
                id='link-${e8.elementId}'
                tabindex='0'
              >
                <span style = 'display:flex; pointer-events: none; align-items:start; ${e8.deprecated ? "filter:opacity(0.5)" : ""}'>
                  ${q`<span class='nav-method ${this.showMethodInNavBar} ${e8.method}' style='pointer-events: none;'>
                      ${"as-colored-block" === this.showMethodInNavBar ? e8.method.substring(0, 3).toUpperCase() : e8.method.toUpperCase()}
                    </span>`}
                  ${e8.isWebhook ? q`<span style='font-weight:bold; pointer-events: none; margin-right:8px; font-size: calc(var(--font-size-small) - 2px)'>WEBHOOK</span>` : ""}
                  ${"true" === this.usePathInNavBar ? q`<span style='pointer-events: none;' class='mono-font'>${e8.path}</span>` : e8.summary || e8.shortSummary}
                </span>
              </div>`)}
            </div>
          </div>
        `;
      })}

      <!-- COMPONENTS -->
      ${this.resolvedSpec.components && "true" === this.showComponents && "focused" === this.renderStyle ? q`
          <div id='link-components' class='nav-bar-section components'>
            <div></div>
            <div class='nav-bar-section-title'>COMPONENTS</div>
          </div>
          ${this.resolvedSpec.components.map((e7) => e7.subComponents.length ? q`
              <div class='nav-bar-tag'
                part='section-navbar-item section-navbar-tag'
                data-action='navigate' 
                data-content-id='cmp--${e7.name.toLowerCase()}' 
                id='link-cmp--${e7.name.toLowerCase()}'
              >
                ${e7.name}
              </div>
              ${e7.subComponents.filter((e8) => false !== e8.expanded).map((e8) => q`
                <div class='nav-bar-path' data-action='navigate' data-content-id='cmp--${e8.id}' id='link-cmp--${e8.id}'>
                  <span> ${e8.name} </span>
                </div>`)}` : "")}` : ""}
    </nav>`}
</nav>
`;
    }
    function oR(e6) {
      const t5 = new We.Renderer();
      return t5.heading = (t6, r6, n6, o5) => `<h${r6} class="observe-me" id="${e6}--${o5.slug(n6)}">${t6}</h${r6}>`, t5;
    }
    function aR(e6) {
      return q`
    <div class='regular-font section-gap--focused-mode' part="section-operations-in-tag">
      ${e6}
    </div>`;
    }
    function iR() {
      var e6;
      if ("true" === this.showInfo)
        return aR(YP.call(this));
      const t5 = this.resolvedSpec.tags[0], r6 = null === (e6 = this.resolvedSpec.tags[0]) || void 0 === e6 ? void 0 : e6.paths[0];
      return aR(t5 && r6 ? HP.call(this, r6, t5.name) : "");
    }
    function sR(e6) {
      return q`
    <h1 id="${e6.elementId}">${e6.name}</h1>
    ${"show-description" === this.onNavTagClick && e6.description ? q`
        <div class="m-markdown">
          ${Q_(`
            <div class="m-markdown regular-font">
              ${We(e6.description || "", "true" === this.infoDescriptionHeadingsInNavBar ? { renderer: oR(e6.elementId) } : void 0)}
            </div>`)}
        </div>` : ""}
  `;
    }
    function lR() {
      if (!this.focusedElementId || !this.resolvedSpec)
        return;
      const e6 = this.focusedElementId;
      let t5, r6 = null, n6 = null, o5 = 0;
      if (e6.startsWith("overview") && "true" === this.showInfo)
        t5 = YP.call(this);
      else if ("auth" === e6 && "true" === this.allowAuthentication)
        t5 = hP.call(this);
      else if ("servers" === e6 && "true" === this.allowServerSelection)
        t5 = eR.call(this);
      else if ("operations-top" === e6)
        t5 = q`
    <div id="operations-top" class="observe-me">
      <slot name="operations-top"></slot>
    </div>`;
      else if (e6.startsWith("cmp--") && "true" === this.showComponents)
        t5 = KP.call(this);
      else if (e6.startsWith("tag--")) {
        const r7 = e6.indexOf("--", 4) > 0 ? e6.substring(0, e6.indexOf("--", 5)) : e6;
        n6 = this.resolvedSpec.tags.find((e7) => e7.elementId === r7), t5 = n6 ? aR.call(this, sR.call(this, n6)) : iR.call(this);
      } else {
        for (o5 = 0; o5 < this.resolvedSpec.tags.length && (n6 = this.resolvedSpec.tags[o5], r6 = this.resolvedSpec.tags[o5].paths.find((t6) => `${t6.elementId}` === e6), !r6); o5 += 1)
          ;
        if (r6) {
          tR(this.shadowRoot.getElementById(`link-${e6}`), "expand"), t5 = aR.call(this, HP.call(this, r6, n6.name || "", n6.description || ""));
        } else
          t5 = iR.call(this);
      }
      return t5;
    }
    function cR(e6) {
      if (e6.expanded)
        e6.expanded = false, "true" === this.updateRoute && this.replaceHistoryState("");
      else if (e6.expanded = true, "true" === this.updateRoute) {
        const t5 = `${this.routePrefix || "#"}${e6.elementId}`;
        window.location.hash !== t5 && this.replaceHistoryState(e6.elementId);
      }
      this.requestUpdate();
    }
    function pR(e6, t5 = "expand-all") {
      const r6 = [...e6.querySelectorAll(".section-tag")];
      "expand-all" === t5 ? r6.map((e7) => {
        e7.classList.replace("collapsed", "expanded");
      }) : r6.map((e7) => {
        e7.classList.replace("expanded", "collapsed");
      });
    }
    function dR(e6, t5 = "expand-all") {
      pR.call(this, e6.target.closest(".operations-root"), t5);
    }
    function uR(e6, t5 = false) {
      return q`
  <summary @click="${(t6) => {
        cR.call(this, e6, t6);
      }}" part="section-endpoint-head-${e6.expanded ? "expanded" : "collapsed"}" class='endpoint-head ${e6.method} ${e6.deprecated ? "deprecated" : ""} ${t5 || e6.expanded ? "expanded" : "collapsed"}'>
    <div part="section-endpoint-head-method" class="method ${e6.method} ${e6.deprecated ? "deprecated" : ""}"> ${e6.method} </div> 
    <div  part="section-endpoint-head-path" class="path ${e6.deprecated ? "deprecated" : ""}"> 
      ${e6.path} 
      ${e6.isWebhook ? q`<span style="font-family: var(--font-regular); font-size: var(--); font-size: var(--font-size-small); color:var(--primary-color); margin-left: 16px"> Webhook</span>` : ""}
    </div>
    ${e6.deprecated ? q`
        <span style="font-size:var(--font-size-small); text-transform:uppercase; font-weight:bold; color:var(--red); margin:2px 0 0 5px;"> 
          deprecated 
        </span>` : ""}
    ${this.showSummaryWhenCollapsed ? q`
        <div class="only-large-screen" style="min-width:60px; flex:1"></div>
        <div part="section-endpoint-head-description" class="descr">${e6.summary || e6.shortSummary} </div>` : ""}
  </summary>
  `;
    }
    function hR(e6) {
      var t5, r6, n6, o5, a2, i4, s6;
      const l2 = /* @__PURE__ */ new Set();
      for (const t6 in e6.responses)
        for (const r7 in null === (c3 = e6.responses[t6]) || void 0 === c3 ? void 0 : c3.content) {
          var c3;
          l2.add(r7.trim());
        }
      const p2 = [...l2].join(", "), d2 = this.resolvedSpec.securitySchemes.filter((t6) => {
        var r7;
        return t6.finalKeyValue && (null === (r7 = e6.security) || void 0 === r7 ? void 0 : r7.some((e7) => t6.securitySchemeId in e7));
      }) || [], u3 = this.resolvedSpec.securitySchemes.find((e7) => e7.securitySchemeId === at && "-" !== e7.value);
      u3 && d2.push(u3);
      const h2 = e6.xCodeSamples ? mP(e6.xCodeSamples) : "";
      return q`
  <div part="section-endpoint-body-${e6.expanded ? "expanded" : "collapsed"}" class='endpoint-body ${e6.method} ${e6.deprecated ? "deprecated" : ""}'>
    <div class="summary">
      ${e6.summary ? q`<div class="title" part="section-endpoint-body-title">${e6.summary}<div>` : e6.shortSummary !== e6.description ? q`<div class="title" part="section-endpoint-body-title">${e6.shortSummary}</div>` : ""}
      ${e6.xBadges && (null === (t5 = e6.xBadges) || void 0 === t5 ? void 0 : t5.length) > 0 ? q`
          <div style="display:flex; flex-wrap:wrap;font-size: var(--font-size-small);">
            ${e6.xBadges.map((e7) => q`<span part="endpoint-badge" style="margin:1px; margin-right:5px; padding:1px 8px; font-weight:bold; border-radius:12px;  background-color: var(--light-${e7.color}, var(--input-bg)); color:var(--${e7.color}); border:1px solid var(--${e7.color})">${e7.label}</span>`)}
          </div>
          ` : ""}

      ${e6.description ? q`<div part="section-endpoint-body-description" class="m-markdown"> ${Q_(We(e6.description))}</div>` : ""}
      ${null !== (r6 = e6.externalDocs) && void 0 !== r6 && r6.url || null !== (n6 = e6.externalDocs) && void 0 !== n6 && n6.description ? q`<div style="background-color:var(--bg3); padding:2px 8px 8px 8px; margin:8px 0; border-radius:var(--border-radius)"> 
            <div class="m-markdown"> ${Q_(We((null === (o5 = e6.externalDocs) || void 0 === o5 ? void 0 : o5.description) || ""))} </div>
            ${null !== (a2 = e6.externalDocs) && void 0 !== a2 && a2.url ? q`<a style="font-family:var(--font-mono); font-size:var(--font-size-small)" href="${null === (i4 = e6.externalDocs) || void 0 === i4 ? void 0 : i4.url}" target="_blank"> 
                  ${null === (s6 = e6.externalDocs) || void 0 === s6 ? void 0 : s6.url} <div style="transform: rotate(270deg) scale(1.5); display: inline-block; margin-left:5px">⇲</div>
                </a>` : ""}
          </div>` : ""}
      <slot name="${e6.elementId}"></slot>
      ${fP.call(this, e6.security)}
      ${h2}
    </div>  
    <div class='req-resp-container'> 
      <div style="display:flex; flex-direction:column" class="view-mode-request ${this.layout}-layout">
        <api-request
          class = "${this.renderStyle}-mode ${this.layout}-layout"
          style = "width:100%;"
          webhook = "${e6.isWebhook}"
          method = "${e6.method}"
          path = "${e6.path}"
          .security = "${e6.security}"
          .parameters = "${e6.parameters}"
          .request_body = "${e6.requestBody}"
          .api_keys = "${d2}"
          .servers = "${e6.servers}" 
          server-url = "${e6.servers && e6.servers.length > 0 ? e6.servers[0].url : this.selectedServer.computedUrl}" 
          active-schema-tab = "${this.defaultSchemaTab}"
          fill-request-fields-with-example = "${this.fillRequestFieldsWithExample}"
          allow-try = "${this.allowTry}"
          show-curl-before-try = "${this.showCurlBeforeTry}"
          accept = "${p2}"
          render-style="${this.renderStyle}" 
          schema-style = "${this.schemaStyle}" 
          schema-expand-level = "${this.schemaExpandLevel}"
          schema-description-expanded = "${this.schemaDescriptionExpanded}"
          allow-schema-description-expand-toggle = "${this.allowSchemaDescriptionExpandToggle}"
          schema-hide-read-only = "${"never" === this.schemaHideReadOnly || e6.isWebhook ? "false" : "true"}"
          schema-hide-write-only = "${"never" === this.schemaHideWriteOnly ? "false" : e6.isWebhook ? "true" : "false"}"
          fetch-credentials = "${this.fetchCredentials}"
          exportparts = "wrap-request-btn:wrap-request-btn, btn:btn, btn-fill:btn-fill, btn-outline:btn-outline, btn-try:btn-try, btn-clear:btn-clear, btn-clear-resp:btn-clear-resp,
            file-input:file-input, textbox:textbox, textbox-param:textbox-param, textarea:textarea, textarea-param:textarea-param, 
            anchor:anchor, anchor-param-example:anchor-param-example, schema-description:schema-description, schema-multiline-toggle:schema-multiline-toggle"
          > </api-request>

          ${e6.callbacks ? yP.call(this, e6.callbacks) : ""}
        </div>  

        <api-response
          class = "${this.renderStyle}-mode"
          style = "width:100%;"
          webhook = "${e6.isWebhook}"
          .responses="${e6.responses}"
          active-schema-tab = "${this.defaultSchemaTab}" 
          render-style="${this.renderStyle}" 
          schema-style="${this.schemaStyle}"
          schema-expand-level = "${this.schemaExpandLevel}"
          schema-description-expanded = "${this.schemaDescriptionExpanded}"
          allow-schema-description-expand-toggle = "${this.allowSchemaDescriptionExpandToggle}"
          schema-hide-read-only = "${"never" === this.schemaHideReadOnly ? "false" : e6.isWebhook ? "true" : "false"}"
          schema-hide-write-only = "${"never" === this.schemaHideWriteOnly || e6.isWebhook ? "false" : "true"}"
          selected-status = "${Object.keys(e6.responses || {})[0] || ""}"
          exportparts = "btn:btn, btn-fill:btn-fill, btn-outline:btn-outline, btn-try:btn-try, file-input:file-input, 
          textbox:textbox, textbox-param:textbox-param, textarea:textarea, textarea-param:textarea-param, anchor:anchor, anchor-param-example:anchor-param-example, btn-clear-resp:btn-clear-resp,
          schema-description:schema-description, schema-multiline-toggle:schema-multiline-toggle"
        > </api-response>
      </div>
  </div>`;
    }
    function fR(e6 = true, t5 = true, r6 = false) {
      return this.resolvedSpec ? q`
    ${e6 ? q`
        <div style="display:flex; justify-content:flex-end;"> 
          <span @click="${(e7) => dR(e7, "expand-all")}" style="color:var(--primary-color); cursor:pointer;">
            Expand all
          </span> 
          &nbsp;|&nbsp; 
          <span @click="${(e7) => dR(e7, "collapse-all")}" style="color:var(--primary-color); cursor:pointer;" >
            Collapse all
          </span> 
          &nbsp; sections
        </div>` : ""}
    ${this.resolvedSpec.tags.map((e7) => q`
      ${t5 ? q` 
          <div class='regular-font section-gap section-tag ${e7.expanded ? "expanded" : "collapsed"}'> 
            <div class='section-tag-header' @click="${() => {
        e7.expanded = !e7.expanded, this.requestUpdate();
      }}">
              <div id='${e7.elementId}' class="sub-title tag" style="color:var(--primary-color)">${e7.name}</div>
            </div>
            <div class='section-tag-body'>
              <slot name="${e7.elementId}"></slot>
              <div class="regular-font regular-font-size m-markdown" style="padding-bottom:12px">
                ${Q_(We(e7.description || ""))}
              </div>
              ${e7.paths.filter((e8) => !this.matchPaths || lt(this.matchPaths, e8, this.matchType)).map((e8) => q`
                <section part="section-endpoint" id='${e8.elementId}' class='m-endpoint regular-font ${e8.method} ${r6 || e8.expanded ? "expanded" : "collapsed"}'>
                  ${uR.call(this, e8, r6)}      
                  ${r6 || e8.expanded ? hR.call(this, e8) : ""}
                </section>`)}
            </div>
          </div>` : q`
          <div class='section-tag-body'>
          ${e7.paths.filter((e8) => !this.matchPaths || lt(this.matchPaths, e8, this.matchType)).map((e8) => q`
            <section id='${e8.elementId}' class='m-endpoint regular-font ${e8.method} ${r6 || e8.expanded ? "expanded" : "collapsed"}'>
              ${uR.call(this, e8, r6)}      
              ${r6 || e8.expanded ? hR.call(this, e8) : ""}
            </section>`)}
          </div>
        `}
  `)}` : "";
    }
    function mR() {
      return q`
  <header class="row main-header regular-font" part="section-header" style="padding:8px 4px 8px 4px;min-height:48px;">
    <div class="only-large-screen-flex" style="align-items: center;">
      <slot name="logo" class="logo" part="section-logo">
        ${e6 = "height:36px;width:36px;margin-left:5px", q`
  <div style=${e6}>
    <svg xmlns="http://www.w3.org/2000/svg" viewBox="1 0 511 512">
      <path d="M351 411a202 202 0 01-350 0 203 203 0 01333-24 203 203 0 0117 24zm0 0" fill="#adc165"/>
      <path d="M334 387a202 202 0 01-216-69 202 202 0 01216 69zm78 32H85a8 8 0 01-8-8 8 8 0 018-8h327a8 8 0 017 8 8 8 0 01-7 8zm0 0" fill="#99aa52"/>
      <path d="M374 338l-5 30a202 202 0 01-248-248 203 203 0 01253 218zm0 0" fill="#ffc73b"/>
      <path d="M374 338a202 202 0 01-100-197 203 203 0 01100 197zm38 81l-6-2-231-231a8 8 0 0111-11l231 230a8 8 0 01-5 14zm0 0" fill="#efb025"/>
      <path d="M311 175c0 75 40 140 101 175a202 202 0 000-350 202 202 0 00-101 175zm0 0" fill="#ff903e"/>
      <path d="M412 419a8 8 0 01-8-8V85a8 8 0 0115 0v326a8 8 0 01-7 8zm0 0" fill="#e87425"/>
    </svg>
  </div>    
`}
        <!-- m-logo style="height:36px;width:36px;margin-left:5px"></m-logo -->
      </slot>  
      <div class="header-title" part="label-header-title">${this.headingText}</div>
    </div>  
    <div style="margin: 0px 8px;display:flex;flex:1">
      ${"false" === this.allowSpecUrlLoad ? "" : q`
          <input id="spec-url" 
            type="text" 
            style="font-size:var(--font-size-small)" 
            class="header-input mono-font"
            part="textbox textbox-spec-url" 
            placeholder="Spec URL" 
            value="${this.specUrl || ""}" 
            @change="${this.onSpecUrlChange}" 
            spellcheck="false"
          >
          <div style="margin: 6px 5px 0 -24px; font-size:var(--font-size-regular); cursor:pointer;">&#x21a9;</div> 
        `} 
      ${"false" === this.allowSpecFileLoad ? "" : q`
          <input id="spec-file" 
            part = "file-input"
            type="file" 
            style="display:none" 
            value="${this.specFile || ""}" 
            @change="${this.onSpecFileChange}" 
            spellcheck="false"
           >
          <button class="m-btn primary only-large-screen" style="margin-left:10px;" part="btn btn-fill" @click="${this.onFileLoadClick}"> LOCAL JSON FILE </button>
        `}
      <slot name="header"></slot>
      ${"false" === this.allowSearch || "read focused".includes(this.renderStyle) ? "" : q`  
          <input id="search" class="header-input" type="text" part="textbox textbox-header-filter" placeholder="Filter" @change="${this.onSearchChange}" style="max-width:130px;margin-left:10px;" spellcheck="false" >
          <div style="margin: 6px 5px 0 -24px; font-size:var(--font-size-regular); cursor:pointer;">&#x21a9;</div>
        `}
      
      ${"false" === this.allowAdvancedSearch || "read focused".includes(this.renderStyle) ? "" : q`
          <button class="m-btn primary only-large-screen" part="btn btn-fill btn-search" style="margin-left:10px;" @click="${this.onShowSearchModalClicked}">
            Search
          </button>
        `}
    </div>
    </header>`;
      var e6;
    }
    customElements.define("api-response", class extends ie {
      constructor() {
        super(), this.selectedStatus = "", this.headersForEachRespStatus = {}, this.mimeResponsesForEachStatus = {}, this.activeSchemaTab = "schema";
      }
      static get properties() {
        return { callback: { type: String }, webhook: { type: String }, responses: { type: Object }, parser: { type: Object }, schemaStyle: { type: String, attribute: "schema-style" }, renderStyle: { type: String, attribute: "render-style" }, selectedStatus: { type: String, attribute: "selected-status" }, selectedMimeType: { type: String, attribute: "selected-mime-type" }, activeSchemaTab: { type: String, attribute: "active-schema-tab" }, schemaExpandLevel: { type: Number, attribute: "schema-expand-level" }, schemaDescriptionExpanded: { type: String, attribute: "schema-description-expanded" }, allowSchemaDescriptionExpandToggle: { type: String, attribute: "allow-schema-description-expand-toggle" }, schemaHideReadOnly: { type: String, attribute: "schema-hide-read-only" }, schemaHideWriteOnly: { type: String, attribute: "schema-hide-write-only" } };
      }
      static get styles() {
        return [Ke, Ye, et, Ze, Je, SP, c2`
      :where(button, input[type="checkbox"], [tabindex="0"]):focus-visible { box-shadow: var(--focus-shadow); }
      :where(input[type="text"], input[type="password"], select, textarea):focus-visible { border-color: var(--primary-color); }
      .resp-head{
        vertical-align: middle;
        padding:16px 0 8px;
      }
      .resp-head.divider{
        border-top: 1px solid var(--border-color);
        margin-top:10px;
      }
      .resp-status{ 
        font-weight:bold;
        font-size:calc(var(--font-size-small) + 1px);
      }
      .resp-descr{
        font-size:calc(var(--font-size-small) + 1px);
        color:var(--light-fg);
        text-align:left;
      }
      .top-gap{margin-top:16px;}
      .example-panel{
        font-size:var(--font-size-small);
        margin:0;
      }
      .focused-mode,
      .read-mode {
        padding-top:24px;
        margin-top:12px;
        border-top: 1px dashed var(--border-color);
      }`, nt];
      }
      render() {
        return q`
    <div class="col regular-font response-panel ${this.renderStyle}-mode">
      <div class=" ${"true" === this.callback ? "tiny-title" : "req-res-title"} "> 
        ${"true" === this.callback ? "CALLBACK RESPONSE" : "RESPONSE"}
      </div>
      <div>
        ${this.responseTemplate()}
      <div>  
    </div>  
    `;
      }
      resetSelection() {
        this.selectedStatus = "", this.selectedMimeType = "";
      }
      responseTemplate() {
        if (!this.responses)
          return "";
        for (const n6 in this.responses) {
          this.selectedStatus || (this.selectedStatus = n6);
          const o5 = {};
          for (const r7 in null === (e6 = this.responses[n6]) || void 0 === e6 ? void 0 : e6.content) {
            var e6, t5;
            const a3 = this.responses[n6].content[r7];
            this.selectedMimeType || (this.selectedMimeType = r7);
            const i4 = DP(a3.schema, {}), s6 = BP(a3.schema, r7, a3.examples, a3.example, "true" !== this.callback && "true" !== this.webhook, "true" === this.callback || "true" === this.webhook, r7.includes("json") ? "json" : "text");
            o5[r7] = { description: this.responses[n6].description, examples: s6, selectedExample: (null === (t5 = s6[0]) || void 0 === t5 ? void 0 : t5.exampleId) || "", schemaTree: i4 };
          }
          const a2 = [];
          for (const e7 in null === (r6 = this.responses[n6]) || void 0 === r6 ? void 0 : r6.headers) {
            var r6;
            a2.push({ name: e7, ...this.responses[n6].headers[e7] });
          }
          this.headersForEachRespStatus[n6] = a2, this.mimeResponsesForEachStatus[n6] = o5;
        }
        return q`
      ${Object.keys(this.responses).length > 1 ? q`<div class='row' style='flex-wrap:wrap'>
          ${Object.keys(this.responses).map((e7) => q`
            ${"$$ref" === e7 ? "" : q`
                <button 
                  @click="${() => {
          this.selectedStatus = e7, this.responses[e7].content && Object.keys(this.responses[e7].content)[0] ? this.selectedMimeType = Object.keys(this.responses[e7].content)[0] : this.selectedMimeType = void 0;
        }}"
                  class='m-btn small ${this.selectedStatus === e7 ? "primary" : ""}'
                  part="btn ${this.selectedStatus === e7 ? "btn-response-status btn-selected-response-status" : " btn-response-status"}"
                  style='margin: 8px 4px 0 0'
                > 
                  ${e7} 
                </button>`}`)}` : q`<span>${Object.keys(this.responses)[0]}</span>`}
      </div>

      ${Object.keys(this.responses).map((e7) => {
          var t6, r7;
          return q`
        <div style = 'display: ${e7 === this.selectedStatus ? "block" : "none"}' >
          <div class="top-gap">
            <span class="resp-descr m-markdown ">${Q_(We((null === (t6 = this.responses[e7]) || void 0 === t6 ? void 0 : t6.description) || ""))}</span>
            ${this.headersForEachRespStatus[e7] && (null === (r7 = this.headersForEachRespStatus[e7]) || void 0 === r7 ? void 0 : r7.length) > 0 ? q`${this.responseHeaderListTemplate(this.headersForEachRespStatus[e7])}` : ""}
          </div>
          ${0 === Object.keys(this.mimeResponsesForEachStatus[e7]).length ? "" : q`  
              <div class="tab-panel col">
                <div class="tab-buttons row" @click="${(e8) => {
            "button" === e8.target.tagName.toLowerCase() && (this.activeSchemaTab = e8.target.dataset.tab);
          }}" >
                  <button class="tab-btn ${"example" === this.activeSchemaTab ? "active" : ""}" data-tab = 'example'>EXAMPLE </button>
                  <button class="tab-btn ${"example" !== this.activeSchemaTab ? "active" : ""}" data-tab = 'schema' >SCHEMA</button>
                  <div style="flex:1"></div>
                  ${1 === Object.keys(this.mimeResponsesForEachStatus[e7]).length ? q`<span class='small-font-size gray-text' style='align-self:center; margin-top:8px;'> ${Object.keys(this.mimeResponsesForEachStatus[e7])[0]} </span>` : q`${this.mimeTypeDropdownTemplate(Object.keys(this.mimeResponsesForEachStatus[e7]))}`}
                </div>
                ${"example" === this.activeSchemaTab ? q`<div class ='tab-content col' style = 'flex:1;'>
                      ${this.mimeExampleTemplate(this.mimeResponsesForEachStatus[e7][this.selectedMimeType])}
                    </div>` : q`<div class ='tab-content col' style = 'flex:1;'>
                      ${this.mimeSchemaTemplate(this.mimeResponsesForEachStatus[e7][this.selectedMimeType])}
                    </div>`}
              </div>
            `}`;
        })}
    `;
      }
      responseHeaderListTemplate(e6) {
        return q`
      <div style="padding:16px 0 8px 0" class="resp-headers small-font-size bold-text">RESPONSE HEADERS</div> 
      <table role="presentation" style="border-collapse: collapse; margin-bottom:16px; border:1px solid var(--border-color); border-radius: var(--border-radius)" class="small-font-size mono-font">
        ${e6.map((e7) => {
          var t5, r6;
          return q`
          <tr>
            <td style="padding:8px; vertical-align: baseline; min-width:120px; border-top: 1px solid var(--light-border-color); text-overflow: ellipsis;">
              ${e7.name || ""}
            </td> 
            <td style="padding:4px; vertical-align: baseline; padding:0 5px; border-top: 1px solid var(--light-border-color); text-overflow: ellipsis;">
              ${(null === (t5 = e7.schema) || void 0 === t5 ? void 0 : t5.type) || ""}
            </td> 
            <td style="padding:8px; vertical-align: baseline; border-top: 1px solid var(--light-border-color);text-overflow: ellipsis;">
              <div class="m-markdown-small regular-font" >${Q_(We(e7.description || ""))}</div>
            </td>
            <td style="padding:8px; vertical-align: baseline; border-top: 1px solid var(--light-border-color); text-overflow: ellipsis;">
              ${(null === (r6 = e7.schema) || void 0 === r6 ? void 0 : r6.example) || ""}
            </td>
          </tr>
        `;
        })}
    </table>`;
      }
      mimeTypeDropdownTemplate(e6) {
        return q`
      <select aria-label='mime types' @change="${(e7) => {
          this.selectedMimeType = e7.target.value;
        }}" style='margin-bottom: -1px; z-index:1'>
        ${e6.map((e7) => q`<option value='${e7}' ?selected = '${e7 === this.selectedMimeType}'> ${e7} </option>`)}
      </select>`;
      }
      onSelectExample(e6) {
        [...e6.target.closest(".example-panel").querySelectorAll(".example")].forEach((t5) => {
          t5.style.display = t5.dataset.example === e6.target.value ? "block" : "none";
        });
      }
      mimeExampleTemplate(e6) {
        return e6 ? q`
      ${1 === e6.examples.length ? q`
          ${"json" === e6.examples[0].exampleFormat ? q`
              ${e6.examples[0].exampleSummary && e6.examples[0].exampleSummary.length > 80 ? q`<div style="padding: 4px 0"> ${e6.examples[0].exampleSummary} </div>` : ""}
              ${e6.examples[0].exampleDescription ? q`<div class="m-markdown-small" style="padding: 4px 0"> ${Q_(We(e6.examples[0].exampleDescription || ""))} </div>` : ""}
              <json-tree 
                render-style = '${this.renderStyle}'
                .data="${e6.examples[0].exampleValue}"
                class = 'example-panel ${"read" === this.renderStyle ? "border pad-8-16" : "border-top pad-top-8"}'
                exportparts = "btn:btn, btn-fill:btn-fill, btn-copy:btn-copy" 
              ></json-tree>` : q`
              ${e6.examples[0].exampleSummary && e6.examples[0].exampleSummary.length > 80 ? q`<div style="padding: 4px 0"> ${e6.examples[0].exampleSummary} </div>` : ""}
              ${e6.examples[0].exampleDescription ? q`<div class="m-markdown-small" style="padding: 4px 0"> ${Q_(We(e6.examples[0].exampleDescription || ""))} </div>` : ""}
              <pre class = 'example-panel ${"read" === this.renderStyle ? "border pad-8-16" : "border-top pad-top-8"}'>${e6.examples[0].exampleValue}</pre>
            `}` : q`
          <span class = 'example-panel ${"read" === this.renderStyle ? "border pad-8-16" : "border-top pad-top-8"}'>
            <select aria-label='response examples' style="min-width:100px; max-width:100%" @change='${(e7) => this.onSelectExample(e7)}'>
              ${e6.examples.map((t5) => q`<option value="${t5.exampleId}" ?selected=${t5.exampleId === e6.selectedExample} > 
                ${t5.exampleSummary.length > 80 ? t5.exampleId : t5.exampleSummary} 
              </option>`)}
            </select>
            ${e6.examples.map((t5) => q`
              <div class="example" data-example = '${t5.exampleId}' style = "display: ${t5.exampleId === e6.selectedExample ? "block" : "none"}">
                ${t5.exampleSummary && t5.exampleSummary.length > 80 ? q`<div style="padding: 4px 0"> ${t5.exampleSummary} </div>` : ""}
                ${t5.exampleDescription ? q`<div class="m-markdown-small"  style="padding: 4px 0"> ${Q_(We(t5.exampleDescription || ""))} </div>` : ""}
                ${"json" === t5.exampleFormat ? q`
                    <json-tree 
                      render-style = '${this.renderStyle}'
                      .data = '${t5.exampleValue}'
                      exportparts = "btn:btn, btn-fill:btn-fill, btn-copy:btn-copy" 
                    ></json-tree>` : q`<pre>${t5.exampleValue}</pre>`}
              </div>  
            `)}
          </span>  
        `}
    ` : q`
        <pre style='color:var(--red)' class = '${"read" === this.renderStyle ? "read example-panel border pad-8-16" : "example-panel border-top"}'> No example provided </pre>
      `;
      }
      mimeSchemaTemplate(e6) {
        return e6 ? q`
      ${"table" === this.schemaStyle ? q`
          <schema-table
            .data = "${e6.schemaTree}"
            schema-expand-level = "${this.schemaExpandLevel}"
            schema-description-expanded = "${this.schemaDescriptionExpanded}"
            allow-schema-description-expand-toggle = "${this.allowSchemaDescriptionExpandToggle}"
            schema-hide-read-only = "${this.schemaHideReadOnly}"
            schema-hide-write-only = "${this.schemaHideWriteOnly}"
            exportparts = "schema-description:schema-description, schema-multiline-toggle:schema-multiline-toggle"
          > </schema-table> ` : q`
          <schema-tree
            .data = '${e6.schemaTree}'
            schema-expand-level = "${this.schemaExpandLevel}"
            schema-description-expanded = "${this.schemaDescriptionExpanded}"
            allow-schema-description-expand-toggle = "${this.allowSchemaDescriptionExpandToggle}"
            schema-hide-read-only = "${this.schemaHideReadOnly}"
            schema-hide-write-only = "${this.schemaHideWriteOnly}"
            exportparts = "schema-description:schema-description, schema-multiline-toggle:schema-multiline-toggle"
          > </schema-tree>`}` : q`
        <pre style='color:var(--red)' class = '${"read" === this.renderStyle ? "border pad-8-16" : "border-top"}'> Schema not found</pre>
      `;
      }
    });
    const yR = c2`
  *, *:before, *:after { box-sizing: border-box; }

  .dialog-box-overlay {
    background-color: var(--overlay-bg);
    position: fixed;
    left: 0;
    top: 0;
    width: 100vw;
    height: 100vh;
    overflow: hidden;
    z-index: var(--dialog-z-index);
  }
  
  .dialog-box {
    position: fixed;
    top: 100px;
    left: 50%;
    transform: translate(-50%, 0%);
    display: flex;
    flex-direction: column;
    width: 70vw;
    background-color: var(--bg2);
    color: var(--fg2);
    border-radius: 4px;
    max-height: 500px;
    overflow: hidden;
    border: 1px solid var(--border-color);
    box-shadow: 0 14px 28px rgba(0,0,0,0.25), 0 10px 10px rgba(0,0,0,0.22);
  }
  
  .dialog-box-header {
    position: sticky;
    top: 0;
    align-self: stretch;
    display: flex;
    align-items: center;
    padding: 0px 16px;
    min-height: 60px;
    max-height: 60px;
    border-bottom: 1px solid var(--light-border-color);
    overflow: hidden;
  }
  
  .dialog-box-header button {
    font-size: 1.5rem;
    font-weight: 700;
    line-height: 1;
    color: var(--fg);
    border: none;
    outline: none;
    background-color: transparent;
    cursor:pointer;
    border: 1px solid transparent;
    border-radius: 50%;
    margin-right: -8px;
  }
  .dialog-box-header button:hover {
    border-color: var(--primary-color);
  }

  .dialog-box-content {
    padding: 16px;
    display:block;
    overflow: auto;
    height: 100%;
  }

  .dialog-box-title {
    flex-grow: 1;
    font-size:24px;
  }
`;
    function gR() {
      var e6;
      return document.addEventListener("close", () => {
        this.showAdvancedSearchDialog = false;
      }), document.addEventListener("open", this.onOpenSearchDialog), q`
    <dialog-box 
      heading="Search" 
      show="${!!this.showAdvancedSearchDialog}"
    >
      <span class="advanced-search-options">
        <input
          style="width:100%; padding-right:20px;"
          type="text"
          part="textbox textbox-search-dialog"
          placeholder="search text..."
          spellcheck="false"
          @keyup = "${(e7) => this.onAdvancedSearch(e7, 400)}"
        >
        <div style="display:flex; margin:8px 0 24px;">
          <div>
            <input style="cursor:pointer;" type="checkbox" part="checkbox checkbox-search-dialog" id="search-api-path" checked @change = "${(e7) => this.onAdvancedSearch(e7, 0)}">
            <label for="search-api-path" style="cursor:pointer;"> API Path </label>
            </div>
          <div style="margin-left: 16px;">
            <input style="cursor:pointer;" type="checkbox" part="checkbox checkbox-search-dialog" id="search-api-descr" checked @change = "${(e7) => this.onAdvancedSearch(e7, 0)}">
            <label style="cursor:pointer;" for="search-api-descr"> API Description </label>
          </div>
          <div style="margin-left: 16px;">
            <input style="cursor:pointer;" type="checkbox" part="checkbox checkbox-search-dialog" id="search-api-params" @change = "${(e7) => this.onAdvancedSearch(e7, 0)}">
            <label style="cursor:pointer;" for="search-api-params"> API Parameters </label>
          </div>
          <div style="margin-left: 16px;">
            <input style="cursor:pointer;" type="checkbox" part="checkbox checkbox-search-dialog" id="search-api-request-body" @change = "${(e7) => this.onAdvancedSearch(e7, 0)}">
            <label style="cursor:pointer;" for="search-api-request-body"> Request Body Parameters </label>
          </div>
          <div style="margin-left: 16px;">
            <input style="cursor:pointer;" type="checkbox" part="checkbox checkbox-search-dialog" id="search-api-resp-descr" @change = "${(e7) => this.onAdvancedSearch(e7, 0)}">
            <label style="cursor:pointer;" for="search-api-resp-descr"> Response Description </label>
          </div>
        </div>
      </span>
      
      ${null === (e6 = this.advancedSearchMatches) || void 0 === e6 ? void 0 : e6.map((e7) => q`
      <div
        class="mono-font small-font-size hover-bg"
        style='padding: 5px; cursor: pointer; border-bottom: 1px solid var(--light-border-color); ${e7.deprecated ? "filter:opacity(0.5);" : ""}' 
        data-content-id='${e7.elementId}'
        tabindex = '0'
        @click="${(e8) => {
        this.matchPaths = "", this.showAdvancedSearchDialog = false, this.requestUpdate(), this.scrollToEventTarget(e8, true);
      }}"
      > 
        <span class="upper bold-text method-fg ${e7.method}">${e7.method}</span> 
        <span>${e7.path}</span>
        <span class="regular-font gray-text">${e7.summary}</span>
      </div>
    `)}
    </dialog-box>
  `;
    }
    customElements.define("dialog-box", class extends ie {
      static get properties() {
        return { heading: { type: String, attribute: "heading" }, show: { type: String, attribute: "show" } };
      }
      static get styles() {
        return [yR];
      }
      connectedCallback() {
        super.connectedCallback(), document.addEventListener("keydown", (e6) => {
          "Escape" === e6.code && this.onClose();
        });
      }
      attributeChangedCallback(e6, t5, r6) {
        t5 !== r6 && ("heading" === e6 && (this.heading = r6), "show" === e6 && (this.show = r6, "true" === r6 && document.dispatchEvent(new CustomEvent("open", { bubbles: true, composed: true, detail: this })))), super.attributeChangedCallback(e6, t5, r6);
      }
      render() {
        return q`
    ${"true" === this.show ? q`
        <div class="dialog-box-overlay">
          <div class="dialog-box">
            <header class="dialog-box-header">
              <span class="dialog-box-title">${this.heading}</span>
              <button type="button" @click="${this.onClose}">&times;</button>
            </header>
            <div class="dialog-box-content">
              <slot></slot>
            </div>
          </div>
        </div>` : ""}`;
      }
      onClose() {
        document.dispatchEvent(new CustomEvent("close", { bubbles: true, composed: true }));
      }
    });
    const vR = { color: { inputReverseFg: "#fff", inputReverseBg: "#333", headerBg: "#444", getRgb(e6) {
      if (0 === e6.indexOf("#") && (e6 = e6.slice(1, 7)), 3 !== e6.length && 4 !== e6.length || (e6 = e6[0] + e6[0] + e6[1] + e6[1] + e6[2] + e6[2]), 6 !== e6.length)
        throw new Error("Invalid HEX color.");
      return { r: parseInt(e6.slice(0, 2), 16), g: parseInt(e6.slice(2, 4), 16), b: parseInt(e6.slice(4, 6), 16) };
    }, luminanace(e6) {
      const t5 = this.getRgb(e6);
      return 0.299 * t5.r + 0.587 * t5.g + 0.114 * t5.b;
    }, invert(e6) {
      return this.luminanace(e6) > 135 ? "#000" : "#fff";
    }, opacity(e6, t5) {
      const r6 = this.getRgb(e6);
      return `rgba(${r6.r}, ${r6.g}, ${r6.b}, ${t5})`;
    }, brightness(e6, t5) {
      const r6 = this.getRgb(e6);
      return r6.r += t5, r6.g += t5, r6.b += t5, r6.r > 255 ? r6.r = 255 : r6.r < 0 && (r6.r = 0), r6.g > 255 ? r6.g = 255 : r6.g < 0 && (r6.g = 0), r6.b > 255 ? r6.b = 255 : r6.b < 0 && (r6.b = 0), `#${r6.r.toString(16).padStart(2, "0")}${r6.g.toString(16).padStart(2, "0")}${r6.b.toString(16).padStart(2, "0")}`;
    }, hasGoodContrast(e6, t5) {
      return this.luminanace(e6) - this.luminanace(t5);
    } } };
    function bR(e6) {
      return /^#([A-Fa-f0-9]{6}|[A-Fa-f0-9]{3}|[A-Fa-f0-9]{8}|[A-Fa-f0-9]{4})$/i.test(e6);
    }
    function xR(e6, t5 = {}) {
      let r6 = {};
      const n6 = t5.primaryColor ? t5.primaryColor : "dark" === e6 ? "#f76b39" : "#ff591e", o5 = vR.color.invert(n6), a2 = vR.color.opacity(n6, "0.4");
      if ("dark" === e6) {
        const e7 = t5.bg1 ? t5.bg1 : "#2a2b2c", i4 = t5.fg1 ? t5.fg1 : "#bbb", s6 = t5.bg2 ? t5.bg2 : vR.color.brightness(e7, 5), l2 = t5.bg3 ? t5.bg3 : vR.color.brightness(e7, 17), c3 = t5.bg3 ? t5.bg3 : vR.color.brightness(e7, 35), p2 = t5.fg2 ? t5.fg2 : vR.color.brightness(i4, -15), d2 = t5.fg3 ? t5.fg3 : vR.color.brightness(i4, -20), u3 = t5.fg3 ? t5.fg3 : vR.color.brightness(i4, -65), h2 = t5.inlineCodeFg ? t5.inlineCodeFg : "#aaa", f3 = "#bbb", m2 = "#eee", y2 = t5.headerColor ? t5.headerColor : vR.color.brightness(e7, 10), g2 = t5.navBgColor ? t5.navBgColor : vR.color.brightness(e7, 10), v2 = t5.navTextColor ? t5.navTextColor : vR.color.opacity(vR.color.invert(g2), "0.50"), b2 = t5.navHoverBgColor ? t5.navHoverBgColor : vR.color.brightness(g2, -15), x3 = t5.navHoverTextColor ? t5.navHoverTextColor : vR.color.invert(g2), w2 = t5.navAccentColor ? t5.navAccentColor : vR.color.brightness(n6, 25);
        r6 = { bg1: e7, bg2: s6, bg3: l2, lightBg: c3, fg1: i4, fg2: p2, fg3: d2, lightFg: u3, inlineCodeFg: h2, primaryColor: n6, primaryColorTrans: a2, primaryColorInvert: o5, selectionBg: f3, selectionFg: m2, overlayBg: "rgba(80, 80, 80, 0.4)", navBgColor: g2, navTextColor: v2, navHoverBgColor: b2, navHoverTextColor: x3, navAccentColor: w2, navAccentTextColor: t5.navAccentTextColor ? t5.navAccenttextColor : vR.color.invert(w2), headerColor: y2, headerColorInvert: vR.color.invert(y2), headerColorDarker: vR.color.brightness(y2, -20), headerColorBorder: vR.color.brightness(y2, 10), borderColor: t5.borderColor || vR.color.brightness(e7, 20), lightBorderColor: t5.lightBorderColor || vR.color.brightness(e7, 15), codeBorderColor: t5.codeBorderColor || vR.color.brightness(e7, 30), inputBg: t5.inputBg || vR.color.brightness(e7, -5), placeHolder: t5.placeHolder || vR.color.opacity(i4, "0.3"), hoverColor: t5.hoverColor || vR.color.brightness(e7, -10), red: t5.red ? t5.red : "#F06560", lightRed: t5.lightRed ? t5.lightRed : vR.color.brightness(e7, -10), pink: t5.pink ? t5.pink : "#ffb2b2", lightPink: t5.lightPink || vR.color.brightness(e7, -10), green: t5.green || "#7ec699", lightGreen: t5.lightGreen || vR.color.brightness(e7, -10), blue: t5.blue || "#71b7ff", lightBlue: t5.lightBlue || vR.color.brightness(e7, -10), orange: t5.orange ? t5.orange : "#f08d49", lightOrange: t5.lightOrange || vR.color.brightness(e7, -10), yellow: t5.yellow || "#827717", lightYellow: t5.lightYellow || vR.color.brightness(e7, -10), purple: t5.purple || "#786FF1", brown: t5.brown || "#D4AC0D", codeBg: t5.codeBg || vR.color.opacity(vR.color.brightness(e7, -15), 0.7), codeFg: t5.codeFg || "#aaa", codePropertyColor: t5.codePropertyColor || "#f8c555", codeKeywordColor: t5.codeKeywordColor || "#cc99cd", codeOperatorColor: t5.codeOperatorColor || "#67cdcc" };
      } else {
        const e7 = t5.bg1 ? t5.bg1 : "#fafbfc", i4 = t5.fg1 ? t5.fg1 : "#444444", s6 = t5.bg2 ? t5.bg2 : vR.color.brightness(e7, -5), l2 = t5.bg3 ? t5.bg3 : vR.color.brightness(e7, -15), c3 = t5.bg3 ? t5.bg3 : vR.color.brightness(e7, -45), p2 = t5.fg2 ? t5.fg2 : vR.color.brightness(i4, 17), d2 = t5.fg3 ? t5.fg3 : vR.color.brightness(i4, 30), u3 = t5.fg3 ? t5.fg3 : vR.color.brightness(i4, 70), h2 = t5.inlineCodeFg ? t5.inlineCodeFg : "brown", f3 = "#444", m2 = "#eee", y2 = t5.headerColor ? t5.headerColor : vR.color.brightness(e7, -180), g2 = t5.navBgColor ? t5.navBgColor : vR.color.brightness(e7, -200), v2 = t5.navTextColor ? t5.navTextColor : vR.color.opacity(vR.color.invert(g2), "0.65"), b2 = t5.navHoverBgColor ? t5.navHoverBgColor : vR.color.brightness(g2, -15), x3 = t5.navHoverTextColor ? t5.navHoverTextColor : vR.color.invert(g2), w2 = t5.navAccentColor ? t5.navAccentColor : vR.color.brightness(n6, 25);
        r6 = { bg1: e7, bg2: s6, bg3: l2, lightBg: c3, fg1: i4, fg2: p2, fg3: d2, lightFg: u3, inlineCodeFg: h2, primaryColor: n6, primaryColorTrans: a2, primaryColorInvert: o5, selectionBg: f3, selectionFg: m2, overlayBg: "rgba(0, 0, 0, 0.4)", navBgColor: g2, navTextColor: v2, navHoverBgColor: b2, navHoverTextColor: x3, navAccentColor: w2, navAccentTextColor: t5.navAccentTextColor ? t5.navAccenttextColor : vR.color.invert(w2), headerColor: y2, headerColorInvert: vR.color.invert(y2), headerColorDarker: vR.color.brightness(y2, -20), headerColorBorder: vR.color.brightness(y2, 10), borderColor: t5.borderColor || vR.color.brightness(e7, -38), lightBorderColor: t5.lightBorderColor || vR.color.brightness(e7, -23), codeBorderColor: t5.codeBorderColor || "transparent", inputBg: t5.inputBg || vR.color.brightness(e7, 10), placeHolder: t5.placeHolder || vR.color.brightness(u3, 20), hoverColor: t5.hoverColor || vR.color.brightness(e7, -5), red: t5.red || "#F06560", lightRed: t5.lightRed || "#fff0f0", pink: t5.pink ? t5.pink : "#990055", lightPink: t5.lightPink ? t5.lightPink : "#ffb2b2", green: t5.green || "#690", lightGreen: t5.lightGreen || "#fbfff0", blue: t5.blue || "#47AFE8", lightBlue: t5.lightBlue || "#eff8fd", orange: t5.orange || "#FF9900", lightOrange: t5.lightOrange || "#fff5e6", yellow: t5.yellow || "#827717", lightYellow: t5.lightYellow || "#fff5cc", purple: t5.purple || "#786FF1", brown: t5.brown || "#D4AC0D", codeBg: t5.codeBg || vR.color.opacity(vR.color.brightness(e7, -15), 0.7), codeFg: t5.codeFg || "#666", codePropertyColor: t5.codePropertyColor || "#905", codeKeywordColor: t5.codeKeywordColor || "#07a", codeOperatorColor: t5.codeOperatorColor || "#9a6e3a" };
      }
      return q`
  <style>
  *, *:before, *:after { box-sizing: border-box; }
  
  :host {
    /* Common Styles - irrespective of themes */  
    --border-radius: 2px;
    --layout: ${this.layout || "row"};
    --font-mono: ${this.monoFont || 'Monaco, "Andale Mono", "Roboto Mono", Consolas, monospace'};
    --font-regular: ${this.regularFont || '"Open Sans", Avenir, "Segoe UI", Arial, sans-serif'};
    --scroll-bar-width: 8px;
    --nav-item-padding: ${"relaxed" === this.navItemSpacing ? "10px 16px 10px 10px" : "compact" === this.navItemSpacing ? "5px 16px 5px 10px" : "7px 16px 7px 10px"};
    
    --resp-area-height: ${this.responseAreaHeight};
    --font-size-small: ${"default" === this.fontSize ? "12px" : "large" === this.fontSize ? "13px" : "14px"};
    --font-size-mono: ${"default" === this.fontSize ? "13px" : "large" === this.fontSize ? "14px" : "15px"};
    --font-size-regular: ${"default" === this.fontSize ? "14px" : "large" === this.fontSize ? "15px" : "16px"};
    --dialog-z-index: 1000;

    --focus-shadow: 0 0 0 1px transparent, 0 0 0 3px ${r6.primaryColorTrans};

    /* Theme specific styles */  
    --bg:${r6.bg1};
    --bg2:${r6.bg2};
    --bg3:${r6.bg3};
    --light-bg:${r6.lightBg};
    --fg:${r6.fg1};
    --fg2:${r6.fg2};
    --fg3:${r6.fg3};
    --light-fg:${r6.lightFg};
    --selection-bg:${r6.selectionBg};
    --selection-fg:${r6.selectionFg};
    --overlay-bg:${r6.overlayBg};
    
    /* Border Colors */
    --border-color:${r6.borderColor};
    --light-border-color:${r6.lightBorderColor};
    --code-border-color:${r6.codeBorderColor};

    --input-bg:${r6.inputBg};
    --placeholder-color:${r6.placeHolder};
    --hover-color:${r6.hoverColor};
    --red:${r6.red};
    --light-red:${r6.lightRed};
    --pink:${r6.pink};
    --light-pink:${r6.lightPink};
    --green:${r6.green};
    --light-green:${r6.lightGreen};
    --blue:${r6.blue};
    --light-blue:${r6.lightBlue};
    --orange:${r6.orange};
    --light-orange:${r6.lightOrange};
    --yellow:${r6.yellow};
    --light-yellow:${r6.lightYellow};
    --purple:${r6.purple};
    --brown:${r6.brown};

    /* Header Color */
    --header-bg:${r6.headerColor};
    --header-fg:${r6.headerColorInvert};
    --header-color-darker:${r6.headerColorDarker};
    --header-color-border:${r6.headerColorBorder};

    /* Nav Colors */  
    --nav-bg-color:${r6.navBgColor};
    --nav-text-color:${r6.navTextColor};
    --nav-hover-bg-color:${r6.navHoverBgColor};
    --nav-hover-text-color:${r6.navHoverTextColor};
    --nav-accent-color:${r6.navAccentColor};
    --nav-accent-text-color:${r6.navAccentTextColor};

    /* Nav API Method Colors*/
    --nav-get-color:${r6.blue};
    --nav-put-color:${r6.orange};
    --nav-post-color:${r6.green};
    --nav-delete-color:${r6.red};
    --nav-head-color:${r6.yellow};

    /* Primary Colors */  
    --primary-color:${r6.primaryColor};
    --primary-color-invert:${r6.primaryColorInvert};
    --primary-color-trans:${r6.primaryColorTrans};

    /*Code Syntax Color*/
    --code-bg:${r6.codeBg};
    --code-fg:${r6.codeFg};
    --inline-code-fg:${r6.inlineCodeFg};
    --code-property-color:${r6.codePropertyColor};
    --code-keyword-color:${r6.codeKeywordColor};
    --code-operator-color:${r6.codeOperatorColor};
  }
  </style>`;
    }
    function wR(e6 = false, t5 = true, r6 = true, n6 = false) {
      if (!this.resolvedSpec)
        return "";
      "true" === this.persistAuth && aP.call(this);
      const o5 = { bg1: bR(this.bgColor) ? this.bgColor : "", fg1: bR(this.textColor) ? this.textColor : "", headerColor: bR(this.headerColor) ? this.headerColor : "", primaryColor: bR(this.primaryColor) ? this.primaryColor : "", navBgColor: bR(this.navBgColor) ? this.navBgColor : "", navTextColor: bR(this.navTextColor) ? this.navTextColor : "", navHoverBgColor: bR(this.navHoverBgColor) ? this.navHoverBgColor : "", navHoverTextColor: bR(this.navHoverTextColor) ? this.navHoverTextColor : "", navAccentColor: bR(this.navAccentColor) ? this.navAccentColor : "", navAccentTextColor: bR(this.navAccentTextColor) ? this.navAccentTextColor : "" };
      return this.resolvedSpec.specLoadError ? e6 ? q`
        ${"dark" === this.theme ? xR.call(this, "dark", o5) : xR.call(this, "light", o5)}
        <div style='display:flex; align-items:center; border:1px dashed var(--border-color); height:42px; padding:5px; font-size:var(--font-size-small); color:var(--red); font-family:var(--font-mono)'> ${this.resolvedSpec.info.description} </div>
      ` : q`
      ${"dark" === this.theme ? xR.call(this, "dark", o5) : xR.call(this, "light", o5)}
      <!-- Header -->
      ${mR.call(this)}
      <main class='main-content regular-font' part='section-main-content'>
        <slot></slot>
        <div style='margin:24px; text-align: center;'>
          <h1 style='color: var(--red)'> ${this.resolvedSpec.info.title} </h1>
          <div style='font-family:var(--font-mono)'> ${this.resolvedSpec.info.description} </div>
        </div>
      </main>  
    ` : this.resolvedSpec.isSpecLoading ? q`
      ${"dark" === this.theme ? xR.call(this, "dark", o5) : xR.call(this, "light", o5)}
      <main class='main-content regular-font' part='section-main-content'>
        <slot></slot>
        <div class='main-content-inner--${this.renderStyle}-mode'>
          <div class='loader'></div>
        </div>
      </main>
    ` : q`
    ${"dark" === this.theme ? xR.call(this, "dark", o5) : xR.call(this, "light", o5)}

    <!-- Header -->
    ${"false" === this.showHeader ? "" : mR.call(this)}
    
    <!-- Advanced Search -->
    ${"false" === this.allowAdvancedSearch ? "" : gR.call(this)}

    <div id='the-main-body' class='body ${this.cssClasses}' dir='${this.pageDirection}' >
      <!-- Side Nav -->
      ${"read" !== this.renderStyle && "focused" !== this.renderStyle || "true" !== this.showSideNav || !this.resolvedSpec ? "" : nR.call(this)}

      <!-- Main Content -->
      <main class='main-content regular-font' tabindex='-1' part='section-main-content'>
        <slot></slot>
        <div class='main-content-inner--${this.renderStyle}-mode'>
          ${true === this.loading ? q`<div class='loader'></div>` : q`
              ${true === this.loadFailed ? q`<div style='text-align: center;margin: 16px;'> Unable to load the Spec</div>` : q`
                  <div class='operations-root' @click='${(e7) => {
        this.handleHref(e7);
      }}'>
                  ${"focused" === this.renderStyle ? q`${lR.call(this)}` : q`
                      ${"true" === this.showInfo ? YP.call(this) : ""}
                      ${"true" === this.allowServerSelection ? eR.call(this) : ""}
                      ${"true" === this.allowAuthentication ? hP.call(this) : ""}
                      <div id='operations-top' class='observe-me'>
                        <slot name='operations-top'></slot>
                      </div>  
                      ${"read" === this.renderStyle ? WP.call(this) : fR.call(this, t5, r6, n6)}
                    `}
                  </div>
                `}`}
        </div>
        <slot name='footer'></slot>
      </main>
    </div>  
  `;
    }
    class $R extends ie {
      constructor() {
        super();
        const e6 = { root: this.getRootNode().host, rootMargin: "-50px 0px -50px 0px", threshold: 0 };
        this.showSummaryWhenCollapsed = true, this.isIntersectionObserverActive = false, this.intersectionObserver = new IntersectionObserver((e7) => {
          this.onIntersect(e7);
        }, e6);
      }
      static get properties() {
        return { headingText: { type: String, attribute: "heading-text" }, gotoPath: { type: String, attribute: "goto-path" }, updateRoute: { type: String, attribute: "update-route" }, routePrefix: { type: String, attribute: "route-prefix" }, specUrl: { type: String, attribute: "spec-url" }, sortTags: { type: String, attribute: "sort-tags" }, generateMissingTags: { type: String, attribute: "generate-missing-tags" }, sortEndpointsBy: { type: String, attribute: "sort-endpoints-by" }, specFile: { type: String, attribute: false }, layout: { type: String }, renderStyle: { type: String, attribute: "render-style" }, defaultSchemaTab: { type: String, attribute: "default-schema-tab" }, responseAreaHeight: { type: String, attribute: "response-area-height" }, fillRequestFieldsWithExample: { type: String, attribute: "fill-request-fields-with-example" }, persistAuth: { type: String, attribute: "persist-auth" }, onNavTagClick: { type: String, attribute: "on-nav-tag-click" }, schemaStyle: { type: String, attribute: "schema-style" }, schemaExpandLevel: { type: Number, attribute: "schema-expand-level" }, schemaDescriptionExpanded: { type: String, attribute: "schema-description-expanded" }, schemaHideReadOnly: { type: String, attribute: "schema-hide-read-only" }, schemaHideWriteOnly: { type: String, attribute: "schema-hide-write-only" }, apiKeyName: { type: String, attribute: "api-key-name" }, apiKeyLocation: { type: String, attribute: "api-key-location" }, apiKeyValue: { type: String, attribute: "api-key-value" }, defaultApiServerUrl: { type: String, attribute: "default-api-server" }, serverUrl: { type: String, attribute: "server-url" }, oauthReceiver: { type: String, attribute: "oauth-receiver" }, showHeader: { type: String, attribute: "show-header" }, showSideNav: { type: String, attribute: "show-side-nav" }, showInfo: { type: String, attribute: "show-info" }, allowAuthentication: { type: String, attribute: "allow-authentication" }, allowTry: { type: String, attribute: "allow-try" }, showCurlBeforeTry: { type: String, attribute: "show-curl-before-try" }, allowSpecUrlLoad: { type: String, attribute: "allow-spec-url-load" }, allowSpecFileLoad: { type: String, attribute: "allow-spec-file-load" }, allowSpecFileDownload: { type: String, attribute: "allow-spec-file-download" }, allowSearch: { type: String, attribute: "allow-search" }, allowAdvancedSearch: { type: String, attribute: "allow-advanced-search" }, allowServerSelection: { type: String, attribute: "allow-server-selection" }, allowSchemaDescriptionExpandToggle: { type: String, attribute: "allow-schema-description-expand-toggle" }, showComponents: { type: String, attribute: "show-components" }, pageDirection: { type: String, attribute: "page-direction" }, theme: { type: String }, bgColor: { type: String, attribute: "bg-color" }, textColor: { type: String, attribute: "text-color" }, headerColor: { type: String, attribute: "header-color" }, primaryColor: { type: String, attribute: "primary-color" }, fontSize: { type: String, attribute: "font-size" }, regularFont: { type: String, attribute: "regular-font" }, monoFont: { type: String, attribute: "mono-font" }, loadFonts: { type: String, attribute: "load-fonts" }, cssFile: { type: String, attribute: "css-file" }, cssClasses: { type: String, attribute: "css-classes" }, navBgColor: { type: String, attribute: "nav-bg-color" }, navTextColor: { type: String, attribute: "nav-text-color" }, navHoverBgColor: { type: String, attribute: "nav-hover-bg-color" }, navHoverTextColor: { type: String, attribute: "nav-hover-text-color" }, navAccentColor: { type: String, attribute: "nav-accent-color" }, navAccentTextColor: { type: String, attribute: "nav-accent-text-color" }, navActiveItemMarker: { type: String, attribute: "nav-active-item-marker" }, navItemSpacing: { type: String, attribute: "nav-item-spacing" }, showMethodInNavBar: { type: String, attribute: "show-method-in-nav-bar" }, usePathInNavBar: { type: String, attribute: "use-path-in-nav-bar" }, infoDescriptionHeadingsInNavBar: { type: String, attribute: "info-description-headings-in-navbar" }, fetchCredentials: { type: String, attribute: "fetch-credentials" }, matchPaths: { type: String, attribute: "match-paths" }, matchType: { type: String, attribute: "match-type" }, loading: { type: Boolean }, focusedElementId: { type: String }, showAdvancedSearchDialog: { type: Boolean }, advancedSearchMatches: { type: Object } };
      }
      static get styles() {
        return [Ke, Je, Ye, Ze, Qe, Xe, et, tt, rt, c2`
      :host {
        display:flex;
        flex-direction: column;
        min-width:360px;
        width:100%;
        height:100%;
        margin:0;
        padding:0;
        overflow: hidden;
        letter-spacing:normal;
        color:var(--fg);
        background-color:var(--bg);
        font-family:var(--font-regular);
      }
      :where(button, input[type="checkbox"], [tabindex="0"]):focus-visible { box-shadow: var(--focus-shadow); }
      :where(input[type="text"], input[type="password"], select, textarea):focus-visible { border-color: var(--primary-color); }
    .body {
        display:flex;
        height:100%;
        width:100%;
        overflow:hidden;
      }
      .main-content { 
        margin:0;
        padding: 0; 
        display:block;
        flex:1;
        height:100%;
        overflow-y: auto;
        overflow-x: hidden;
        scrollbar-width: thin;
        scrollbar-color: var(--border-color) transparent;
      }

      .main-content-inner--view-mode {
        padding: 0 8px;
      }
      .main-content::-webkit-scrollbar {
        width: 8px;
        height: 8px;
      }
      .main-content::-webkit-scrollbar-track {
        background:transparent;
      }
      .main-content::-webkit-scrollbar-thumb {
        background-color: var(--border-color);
      }

      .section-gap.section-tag {
        border-bottom:1px solid var(--border-color);
      }
      .section-gap,
      .section-gap--focused-mode,
      .section-gap--read-mode { 
        padding: 0px 4px; 
      }
      .section-tag-header {
        position:relative;
        cursor: n-resize;
        padding: 12px 0;
      }
      .collapsed .section-tag-header:hover{
        cursor: s-resize;
      }

      .section-tag-header:hover{
        background-image: linear-gradient(to right, rgba(0,0,0,0), var(--border-color), rgba(0,0,0,0));
      }

      .section-tag-header:hover::after {
        position:absolute;
        margin-left:-24px;
        font-size:20px;
        top: calc(50% - 14px);
        color:var(--primary-color);
        content: '⬆'; 
      }

      .collapsed .section-tag-header::after {
        position:absolute;
        margin-left:-24px;
        font-size:20px;
        top: calc(50% - 14px);
        color: var(--border-color);
        content: '⬇'; 
      }
      .collapsed .section-tag-header:hover::after {
        color:var(--primary-color);
      }

      .collapsed .section-tag-body {
        display:none;
      }

      .logo {
        height:36px;
        width:36px;
        margin-left:5px; 
      }
      .only-large-screen-flex,
      .only-large-screen{
        display:none;
      }
      .tag.title {
        text-transform: uppercase;
      }
      .main-header {
        background-color:var(--header-bg);
        color:var(--header-fg);
        width:100%;
      }
      .header-title {
        font-size:calc(var(--font-size-regular) + 8px); 
        padding:0 8px;
      }
      input.header-input{
        background:var(--header-color-darker);
        color:var(--header-fg);
        border:1px solid var(--header-color-border);
        flex:1; 
        padding-right:24px;
        border-radius:3px;
      }
      input.header-input::placeholder {
        opacity:0.4;
      }
      .loader {
        margin: 16px auto 16px auto; 
        border: 4px solid var(--bg3);
        border-radius: 50%;
        border-top: 4px solid var(--primary-color);
        width: 36px;
        height: 36px;
        animation: spin 2s linear infinite;
      }
      .expanded-endpoint-body { 
        position: relative;
        padding: 6px 0px; 
      }
      .expanded-endpoint-body .tag-description {
        background: var(--code-bg);
        border-radius: var(--border-radius);
        transition: max-height .2s ease-out;
      }
      .expanded-endpoint-body .tag-icon {
        transition: transform .2s ease-out;
      }
      .expanded-endpoint-body .tag-icon.expanded {
        transform: rotate(180deg);
      }
      .divider { 
        border-top: 2px solid var(--border-color);
        margin: 24px 0;
        width:100%;
      }

      .tooltip {
        cursor:pointer;
        border: 1px solid var(--border-color);
        border-left-width: 4px;
        margin-left:2px;
      }
      .tooltip a {
        color: var(--fg2);
        text-decoration: none;
      }
      .tooltip-text {
        color: var(--fg2);
        max-width: 400px;
        position: absolute;
        z-index:1;
        background-color: var(--bg2);
        visibility: hidden;

        overflow-wrap: break-word;
      }
      .tooltip:hover {
        color: var(--primary-color);
        border-color: var(--primary-color);
      }
      .tooltip:hover a:hover {
        color: var(--primary-color);
      }

      .tooltip:hover .tooltip-text {
        visibility: visible;
      }

      @keyframes spin {
        0% { transform: rotate(0deg); }
        100% { transform: rotate(360deg); }
      }

      .nav-method { font-weight: bold; margin-right: 4px; font-size: calc(var(--font-size-small) - 2px); white-space: nowrap; }
      .nav-method.false { display: none; }

      .nav-method.as-colored-text.get { color:var(--nav-get-color); }
      .nav-method.as-colored-text.put { color:var(--nav-put-color); }
      .nav-method.as-colored-text.post { color:var(--nav-post-color); }
      .nav-method.as-colored-text.delete { color:var(--nav-delete-color); }
      .nav-method.as-colored-text.head, .nav-method.as-colored-text.patch, .nav-method.as-colored-text.options { color:var(--nav-head-color); }
      
      .nav-method.as-colored-block {
        padding: 1px 4px;
        min-width: 30px;
        border-radius: 4px 0 0 4px;
        color: #000;
      }
      .colored-block .nav-method.as-colored-block {
        outline: 1px solid;
      }

      .nav-method.as-colored-block.get { background-color: var(--blue); }
      .nav-method.as-colored-block.put { background-color: var(--orange); }
      .nav-method.as-colored-block.post { background-color: var(--green); }
      .nav-method.as-colored-block.delete { background-color: var(--red); }
      .nav-method.as-colored-block.head, .nav-method.as-colored-block.patch , .nav-method.as-colored-block.options { 
        background-color: var(--yellow); 
      }

      @media only screen and (min-width: 768px) {
        .nav-bar {
          width: 260px;
          display:flex;
        }
        .only-large-screen{
          display:block;
        }
        .only-large-screen-flex{
          display:flex;
        }
        .section-gap { 
          padding: 0 0 0 24px; 
        }
        .section-gap--focused-mode {
          padding: 24px 8px; 
        }
        .section-gap--read-mode { 
          padding: 24px 8px; 
        }
        .endpoint-body {
          position: relative;
          padding:36px 0 48px 0;
        }
      }

      @media only screen and (min-width: 1024px) {
        .nav-bar {
          width: ${l("default" === this.fontSize ? "300px" : "large" === this.fontSize ? "315px" : "330px")};
          display:flex;
        }
        .section-gap--focused-mode { 
          padding: 12px 80px 12px 80px; 
        }
        .section-gap--read-mode { 
          padding: 24px 80px 12px 80px; 
        }
      }`, nt];
      }
      connectedCallback() {
        super.connectedCallback();
        const e6 = this.parentElement;
        if (e6 && (0 === e6.offsetWidth && "" === e6.style.width && (e6.style.width = "100vw"), 0 === e6.offsetHeight && "" === e6.style.height && (e6.style.height = "100vh"), "BODY" === e6.tagName && (e6.style.marginTop || (e6.style.marginTop = "0"), e6.style.marginRight || (e6.style.marginRight = "0"), e6.style.marginBottom || (e6.style.marginBottom = "0"), e6.style.marginLeft || (e6.style.marginLeft = "0"))), "false" !== this.loadFonts) {
          const e7 = { family: "Open Sans", style: "normal", weight: "300", unicodeRange: "U+0000-00FF, U+0131, U+0152-0153, U+02BB-02BC, U+02C6, U+02DA, U+02DC, U+2000-206F, U+2074, U+20AC, U+2122, U+2191, U+2193, U+2212, U+2215, U+FEFF, U+FFFD" }, t5 = new FontFace("Open Sans", "url(https://fonts.gstatic.com/s/opensans/v18/mem5YaGs126MiZpBA-UN_r8OUuhpKKSTjw.woff2) format('woff2')", e7);
          e7.weight = "600";
          const r6 = new FontFace("Open Sans", "url(https://fonts.gstatic.com/s/opensans/v18/mem5YaGs126MiZpBA-UNirkOUuhpKKSTjw.woff2) format('woff2')", e7);
          t5.load().then((e8) => {
            document.fonts.add(e8);
          }), r6.load().then((e8) => {
            document.fonts.add(e8);
          });
        }
        this.layout && "row, column,".includes(`${this.layout},`) || (this.layout = "row"), this.renderStyle && "read, view, focused,".includes(`${this.renderStyle},`) || (this.renderStyle = "focused"), this.schemaStyle && "tree, table,".includes(`${this.schemaStyle},`) || (this.schemaStyle = "tree"), this.theme && "light, dark,".includes(`${this.theme},`) || (this.theme = window.matchMedia && window.matchMedia("(prefers-color-scheme: light)").matches ? "light" : "dark"), this.defaultSchemaTab && "example, schema, model,".includes(`${this.defaultSchemaTab},`) ? "model" === this.defaultSchemaTab && (this.defaultSchemaTab = "schema") : this.defaultSchemaTab = "example", (!this.schemaExpandLevel || this.schemaExpandLevel < 1) && (this.schemaExpandLevel = 99999), this.schemaDescriptionExpanded && "true, false,".includes(`${this.schemaDescriptionExpanded},`) || (this.schemaDescriptionExpanded = "false"), this.schemaHideReadOnly && "default, never,".includes(`${this.schemaHideReadOnly},`) || (this.schemaHideReadOnly = "default"), this.schemaHideWriteOnly && "default, never,".includes(`${this.schemaHideWriteOnly},`) || (this.schemaHideWriteOnly = "default"), this.fillRequestFieldsWithExample && "true, false,".includes(`${this.fillRequestFieldsWithExample},`) || (this.fillRequestFieldsWithExample = "true"), this.persistAuth && "true, false,".includes(`${this.persistAuth},`) || (this.persistAuth = "false"), this.responseAreaHeight || (this.responseAreaHeight = "400px"), this.allowSearch && "true, false,".includes(`${this.allowSearch},`) || (this.allowSearch = "true"), this.allowAdvancedSearch && "true, false,".includes(`${this.allowAdvancedSearch},`) || (this.allowAdvancedSearch = "true"), this.allowTry && "true, false,".includes(`${this.allowTry},`) || (this.allowTry = "true"), this.apiKeyValue || (this.apiKeyValue = "-"), this.apiKeyLocation || (this.apiKeyLocation = "header"), this.apiKeyName || (this.apiKeyName = ""), this.oauthReceiver || (this.oauthReceiver = "oauth-receiver.html"), this.updateRoute && "true, false,".includes(`${this.updateRoute},`) || (this.updateRoute = "true"), this.routePrefix || (this.routePrefix = "#"), this.sortTags && "true, false,".includes(`${this.sortTags},`) || (this.sortTags = "false"), this.generateMissingTags && "true, false,".includes(`${this.generateMissingTags},`) || (this.generateMissingTags = "false"), this.sortEndpointsBy && "method, path, summary, none,".includes(`${this.sortEndpointsBy},`) || (this.sortEndpointsBy = "path"), this.onNavTagClick && "expand-collapse, show-description,".includes(`${this.onNavTagClick},`) || (this.onNavTagClick = "expand-collapse"), this.navItemSpacing && "compact, relaxed, default,".includes(`${this.navItemSpacing},`) || (this.navItemSpacing = "default"), this.showMethodInNavBar && "false, as-plain-text, as-colored-text, as-colored-block,".includes(`${this.showMethodInNavBar},`) || (this.showMethodInNavBar = "false"), this.usePathInNavBar && "true, false,".includes(`${this.usePathInNavBar},`) || (this.usePathInNavBar = "false"), this.navActiveItemMarker && "left-bar, colored-block".includes(`${this.navActiveItemMarker},`) || (this.navActiveItemMarker = "left-bar"), this.fontSize && "default, large, largest,".includes(`${this.fontSize},`) || (this.fontSize = "default"), this.showInfo && "true, false,".includes(`${this.showInfo},`) || (this.showInfo = "true"), this.allowServerSelection && "true, false,".includes(`${this.allowServerSelection},`) || (this.allowServerSelection = "true"), this.allowAuthentication && "true, false,".includes(`${this.allowAuthentication},`) || (this.allowAuthentication = "true"), this.allowSchemaDescriptionExpandToggle && "true, false,".includes(`${this.allowSchemaDescriptionExpandToggle},`) || (this.allowSchemaDescriptionExpandToggle = "true"), this.showSideNav && "true false".includes(this.showSideNav) || (this.showSideNav = "true"), this.showComponents && "true false".includes(this.showComponents) || (this.showComponents = "false"), this.infoDescriptionHeadingsInNavBar && "true, false,".includes(`${this.infoDescriptionHeadingsInNavBar},`) || (this.infoDescriptionHeadingsInNavBar = "false"), this.fetchCredentials && "omit, same-origin, include,".includes(`${this.fetchCredentials},`) || (this.fetchCredentials = ""), this.matchType && "includes regex".includes(this.matchType) || (this.matchType = "includes"), this.showAdvancedSearchDialog || (this.showAdvancedSearchDialog = false), this.cssFile || (this.cssFile = null), this.cssClasses || (this.cssClasses = ""), We.setOptions({ highlight: (e7, t5) => Ge().languages[t5] ? Ge().highlight(e7, Ge().languages[t5], t5) : e7 }), window.addEventListener("hashchange", () => {
          this.scrollToPath(this.getElementIDFromURL());
        }, true);
      }
      disconnectedCallback() {
        this.intersectionObserver && this.intersectionObserver.disconnect(), super.disconnectedCallback();
      }
      infoDescriptionHeadingRenderer() {
        const e6 = new We.Renderer();
        return e6.heading = (e7, t5, r6, n6) => `<h${t5} class="observe-me" id="${n6.slug(r6)}">${e7}</h${t5}>`, e6;
      }
      render() {
        const e6 = document.querySelector(`link[href*="${this.cssFile}"]`);
        return e6 && this.shadowRoot.appendChild(e6.cloneNode()), wR.call(this);
      }
      observeExpandedContent() {
        this.shadowRoot.querySelectorAll(".observe-me").forEach((e6) => {
          this.intersectionObserver.observe(e6);
        });
      }
      attributeChangedCallback(e6, t5, r6) {
        if ("spec-url" === e6 && t5 !== r6 && window.setTimeout(async () => {
          await this.loadSpec(r6), this.gotoPath && !window.location.hash && this.scrollToPath(this.gotoPath);
        }, 0), "render-style" === e6 && ("read" === r6 ? window.setTimeout(() => {
          this.observeExpandedContent();
        }, 100) : this.intersectionObserver.disconnect()), "api-key-name" === e6 || "api-key-location" === e6 || "api-key-value" === e6) {
          let t6 = false, n6 = "", o5 = "", a2 = "";
          if ("api-key-name" === e6 ? this.getAttribute("api-key-location") && this.getAttribute("api-key-value") && (n6 = r6, o5 = this.getAttribute("api-key-location"), a2 = this.getAttribute("api-key-value"), t6 = true) : "api-key-location" === e6 ? this.getAttribute("api-key-name") && this.getAttribute("api-key-value") && (o5 = r6, n6 = this.getAttribute("api-key-name"), a2 = this.getAttribute("api-key-value"), t6 = true) : "api-key-value" === e6 && this.getAttribute("api-key-name") && this.getAttribute("api-key-location") && (a2 = r6, o5 = this.getAttribute("api-key-location"), n6 = this.getAttribute("api-key-name"), t6 = true), t6 && this.resolvedSpec) {
            const e7 = this.resolvedSpec.securitySchemes.find((e8) => e8.securitySchemeId === at);
            e7 ? (e7.name = n6, e7.in = o5, e7.value = a2, e7.finalKeyValue = a2) : this.resolvedSpec.securitySchemes.push({ securitySchemeId: at, description: "api-key provided in rapidoc element attributes", type: "apiKey", name: n6, in: o5, value: a2, finalKeyValue: a2 }), this.requestUpdate();
          }
        }
        super.attributeChangedCallback(e6, t5, r6);
      }
      onSpecUrlChange() {
        this.setAttribute("spec-url", this.shadowRoot.getElementById("spec-url").value);
      }
      onSpecFileChange(e6) {
        this.setAttribute("spec-file", this.shadowRoot.getElementById("spec-file").value);
        const t5 = e6.target.files[0], r6 = new FileReader();
        r6.onload = () => {
          try {
            const e7 = JSON.parse(r6.result);
            this.loadSpec(e7), this.shadowRoot.getElementById("spec-url").value = "";
          } catch (e7) {
            console.error("RapiDoc: Unable to read or parse json");
          }
        }, r6.readAsText(t5);
      }
      onFileLoadClick() {
        this.shadowRoot.getElementById("spec-file").click();
      }
      onSearchChange(e6) {
        this.matchPaths = e6.target.value, this.resolvedSpec.tags.forEach((e7) => e7.paths.filter((t5) => {
          this.matchPaths && lt(this.matchPaths, t5, this.matchType) && (e7.expanded = true);
        })), this.resolvedSpec.components.forEach((e7) => e7.subComponents.filter((e8) => {
          e8.expanded = false, this.matchPaths && !function(e9, t5) {
            return t5.name.toLowerCase().includes(e9.toLowerCase());
          }(this.matchPaths, e8) || (e8.expanded = true);
        })), this.requestUpdate();
      }
      onClearSearch() {
        this.shadowRoot.getElementById("nav-bar-search").value = "", this.matchPaths = "", this.resolvedSpec.components.forEach((e6) => e6.subComponents.filter((e7) => {
          e7.expanded = true;
        }));
      }
      onShowSearchModalClicked() {
        this.showAdvancedSearchDialog = true;
      }
      async onOpenSearchDialog(e6) {
        const t5 = e6.detail.querySelector("input");
        await it(0), t5 && t5.focus();
      }
      async loadSpec(e6) {
        if (e6) {
          this.matchPaths = "";
          try {
            this.resolvedSpec = { specLoadError: false, isSpecLoading: true, tags: [] }, this.loading = true, this.loadFailed = false;
            const t5 = await M_.call(this, e6, "true" === this.generateMissingTags, "true" === this.sortTags, this.getAttribute("sort-endpoints-by"), this.getAttribute("api-key-name"), this.getAttribute("api-key-location"), this.getAttribute("api-key-value"), this.getAttribute("server-url"));
            this.loading = false, this.afterSpecParsedAndValidated(t5);
          } catch (e7) {
            this.loading = false, this.loadFailed = true, this.resolvedSpec = null, console.error(`RapiDoc: Unable to resolve the API spec..  ${e7.message}`);
          }
        }
      }
      async afterSpecParsedAndValidated(e6) {
        for (this.resolvedSpec = e6, this.selectedServer = void 0, this.defaultApiServerUrl && (this.defaultApiServerUrl === this.serverUrl ? this.selectedServer = { url: this.serverUrl, computedUrl: this.serverUrl } : this.resolvedSpec.servers && (this.selectedServer = this.resolvedSpec.servers.find((e7) => e7.url === this.defaultApiServerUrl))), this.selectedServer || this.resolvedSpec.servers && (this.selectedServer = this.resolvedSpec.servers[0]), this.requestUpdate(); !await this.updateComplete; )
          ;
        const t5 = new CustomEvent("spec-loaded", { detail: e6 });
        this.dispatchEvent(t5), this.intersectionObserver.disconnect(), "read" === this.renderStyle && (await it(100), this.observeExpandedContent()), this.isIntersectionObserverActive = true;
        const r6 = this.getElementIDFromURL();
        if (r6)
          "view" === this.renderStyle ? this.expandAndGotoOperation(r6, true, true) : this.scrollToPath(r6);
        else if ("focused" === this.renderStyle && !this.gotoPath) {
          var n6;
          const e7 = this.showInfo ? "overview" : null === (n6 = this.resolvedSpec.tags[0]) || void 0 === n6 ? void 0 : n6.paths[0];
          this.scrollToPath(e7);
        }
      }
      getComponentBaseURL() {
        const { href: e6 } = window.location, t5 = this.routePrefix.replace(/(#|\/)$/, "");
        if (!t5)
          return e6.split("#")[0];
        const r6 = e6.lastIndexOf(t5);
        return -1 === r6 ? e6 : e6.slice(0, r6);
      }
      getElementIDFromURL() {
        const e6 = this.getComponentBaseURL();
        return window.location.href.replace(e6 + this.routePrefix, "");
      }
      replaceHistoryState(e6) {
        const t5 = this.getComponentBaseURL();
        window.history.replaceState(null, null, `${t5}${this.routePrefix || "#"}${e6}`);
      }
      expandAndGotoOperation(e6, t5 = true) {
        if (!this.resolvedSpec)
          return;
        let r6 = true;
        const n6 = -1 === e6.indexOf("#") ? e6 : e6.substring(1);
        if (n6.startsWith("overview") || "servers" === n6 || "auth" === n6)
          r6 = false;
        else
          for (let t6 = 0; t6 < (null === (o5 = this.resolvedSpec.tags) || void 0 === o5 ? void 0 : o5.length); t6++) {
            var o5, a2;
            const n7 = this.resolvedSpec.tags[t6], i4 = null === (a2 = n7.paths) || void 0 === a2 ? void 0 : a2.find((t7) => t7.elementId === e6);
            i4 && (i4.expanded && n7.expanded ? r6 = false : (i4.expanded = true, n7.expanded = true));
          }
        t5 && (r6 && this.requestUpdate(), window.setTimeout(() => {
          const e7 = this.shadowRoot.getElementById(n6);
          e7 && (e7.scrollIntoView({ behavior: "auto", block: "start" }), "true" === this.updateRoute && this.replaceHistoryState(n6));
        }, r6 ? 150 : 0));
      }
      isValidTopId(e6) {
        return e6.startsWith("overview") || "servers" === e6 || "auth" === e6;
      }
      isValidPathId(e6) {
        var t5, r6, n6, o5;
        return !("overview" !== e6 || !this.showInfo) || (!("servers" !== e6 || !this.allowServerSelection) || (!("auth" !== e6 || !this.allowAuthentication) || (e6.startsWith("tag--") ? null === (n6 = this.resolvedSpec) || void 0 === n6 || null === (o5 = n6.tags) || void 0 === o5 ? void 0 : o5.find((t6) => t6.elementId === e6) : null === (t5 = this.resolvedSpec) || void 0 === t5 || null === (r6 = t5.tags) || void 0 === r6 ? void 0 : r6.find((t6) => t6.paths.find((t7) => t7.elementId === e6)))));
      }
      onIntersect(e6) {
        false !== this.isIntersectionObserverActive && e6.forEach((e7) => {
          if (e7.isIntersecting && e7.intersectionRatio > 0) {
            const t5 = this.shadowRoot.querySelector(".nav-bar-tag.active, .nav-bar-path.active, .nav-bar-info.active, .nav-bar-h1.active, .nav-bar-h2.active, .operations.active"), r6 = this.shadowRoot.getElementById(`link-${e7.target.id}`);
            r6 && ("true" === this.updateRoute && this.replaceHistoryState(e7.target.id), r6.scrollIntoView({ behavior: "auto", block: "center" }), r6.classList.add("active"), r6.part.add("section-navbar-active-item")), t5 && t5 !== r6 && (t5.classList.remove("active"), t5.part.remove("section-navbar-active-item"));
          }
        });
      }
      handleHref(e6) {
        if ("a" === e6.target.tagName.toLowerCase() && e6.target.getAttribute("href").startsWith("#")) {
          const t5 = this.shadowRoot.getElementById(e6.target.getAttribute("href").replace("#", ""));
          t5 && t5.scrollIntoView({ behavior: "auto", block: "start" });
        }
      }
      async scrollToEventTarget(e6, t5 = true) {
        if ("click" !== e6.type && ("keyup" !== e6.type || 13 !== e6.keyCode))
          return;
        const r6 = e6.target;
        if (r6.dataset.contentId) {
          if (this.isIntersectionObserverActive = false, "focused" === this.renderStyle) {
            const e7 = this.shadowRoot.querySelector("api-request");
            e7 && e7.beforeNavigationFocusedMode();
          }
          this.scrollToPath(r6.dataset.contentId, true, t5), setTimeout(() => {
            this.isIntersectionObserverActive = true;
          }, 300);
        }
      }
      async scrollToPath(e6, t5 = true, r6 = true) {
        if ("focused" === this.renderStyle && (this.focusedElementId = e6, await it(0)), "view" === this.renderStyle)
          this.expandAndGotoOperation(e6, t5, true);
        else {
          let t6 = false;
          const n6 = this.shadowRoot.getElementById(e6);
          if (n6 ? (t6 = true, n6.scrollIntoView({ behavior: "auto", block: "start" })) : t6 = false, t6) {
            if ("focused" === this.renderStyle) {
              const e7 = this.shadowRoot.querySelector("api-request");
              e7 && e7.afterNavigationFocusedMode();
              const t8 = this.shadowRoot.querySelector("api-response");
              t8 && t8.resetSelection();
            }
            "true" === this.updateRoute && this.replaceHistoryState(e6);
            const t7 = this.shadowRoot.getElementById(`link-${e6}`);
            if (t7) {
              r6 && t7.scrollIntoView({ behavior: "auto", block: "center" }), await it(0);
              const e7 = this.shadowRoot.querySelector(".nav-bar-tag.active, .nav-bar-path.active, .nav-bar-info.active, .nav-bar-h1.active, .nav-bar-h2.active, .operations.active");
              e7 && (e7.classList.remove("active"), e7.part.remove("active"), e7.part.remove("section-navbar-active-item")), t7.classList.add("active"), t7.part.add("section-navbar-active-item");
            }
          }
        }
      }
      setHttpUserNameAndPassword(e6, t5, r6) {
        return tP.call(this, e6, t5, r6);
      }
      setApiKey(e6, t5) {
        return tP.call(this, e6, "", "", t5);
      }
      removeAllSecurityKeys() {
        return rP.call(this);
      }
      setApiServer(e6) {
        return ZP.call(this, e6);
      }
      onAdvancedSearch(e6, t5) {
        const r6 = e6.target;
        clearTimeout(this.timeoutId), this.timeoutId = setTimeout(() => {
          let e7;
          e7 = "text" === r6.type ? r6 : r6.closest(".advanced-search-options").querySelector("input[type=text]");
          const t6 = [...r6.closest(".advanced-search-options").querySelectorAll("input:checked")].map((e8) => e8.id);
          this.advancedSearchMatches = function(e8, t7, r7 = []) {
            if (!e8.trim() || 0 === r7.length)
              return;
            const n6 = [];
            return t7.forEach((t8) => {
              t8.paths.forEach((t9) => {
                let o5 = "";
                var a2;
                if (r7.includes("search-api-path") && (o5 = t9.path), r7.includes("search-api-descr") && (o5 = `${o5} ${t9.summary || t9.description || ""}`), r7.includes("search-api-params") && (o5 = `${o5} ${(null === (a2 = t9.parameters) || void 0 === a2 ? void 0 : a2.map((e9) => e9.name).join(" ")) || ""}`), r7.includes("search-api-request-body") && t9.requestBody) {
                  let e9 = /* @__PURE__ */ new Set();
                  for (const r8 in null === (i4 = t9.requestBody) || void 0 === i4 ? void 0 : i4.content) {
                    var i4, s6, l2;
                    null !== (s6 = t9.requestBody.content[r8].schema) && void 0 !== s6 && s6.properties && (e9 = ct(null === (l2 = t9.requestBody.content[r8].schema) || void 0 === l2 ? void 0 : l2.properties)), o5 = `${o5} ${[...e9].join(" ")}`;
                  }
                }
                r7.includes("search-api-resp-descr") && (o5 = `${o5} ${Object.values(t9.responses).map((e9) => e9.description || "").join(" ")}`), o5.toLowerCase().includes(e8.trim().toLowerCase()) && n6.push({ elementId: t9.elementId, method: t9.method, path: t9.path, summary: t9.summary || t9.description || "", deprecated: t9.deprecated });
              });
            }), n6;
          }(e7.value, this.resolvedSpec.tags, t6);
        }, t5);
      }
    }
    customElements.define("rapi-doc", $R);
    customElements.define("rapi-doc-mini", class extends ie {
      constructor() {
        super(), this.isMini = true, this.updateRoute = "false", this.renderStyle = "view", this.showHeader = "false", this.allowAdvancedSearch = "false";
      }
      static get properties() {
        return { specUrl: { type: String, attribute: "spec-url" }, sortEndpointsBy: { type: String, attribute: "sort-endpoints-by" }, layout: { type: String }, pathsExpanded: { type: String, attribute: "paths-expanded" }, defaultSchemaTab: { type: String, attribute: "default-schema-tab" }, responseAreaHeight: { type: String, attribute: "response-area-height" }, showSummaryWhenCollapsed: { type: String, attribute: "show-summary-when-collapsed" }, fillRequestFieldsWithExample: { type: String, attribute: "fill-request-fields-with-example" }, persistAuth: { type: String, attribute: "persist-auth" }, schemaStyle: { type: String, attribute: "schema-style" }, schemaExpandLevel: { type: Number, attribute: "schema-expand-level" }, schemaDescriptionExpanded: { type: String, attribute: "schema-description-expanded" }, apiKeyName: { type: String, attribute: "api-key-name" }, apiKeyLocation: { type: String, attribute: "api-key-location" }, apiKeyValue: { type: String, attribute: "api-key-value" }, defaultApiServerUrl: { type: String, attribute: "default-api-server" }, serverUrl: { type: String, attribute: "server-url" }, oauthReceiver: { type: String, attribute: "oauth-receiver" }, allowTry: { type: String, attribute: "allow-try" }, theme: { type: String }, bgColor: { type: String, attribute: "bg-color" }, textColor: { type: String, attribute: "text-color" }, primaryColor: { type: String, attribute: "primary-color" }, fontSize: { type: String, attribute: "font-size" }, regularFont: { type: String, attribute: "regular-font" }, monoFont: { type: String, attribute: "mono-font" }, loadFonts: { type: String, attribute: "load-fonts" }, fetchCredentials: { type: String, attribute: "fetch-credentials" }, matchPaths: { type: String, attribute: "match-paths" }, matchType: { type: String, attribute: "match-type" }, loading: { type: Boolean } };
      }
      static get styles() {
        return [Ke, Je, Ye, Ze, Qe, Xe, et, tt, rt, c2`
      :host {
        display:flex;
        flex-direction: column;
        min-width:360px;
        width:100%;
        height:100%;
        margin:0;
        padding:0;
        overflow: hidden;
        letter-spacing:normal;
        color:var(--fg);
        background-color:var(--bg);
        font-family:var(--font-regular);
      }

      @media only screen and (min-width: 768px) {
        .only-large-screen{
          display:block;
        }
        .only-large-screen-flex{
          display:flex;
        }
      }`];
      }
      connectedCallback() {
        if (super.connectedCallback(), "false" !== this.loadFonts) {
          const e6 = { family: "Open Sans", style: "normal", weight: "300", unicodeRange: "U+0000-00FF, U+0131, U+0152-0153, U+02BB-02BC, U+02C6, U+02DA, U+02DC, U+2000-206F, U+2074, U+20AC, U+2122, U+2191, U+2193, U+2212, U+2215, U+FEFF, U+FFFD" }, t5 = new FontFace("Open Sans", "url(https://fonts.gstatic.com/s/opensans/v18/mem5YaGs126MiZpBA-UN_r8OUuhpKKSTjw.woff2) format('woff2')", e6);
          e6.weight = "600";
          const r6 = new FontFace("Open Sans", "url(https://fonts.gstatic.com/s/opensans/v18/mem5YaGs126MiZpBA-UNirkOUuhpKKSTjw.woff2) format('woff2')", e6);
          t5.load().then((e7) => {
            document.fonts.add(e7);
          }), r6.load().then((e7) => {
            document.fonts.add(e7);
          });
        }
        this.showSummaryWhenCollapsed && "true, false,".includes(`${this.showSummaryWhenCollapsed},`) || (this.showSummaryWhenCollapsed = "true"), this.layout && "row, column,".includes(`${this.layout},`) || (this.layout = "row"), this.schemaStyle && "tree, table,".includes(`${this.schemaStyle},`) || (this.schemaStyle = "tree"), this.theme && "light, dark,".includes(`${this.theme},`) || (this.theme = window.matchMedia && window.matchMedia("(prefers-color-scheme: light)").matches ? "light" : "dark"), this.defaultSchemaTab && "example, schema, model,".includes(`${this.defaultSchemaTab},`) ? "model" === this.defaultSchemaTab && (this.defaultSchemaTab = "schema") : this.defaultSchemaTab = "example", this.pathsExpanded = "true" === this.pathsExpanded, (!this.schemaExpandLevel || this.schemaExpandLevel < 1) && (this.schemaExpandLevel = 99999), this.schemaDescriptionExpanded && "true, false,".includes(`${this.schemaDescriptionExpanded},`) || (this.schemaDescriptionExpanded = "false"), this.fillRequestFieldsWithExample && "true, false,".includes(`${this.fillRequestFieldsWithExample},`) || (this.fillRequestFieldsWithExample = "true"), this.persistAuth && "true, false,".includes(`${this.persistAuth},`) || (this.persistAuth = "false"), this.responseAreaHeight || (this.responseAreaHeight = "300px"), this.allowTry && "true, false,".includes(`${this.allowTry},`) || (this.allowTry = "true"), this.apiKeyValue || (this.apiKeyValue = "-"), this.apiKeyLocation || (this.apiKeyLocation = "header"), this.apiKeyName || (this.apiKeyName = ""), this.oauthReceiver || (this.oauthReceiver = "oauth-receiver.html"), this.sortTags && "true, false,".includes(`${this.sortTags},`) || (this.sortTags = "false"), this.sortEndpointsBy && "method, path, summary,".includes(`${this.sortEndpointsBy},`) || (this.sortEndpointsBy = "path"), this.fontSize && "default, large, largest,".includes(`${this.fontSize},`) || (this.fontSize = "default"), this.matchType && "includes regex".includes(this.matchType) || (this.matchType = "includes"), this.allowSchemaDescriptionExpandToggle && "true, false,".includes(`${this.allowSchemaDescriptionExpandToggle},`) || (this.allowSchemaDescriptionExpandToggle = "true"), this.fetchCredentials && "omit, same-origin, include,".includes(`${this.fetchCredentials},`) || (this.fetchCredentials = ""), We.setOptions({ highlight: (e6, t5) => Ge().languages[t5] ? Ge().highlight(e6, Ge().languages[t5], t5) : e6 });
      }
      render() {
        return wR.call(this, true, false, false, this.pathsExpanded);
      }
      attributeChangedCallback(e6, t5, r6) {
        if ("spec-url" === e6 && t5 !== r6 && window.setTimeout(async () => {
          await this.loadSpec(r6);
        }, 0), "api-key-name" === e6 || "api-key-location" === e6 || "api-key-value" === e6) {
          let t6 = false, n6 = "", o5 = "", a2 = "";
          if ("api-key-name" === e6 ? this.getAttribute("api-key-location") && this.getAttribute("api-key-value") && (n6 = r6, o5 = this.getAttribute("api-key-location"), a2 = this.getAttribute("api-key-value"), t6 = true) : "api-key-location" === e6 ? this.getAttribute("api-key-name") && this.getAttribute("api-key-value") && (o5 = r6, n6 = this.getAttribute("api-key-name"), a2 = this.getAttribute("api-key-value"), t6 = true) : "api-key-value" === e6 && this.getAttribute("api-key-name") && this.getAttribute("api-key-location") && (a2 = r6, o5 = this.getAttribute("api-key-location"), n6 = this.getAttribute("api-key-name"), t6 = true), t6 && this.resolvedSpec) {
            const e7 = this.resolvedSpec.securitySchemes.find((e8) => e8.securitySchemeId === at);
            e7 ? (e7.name = n6, e7.in = o5, e7.value = a2, e7.finalKeyValue = a2) : this.resolvedSpec.securitySchemes.push({ apiKeyId: at, description: "api-key provided in rapidoc element attributes", type: "apiKey", name: n6, in: o5, value: a2, finalKeyValue: a2 }), this.requestUpdate();
          }
        }
        super.attributeChangedCallback(e6, t5, r6);
      }
      onSpecUrlChange() {
        this.setAttribute("spec-url", this.shadowRoot.getElementById("spec-url").value);
      }
      async loadSpec(e6) {
        if (e6)
          try {
            this.resolvedSpec = { specLoadError: false, isSpecLoading: true, tags: [] }, this.loading = true, this.loadFailed = false, this.requestUpdate();
            const t5 = await M_.call(this, e6, "true" === this.generateMissingTags, "true" === this.sortTags, this.getAttribute("sort-endpoints-by"), this.getAttribute("api-key-name"), this.getAttribute("api-key-location"), this.getAttribute("api-key-value"), this.getAttribute("server-url"));
            this.loading = false, this.afterSpecParsedAndValidated(t5);
          } catch (e7) {
            this.loading = false, this.loadFailed = true, this.resolvedSpec = null, console.error(`RapiDoc: Unable to resolve the API spec..  ${e7.message}`);
          }
      }
      setHttpUserNameAndPassword(e6, t5, r6) {
        return tP.call(this, e6, t5, r6);
      }
      setApiKey(e6, t5) {
        return tP.call(this, e6, "", "", t5);
      }
      removeAllSecurityKeys() {
        return rP.call(this);
      }
      setApiServer(e6) {
        return ZP.call(this, e6);
      }
      async afterSpecParsedAndValidated(e6) {
        for (this.resolvedSpec = e6, this.selectedServer = void 0, this.defaultApiServerUrl && (this.defaultApiServerUrl === this.serverUrl ? this.selectedServer = { url: this.serverUrl, computedUrl: this.serverUrl } : this.resolvedSpec.servers && (this.selectedServer = this.resolvedSpec.servers.find((e7) => e7.url === this.defaultApiServerUrl))), this.selectedServer || this.resolvedSpec.servers && (this.selectedServer = this.resolvedSpec.servers[0]), this.requestUpdate(); !await this.updateComplete; )
          ;
        const t5 = new CustomEvent("spec-loaded", { detail: e6 });
        this.dispatchEvent(t5);
      }
      handleHref(e6) {
        if ("a" === e6.target.tagName.toLowerCase() && e6.target.getAttribute("href").startsWith("#")) {
          const t5 = this.shadowRoot.getElementById(e6.target.getAttribute("href").replace("#", ""));
          t5 && t5.scrollIntoView({ behavior: "auto", block: "start" });
        }
      }
    });
    class kR extends HTMLElement {
      connectedCallback() {
        this.receiveAuthParms(), window.addEventListener("storage", (e6) => this.receiveStorage(e6), true);
      }
      receiveAuthParms() {
        let e6 = {};
        if (document.location.search) {
          const t5 = new URLSearchParams(document.location.search);
          e6 = { code: t5.get("code"), error: t5.get("error"), state: t5.get("state"), responseType: "code" };
        } else if (window.location.hash) {
          e6 = { token_type: this.parseQueryString(window.location.hash.substring(1), "token_type"), access_token: this.parseQueryString(window.location.hash.substring(1), "access_token"), responseType: "token" };
        }
        window.opener ? window.opener.postMessage(e6, this.target) : sessionStorage.setItem("rapidoc-oauth-data", JSON.stringify(e6));
      }
      relayAuthParams(e6) {
        if (window.parent && "rapidoc-oauth-data" === e6.key) {
          const t5 = JSON.parse(e6.newValue);
          window.parent.postMessage(t5, this.target);
        }
      }
      parseQueryString(e6, t5) {
        const r6 = e6.split("&");
        for (let e7 = 0; e7 < r6.length; e7++) {
          const n6 = r6[e7].split("=");
          if (decodeURIComponent(n6[0]) === t5)
            return decodeURIComponent(n6[1]);
        }
      }
    }
    function SR() {
      return q`
  <nav class='nav-bar' part="section-navbar">
    <slot name="nav-logo" class="logo"></slot>
    <div style="display:flex;line-height:22px; padding:8px">
      <input id="nav-bar-search" 
        part = "textbox textbox-nav-filter"
        style = "width:100%; height: 26px; padding-right:20px; color:var(--nav-hover-text-color); border-color:var(--nav-accent-color); background-color:var(--nav-hover-bg-color)" 
        type = "text"
        placeholder = "Filter" 
        @change = "${this.onSearchChange}"  
        spellcheck = "false" 
      >
      <div style="margin: 6px 5px 0 -24px; font-size:var(--font-size-regular); cursor:pointer;">&#x21a9;</div>
    </div>
    <nav style="flex:1" class='nav-scroll' part="section-navbar-scroll">
      ${this.resolvedSpec.schemaAndExamples.map((e6) => q`
        <div class='nav-bar-path' data-content-id='${e6.elementId}' id='link-${e6.elementId}'
          @click = '${(e7) => {
        this.scrollToEventTarget(e7, false);
      }}'
        > 
          ${e6.name}
        </div>`)}
    </nav>  
  </nav>
  `;
    }
    function AR() {
      return q`
    ${"true" === this.showInfo ? YP.call(this) : ""}
    <div style="font-size:var(--font-size-regular);">
    ${this.resolvedSpec.schemaAndExamples.map((e6) => {
        var t5;
        const r6 = BP(e6.schema, "json", e6.examples, e6.example, true, false, "json", true);
        return e6.selectedExample = null === (t5 = r6[0]) || void 0 === t5 ? void 0 : t5.exampleId, q`
        <section id='${e6.elementId}' class='json-schema-and-example regular-font' style="display:flex; flex-direction: column; border:1px solid var(--border-color); margin-bottom:32px; border-top: 5px solid var(--border-color)">
          <div style="padding:16px; border-bottom: 1px solid var(--border-color)">
            <div style="font-size:var(--font-size-small); font-weight:bold">${e6.name}</div>
            <span class="json-schema-description m-markdown ">${Q_(We(e6.description || ""))}</span>
          </div>  
          <div style="display:flex; flex-direction: row; gap:16px;">
            <div class="json-schema-def" style="flex:1; padding:16px 0 16px 16px; ">
              <schema-tree
                .data = "${DP(e6.schema, {})}"
                schema-expand-level = "${this.schemaExpandLevel}"
                schema-description-expanded = "${this.schemaDescriptionExpanded}"
                allow-schema-description-expand-toggle = "${this.allowSchemaDescriptionExpandToggle}"
                schema-hide-read-only = "false"
                schema-hide-write-only = "false"
              > </schema-tree>
            </div>
            <div class="json-schema-example-panel" style="width:400px; background-color: var(--input-bg); padding:16px 0 16px 16px; border-left: 1px dashed var(--border-color);">
              ${r6.length > 1 ? q`<select style="min-width:100px; max-width:100%" @change='${(t6) => this.onSelectExample(t6, e6)}'>
                    ${r6.map((t6) => q`
                      <option value="${t6.exampleId}" ?selected=${t6.exampleId === e6.selectedExample}> 
                        ${t6.exampleSummary.length > 80 ? t6.exampleId : t6.exampleSummary}
                      </option>`)}
                  </select>` : q`<div style="font-size: var(--font-size-small);font-weight:700; margin:5px 0"> ${r6[0].exampleSummary}</div>`}
              ${r6.map((t6) => q`
                <json-tree 
                  .data = "${t6.exampleValue}"
                  data-example = "${t6.exampleId}"
                  class = "example"
                  style = "margin-top:16px; display: ${t6.exampleId === e6.selectedExample ? "flex" : "none"}"
                ></json-tree>`)}
            </div>
          </div>
        </section>`;
      })}
    </div>
  `;
    }
    function ER(e6 = false) {
      if (!this.resolvedSpec)
        return "";
      const t5 = { bg1: bR(this.bgColor) ? this.bgColor : "", fg1: bR(this.textColor) ? this.textColor : "", headerColor: bR(this.headerColor) ? this.headerColor : "", primaryColor: bR(this.primaryColor) ? this.primaryColor : "", navBgColor: bR(this.navBgColor) ? this.navBgColor : "", navTextColor: bR(this.navTextColor) ? this.navTextColor : "", navHoverBgColor: bR(this.navHoverBgColor) ? this.navHoverBgColor : "", navHoverTextColor: bR(this.navHoverTextColor) ? this.navHoverTextColor : "", navAccentColor: bR(this.navAccentColor) ? this.navAccentColor : "", navAccenttextColor: bR(this.navAccentTextColor) ? this.navAccentTextColor : "" };
      return this.resolvedSpec.specLoadError ? e6 ? q`
        ${"dark" === this.theme ? xR.call(this, "dark", t5) : xR.call(this, "light", t5)}
        <div style="display:flex; align-items:center; border:1px dashed var(--border-color); height:42px; padding:5px; font-size:var(--font-size-small); color:var(--red); font-family:var(--font-mono)"> ${this.resolvedSpec.info.description} </div>
      ` : q`
      ${"dark" === this.theme ? xR.call(this, "dark", t5) : xR.call(this, "light", t5)}
      <!-- Header -->
      ${mR.call(this)}
      <h1> Header </h1>
      <main class="main-content regular-font" part="section-main-content">
        <slot></slot>
        <div style="margin:24px; text-align: center;">
          <h1 style="color: var(--red)"> ${this.resolvedSpec.info.title} </h1>
          <div style="font-family:var(--font-mono)"> ${this.resolvedSpec.info.description} </div>
        </div>
      </main>  
    ` : this.resolvedSpec.isSpecLoading ? q`
      ${"dark" === this.theme ? xR.call(this, "dark", t5) : xR.call(this, "light", t5)}
      <main class="main-content regular-font" part="section-main-content">
        <slot></slot>
        <div class="main-content-inner--${this.renderStyle}-mode">
          <div class="loader"></div>
        </div>
      </main>  
    ` : q`
    ${"dark" === this.theme ? xR.call(this, "dark", t5) : xR.call(this, "light", t5)}

    <!-- Header -->
    ${"false" === this.showHeader ? "" : mR.call(this)}
    
    <div id='the-main-body' class="body ${this.cssClasses}" dir= ${this.pageDirection}>

      <!-- Side Nav -->
      ${SR.call(this)}

      <!-- Main Content -->
      <main class="main-content regular-font" part="section-main-content">
        <slot></slot>
        <div class="main-content-inner--${this.renderStyle}-mode">
          ${true === this.loading ? q`<div class="loader"></div>` : q`
              ${true === this.loadFailed ? q`<div style="text-align: center;margin: 16px;"> Unable to load the Spec</div>` : q`
                  <div class="operations-root" @click="${(e7) => {
        this.handleHref(e7);
      }}">
                    ${AR.call(this)}
                  </div>
                `}`}
        </div>
        <slot name="footer"></slot>
      </main>
    </div>  
  `;
    }
    customElements.define("oauth-receiver", kR);
    customElements.define("json-schema-viewer", class extends ie {
      constructor() {
        super(), this.isMini = false, this.updateRoute = "false", this.renderStyle = "focused", this.showHeader = "true", this.allowAdvancedSearch = "false", this.selectedExampleForEachSchema = {};
      }
      static get properties() {
        return { specUrl: { type: String, attribute: "spec-url" }, schemaStyle: { type: String, attribute: "schema-style" }, schemaExpandLevel: { type: Number, attribute: "schema-expand-level" }, schemaDescriptionExpanded: { type: String, attribute: "schema-description-expanded" }, allowSchemaDescriptionExpandToggle: { type: String, attribute: "allow-schema-description-expand-toggle" }, showHeader: { type: String, attribute: "show-header" }, showSideNav: { type: String, attribute: "show-side-nav" }, showInfo: { type: String, attribute: "show-info" }, allowSpecUrlLoad: { type: String, attribute: "allow-spec-url-load" }, allowSpecFileLoad: { type: String, attribute: "allow-spec-file-load" }, allowSpecFileDownload: { type: String, attribute: "allow-spec-file-download" }, allowSearch: { type: String, attribute: "allow-search" }, theme: { type: String }, bgColor: { type: String, attribute: "bg-color" }, textColor: { type: String, attribute: "text-color" }, primaryColor: { type: String, attribute: "primary-color" }, fontSize: { type: String, attribute: "font-size" }, regularFont: { type: String, attribute: "regular-font" }, monoFont: { type: String, attribute: "mono-font" }, loadFonts: { type: String, attribute: "load-fonts" }, loading: { type: Boolean } };
      }
      static get styles() {
        return [Ke, Je, Ye, Ze, Qe, Xe, et, tt, rt, c2`
      :host {
        display:flex;
        flex-direction: column;
        min-width:360px;
        width:100%;
        height:100%;
        margin:0;
        padding:0;
        overflow: hidden;
        letter-spacing:normal;
        color:var(--fg);
        background-color:var(--bg);
        font-family:var(--font-regular);
      }
      .body {
        display:flex;
        height:100%;
        width:100%;
        overflow:hidden;
      }
      .nav-bar {
        width: 230px;
        display:flex;
      }

      .main-content { 
        margin:0;
        padding: 16px; 
        display:block;
        flex:1;
        height:100%;
        overflow-y: auto;
        overflow-x: hidden;
        scrollbar-width: thin;
        scrollbar-color: var(--border-color) transparent;
      }
      .main-content-inner--view-mode {
        padding: 0 8px;
      }
      .main-content::-webkit-scrollbar {
        width: 8px;
        height: 8px;
      }
      .main-content::-webkit-scrollbar-track {
        background:transparent;
      }
      .main-content::-webkit-scrollbar-thumb {
        background-color: var(--border-color);
      }
      .main-header {
        background-color:var(--header-bg);
        color:var(--header-fg);
        width:100%;
      }
      .header-title {
        font-size:calc(var(--font-size-regular) + 8px); 
        padding:0 8px;
      }
      input.header-input{
        background:var(--header-color-darker);
        color:var(--header-fg);
        border:1px solid var(--header-color-border);
        flex:1; 
        padding-right:24px;
        border-radius:3px;
      }
      input.header-input::placeholder {
        opacity:0.4;
      }
      .loader {
        margin: 16px auto 16px auto; 
        border: 4px solid var(--bg3);
        border-radius: 50%;
        border-top: 4px solid var(--primary-color);
        width: 36px;
        height: 36px;
        animation: spin 2s linear infinite;
      }
      @media only screen and (min-width: 768px) {
        .only-large-screen{
          display:block;
        }
        .only-large-screen-flex{
          display:flex;
        }
      }`];
      }
      connectedCallback() {
        super.connectedCallback();
        const e6 = this.parentElement;
        if (e6 && (0 === e6.offsetWidth && "" === e6.style.width && (e6.style.width = "100vw"), 0 === e6.offsetHeight && "" === e6.style.height && (e6.style.height = "100vh"), "BODY" === e6.tagName && (e6.style.marginTop || (e6.style.marginTop = "0"), e6.style.marginRight || (e6.style.marginRight = "0"), e6.style.marginBottom || (e6.style.marginBottom = "0"), e6.style.marginLeft || (e6.style.marginLeft = "0"))), "false" !== this.loadFonts) {
          const e7 = { family: "Open Sans", style: "normal", weight: "300", unicodeRange: "U+0000-00FF, U+0131, U+0152-0153, U+02BB-02BC, U+02C6, U+02DA, U+02DC, U+2000-206F, U+2074, U+20AC, U+2122, U+2191, U+2193, U+2212, U+2215, U+FEFF, U+FFFD" }, t5 = new FontFace("Open Sans", "url(https://fonts.gstatic.com/s/opensans/v18/mem5YaGs126MiZpBA-UN_r8OUuhpKKSTjw.woff2) format('woff2')", e7);
          e7.weight = "600";
          const r6 = new FontFace("Open Sans", "url(https://fonts.gstatic.com/s/opensans/v18/mem5YaGs126MiZpBA-UNirkOUuhpKKSTjw.woff2) format('woff2')", e7);
          t5.load().then((e8) => {
            document.fonts.add(e8);
          }), r6.load().then((e8) => {
            document.fonts.add(e8);
          });
        }
        this.renderStyle = "focused", this.pathsExpanded = "true" === this.pathsExpanded, this.showInfo && "true, false,".includes(`${this.showInfo},`) || (this.showInfo = "true"), this.showSideNav && "true false".includes(this.showSideNav) || (this.showSideNav = "true"), this.showHeader && "true, false,".includes(`${this.showHeader},`) || (this.showHeader = "true"), this.schemaStyle && "tree, table,".includes(`${this.schemaStyle},`) || (this.schemaStyle = "tree"), this.theme && "light, dark,".includes(`${this.theme},`) || (this.theme = window.matchMedia && window.matchMedia("(prefers-color-scheme: light)").matches ? "light" : "dark"), this.allowSearch && "true, false,".includes(`${this.allowSearch},`) || (this.allowSearch = "true"), (!this.schemaExpandLevel || this.schemaExpandLevel < 1) && (this.schemaExpandLevel = 99999), this.schemaDescriptionExpanded && "true, false,".includes(`${this.schemaDescriptionExpanded},`) || (this.schemaDescriptionExpanded = "false"), this.fontSize && "default, large, largest,".includes(`${this.fontSize},`) || (this.fontSize = "default"), this.matchType && "includes regex".includes(this.matchType) || (this.matchType = "includes"), this.allowSchemaDescriptionExpandToggle && "true, false,".includes(`${this.allowSchemaDescriptionExpandToggle},`) || (this.allowSchemaDescriptionExpandToggle = "true"), We.setOptions({ highlight: (e7, t5) => Ge().languages[t5] ? Ge().highlight(e7, Ge().languages[t5], t5) : e7 });
      }
      render() {
        return ER.call(this, true, false, false, this.pathsExpanded);
      }
      attributeChangedCallback(e6, t5, r6) {
        "spec-url" === e6 && t5 !== r6 && window.setTimeout(async () => {
          await this.loadSpec(r6);
        }, 0), super.attributeChangedCallback(e6, t5, r6);
      }
      onSpecUrlChange() {
        this.setAttribute("spec-url", this.shadowRoot.getElementById("spec-url").value);
      }
      onSearchChange(e6) {
        this.matchPaths = e6.target.value;
      }
      async loadSpec(e6) {
        if (e6)
          try {
            this.resolvedSpec = { specLoadError: false, isSpecLoading: true, tags: [] }, this.loading = true, this.loadFailed = false, this.requestUpdate();
            const t5 = await M_.call(this, e6, "true" === this.generateMissingTags, "true" === this.sortTags, this.getAttribute("sort-endpoints-by"));
            this.loading = false, this.afterSpecParsedAndValidated(t5);
          } catch (e7) {
            this.loading = false, this.loadFailed = true, this.resolvedSpec = null, console.error(`RapiDoc: Unable to resolve the API spec..  ${e7.message}`);
          }
      }
      async afterSpecParsedAndValidated(e6) {
        this.resolvedSpec = e6;
        const t5 = new CustomEvent("spec-loaded", { detail: e6 });
        this.dispatchEvent(t5);
      }
      handleHref(e6) {
        if ("a" === e6.target.tagName.toLowerCase() && e6.target.getAttribute("href").startsWith("#")) {
          const t5 = this.shadowRoot.getElementById(e6.target.getAttribute("href").replace("#", ""));
          t5 && t5.scrollIntoView({ behavior: "auto", block: "start" });
        }
      }
      onSelectExample(e6) {
        [...e6.target.closest(".json-schema-example-panel").querySelectorAll(".example")].forEach((t5) => {
          t5.style.display = t5.dataset.example === e6.target.value ? "flex" : "none";
        });
      }
      async scrollToEventTarget(e6) {
        const t5 = e6.currentTarget;
        if (!t5.dataset.contentId)
          return;
        const r6 = this.shadowRoot.getElementById(t5.dataset.contentId);
        r6 && r6.scrollIntoView({ behavior: "auto", block: "start" });
      }
    });
  }, 742: (e5, t4) => {
    "use strict";
    t4.byteLength = function(e6) {
      var t5 = l(e6), r6 = t5[0], n6 = t5[1];
      return 3 * (r6 + n6) / 4 - n6;
    }, t4.toByteArray = function(e6) {
      var t5, r6, a2 = l(e6), i4 = a2[0], s6 = a2[1], c3 = new o4(function(e7, t6, r7) {
        return 3 * (t6 + r7) / 4 - r7;
      }(0, i4, s6)), p = 0, d = s6 > 0 ? i4 - 4 : i4;
      for (r6 = 0; r6 < d; r6 += 4)
        t5 = n5[e6.charCodeAt(r6)] << 18 | n5[e6.charCodeAt(r6 + 1)] << 12 | n5[e6.charCodeAt(r6 + 2)] << 6 | n5[e6.charCodeAt(r6 + 3)], c3[p++] = t5 >> 16 & 255, c3[p++] = t5 >> 8 & 255, c3[p++] = 255 & t5;
      2 === s6 && (t5 = n5[e6.charCodeAt(r6)] << 2 | n5[e6.charCodeAt(r6 + 1)] >> 4, c3[p++] = 255 & t5);
      1 === s6 && (t5 = n5[e6.charCodeAt(r6)] << 10 | n5[e6.charCodeAt(r6 + 1)] << 4 | n5[e6.charCodeAt(r6 + 2)] >> 2, c3[p++] = t5 >> 8 & 255, c3[p++] = 255 & t5);
      return c3;
    }, t4.fromByteArray = function(e6) {
      for (var t5, n6 = e6.length, o5 = n6 % 3, a2 = [], i4 = 16383, s6 = 0, l2 = n6 - o5; s6 < l2; s6 += i4)
        a2.push(c2(e6, s6, s6 + i4 > l2 ? l2 : s6 + i4));
      1 === o5 ? (t5 = e6[n6 - 1], a2.push(r5[t5 >> 2] + r5[t5 << 4 & 63] + "==")) : 2 === o5 && (t5 = (e6[n6 - 2] << 8) + e6[n6 - 1], a2.push(r5[t5 >> 10] + r5[t5 >> 4 & 63] + r5[t5 << 2 & 63] + "="));
      return a2.join("");
    };
    for (var r5 = [], n5 = [], o4 = "undefined" != typeof Uint8Array ? Uint8Array : Array, a = "ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/", i3 = 0, s5 = a.length; i3 < s5; ++i3)
      r5[i3] = a[i3], n5[a.charCodeAt(i3)] = i3;
    function l(e6) {
      var t5 = e6.length;
      if (t5 % 4 > 0)
        throw new Error("Invalid string. Length must be a multiple of 4");
      var r6 = e6.indexOf("=");
      return -1 === r6 && (r6 = t5), [r6, r6 === t5 ? 0 : 4 - r6 % 4];
    }
    function c2(e6, t5, n6) {
      for (var o5, a2, i4 = [], s6 = t5; s6 < n6; s6 += 3)
        o5 = (e6[s6] << 16 & 16711680) + (e6[s6 + 1] << 8 & 65280) + (255 & e6[s6 + 2]), i4.push(r5[(a2 = o5) >> 18 & 63] + r5[a2 >> 12 & 63] + r5[a2 >> 6 & 63] + r5[63 & a2]);
      return i4.join("");
    }
    n5["-".charCodeAt(0)] = 62, n5["_".charCodeAt(0)] = 63;
  }, 764: (e5, t4, r5) => {
    "use strict";
    const n5 = r5(742), o4 = r5(645), a = "function" == typeof Symbol && "function" == typeof Symbol.for ? Symbol.for("nodejs.util.inspect.custom") : null;
    t4.lW = l, t4.h2 = 50;
    const i3 = 2147483647;
    function s5(e6) {
      if (e6 > i3)
        throw new RangeError('The value "' + e6 + '" is invalid for option "size"');
      const t5 = new Uint8Array(e6);
      return Object.setPrototypeOf(t5, l.prototype), t5;
    }
    function l(e6, t5, r6) {
      if ("number" == typeof e6) {
        if ("string" == typeof t5)
          throw new TypeError('The "string" argument must be of type string. Received type number');
        return d(e6);
      }
      return c2(e6, t5, r6);
    }
    function c2(e6, t5, r6) {
      if ("string" == typeof e6)
        return function(e7, t6) {
          "string" == typeof t6 && "" !== t6 || (t6 = "utf8");
          if (!l.isEncoding(t6))
            throw new TypeError("Unknown encoding: " + t6);
          const r7 = 0 | m(e7, t6);
          let n7 = s5(r7);
          const o6 = n7.write(e7, t6);
          o6 !== r7 && (n7 = n7.slice(0, o6));
          return n7;
        }(e6, t5);
      if (ArrayBuffer.isView(e6))
        return function(e7) {
          if (J(e7, Uint8Array)) {
            const t6 = new Uint8Array(e7);
            return h(t6.buffer, t6.byteOffset, t6.byteLength);
          }
          return u2(e7);
        }(e6);
      if (null == e6)
        throw new TypeError("The first argument must be one of type string, Buffer, ArrayBuffer, Array, or Array-like Object. Received type " + typeof e6);
      if (J(e6, ArrayBuffer) || e6 && J(e6.buffer, ArrayBuffer))
        return h(e6, t5, r6);
      if ("undefined" != typeof SharedArrayBuffer && (J(e6, SharedArrayBuffer) || e6 && J(e6.buffer, SharedArrayBuffer)))
        return h(e6, t5, r6);
      if ("number" == typeof e6)
        throw new TypeError('The "value" argument must not be of type number. Received type number');
      const n6 = e6.valueOf && e6.valueOf();
      if (null != n6 && n6 !== e6)
        return l.from(n6, t5, r6);
      const o5 = function(e7) {
        if (l.isBuffer(e7)) {
          const t6 = 0 | f2(e7.length), r7 = s5(t6);
          return 0 === r7.length || e7.copy(r7, 0, 0, t6), r7;
        }
        if (void 0 !== e7.length)
          return "number" != typeof e7.length || Y(e7.length) ? s5(0) : u2(e7);
        if ("Buffer" === e7.type && Array.isArray(e7.data))
          return u2(e7.data);
      }(e6);
      if (o5)
        return o5;
      if ("undefined" != typeof Symbol && null != Symbol.toPrimitive && "function" == typeof e6[Symbol.toPrimitive])
        return l.from(e6[Symbol.toPrimitive]("string"), t5, r6);
      throw new TypeError("The first argument must be one of type string, Buffer, ArrayBuffer, Array, or Array-like Object. Received type " + typeof e6);
    }
    function p(e6) {
      if ("number" != typeof e6)
        throw new TypeError('"size" argument must be of type number');
      if (e6 < 0)
        throw new RangeError('The value "' + e6 + '" is invalid for option "size"');
    }
    function d(e6) {
      return p(e6), s5(e6 < 0 ? 0 : 0 | f2(e6));
    }
    function u2(e6) {
      const t5 = e6.length < 0 ? 0 : 0 | f2(e6.length), r6 = s5(t5);
      for (let n6 = 0; n6 < t5; n6 += 1)
        r6[n6] = 255 & e6[n6];
      return r6;
    }
    function h(e6, t5, r6) {
      if (t5 < 0 || e6.byteLength < t5)
        throw new RangeError('"offset" is outside of buffer bounds');
      if (e6.byteLength < t5 + (r6 || 0))
        throw new RangeError('"length" is outside of buffer bounds');
      let n6;
      return n6 = void 0 === t5 && void 0 === r6 ? new Uint8Array(e6) : void 0 === r6 ? new Uint8Array(e6, t5) : new Uint8Array(e6, t5, r6), Object.setPrototypeOf(n6, l.prototype), n6;
    }
    function f2(e6) {
      if (e6 >= i3)
        throw new RangeError("Attempt to allocate Buffer larger than maximum size: 0x" + i3.toString(16) + " bytes");
      return 0 | e6;
    }
    function m(e6, t5) {
      if (l.isBuffer(e6))
        return e6.length;
      if (ArrayBuffer.isView(e6) || J(e6, ArrayBuffer))
        return e6.byteLength;
      if ("string" != typeof e6)
        throw new TypeError('The "string" argument must be one of type string, Buffer, or ArrayBuffer. Received type ' + typeof e6);
      const r6 = e6.length, n6 = arguments.length > 2 && true === arguments[2];
      if (!n6 && 0 === r6)
        return 0;
      let o5 = false;
      for (; ; )
        switch (t5) {
          case "ascii":
          case "latin1":
          case "binary":
            return r6;
          case "utf8":
          case "utf-8":
            return V(e6).length;
          case "ucs2":
          case "ucs-2":
          case "utf16le":
          case "utf-16le":
            return 2 * r6;
          case "hex":
            return r6 >>> 1;
          case "base64":
            return G(e6).length;
          default:
            if (o5)
              return n6 ? -1 : V(e6).length;
            t5 = ("" + t5).toLowerCase(), o5 = true;
        }
    }
    function y(e6, t5, r6) {
      let n6 = false;
      if ((void 0 === t5 || t5 < 0) && (t5 = 0), t5 > this.length)
        return "";
      if ((void 0 === r6 || r6 > this.length) && (r6 = this.length), r6 <= 0)
        return "";
      if ((r6 >>>= 0) <= (t5 >>>= 0))
        return "";
      for (e6 || (e6 = "utf8"); ; )
        switch (e6) {
          case "hex":
            return j(this, t5, r6);
          case "utf8":
          case "utf-8":
            return E(this, t5, r6);
          case "ascii":
            return T2(this, t5, r6);
          case "latin1":
          case "binary":
            return C(this, t5, r6);
          case "base64":
            return A(this, t5, r6);
          case "ucs2":
          case "ucs-2":
          case "utf16le":
          case "utf-16le":
            return I(this, t5, r6);
          default:
            if (n6)
              throw new TypeError("Unknown encoding: " + e6);
            e6 = (e6 + "").toLowerCase(), n6 = true;
        }
    }
    function g(e6, t5, r6) {
      const n6 = e6[t5];
      e6[t5] = e6[r6], e6[r6] = n6;
    }
    function v(e6, t5, r6, n6, o5) {
      if (0 === e6.length)
        return -1;
      if ("string" == typeof r6 ? (n6 = r6, r6 = 0) : r6 > 2147483647 ? r6 = 2147483647 : r6 < -2147483648 && (r6 = -2147483648), Y(r6 = +r6) && (r6 = o5 ? 0 : e6.length - 1), r6 < 0 && (r6 = e6.length + r6), r6 >= e6.length) {
        if (o5)
          return -1;
        r6 = e6.length - 1;
      } else if (r6 < 0) {
        if (!o5)
          return -1;
        r6 = 0;
      }
      if ("string" == typeof t5 && (t5 = l.from(t5, n6)), l.isBuffer(t5))
        return 0 === t5.length ? -1 : b(e6, t5, r6, n6, o5);
      if ("number" == typeof t5)
        return t5 &= 255, "function" == typeof Uint8Array.prototype.indexOf ? o5 ? Uint8Array.prototype.indexOf.call(e6, t5, r6) : Uint8Array.prototype.lastIndexOf.call(e6, t5, r6) : b(e6, [t5], r6, n6, o5);
      throw new TypeError("val must be string, number or Buffer");
    }
    function b(e6, t5, r6, n6, o5) {
      let a2, i4 = 1, s6 = e6.length, l2 = t5.length;
      if (void 0 !== n6 && ("ucs2" === (n6 = String(n6).toLowerCase()) || "ucs-2" === n6 || "utf16le" === n6 || "utf-16le" === n6)) {
        if (e6.length < 2 || t5.length < 2)
          return -1;
        i4 = 2, s6 /= 2, l2 /= 2, r6 /= 2;
      }
      function c3(e7, t6) {
        return 1 === i4 ? e7[t6] : e7.readUInt16BE(t6 * i4);
      }
      if (o5) {
        let n7 = -1;
        for (a2 = r6; a2 < s6; a2++)
          if (c3(e6, a2) === c3(t5, -1 === n7 ? 0 : a2 - n7)) {
            if (-1 === n7 && (n7 = a2), a2 - n7 + 1 === l2)
              return n7 * i4;
          } else
            -1 !== n7 && (a2 -= a2 - n7), n7 = -1;
      } else
        for (r6 + l2 > s6 && (r6 = s6 - l2), a2 = r6; a2 >= 0; a2--) {
          let r7 = true;
          for (let n7 = 0; n7 < l2; n7++)
            if (c3(e6, a2 + n7) !== c3(t5, n7)) {
              r7 = false;
              break;
            }
          if (r7)
            return a2;
        }
      return -1;
    }
    function x2(e6, t5, r6, n6) {
      r6 = Number(r6) || 0;
      const o5 = e6.length - r6;
      n6 ? (n6 = Number(n6)) > o5 && (n6 = o5) : n6 = o5;
      const a2 = t5.length;
      let i4;
      for (n6 > a2 / 2 && (n6 = a2 / 2), i4 = 0; i4 < n6; ++i4) {
        const n7 = parseInt(t5.substr(2 * i4, 2), 16);
        if (Y(n7))
          return i4;
        e6[r6 + i4] = n7;
      }
      return i4;
    }
    function w(e6, t5, r6, n6) {
      return K(V(t5, e6.length - r6), e6, r6, n6);
    }
    function $(e6, t5, r6, n6) {
      return K(function(e7) {
        const t6 = [];
        for (let r7 = 0; r7 < e7.length; ++r7)
          t6.push(255 & e7.charCodeAt(r7));
        return t6;
      }(t5), e6, r6, n6);
    }
    function k(e6, t5, r6, n6) {
      return K(G(t5), e6, r6, n6);
    }
    function S(e6, t5, r6, n6) {
      return K(function(e7, t6) {
        let r7, n7, o5;
        const a2 = [];
        for (let i4 = 0; i4 < e7.length && !((t6 -= 2) < 0); ++i4)
          r7 = e7.charCodeAt(i4), n7 = r7 >> 8, o5 = r7 % 256, a2.push(o5), a2.push(n7);
        return a2;
      }(t5, e6.length - r6), e6, r6, n6);
    }
    function A(e6, t5, r6) {
      return 0 === t5 && r6 === e6.length ? n5.fromByteArray(e6) : n5.fromByteArray(e6.slice(t5, r6));
    }
    function E(e6, t5, r6) {
      r6 = Math.min(e6.length, r6);
      const n6 = [];
      let o5 = t5;
      for (; o5 < r6; ) {
        const t6 = e6[o5];
        let a2 = null, i4 = t6 > 239 ? 4 : t6 > 223 ? 3 : t6 > 191 ? 2 : 1;
        if (o5 + i4 <= r6) {
          let r7, n7, s6, l2;
          switch (i4) {
            case 1:
              t6 < 128 && (a2 = t6);
              break;
            case 2:
              r7 = e6[o5 + 1], 128 == (192 & r7) && (l2 = (31 & t6) << 6 | 63 & r7, l2 > 127 && (a2 = l2));
              break;
            case 3:
              r7 = e6[o5 + 1], n7 = e6[o5 + 2], 128 == (192 & r7) && 128 == (192 & n7) && (l2 = (15 & t6) << 12 | (63 & r7) << 6 | 63 & n7, l2 > 2047 && (l2 < 55296 || l2 > 57343) && (a2 = l2));
              break;
            case 4:
              r7 = e6[o5 + 1], n7 = e6[o5 + 2], s6 = e6[o5 + 3], 128 == (192 & r7) && 128 == (192 & n7) && 128 == (192 & s6) && (l2 = (15 & t6) << 18 | (63 & r7) << 12 | (63 & n7) << 6 | 63 & s6, l2 > 65535 && l2 < 1114112 && (a2 = l2));
          }
        }
        null === a2 ? (a2 = 65533, i4 = 1) : a2 > 65535 && (a2 -= 65536, n6.push(a2 >>> 10 & 1023 | 55296), a2 = 56320 | 1023 & a2), n6.push(a2), o5 += i4;
      }
      return function(e7) {
        const t6 = e7.length;
        if (t6 <= O)
          return String.fromCharCode.apply(String, e7);
        let r7 = "", n7 = 0;
        for (; n7 < t6; )
          r7 += String.fromCharCode.apply(String, e7.slice(n7, n7 += O));
        return r7;
      }(n6);
    }
    l.TYPED_ARRAY_SUPPORT = function() {
      try {
        const e6 = new Uint8Array(1), t5 = { foo: function() {
          return 42;
        } };
        return Object.setPrototypeOf(t5, Uint8Array.prototype), Object.setPrototypeOf(e6, t5), 42 === e6.foo();
      } catch (e6) {
        return false;
      }
    }(), l.TYPED_ARRAY_SUPPORT || "undefined" == typeof console || "function" != typeof console.error || console.error("This browser lacks typed array (Uint8Array) support which is required by `buffer` v5.x. Use `buffer` v4.x if you require old browser support."), Object.defineProperty(l.prototype, "parent", { enumerable: true, get: function() {
      if (l.isBuffer(this))
        return this.buffer;
    } }), Object.defineProperty(l.prototype, "offset", { enumerable: true, get: function() {
      if (l.isBuffer(this))
        return this.byteOffset;
    } }), l.poolSize = 8192, l.from = function(e6, t5, r6) {
      return c2(e6, t5, r6);
    }, Object.setPrototypeOf(l.prototype, Uint8Array.prototype), Object.setPrototypeOf(l, Uint8Array), l.alloc = function(e6, t5, r6) {
      return function(e7, t6, r7) {
        return p(e7), e7 <= 0 ? s5(e7) : void 0 !== t6 ? "string" == typeof r7 ? s5(e7).fill(t6, r7) : s5(e7).fill(t6) : s5(e7);
      }(e6, t5, r6);
    }, l.allocUnsafe = function(e6) {
      return d(e6);
    }, l.allocUnsafeSlow = function(e6) {
      return d(e6);
    }, l.isBuffer = function(e6) {
      return null != e6 && true === e6._isBuffer && e6 !== l.prototype;
    }, l.compare = function(e6, t5) {
      if (J(e6, Uint8Array) && (e6 = l.from(e6, e6.offset, e6.byteLength)), J(t5, Uint8Array) && (t5 = l.from(t5, t5.offset, t5.byteLength)), !l.isBuffer(e6) || !l.isBuffer(t5))
        throw new TypeError('The "buf1", "buf2" arguments must be one of type Buffer or Uint8Array');
      if (e6 === t5)
        return 0;
      let r6 = e6.length, n6 = t5.length;
      for (let o5 = 0, a2 = Math.min(r6, n6); o5 < a2; ++o5)
        if (e6[o5] !== t5[o5]) {
          r6 = e6[o5], n6 = t5[o5];
          break;
        }
      return r6 < n6 ? -1 : n6 < r6 ? 1 : 0;
    }, l.isEncoding = function(e6) {
      switch (String(e6).toLowerCase()) {
        case "hex":
        case "utf8":
        case "utf-8":
        case "ascii":
        case "latin1":
        case "binary":
        case "base64":
        case "ucs2":
        case "ucs-2":
        case "utf16le":
        case "utf-16le":
          return true;
        default:
          return false;
      }
    }, l.concat = function(e6, t5) {
      if (!Array.isArray(e6))
        throw new TypeError('"list" argument must be an Array of Buffers');
      if (0 === e6.length)
        return l.alloc(0);
      let r6;
      if (void 0 === t5)
        for (t5 = 0, r6 = 0; r6 < e6.length; ++r6)
          t5 += e6[r6].length;
      const n6 = l.allocUnsafe(t5);
      let o5 = 0;
      for (r6 = 0; r6 < e6.length; ++r6) {
        let t6 = e6[r6];
        if (J(t6, Uint8Array))
          o5 + t6.length > n6.length ? (l.isBuffer(t6) || (t6 = l.from(t6)), t6.copy(n6, o5)) : Uint8Array.prototype.set.call(n6, t6, o5);
        else {
          if (!l.isBuffer(t6))
            throw new TypeError('"list" argument must be an Array of Buffers');
          t6.copy(n6, o5);
        }
        o5 += t6.length;
      }
      return n6;
    }, l.byteLength = m, l.prototype._isBuffer = true, l.prototype.swap16 = function() {
      const e6 = this.length;
      if (e6 % 2 != 0)
        throw new RangeError("Buffer size must be a multiple of 16-bits");
      for (let t5 = 0; t5 < e6; t5 += 2)
        g(this, t5, t5 + 1);
      return this;
    }, l.prototype.swap32 = function() {
      const e6 = this.length;
      if (e6 % 4 != 0)
        throw new RangeError("Buffer size must be a multiple of 32-bits");
      for (let t5 = 0; t5 < e6; t5 += 4)
        g(this, t5, t5 + 3), g(this, t5 + 1, t5 + 2);
      return this;
    }, l.prototype.swap64 = function() {
      const e6 = this.length;
      if (e6 % 8 != 0)
        throw new RangeError("Buffer size must be a multiple of 64-bits");
      for (let t5 = 0; t5 < e6; t5 += 8)
        g(this, t5, t5 + 7), g(this, t5 + 1, t5 + 6), g(this, t5 + 2, t5 + 5), g(this, t5 + 3, t5 + 4);
      return this;
    }, l.prototype.toString = function() {
      const e6 = this.length;
      return 0 === e6 ? "" : 0 === arguments.length ? E(this, 0, e6) : y.apply(this, arguments);
    }, l.prototype.toLocaleString = l.prototype.toString, l.prototype.equals = function(e6) {
      if (!l.isBuffer(e6))
        throw new TypeError("Argument must be a Buffer");
      return this === e6 || 0 === l.compare(this, e6);
    }, l.prototype.inspect = function() {
      let e6 = "";
      const r6 = t4.h2;
      return e6 = this.toString("hex", 0, r6).replace(/(.{2})/g, "$1 ").trim(), this.length > r6 && (e6 += " ... "), "<Buffer " + e6 + ">";
    }, a && (l.prototype[a] = l.prototype.inspect), l.prototype.compare = function(e6, t5, r6, n6, o5) {
      if (J(e6, Uint8Array) && (e6 = l.from(e6, e6.offset, e6.byteLength)), !l.isBuffer(e6))
        throw new TypeError('The "target" argument must be one of type Buffer or Uint8Array. Received type ' + typeof e6);
      if (void 0 === t5 && (t5 = 0), void 0 === r6 && (r6 = e6 ? e6.length : 0), void 0 === n6 && (n6 = 0), void 0 === o5 && (o5 = this.length), t5 < 0 || r6 > e6.length || n6 < 0 || o5 > this.length)
        throw new RangeError("out of range index");
      if (n6 >= o5 && t5 >= r6)
        return 0;
      if (n6 >= o5)
        return -1;
      if (t5 >= r6)
        return 1;
      if (this === e6)
        return 0;
      let a2 = (o5 >>>= 0) - (n6 >>>= 0), i4 = (r6 >>>= 0) - (t5 >>>= 0);
      const s6 = Math.min(a2, i4), c3 = this.slice(n6, o5), p2 = e6.slice(t5, r6);
      for (let e7 = 0; e7 < s6; ++e7)
        if (c3[e7] !== p2[e7]) {
          a2 = c3[e7], i4 = p2[e7];
          break;
        }
      return a2 < i4 ? -1 : i4 < a2 ? 1 : 0;
    }, l.prototype.includes = function(e6, t5, r6) {
      return -1 !== this.indexOf(e6, t5, r6);
    }, l.prototype.indexOf = function(e6, t5, r6) {
      return v(this, e6, t5, r6, true);
    }, l.prototype.lastIndexOf = function(e6, t5, r6) {
      return v(this, e6, t5, r6, false);
    }, l.prototype.write = function(e6, t5, r6, n6) {
      if (void 0 === t5)
        n6 = "utf8", r6 = this.length, t5 = 0;
      else if (void 0 === r6 && "string" == typeof t5)
        n6 = t5, r6 = this.length, t5 = 0;
      else {
        if (!isFinite(t5))
          throw new Error("Buffer.write(string, encoding, offset[, length]) is no longer supported");
        t5 >>>= 0, isFinite(r6) ? (r6 >>>= 0, void 0 === n6 && (n6 = "utf8")) : (n6 = r6, r6 = void 0);
      }
      const o5 = this.length - t5;
      if ((void 0 === r6 || r6 > o5) && (r6 = o5), e6.length > 0 && (r6 < 0 || t5 < 0) || t5 > this.length)
        throw new RangeError("Attempt to write outside buffer bounds");
      n6 || (n6 = "utf8");
      let a2 = false;
      for (; ; )
        switch (n6) {
          case "hex":
            return x2(this, e6, t5, r6);
          case "utf8":
          case "utf-8":
            return w(this, e6, t5, r6);
          case "ascii":
          case "latin1":
          case "binary":
            return $(this, e6, t5, r6);
          case "base64":
            return k(this, e6, t5, r6);
          case "ucs2":
          case "ucs-2":
          case "utf16le":
          case "utf-16le":
            return S(this, e6, t5, r6);
          default:
            if (a2)
              throw new TypeError("Unknown encoding: " + n6);
            n6 = ("" + n6).toLowerCase(), a2 = true;
        }
    }, l.prototype.toJSON = function() {
      return { type: "Buffer", data: Array.prototype.slice.call(this._arr || this, 0) };
    };
    const O = 4096;
    function T2(e6, t5, r6) {
      let n6 = "";
      r6 = Math.min(e6.length, r6);
      for (let o5 = t5; o5 < r6; ++o5)
        n6 += String.fromCharCode(127 & e6[o5]);
      return n6;
    }
    function C(e6, t5, r6) {
      let n6 = "";
      r6 = Math.min(e6.length, r6);
      for (let o5 = t5; o5 < r6; ++o5)
        n6 += String.fromCharCode(e6[o5]);
      return n6;
    }
    function j(e6, t5, r6) {
      const n6 = e6.length;
      (!t5 || t5 < 0) && (t5 = 0), (!r6 || r6 < 0 || r6 > n6) && (r6 = n6);
      let o5 = "";
      for (let n7 = t5; n7 < r6; ++n7)
        o5 += Z[e6[n7]];
      return o5;
    }
    function I(e6, t5, r6) {
      const n6 = e6.slice(t5, r6);
      let o5 = "";
      for (let e7 = 0; e7 < n6.length - 1; e7 += 2)
        o5 += String.fromCharCode(n6[e7] + 256 * n6[e7 + 1]);
      return o5;
    }
    function _(e6, t5, r6) {
      if (e6 % 1 != 0 || e6 < 0)
        throw new RangeError("offset is not uint");
      if (e6 + t5 > r6)
        throw new RangeError("Trying to access beyond buffer length");
    }
    function P(e6, t5, r6, n6, o5, a2) {
      if (!l.isBuffer(e6))
        throw new TypeError('"buffer" argument must be a Buffer instance');
      if (t5 > o5 || t5 < a2)
        throw new RangeError('"value" argument is out of bounds');
      if (r6 + n6 > e6.length)
        throw new RangeError("Index out of range");
    }
    function R(e6, t5, r6, n6, o5) {
      z(t5, n6, o5, e6, r6, 7);
      let a2 = Number(t5 & BigInt(4294967295));
      e6[r6++] = a2, a2 >>= 8, e6[r6++] = a2, a2 >>= 8, e6[r6++] = a2, a2 >>= 8, e6[r6++] = a2;
      let i4 = Number(t5 >> BigInt(32) & BigInt(4294967295));
      return e6[r6++] = i4, i4 >>= 8, e6[r6++] = i4, i4 >>= 8, e6[r6++] = i4, i4 >>= 8, e6[r6++] = i4, r6;
    }
    function L(e6, t5, r6, n6, o5) {
      z(t5, n6, o5, e6, r6, 7);
      let a2 = Number(t5 & BigInt(4294967295));
      e6[r6 + 7] = a2, a2 >>= 8, e6[r6 + 6] = a2, a2 >>= 8, e6[r6 + 5] = a2, a2 >>= 8, e6[r6 + 4] = a2;
      let i4 = Number(t5 >> BigInt(32) & BigInt(4294967295));
      return e6[r6 + 3] = i4, i4 >>= 8, e6[r6 + 2] = i4, i4 >>= 8, e6[r6 + 1] = i4, i4 >>= 8, e6[r6] = i4, r6 + 8;
    }
    function F(e6, t5, r6, n6, o5, a2) {
      if (r6 + n6 > e6.length)
        throw new RangeError("Index out of range");
      if (r6 < 0)
        throw new RangeError("Index out of range");
    }
    function D(e6, t5, r6, n6, a2) {
      return t5 = +t5, r6 >>>= 0, a2 || F(e6, 0, r6, 4), o4.write(e6, t5, r6, n6, 23, 4), r6 + 4;
    }
    function B(e6, t5, r6, n6, a2) {
      return t5 = +t5, r6 >>>= 0, a2 || F(e6, 0, r6, 8), o4.write(e6, t5, r6, n6, 52, 8), r6 + 8;
    }
    l.prototype.slice = function(e6, t5) {
      const r6 = this.length;
      (e6 = ~~e6) < 0 ? (e6 += r6) < 0 && (e6 = 0) : e6 > r6 && (e6 = r6), (t5 = void 0 === t5 ? r6 : ~~t5) < 0 ? (t5 += r6) < 0 && (t5 = 0) : t5 > r6 && (t5 = r6), t5 < e6 && (t5 = e6);
      const n6 = this.subarray(e6, t5);
      return Object.setPrototypeOf(n6, l.prototype), n6;
    }, l.prototype.readUintLE = l.prototype.readUIntLE = function(e6, t5, r6) {
      e6 >>>= 0, t5 >>>= 0, r6 || _(e6, t5, this.length);
      let n6 = this[e6], o5 = 1, a2 = 0;
      for (; ++a2 < t5 && (o5 *= 256); )
        n6 += this[e6 + a2] * o5;
      return n6;
    }, l.prototype.readUintBE = l.prototype.readUIntBE = function(e6, t5, r6) {
      e6 >>>= 0, t5 >>>= 0, r6 || _(e6, t5, this.length);
      let n6 = this[e6 + --t5], o5 = 1;
      for (; t5 > 0 && (o5 *= 256); )
        n6 += this[e6 + --t5] * o5;
      return n6;
    }, l.prototype.readUint8 = l.prototype.readUInt8 = function(e6, t5) {
      return e6 >>>= 0, t5 || _(e6, 1, this.length), this[e6];
    }, l.prototype.readUint16LE = l.prototype.readUInt16LE = function(e6, t5) {
      return e6 >>>= 0, t5 || _(e6, 2, this.length), this[e6] | this[e6 + 1] << 8;
    }, l.prototype.readUint16BE = l.prototype.readUInt16BE = function(e6, t5) {
      return e6 >>>= 0, t5 || _(e6, 2, this.length), this[e6] << 8 | this[e6 + 1];
    }, l.prototype.readUint32LE = l.prototype.readUInt32LE = function(e6, t5) {
      return e6 >>>= 0, t5 || _(e6, 4, this.length), (this[e6] | this[e6 + 1] << 8 | this[e6 + 2] << 16) + 16777216 * this[e6 + 3];
    }, l.prototype.readUint32BE = l.prototype.readUInt32BE = function(e6, t5) {
      return e6 >>>= 0, t5 || _(e6, 4, this.length), 16777216 * this[e6] + (this[e6 + 1] << 16 | this[e6 + 2] << 8 | this[e6 + 3]);
    }, l.prototype.readBigUInt64LE = Q(function(e6) {
      M(e6 >>>= 0, "offset");
      const t5 = this[e6], r6 = this[e6 + 7];
      void 0 !== t5 && void 0 !== r6 || H(e6, this.length - 8);
      const n6 = t5 + 256 * this[++e6] + 65536 * this[++e6] + this[++e6] * 2 ** 24, o5 = this[++e6] + 256 * this[++e6] + 65536 * this[++e6] + r6 * 2 ** 24;
      return BigInt(n6) + (BigInt(o5) << BigInt(32));
    }), l.prototype.readBigUInt64BE = Q(function(e6) {
      M(e6 >>>= 0, "offset");
      const t5 = this[e6], r6 = this[e6 + 7];
      void 0 !== t5 && void 0 !== r6 || H(e6, this.length - 8);
      const n6 = t5 * 2 ** 24 + 65536 * this[++e6] + 256 * this[++e6] + this[++e6], o5 = this[++e6] * 2 ** 24 + 65536 * this[++e6] + 256 * this[++e6] + r6;
      return (BigInt(n6) << BigInt(32)) + BigInt(o5);
    }), l.prototype.readIntLE = function(e6, t5, r6) {
      e6 >>>= 0, t5 >>>= 0, r6 || _(e6, t5, this.length);
      let n6 = this[e6], o5 = 1, a2 = 0;
      for (; ++a2 < t5 && (o5 *= 256); )
        n6 += this[e6 + a2] * o5;
      return o5 *= 128, n6 >= o5 && (n6 -= Math.pow(2, 8 * t5)), n6;
    }, l.prototype.readIntBE = function(e6, t5, r6) {
      e6 >>>= 0, t5 >>>= 0, r6 || _(e6, t5, this.length);
      let n6 = t5, o5 = 1, a2 = this[e6 + --n6];
      for (; n6 > 0 && (o5 *= 256); )
        a2 += this[e6 + --n6] * o5;
      return o5 *= 128, a2 >= o5 && (a2 -= Math.pow(2, 8 * t5)), a2;
    }, l.prototype.readInt8 = function(e6, t5) {
      return e6 >>>= 0, t5 || _(e6, 1, this.length), 128 & this[e6] ? -1 * (255 - this[e6] + 1) : this[e6];
    }, l.prototype.readInt16LE = function(e6, t5) {
      e6 >>>= 0, t5 || _(e6, 2, this.length);
      const r6 = this[e6] | this[e6 + 1] << 8;
      return 32768 & r6 ? 4294901760 | r6 : r6;
    }, l.prototype.readInt16BE = function(e6, t5) {
      e6 >>>= 0, t5 || _(e6, 2, this.length);
      const r6 = this[e6 + 1] | this[e6] << 8;
      return 32768 & r6 ? 4294901760 | r6 : r6;
    }, l.prototype.readInt32LE = function(e6, t5) {
      return e6 >>>= 0, t5 || _(e6, 4, this.length), this[e6] | this[e6 + 1] << 8 | this[e6 + 2] << 16 | this[e6 + 3] << 24;
    }, l.prototype.readInt32BE = function(e6, t5) {
      return e6 >>>= 0, t5 || _(e6, 4, this.length), this[e6] << 24 | this[e6 + 1] << 16 | this[e6 + 2] << 8 | this[e6 + 3];
    }, l.prototype.readBigInt64LE = Q(function(e6) {
      M(e6 >>>= 0, "offset");
      const t5 = this[e6], r6 = this[e6 + 7];
      void 0 !== t5 && void 0 !== r6 || H(e6, this.length - 8);
      const n6 = this[e6 + 4] + 256 * this[e6 + 5] + 65536 * this[e6 + 6] + (r6 << 24);
      return (BigInt(n6) << BigInt(32)) + BigInt(t5 + 256 * this[++e6] + 65536 * this[++e6] + this[++e6] * 2 ** 24);
    }), l.prototype.readBigInt64BE = Q(function(e6) {
      M(e6 >>>= 0, "offset");
      const t5 = this[e6], r6 = this[e6 + 7];
      void 0 !== t5 && void 0 !== r6 || H(e6, this.length - 8);
      const n6 = (t5 << 24) + 65536 * this[++e6] + 256 * this[++e6] + this[++e6];
      return (BigInt(n6) << BigInt(32)) + BigInt(this[++e6] * 2 ** 24 + 65536 * this[++e6] + 256 * this[++e6] + r6);
    }), l.prototype.readFloatLE = function(e6, t5) {
      return e6 >>>= 0, t5 || _(e6, 4, this.length), o4.read(this, e6, true, 23, 4);
    }, l.prototype.readFloatBE = function(e6, t5) {
      return e6 >>>= 0, t5 || _(e6, 4, this.length), o4.read(this, e6, false, 23, 4);
    }, l.prototype.readDoubleLE = function(e6, t5) {
      return e6 >>>= 0, t5 || _(e6, 8, this.length), o4.read(this, e6, true, 52, 8);
    }, l.prototype.readDoubleBE = function(e6, t5) {
      return e6 >>>= 0, t5 || _(e6, 8, this.length), o4.read(this, e6, false, 52, 8);
    }, l.prototype.writeUintLE = l.prototype.writeUIntLE = function(e6, t5, r6, n6) {
      if (e6 = +e6, t5 >>>= 0, r6 >>>= 0, !n6) {
        P(this, e6, t5, r6, Math.pow(2, 8 * r6) - 1, 0);
      }
      let o5 = 1, a2 = 0;
      for (this[t5] = 255 & e6; ++a2 < r6 && (o5 *= 256); )
        this[t5 + a2] = e6 / o5 & 255;
      return t5 + r6;
    }, l.prototype.writeUintBE = l.prototype.writeUIntBE = function(e6, t5, r6, n6) {
      if (e6 = +e6, t5 >>>= 0, r6 >>>= 0, !n6) {
        P(this, e6, t5, r6, Math.pow(2, 8 * r6) - 1, 0);
      }
      let o5 = r6 - 1, a2 = 1;
      for (this[t5 + o5] = 255 & e6; --o5 >= 0 && (a2 *= 256); )
        this[t5 + o5] = e6 / a2 & 255;
      return t5 + r6;
    }, l.prototype.writeUint8 = l.prototype.writeUInt8 = function(e6, t5, r6) {
      return e6 = +e6, t5 >>>= 0, r6 || P(this, e6, t5, 1, 255, 0), this[t5] = 255 & e6, t5 + 1;
    }, l.prototype.writeUint16LE = l.prototype.writeUInt16LE = function(e6, t5, r6) {
      return e6 = +e6, t5 >>>= 0, r6 || P(this, e6, t5, 2, 65535, 0), this[t5] = 255 & e6, this[t5 + 1] = e6 >>> 8, t5 + 2;
    }, l.prototype.writeUint16BE = l.prototype.writeUInt16BE = function(e6, t5, r6) {
      return e6 = +e6, t5 >>>= 0, r6 || P(this, e6, t5, 2, 65535, 0), this[t5] = e6 >>> 8, this[t5 + 1] = 255 & e6, t5 + 2;
    }, l.prototype.writeUint32LE = l.prototype.writeUInt32LE = function(e6, t5, r6) {
      return e6 = +e6, t5 >>>= 0, r6 || P(this, e6, t5, 4, 4294967295, 0), this[t5 + 3] = e6 >>> 24, this[t5 + 2] = e6 >>> 16, this[t5 + 1] = e6 >>> 8, this[t5] = 255 & e6, t5 + 4;
    }, l.prototype.writeUint32BE = l.prototype.writeUInt32BE = function(e6, t5, r6) {
      return e6 = +e6, t5 >>>= 0, r6 || P(this, e6, t5, 4, 4294967295, 0), this[t5] = e6 >>> 24, this[t5 + 1] = e6 >>> 16, this[t5 + 2] = e6 >>> 8, this[t5 + 3] = 255 & e6, t5 + 4;
    }, l.prototype.writeBigUInt64LE = Q(function(e6, t5 = 0) {
      return R(this, e6, t5, BigInt(0), BigInt("0xffffffffffffffff"));
    }), l.prototype.writeBigUInt64BE = Q(function(e6, t5 = 0) {
      return L(this, e6, t5, BigInt(0), BigInt("0xffffffffffffffff"));
    }), l.prototype.writeIntLE = function(e6, t5, r6, n6) {
      if (e6 = +e6, t5 >>>= 0, !n6) {
        const n7 = Math.pow(2, 8 * r6 - 1);
        P(this, e6, t5, r6, n7 - 1, -n7);
      }
      let o5 = 0, a2 = 1, i4 = 0;
      for (this[t5] = 255 & e6; ++o5 < r6 && (a2 *= 256); )
        e6 < 0 && 0 === i4 && 0 !== this[t5 + o5 - 1] && (i4 = 1), this[t5 + o5] = (e6 / a2 >> 0) - i4 & 255;
      return t5 + r6;
    }, l.prototype.writeIntBE = function(e6, t5, r6, n6) {
      if (e6 = +e6, t5 >>>= 0, !n6) {
        const n7 = Math.pow(2, 8 * r6 - 1);
        P(this, e6, t5, r6, n7 - 1, -n7);
      }
      let o5 = r6 - 1, a2 = 1, i4 = 0;
      for (this[t5 + o5] = 255 & e6; --o5 >= 0 && (a2 *= 256); )
        e6 < 0 && 0 === i4 && 0 !== this[t5 + o5 + 1] && (i4 = 1), this[t5 + o5] = (e6 / a2 >> 0) - i4 & 255;
      return t5 + r6;
    }, l.prototype.writeInt8 = function(e6, t5, r6) {
      return e6 = +e6, t5 >>>= 0, r6 || P(this, e6, t5, 1, 127, -128), e6 < 0 && (e6 = 255 + e6 + 1), this[t5] = 255 & e6, t5 + 1;
    }, l.prototype.writeInt16LE = function(e6, t5, r6) {
      return e6 = +e6, t5 >>>= 0, r6 || P(this, e6, t5, 2, 32767, -32768), this[t5] = 255 & e6, this[t5 + 1] = e6 >>> 8, t5 + 2;
    }, l.prototype.writeInt16BE = function(e6, t5, r6) {
      return e6 = +e6, t5 >>>= 0, r6 || P(this, e6, t5, 2, 32767, -32768), this[t5] = e6 >>> 8, this[t5 + 1] = 255 & e6, t5 + 2;
    }, l.prototype.writeInt32LE = function(e6, t5, r6) {
      return e6 = +e6, t5 >>>= 0, r6 || P(this, e6, t5, 4, 2147483647, -2147483648), this[t5] = 255 & e6, this[t5 + 1] = e6 >>> 8, this[t5 + 2] = e6 >>> 16, this[t5 + 3] = e6 >>> 24, t5 + 4;
    }, l.prototype.writeInt32BE = function(e6, t5, r6) {
      return e6 = +e6, t5 >>>= 0, r6 || P(this, e6, t5, 4, 2147483647, -2147483648), e6 < 0 && (e6 = 4294967295 + e6 + 1), this[t5] = e6 >>> 24, this[t5 + 1] = e6 >>> 16, this[t5 + 2] = e6 >>> 8, this[t5 + 3] = 255 & e6, t5 + 4;
    }, l.prototype.writeBigInt64LE = Q(function(e6, t5 = 0) {
      return R(this, e6, t5, -BigInt("0x8000000000000000"), BigInt("0x7fffffffffffffff"));
    }), l.prototype.writeBigInt64BE = Q(function(e6, t5 = 0) {
      return L(this, e6, t5, -BigInt("0x8000000000000000"), BigInt("0x7fffffffffffffff"));
    }), l.prototype.writeFloatLE = function(e6, t5, r6) {
      return D(this, e6, t5, true, r6);
    }, l.prototype.writeFloatBE = function(e6, t5, r6) {
      return D(this, e6, t5, false, r6);
    }, l.prototype.writeDoubleLE = function(e6, t5, r6) {
      return B(this, e6, t5, true, r6);
    }, l.prototype.writeDoubleBE = function(e6, t5, r6) {
      return B(this, e6, t5, false, r6);
    }, l.prototype.copy = function(e6, t5, r6, n6) {
      if (!l.isBuffer(e6))
        throw new TypeError("argument should be a Buffer");
      if (r6 || (r6 = 0), n6 || 0 === n6 || (n6 = this.length), t5 >= e6.length && (t5 = e6.length), t5 || (t5 = 0), n6 > 0 && n6 < r6 && (n6 = r6), n6 === r6)
        return 0;
      if (0 === e6.length || 0 === this.length)
        return 0;
      if (t5 < 0)
        throw new RangeError("targetStart out of bounds");
      if (r6 < 0 || r6 >= this.length)
        throw new RangeError("Index out of range");
      if (n6 < 0)
        throw new RangeError("sourceEnd out of bounds");
      n6 > this.length && (n6 = this.length), e6.length - t5 < n6 - r6 && (n6 = e6.length - t5 + r6);
      const o5 = n6 - r6;
      return this === e6 && "function" == typeof Uint8Array.prototype.copyWithin ? this.copyWithin(t5, r6, n6) : Uint8Array.prototype.set.call(e6, this.subarray(r6, n6), t5), o5;
    }, l.prototype.fill = function(e6, t5, r6, n6) {
      if ("string" == typeof e6) {
        if ("string" == typeof t5 ? (n6 = t5, t5 = 0, r6 = this.length) : "string" == typeof r6 && (n6 = r6, r6 = this.length), void 0 !== n6 && "string" != typeof n6)
          throw new TypeError("encoding must be a string");
        if ("string" == typeof n6 && !l.isEncoding(n6))
          throw new TypeError("Unknown encoding: " + n6);
        if (1 === e6.length) {
          const t6 = e6.charCodeAt(0);
          ("utf8" === n6 && t6 < 128 || "latin1" === n6) && (e6 = t6);
        }
      } else
        "number" == typeof e6 ? e6 &= 255 : "boolean" == typeof e6 && (e6 = Number(e6));
      if (t5 < 0 || this.length < t5 || this.length < r6)
        throw new RangeError("Out of range index");
      if (r6 <= t5)
        return this;
      let o5;
      if (t5 >>>= 0, r6 = void 0 === r6 ? this.length : r6 >>> 0, e6 || (e6 = 0), "number" == typeof e6)
        for (o5 = t5; o5 < r6; ++o5)
          this[o5] = e6;
      else {
        const a2 = l.isBuffer(e6) ? e6 : l.from(e6, n6), i4 = a2.length;
        if (0 === i4)
          throw new TypeError('The value "' + e6 + '" is invalid for argument "value"');
        for (o5 = 0; o5 < r6 - t5; ++o5)
          this[o5 + t5] = a2[o5 % i4];
      }
      return this;
    };
    const N = {};
    function q(e6, t5, r6) {
      N[e6] = class extends r6 {
        constructor() {
          super(), Object.defineProperty(this, "message", { value: t5.apply(this, arguments), writable: true, configurable: true }), this.name = `${this.name} [${e6}]`, this.stack, delete this.name;
        }
        get code() {
          return e6;
        }
        set code(e7) {
          Object.defineProperty(this, "code", { configurable: true, enumerable: true, value: e7, writable: true });
        }
        toString() {
          return `${this.name} [${e6}]: ${this.message}`;
        }
      };
    }
    function U(e6) {
      let t5 = "", r6 = e6.length;
      const n6 = "-" === e6[0] ? 1 : 0;
      for (; r6 >= n6 + 4; r6 -= 3)
        t5 = `_${e6.slice(r6 - 3, r6)}${t5}`;
      return `${e6.slice(0, r6)}${t5}`;
    }
    function z(e6, t5, r6, n6, o5, a2) {
      if (e6 > r6 || e6 < t5) {
        const n7 = "bigint" == typeof t5 ? "n" : "";
        let o6;
        throw o6 = a2 > 3 ? 0 === t5 || t5 === BigInt(0) ? `>= 0${n7} and < 2${n7} ** ${8 * (a2 + 1)}${n7}` : `>= -(2${n7} ** ${8 * (a2 + 1) - 1}${n7}) and < 2 ** ${8 * (a2 + 1) - 1}${n7}` : `>= ${t5}${n7} and <= ${r6}${n7}`, new N.ERR_OUT_OF_RANGE("value", o6, e6);
      }
      !function(e7, t6, r7) {
        M(t6, "offset"), void 0 !== e7[t6] && void 0 !== e7[t6 + r7] || H(t6, e7.length - (r7 + 1));
      }(n6, o5, a2);
    }
    function M(e6, t5) {
      if ("number" != typeof e6)
        throw new N.ERR_INVALID_ARG_TYPE(t5, "number", e6);
    }
    function H(e6, t5, r6) {
      if (Math.floor(e6) !== e6)
        throw M(e6, r6), new N.ERR_OUT_OF_RANGE(r6 || "offset", "an integer", e6);
      if (t5 < 0)
        throw new N.ERR_BUFFER_OUT_OF_BOUNDS();
      throw new N.ERR_OUT_OF_RANGE(r6 || "offset", `>= ${r6 ? 1 : 0} and <= ${t5}`, e6);
    }
    q("ERR_BUFFER_OUT_OF_BOUNDS", function(e6) {
      return e6 ? `${e6} is outside of buffer bounds` : "Attempt to access memory outside buffer bounds";
    }, RangeError), q("ERR_INVALID_ARG_TYPE", function(e6, t5) {
      return `The "${e6}" argument must be of type number. Received type ${typeof t5}`;
    }, TypeError), q("ERR_OUT_OF_RANGE", function(e6, t5, r6) {
      let n6 = `The value of "${e6}" is out of range.`, o5 = r6;
      return Number.isInteger(r6) && Math.abs(r6) > 2 ** 32 ? o5 = U(String(r6)) : "bigint" == typeof r6 && (o5 = String(r6), (r6 > BigInt(2) ** BigInt(32) || r6 < -(BigInt(2) ** BigInt(32))) && (o5 = U(o5)), o5 += "n"), n6 += ` It must be ${t5}. Received ${o5}`, n6;
    }, RangeError);
    const W = /[^+/0-9A-Za-z-_]/g;
    function V(e6, t5) {
      let r6;
      t5 = t5 || 1 / 0;
      const n6 = e6.length;
      let o5 = null;
      const a2 = [];
      for (let i4 = 0; i4 < n6; ++i4) {
        if (r6 = e6.charCodeAt(i4), r6 > 55295 && r6 < 57344) {
          if (!o5) {
            if (r6 > 56319) {
              (t5 -= 3) > -1 && a2.push(239, 191, 189);
              continue;
            }
            if (i4 + 1 === n6) {
              (t5 -= 3) > -1 && a2.push(239, 191, 189);
              continue;
            }
            o5 = r6;
            continue;
          }
          if (r6 < 56320) {
            (t5 -= 3) > -1 && a2.push(239, 191, 189), o5 = r6;
            continue;
          }
          r6 = 65536 + (o5 - 55296 << 10 | r6 - 56320);
        } else
          o5 && (t5 -= 3) > -1 && a2.push(239, 191, 189);
        if (o5 = null, r6 < 128) {
          if ((t5 -= 1) < 0)
            break;
          a2.push(r6);
        } else if (r6 < 2048) {
          if ((t5 -= 2) < 0)
            break;
          a2.push(r6 >> 6 | 192, 63 & r6 | 128);
        } else if (r6 < 65536) {
          if ((t5 -= 3) < 0)
            break;
          a2.push(r6 >> 12 | 224, r6 >> 6 & 63 | 128, 63 & r6 | 128);
        } else {
          if (!(r6 < 1114112))
            throw new Error("Invalid code point");
          if ((t5 -= 4) < 0)
            break;
          a2.push(r6 >> 18 | 240, r6 >> 12 & 63 | 128, r6 >> 6 & 63 | 128, 63 & r6 | 128);
        }
      }
      return a2;
    }
    function G(e6) {
      return n5.toByteArray(function(e7) {
        if ((e7 = (e7 = e7.split("=")[0]).trim().replace(W, "")).length < 2)
          return "";
        for (; e7.length % 4 != 0; )
          e7 += "=";
        return e7;
      }(e6));
    }
    function K(e6, t5, r6, n6) {
      let o5;
      for (o5 = 0; o5 < n6 && !(o5 + r6 >= t5.length || o5 >= e6.length); ++o5)
        t5[o5 + r6] = e6[o5];
      return o5;
    }
    function J(e6, t5) {
      return e6 instanceof t5 || null != e6 && null != e6.constructor && null != e6.constructor.name && e6.constructor.name === t5.name;
    }
    function Y(e6) {
      return e6 != e6;
    }
    const Z = function() {
      const e6 = "0123456789abcdef", t5 = new Array(256);
      for (let r6 = 0; r6 < 16; ++r6) {
        const n6 = 16 * r6;
        for (let o5 = 0; o5 < 16; ++o5)
          t5[n6 + o5] = e6[r6] + e6[o5];
      }
      return t5;
    }();
    function Q(e6) {
      return "undefined" == typeof BigInt ? X : e6;
    }
    function X() {
      throw new Error("BigInt not supported");
    }
  }, 645: (e5, t4) => {
    t4.read = function(e6, t5, r5, n5, o4) {
      var a, i3, s5 = 8 * o4 - n5 - 1, l = (1 << s5) - 1, c2 = l >> 1, p = -7, d = r5 ? o4 - 1 : 0, u2 = r5 ? -1 : 1, h = e6[t5 + d];
      for (d += u2, a = h & (1 << -p) - 1, h >>= -p, p += s5; p > 0; a = 256 * a + e6[t5 + d], d += u2, p -= 8)
        ;
      for (i3 = a & (1 << -p) - 1, a >>= -p, p += n5; p > 0; i3 = 256 * i3 + e6[t5 + d], d += u2, p -= 8)
        ;
      if (0 === a)
        a = 1 - c2;
      else {
        if (a === l)
          return i3 ? NaN : 1 / 0 * (h ? -1 : 1);
        i3 += Math.pow(2, n5), a -= c2;
      }
      return (h ? -1 : 1) * i3 * Math.pow(2, a - n5);
    }, t4.write = function(e6, t5, r5, n5, o4, a) {
      var i3, s5, l, c2 = 8 * a - o4 - 1, p = (1 << c2) - 1, d = p >> 1, u2 = 23 === o4 ? Math.pow(2, -24) - Math.pow(2, -77) : 0, h = n5 ? 0 : a - 1, f2 = n5 ? 1 : -1, m = t5 < 0 || 0 === t5 && 1 / t5 < 0 ? 1 : 0;
      for (t5 = Math.abs(t5), isNaN(t5) || t5 === 1 / 0 ? (s5 = isNaN(t5) ? 1 : 0, i3 = p) : (i3 = Math.floor(Math.log(t5) / Math.LN2), t5 * (l = Math.pow(2, -i3)) < 1 && (i3--, l *= 2), (t5 += i3 + d >= 1 ? u2 / l : u2 * Math.pow(2, 1 - d)) * l >= 2 && (i3++, l /= 2), i3 + d >= p ? (s5 = 0, i3 = p) : i3 + d >= 1 ? (s5 = (t5 * l - 1) * Math.pow(2, o4), i3 += d) : (s5 = t5 * Math.pow(2, d - 1) * Math.pow(2, o4), i3 = 0)); o4 >= 8; e6[r5 + h] = 255 & s5, h += f2, s5 /= 256, o4 -= 8)
        ;
      for (i3 = i3 << o4 | s5, c2 += o4; c2 > 0; e6[r5 + h] = 255 & i3, h += f2, i3 /= 256, c2 -= 8)
        ;
      e6[r5 + h - f2] |= 128 * m;
    };
  }, 874: () => {
    !function(e5) {
      var t4 = "\\b(?:BASH|BASHOPTS|BASH_ALIASES|BASH_ARGC|BASH_ARGV|BASH_CMDS|BASH_COMPLETION_COMPAT_DIR|BASH_LINENO|BASH_REMATCH|BASH_SOURCE|BASH_VERSINFO|BASH_VERSION|COLORTERM|COLUMNS|COMP_WORDBREAKS|DBUS_SESSION_BUS_ADDRESS|DEFAULTS_PATH|DESKTOP_SESSION|DIRSTACK|DISPLAY|EUID|GDMSESSION|GDM_LANG|GNOME_KEYRING_CONTROL|GNOME_KEYRING_PID|GPG_AGENT_INFO|GROUPS|HISTCONTROL|HISTFILE|HISTFILESIZE|HISTSIZE|HOME|HOSTNAME|HOSTTYPE|IFS|INSTANCE|JOB|LANG|LANGUAGE|LC_ADDRESS|LC_ALL|LC_IDENTIFICATION|LC_MEASUREMENT|LC_MONETARY|LC_NAME|LC_NUMERIC|LC_PAPER|LC_TELEPHONE|LC_TIME|LESSCLOSE|LESSOPEN|LINES|LOGNAME|LS_COLORS|MACHTYPE|MAILCHECK|MANDATORY_PATH|NO_AT_BRIDGE|OLDPWD|OPTERR|OPTIND|ORBIT_SOCKETDIR|OSTYPE|PAPERSIZE|PATH|PIPESTATUS|PPID|PS1|PS2|PS3|PS4|PWD|RANDOM|REPLY|SECONDS|SELINUX_INIT|SESSION|SESSIONTYPE|SESSION_MANAGER|SHELL|SHELLOPTS|SHLVL|SSH_AUTH_SOCK|TERM|UID|UPSTART_EVENTS|UPSTART_INSTANCE|UPSTART_JOB|UPSTART_SESSION|USER|WINDOWID|XAUTHORITY|XDG_CONFIG_DIRS|XDG_CURRENT_DESKTOP|XDG_DATA_DIRS|XDG_GREETER_DATA_DIR|XDG_MENU_PREFIX|XDG_RUNTIME_DIR|XDG_SEAT|XDG_SEAT_PATH|XDG_SESSION_DESKTOP|XDG_SESSION_ID|XDG_SESSION_PATH|XDG_SESSION_TYPE|XDG_VTNR|XMODIFIERS)\\b", r5 = { pattern: /(^(["']?)\w+\2)[ \t]+\S.*/, lookbehind: true, alias: "punctuation", inside: null }, n5 = { bash: r5, environment: { pattern: RegExp("\\$" + t4), alias: "constant" }, variable: [{ pattern: /\$?\(\([\s\S]+?\)\)/, greedy: true, inside: { variable: [{ pattern: /(^\$\(\([\s\S]+)\)\)/, lookbehind: true }, /^\$\(\(/], number: /\b0x[\dA-Fa-f]+\b|(?:\b\d+(?:\.\d*)?|\B\.\d+)(?:[Ee]-?\d+)?/, operator: /--|\+\+|\*\*=?|<<=?|>>=?|&&|\|\||[=!+\-*/%<>^&|]=?|[?~:]/, punctuation: /\(\(?|\)\)?|,|;/ } }, { pattern: /\$\((?:\([^)]+\)|[^()])+\)|`[^`]+`/, greedy: true, inside: { variable: /^\$\(|^`|\)$|`$/ } }, { pattern: /\$\{[^}]+\}/, greedy: true, inside: { operator: /:[-=?+]?|[!\/]|##?|%%?|\^\^?|,,?/, punctuation: /[\[\]]/, environment: { pattern: RegExp("(\\{)" + t4), lookbehind: true, alias: "constant" } } }, /\$(?:\w+|[#?*!@$])/], entity: /\\(?:[abceEfnrtv\\"]|O?[0-7]{1,3}|U[0-9a-fA-F]{8}|u[0-9a-fA-F]{4}|x[0-9a-fA-F]{1,2})/ };
      e5.languages.bash = { shebang: { pattern: /^#!\s*\/.*/, alias: "important" }, comment: { pattern: /(^|[^"{\\$])#.*/, lookbehind: true }, "function-name": [{ pattern: /(\bfunction\s+)[\w-]+(?=(?:\s*\(?:\s*\))?\s*\{)/, lookbehind: true, alias: "function" }, { pattern: /\b[\w-]+(?=\s*\(\s*\)\s*\{)/, alias: "function" }], "for-or-select": { pattern: /(\b(?:for|select)\s+)\w+(?=\s+in\s)/, alias: "variable", lookbehind: true }, "assign-left": { pattern: /(^|[\s;|&]|[<>]\()\w+(?:\.\w+)*(?=\+?=)/, inside: { environment: { pattern: RegExp("(^|[\\s;|&]|[<>]\\()" + t4), lookbehind: true, alias: "constant" } }, alias: "variable", lookbehind: true }, parameter: { pattern: /(^|\s)-{1,2}(?:\w+:[+-]?)?\w+(?:\.\w+)*(?=[=\s]|$)/, alias: "variable", lookbehind: true }, string: [{ pattern: /((?:^|[^<])<<-?\s*)(\w+)\s[\s\S]*?(?:\r?\n|\r)\2/, lookbehind: true, greedy: true, inside: n5 }, { pattern: /((?:^|[^<])<<-?\s*)(["'])(\w+)\2\s[\s\S]*?(?:\r?\n|\r)\3/, lookbehind: true, greedy: true, inside: { bash: r5 } }, { pattern: /(^|[^\\](?:\\\\)*)"(?:\\[\s\S]|\$\([^)]+\)|\$(?!\()|`[^`]+`|[^"\\`$])*"/, lookbehind: true, greedy: true, inside: n5 }, { pattern: /(^|[^$\\])'[^']*'/, lookbehind: true, greedy: true }, { pattern: /\$'(?:[^'\\]|\\[\s\S])*'/, greedy: true, inside: { entity: n5.entity } }], environment: { pattern: RegExp("\\$?" + t4), alias: "constant" }, variable: n5.variable, function: { pattern: /(^|[\s;|&]|[<>]\()(?:add|apropos|apt|apt-cache|apt-get|aptitude|aspell|automysqlbackup|awk|basename|bash|bc|bconsole|bg|bzip2|cal|cargo|cat|cfdisk|chgrp|chkconfig|chmod|chown|chroot|cksum|clear|cmp|column|comm|composer|cp|cron|crontab|csplit|curl|cut|date|dc|dd|ddrescue|debootstrap|df|diff|diff3|dig|dir|dircolors|dirname|dirs|dmesg|docker|docker-compose|du|egrep|eject|env|ethtool|expand|expect|expr|fdformat|fdisk|fg|fgrep|file|find|fmt|fold|format|free|fsck|ftp|fuser|gawk|git|gparted|grep|groupadd|groupdel|groupmod|groups|grub-mkconfig|gzip|halt|head|hg|history|host|hostname|htop|iconv|id|ifconfig|ifdown|ifup|import|install|ip|java|jobs|join|kill|killall|less|link|ln|locate|logname|logrotate|look|lpc|lpr|lprint|lprintd|lprintq|lprm|ls|lsof|lynx|make|man|mc|mdadm|mkconfig|mkdir|mke2fs|mkfifo|mkfs|mkisofs|mknod|mkswap|mmv|more|most|mount|mtools|mtr|mutt|mv|nano|nc|netstat|nice|nl|node|nohup|notify-send|npm|nslookup|op|open|parted|passwd|paste|pathchk|ping|pkill|pnpm|podman|podman-compose|popd|pr|printcap|printenv|ps|pushd|pv|quota|quotacheck|quotactl|ram|rar|rcp|reboot|remsync|rename|renice|rev|rm|rmdir|rpm|rsync|scp|screen|sdiff|sed|sendmail|seq|service|sftp|sh|shellcheck|shuf|shutdown|sleep|slocate|sort|split|ssh|stat|strace|su|sudo|sum|suspend|swapon|sync|sysctl|tac|tail|tar|tee|time|timeout|top|touch|tr|traceroute|tsort|tty|umount|uname|unexpand|uniq|units|unrar|unshar|unzip|update-grub|uptime|useradd|userdel|usermod|users|uudecode|uuencode|v|vcpkg|vdir|vi|vim|virsh|vmstat|wait|watch|wc|wget|whereis|which|who|whoami|write|xargs|xdg-open|yarn|yes|zenity|zip|zsh|zypper)(?=$|[)\s;|&])/, lookbehind: true }, keyword: { pattern: /(^|[\s;|&]|[<>]\()(?:case|do|done|elif|else|esac|fi|for|function|if|in|select|then|until|while)(?=$|[)\s;|&])/, lookbehind: true }, builtin: { pattern: /(^|[\s;|&]|[<>]\()(?:\.|:|alias|bind|break|builtin|caller|cd|command|continue|declare|echo|enable|eval|exec|exit|export|getopts|hash|help|let|local|logout|mapfile|printf|pwd|read|readarray|readonly|return|set|shift|shopt|source|test|times|trap|type|typeset|ulimit|umask|unalias|unset)(?=$|[)\s;|&])/, lookbehind: true, alias: "class-name" }, boolean: { pattern: /(^|[\s;|&]|[<>]\()(?:false|true)(?=$|[)\s;|&])/, lookbehind: true }, "file-descriptor": { pattern: /\B&\d\b/, alias: "important" }, operator: { pattern: /\d?<>|>\||\+=|=[=~]?|!=?|<<[<-]?|[&\d]?>>|\d[<>]&?|[<>][&=]?|&[>&]?|\|[&|]?/, inside: { "file-descriptor": { pattern: /^\d/, alias: "important" } } }, punctuation: /\$?\(\(?|\)\)?|\.\.|[{}[\];\\]/, number: { pattern: /(^|\s)(?:[1-9]\d*|0)(?:[.,]\d+)?\b/, lookbehind: true } }, r5.inside = e5.languages.bash;
      for (var o4 = ["comment", "function-name", "for-or-select", "assign-left", "parameter", "string", "environment", "function", "keyword", "builtin", "boolean", "file-descriptor", "operator", "punctuation", "number"], a = n5.variable[1].inside, i3 = 0; i3 < o4.length; i3++)
        a[o4[i3]] = e5.languages.bash[o4[i3]];
      e5.languages.sh = e5.languages.bash, e5.languages.shell = e5.languages.bash;
    }(Prism);
  }, 16: () => {
    !function(e5) {
      function t4(e6, t5) {
        return e6.replace(/<<(\d+)>>/g, function(e7, r6) {
          return "(?:" + t5[+r6] + ")";
        });
      }
      function r5(e6, r6, n6) {
        return RegExp(t4(e6, r6), n6 || "");
      }
      function n5(e6, t5) {
        for (var r6 = 0; r6 < t5; r6++)
          e6 = e6.replace(/<<self>>/g, function() {
            return "(?:" + e6 + ")";
          });
        return e6.replace(/<<self>>/g, "[^\\s\\S]");
      }
      var o4 = "bool byte char decimal double dynamic float int long object sbyte short string uint ulong ushort var void", a = "class enum interface record struct", i3 = "add alias and ascending async await by descending from(?=\\s*(?:\\w|$)) get global group into init(?=\\s*;) join let nameof not notnull on or orderby partial remove select set unmanaged value when where with(?=\\s*{)", s5 = "abstract as base break case catch checked const continue default delegate do else event explicit extern finally fixed for foreach goto if implicit in internal is lock namespace new null operator out override params private protected public readonly ref return sealed sizeof stackalloc static switch this throw try typeof unchecked unsafe using virtual volatile while yield";
      function l(e6) {
        return "\\b(?:" + e6.trim().replace(/ /g, "|") + ")\\b";
      }
      var c2 = l(a), p = RegExp(l(o4 + " " + a + " " + i3 + " " + s5)), d = l(a + " " + i3 + " " + s5), u2 = l(o4 + " " + a + " " + s5), h = n5(/<(?:[^<>;=+\-*/%&|^]|<<self>>)*>/.source, 2), f2 = n5(/\((?:[^()]|<<self>>)*\)/.source, 2), m = /@?\b[A-Za-z_]\w*\b/.source, y = t4(/<<0>>(?:\s*<<1>>)?/.source, [m, h]), g = t4(/(?!<<0>>)<<1>>(?:\s*\.\s*<<1>>)*/.source, [d, y]), v = /\[\s*(?:,\s*)*\]/.source, b = t4(/<<0>>(?:\s*(?:\?\s*)?<<1>>)*(?:\s*\?)?/.source, [g, v]), x2 = t4(/[^,()<>[\];=+\-*/%&|^]|<<0>>|<<1>>|<<2>>/.source, [h, f2, v]), w = t4(/\(<<0>>+(?:,<<0>>+)+\)/.source, [x2]), $ = t4(/(?:<<0>>|<<1>>)(?:\s*(?:\?\s*)?<<2>>)*(?:\s*\?)?/.source, [w, g, v]), k = { keyword: p, punctuation: /[<>()?,.:[\]]/ }, S = /'(?:[^\r\n'\\]|\\.|\\[Uux][\da-fA-F]{1,8})'/.source, A = /"(?:\\.|[^\\"\r\n])*"/.source, E = /@"(?:""|\\[\s\S]|[^\\"])*"(?!")/.source;
      e5.languages.csharp = e5.languages.extend("clike", { string: [{ pattern: r5(/(^|[^$\\])<<0>>/.source, [E]), lookbehind: true, greedy: true }, { pattern: r5(/(^|[^@$\\])<<0>>/.source, [A]), lookbehind: true, greedy: true }], "class-name": [{ pattern: r5(/(\busing\s+static\s+)<<0>>(?=\s*;)/.source, [g]), lookbehind: true, inside: k }, { pattern: r5(/(\busing\s+<<0>>\s*=\s*)<<1>>(?=\s*;)/.source, [m, $]), lookbehind: true, inside: k }, { pattern: r5(/(\busing\s+)<<0>>(?=\s*=)/.source, [m]), lookbehind: true }, { pattern: r5(/(\b<<0>>\s+)<<1>>/.source, [c2, y]), lookbehind: true, inside: k }, { pattern: r5(/(\bcatch\s*\(\s*)<<0>>/.source, [g]), lookbehind: true, inside: k }, { pattern: r5(/(\bwhere\s+)<<0>>/.source, [m]), lookbehind: true }, { pattern: r5(/(\b(?:is(?:\s+not)?|as)\s+)<<0>>/.source, [b]), lookbehind: true, inside: k }, { pattern: r5(/\b<<0>>(?=\s+(?!<<1>>|with\s*\{)<<2>>(?:\s*[=,;:{)\]]|\s+(?:in|when)\b))/.source, [$, u2, m]), inside: k }], keyword: p, number: /(?:\b0(?:x[\da-f_]*[\da-f]|b[01_]*[01])|(?:\B\.\d+(?:_+\d+)*|\b\d+(?:_+\d+)*(?:\.\d+(?:_+\d+)*)?)(?:e[-+]?\d+(?:_+\d+)*)?)(?:[dflmu]|lu|ul)?\b/i, operator: />>=?|<<=?|[-=]>|([-+&|])\1|~|\?\?=?|[-+*/%&|^!=<>]=?/, punctuation: /\?\.?|::|[{}[\];(),.:]/ }), e5.languages.insertBefore("csharp", "number", { range: { pattern: /\.\./, alias: "operator" } }), e5.languages.insertBefore("csharp", "punctuation", { "named-parameter": { pattern: r5(/([(,]\s*)<<0>>(?=\s*:)/.source, [m]), lookbehind: true, alias: "punctuation" } }), e5.languages.insertBefore("csharp", "class-name", { namespace: { pattern: r5(/(\b(?:namespace|using)\s+)<<0>>(?:\s*\.\s*<<0>>)*(?=\s*[;{])/.source, [m]), lookbehind: true, inside: { punctuation: /\./ } }, "type-expression": { pattern: r5(/(\b(?:default|sizeof|typeof)\s*\(\s*(?!\s))(?:[^()\s]|\s(?!\s)|<<0>>)*(?=\s*\))/.source, [f2]), lookbehind: true, alias: "class-name", inside: k }, "return-type": { pattern: r5(/<<0>>(?=\s+(?:<<1>>\s*(?:=>|[({]|\.\s*this\s*\[)|this\s*\[))/.source, [$, g]), inside: k, alias: "class-name" }, "constructor-invocation": { pattern: r5(/(\bnew\s+)<<0>>(?=\s*[[({])/.source, [$]), lookbehind: true, inside: k, alias: "class-name" }, "generic-method": { pattern: r5(/<<0>>\s*<<1>>(?=\s*\()/.source, [m, h]), inside: { function: r5(/^<<0>>/.source, [m]), generic: { pattern: RegExp(h), alias: "class-name", inside: k } } }, "type-list": { pattern: r5(/\b((?:<<0>>\s+<<1>>|record\s+<<1>>\s*<<5>>|where\s+<<2>>)\s*:\s*)(?:<<3>>|<<4>>|<<1>>\s*<<5>>|<<6>>)(?:\s*,\s*(?:<<3>>|<<4>>|<<6>>))*(?=\s*(?:where|[{;]|=>|$))/.source, [c2, y, m, $, p.source, f2, /\bnew\s*\(\s*\)/.source]), lookbehind: true, inside: { "record-arguments": { pattern: r5(/(^(?!new\s*\()<<0>>\s*)<<1>>/.source, [y, f2]), lookbehind: true, greedy: true, inside: e5.languages.csharp }, keyword: p, "class-name": { pattern: RegExp($), greedy: true, inside: k }, punctuation: /[,()]/ } }, preprocessor: { pattern: /(^[\t ]*)#.*/m, lookbehind: true, alias: "property", inside: { directive: { pattern: /(#)\b(?:define|elif|else|endif|endregion|error|if|line|nullable|pragma|region|undef|warning)\b/, lookbehind: true, alias: "keyword" } } } });
      var O = A + "|" + S, T2 = t4(/\/(?![*/])|\/\/[^\r\n]*[\r\n]|\/\*(?:[^*]|\*(?!\/))*\*\/|<<0>>/.source, [O]), C = n5(t4(/[^"'/()]|<<0>>|\(<<self>>*\)/.source, [T2]), 2), j = /\b(?:assembly|event|field|method|module|param|property|return|type)\b/.source, I = t4(/<<0>>(?:\s*\(<<1>>*\))?/.source, [g, C]);
      e5.languages.insertBefore("csharp", "class-name", { attribute: { pattern: r5(/((?:^|[^\s\w>)?])\s*\[\s*)(?:<<0>>\s*:\s*)?<<1>>(?:\s*,\s*<<1>>)*(?=\s*\])/.source, [j, I]), lookbehind: true, greedy: true, inside: { target: { pattern: r5(/^<<0>>(?=\s*:)/.source, [j]), alias: "keyword" }, "attribute-arguments": { pattern: r5(/\(<<0>>*\)/.source, [C]), inside: e5.languages.csharp }, "class-name": { pattern: RegExp(g), inside: { punctuation: /\./ } }, punctuation: /[:,]/ } } });
      var _ = /:[^}\r\n]+/.source, P = n5(t4(/[^"'/()]|<<0>>|\(<<self>>*\)/.source, [T2]), 2), R = t4(/\{(?!\{)(?:(?![}:])<<0>>)*<<1>>?\}/.source, [P, _]), L = n5(t4(/[^"'/()]|\/(?!\*)|\/\*(?:[^*]|\*(?!\/))*\*\/|<<0>>|\(<<self>>*\)/.source, [O]), 2), F = t4(/\{(?!\{)(?:(?![}:])<<0>>)*<<1>>?\}/.source, [L, _]);
      function D(t5, n6) {
        return { interpolation: { pattern: r5(/((?:^|[^{])(?:\{\{)*)<<0>>/.source, [t5]), lookbehind: true, inside: { "format-string": { pattern: r5(/(^\{(?:(?![}:])<<0>>)*)<<1>>(?=\}$)/.source, [n6, _]), lookbehind: true, inside: { punctuation: /^:/ } }, punctuation: /^\{|\}$/, expression: { pattern: /[\s\S]+/, alias: "language-csharp", inside: e5.languages.csharp } } }, string: /[\s\S]+/ };
      }
      e5.languages.insertBefore("csharp", "string", { "interpolation-string": [{ pattern: r5(/(^|[^\\])(?:\$@|@\$)"(?:""|\\[\s\S]|\{\{|<<0>>|[^\\{"])*"/.source, [R]), lookbehind: true, greedy: true, inside: D(R, P) }, { pattern: r5(/(^|[^@\\])\$"(?:\\.|\{\{|<<0>>|[^\\"{])*"/.source, [F]), lookbehind: true, greedy: true, inside: D(F, L) }], char: { pattern: RegExp(S), greedy: true } }), e5.languages.dotnet = e5.languages.cs = e5.languages.csharp;
    }(Prism);
  }, 251: () => {
    !function(e5) {
      var t4 = /(?:"(?:\\(?:\r\n|[\s\S])|[^"\\\r\n])*"|'(?:\\(?:\r\n|[\s\S])|[^'\\\r\n])*')/;
      e5.languages.css = { comment: /\/\*[\s\S]*?\*\//, atrule: { pattern: RegExp("@[\\w-](?:" + /[^;{\s"']|\s+(?!\s)/.source + "|" + t4.source + ")*?" + /(?:;|(?=\s*\{))/.source), inside: { rule: /^@[\w-]+/, "selector-function-argument": { pattern: /(\bselector\s*\(\s*(?![\s)]))(?:[^()\s]|\s+(?![\s)])|\((?:[^()]|\([^()]*\))*\))+(?=\s*\))/, lookbehind: true, alias: "selector" }, keyword: { pattern: /(^|[^\w-])(?:and|not|only|or)(?![\w-])/, lookbehind: true } } }, url: { pattern: RegExp("\\burl\\((?:" + t4.source + "|" + /(?:[^\\\r\n()"']|\\[\s\S])*/.source + ")\\)", "i"), greedy: true, inside: { function: /^url/i, punctuation: /^\(|\)$/, string: { pattern: RegExp("^" + t4.source + "$"), alias: "url" } } }, selector: { pattern: RegExp(`(^|[{}\\s])[^{}\\s](?:[^{};"'\\s]|\\s+(?![\\s{])|` + t4.source + ")*(?=\\s*\\{)"), lookbehind: true }, string: { pattern: t4, greedy: true }, property: { pattern: /(^|[^-\w\xA0-\uFFFF])(?!\s)[-_a-z\xA0-\uFFFF](?:(?!\s)[-\w\xA0-\uFFFF])*(?=\s*:)/i, lookbehind: true }, important: /!important\b/i, function: { pattern: /(^|[^-a-z0-9])[-a-z0-9]+(?=\()/i, lookbehind: true }, punctuation: /[(){};:,]/ }, e5.languages.css.atrule.inside.rest = e5.languages.css;
      var r5 = e5.languages.markup;
      r5 && (r5.tag.addInlined("style", "css"), r5.tag.addAttribute("style", "css"));
    }(Prism);
  }, 46: () => {
    Prism.languages.go = Prism.languages.extend("clike", { string: { pattern: /(^|[^\\])"(?:\\.|[^"\\\r\n])*"|`[^`]*`/, lookbehind: true, greedy: true }, keyword: /\b(?:break|case|chan|const|continue|default|defer|else|fallthrough|for|func|go(?:to)?|if|import|interface|map|package|range|return|select|struct|switch|type|var)\b/, boolean: /\b(?:_|false|iota|nil|true)\b/, number: [/\b0(?:b[01_]+|o[0-7_]+)i?\b/i, /\b0x(?:[a-f\d_]+(?:\.[a-f\d_]*)?|\.[a-f\d_]+)(?:p[+-]?\d+(?:_\d+)*)?i?(?!\w)/i, /(?:\b\d[\d_]*(?:\.[\d_]*)?|\B\.\d[\d_]*)(?:e[+-]?[\d_]+)?i?(?!\w)/i], operator: /[*\/%^!=]=?|\+[=+]?|-[=-]?|\|[=|]?|&(?:=|&|\^=?)?|>(?:>=?|=)?|<(?:<=?|=|-)?|:=|\.\.\./, builtin: /\b(?:append|bool|byte|cap|close|complex|complex(?:64|128)|copy|delete|error|float(?:32|64)|u?int(?:8|16|32|64)?|imag|len|make|new|panic|print(?:ln)?|real|recover|rune|string|uintptr)\b/ }), Prism.languages.insertBefore("go", "string", { char: { pattern: /'(?:\\.|[^'\\\r\n]){0,10}'/, greedy: true } }), delete Prism.languages.go["class-name"];
  }, 57: () => {
    !function(e5) {
      function t4(e6) {
        return RegExp("(^(?:" + e6 + "):[ 	]*(?![ 	]))[^]+", "i");
      }
      e5.languages.http = { "request-line": { pattern: /^(?:CONNECT|DELETE|GET|HEAD|OPTIONS|PATCH|POST|PRI|PUT|SEARCH|TRACE)\s(?:https?:\/\/|\/)\S*\sHTTP\/[\d.]+/m, inside: { method: { pattern: /^[A-Z]+\b/, alias: "property" }, "request-target": { pattern: /^(\s)(?:https?:\/\/|\/)\S*(?=\s)/, lookbehind: true, alias: "url", inside: e5.languages.uri }, "http-version": { pattern: /^(\s)HTTP\/[\d.]+/, lookbehind: true, alias: "property" } } }, "response-status": { pattern: /^HTTP\/[\d.]+ \d+ .+/m, inside: { "http-version": { pattern: /^HTTP\/[\d.]+/, alias: "property" }, "status-code": { pattern: /^(\s)\d+(?=\s)/, lookbehind: true, alias: "number" }, "reason-phrase": { pattern: /^(\s).+/, lookbehind: true, alias: "string" } } }, header: { pattern: /^[\w-]+:.+(?:(?:\r\n?|\n)[ \t].+)*/m, inside: { "header-value": [{ pattern: t4(/Content-Security-Policy/.source), lookbehind: true, alias: ["csp", "languages-csp"], inside: e5.languages.csp }, { pattern: t4(/Public-Key-Pins(?:-Report-Only)?/.source), lookbehind: true, alias: ["hpkp", "languages-hpkp"], inside: e5.languages.hpkp }, { pattern: t4(/Strict-Transport-Security/.source), lookbehind: true, alias: ["hsts", "languages-hsts"], inside: e5.languages.hsts }, { pattern: t4(/[^:]+/.source), lookbehind: true }], "header-name": { pattern: /^[^:]+/, alias: "keyword" }, punctuation: /^:/ } } };
      var r5, n5 = e5.languages, o4 = { "application/javascript": n5.javascript, "application/json": n5.json || n5.javascript, "application/xml": n5.xml, "text/xml": n5.xml, "text/html": n5.html, "text/css": n5.css, "text/plain": n5.plain }, a = { "application/json": true, "application/xml": true };
      function i3(e6) {
        var t5 = e6.replace(/^[a-z]+\//, "");
        return "(?:" + e6 + "|" + ("\\w+/(?:[\\w.-]+\\+)+" + t5 + "(?![+\\w.-])") + ")";
      }
      for (var s5 in o4)
        if (o4[s5]) {
          r5 = r5 || {};
          var l = a[s5] ? i3(s5) : s5;
          r5[s5.replace(/\//g, "-")] = { pattern: RegExp("(" + /content-type:\s*/.source + l + /(?:(?:\r\n?|\n)[\w-].*)*(?:\r(?:\n|(?!\n))|\n)/.source + ")" + /[^ \t\w-][\s\S]*/.source, "i"), lookbehind: true, inside: o4[s5] };
        }
      r5 && e5.languages.insertBefore("http", "header", r5);
    }(Prism);
  }, 503: () => {
    !function(e5) {
      var t4 = /\b(?:abstract|assert|boolean|break|byte|case|catch|char|class|const|continue|default|do|double|else|enum|exports|extends|final|finally|float|for|goto|if|implements|import|instanceof|int|interface|long|module|native|new|non-sealed|null|open|opens|package|permits|private|protected|provides|public|record(?!\s*[(){}[\]<>=%~.:,;?+\-*/&|^])|requires|return|sealed|short|static|strictfp|super|switch|synchronized|this|throw|throws|to|transient|transitive|try|uses|var|void|volatile|while|with|yield)\b/, r5 = /(?:[a-z]\w*\s*\.\s*)*(?:[A-Z]\w*\s*\.\s*)*/.source, n5 = { pattern: RegExp(/(^|[^\w.])/.source + r5 + /[A-Z](?:[\d_A-Z]*[a-z]\w*)?\b/.source), lookbehind: true, inside: { namespace: { pattern: /^[a-z]\w*(?:\s*\.\s*[a-z]\w*)*(?:\s*\.)?/, inside: { punctuation: /\./ } }, punctuation: /\./ } };
      e5.languages.java = e5.languages.extend("clike", { string: { pattern: /(^|[^\\])"(?:\\.|[^"\\\r\n])*"/, lookbehind: true, greedy: true }, "class-name": [n5, { pattern: RegExp(/(^|[^\w.])/.source + r5 + /[A-Z]\w*(?=\s+\w+\s*[;,=()]|\s*(?:\[[\s,]*\]\s*)?::\s*new\b)/.source), lookbehind: true, inside: n5.inside }, { pattern: RegExp(/(\b(?:class|enum|extends|implements|instanceof|interface|new|record|throws)\s+)/.source + r5 + /[A-Z]\w*\b/.source), lookbehind: true, inside: n5.inside }], keyword: t4, function: [e5.languages.clike.function, { pattern: /(::\s*)[a-z_]\w*/, lookbehind: true }], number: /\b0b[01][01_]*L?\b|\b0x(?:\.[\da-f_p+-]+|[\da-f_]+(?:\.[\da-f_p+-]+)?)\b|(?:\b\d[\d_]*(?:\.[\d_]*)?|\B\.\d[\d_]*)(?:e[+-]?\d[\d_]*)?[dfl]?/i, operator: { pattern: /(^|[^.])(?:<<=?|>>>?=?|->|--|\+\+|&&|\|\||::|[?:~]|[-+*/%&|^!=<>]=?)/m, lookbehind: true }, constant: /\b[A-Z][A-Z_\d]+\b/ }), e5.languages.insertBefore("java", "string", { "triple-quoted-string": { pattern: /"""[ \t]*[\r\n](?:(?:"|"")?(?:\\.|[^"\\]))*"""/, greedy: true, alias: "string" }, char: { pattern: /'(?:\\.|[^'\\\r\n]){1,6}'/, greedy: true } }), e5.languages.insertBefore("java", "class-name", { annotation: { pattern: /(^|[^.])@\w+(?:\s*\.\s*\w+)*/, lookbehind: true, alias: "punctuation" }, generics: { pattern: /<(?:[\w\s,.?]|&(?!&)|<(?:[\w\s,.?]|&(?!&)|<(?:[\w\s,.?]|&(?!&)|<(?:[\w\s,.?]|&(?!&))*>)*>)*>)*>/, inside: { "class-name": n5, keyword: t4, punctuation: /[<>(),.:]/, operator: /[?&|]/ } }, import: [{ pattern: RegExp(/(\bimport\s+)/.source + r5 + /(?:[A-Z]\w*|\*)(?=\s*;)/.source), lookbehind: true, inside: { namespace: n5.inside.namespace, punctuation: /\./, operator: /\*/, "class-name": /\w+/ } }, { pattern: RegExp(/(\bimport\s+static\s+)/.source + r5 + /(?:\w+|\*)(?=\s*;)/.source), lookbehind: true, alias: "static", inside: { namespace: n5.inside.namespace, static: /\b\w+$/, punctuation: /\./, operator: /\*/, "class-name": /\w+/ } }], namespace: { pattern: RegExp(/(\b(?:exports|import(?:\s+static)?|module|open|opens|package|provides|requires|to|transitive|uses|with)\s+)(?!<keyword>)[a-z]\w*(?:\.[a-z]\w*)*\.?/.source.replace(/<keyword>/g, function() {
        return t4.source;
      })), lookbehind: true, inside: { punctuation: /\./ } } });
    }(Prism);
  }, 277: () => {
    Prism.languages.json = { property: { pattern: /(^|[^\\])"(?:\\.|[^\\"\r\n])*"(?=\s*:)/, lookbehind: true, greedy: true }, string: { pattern: /(^|[^\\])"(?:\\.|[^\\"\r\n])*"(?!\s*:)/, lookbehind: true, greedy: true }, comment: { pattern: /\/\/.*|\/\*[\s\S]*?(?:\*\/|$)/, greedy: true }, number: /-?\b\d+(?:\.\d+)?(?:e[+-]?\d+)?\b/i, punctuation: /[{}[\],]/, operator: /:/, boolean: /\b(?:false|true)\b/, null: { pattern: /\bnull\b/, alias: "keyword" } }, Prism.languages.webmanifest = Prism.languages.json;
  }, 366: () => {
    Prism.languages.python = { comment: { pattern: /(^|[^\\])#.*/, lookbehind: true, greedy: true }, "string-interpolation": { pattern: /(?:f|fr|rf)(?:("""|''')[\s\S]*?\1|("|')(?:\\.|(?!\2)[^\\\r\n])*\2)/i, greedy: true, inside: { interpolation: { pattern: /((?:^|[^{])(?:\{\{)*)\{(?!\{)(?:[^{}]|\{(?!\{)(?:[^{}]|\{(?!\{)(?:[^{}])+\})+\})+\}/, lookbehind: true, inside: { "format-spec": { pattern: /(:)[^:(){}]+(?=\}$)/, lookbehind: true }, "conversion-option": { pattern: /![sra](?=[:}]$)/, alias: "punctuation" }, rest: null } }, string: /[\s\S]+/ } }, "triple-quoted-string": { pattern: /(?:[rub]|br|rb)?("""|''')[\s\S]*?\1/i, greedy: true, alias: "string" }, string: { pattern: /(?:[rub]|br|rb)?("|')(?:\\.|(?!\1)[^\\\r\n])*\1/i, greedy: true }, function: { pattern: /((?:^|\s)def[ \t]+)[a-zA-Z_]\w*(?=\s*\()/g, lookbehind: true }, "class-name": { pattern: /(\bclass\s+)\w+/i, lookbehind: true }, decorator: { pattern: /(^[\t ]*)@\w+(?:\.\w+)*/m, lookbehind: true, alias: ["annotation", "punctuation"], inside: { punctuation: /\./ } }, keyword: /\b(?:_(?=\s*:)|and|as|assert|async|await|break|case|class|continue|def|del|elif|else|except|exec|finally|for|from|global|if|import|in|is|lambda|match|nonlocal|not|or|pass|print|raise|return|try|while|with|yield)\b/, builtin: /\b(?:__import__|abs|all|any|apply|ascii|basestring|bin|bool|buffer|bytearray|bytes|callable|chr|classmethod|cmp|coerce|compile|complex|delattr|dict|dir|divmod|enumerate|eval|execfile|file|filter|float|format|frozenset|getattr|globals|hasattr|hash|help|hex|id|input|int|intern|isinstance|issubclass|iter|len|list|locals|long|map|max|memoryview|min|next|object|oct|open|ord|pow|property|range|raw_input|reduce|reload|repr|reversed|round|set|setattr|slice|sorted|staticmethod|str|sum|super|tuple|type|unichr|unicode|vars|xrange|zip)\b/, boolean: /\b(?:False|None|True)\b/, number: /\b0(?:b(?:_?[01])+|o(?:_?[0-7])+|x(?:_?[a-f0-9])+)\b|(?:\b\d+(?:_\d+)*(?:\.(?:\d+(?:_\d+)*)?)?|\B\.\d+(?:_\d+)*)(?:e[+-]?\d+(?:_\d+)*)?j?(?!\w)/i, operator: /[-+%=]=?|!=|:=|\*\*?=?|\/\/?=?|<[<=>]?|>[=>]?|[&|^~]/, punctuation: /[{}[\];(),.:]/ }, Prism.languages.python["string-interpolation"].inside.interpolation.inside.rest = Prism.languages.python, Prism.languages.py = Prism.languages.python;
  }, 358: () => {
    !function(e5) {
      var t4 = /[*&][^\s[\]{},]+/, r5 = /!(?:<[\w\-%#;/?:@&=+$,.!~*'()[\]]+>|(?:[a-zA-Z\d-]*!)?[\w\-%#;/?:@&=+$.~*'()]+)?/, n5 = "(?:" + r5.source + "(?:[ 	]+" + t4.source + ")?|" + t4.source + "(?:[ 	]+" + r5.source + ")?)", o4 = /(?:[^\s\x00-\x08\x0e-\x1f!"#%&'*,\-:>?@[\]`{|}\x7f-\x84\x86-\x9f\ud800-\udfff\ufffe\uffff]|[?:-]<PLAIN>)(?:[ \t]*(?:(?![#:])<PLAIN>|:<PLAIN>))*/.source.replace(/<PLAIN>/g, function() {
        return /[^\s\x00-\x08\x0e-\x1f,[\]{}\x7f-\x84\x86-\x9f\ud800-\udfff\ufffe\uffff]/.source;
      }), a = /"(?:[^"\\\r\n]|\\.)*"|'(?:[^'\\\r\n]|\\.)*'/.source;
      function i3(e6, t5) {
        t5 = (t5 || "").replace(/m/g, "") + "m";
        var r6 = /([:\-,[{]\s*(?:\s<<prop>>[ \t]+)?)(?:<<value>>)(?=[ \t]*(?:$|,|\]|\}|(?:[\r\n]\s*)?#))/.source.replace(/<<prop>>/g, function() {
          return n5;
        }).replace(/<<value>>/g, function() {
          return e6;
        });
        return RegExp(r6, t5);
      }
      e5.languages.yaml = { scalar: { pattern: RegExp(/([\-:]\s*(?:\s<<prop>>[ \t]+)?[|>])[ \t]*(?:((?:\r?\n|\r)[ \t]+)\S[^\r\n]*(?:\2[^\r\n]+)*)/.source.replace(/<<prop>>/g, function() {
        return n5;
      })), lookbehind: true, alias: "string" }, comment: /#.*/, key: { pattern: RegExp(/((?:^|[:\-,[{\r\n?])[ \t]*(?:<<prop>>[ \t]+)?)<<key>>(?=\s*:\s)/.source.replace(/<<prop>>/g, function() {
        return n5;
      }).replace(/<<key>>/g, function() {
        return "(?:" + o4 + "|" + a + ")";
      })), lookbehind: true, greedy: true, alias: "atrule" }, directive: { pattern: /(^[ \t]*)%.+/m, lookbehind: true, alias: "important" }, datetime: { pattern: i3(/\d{4}-\d\d?-\d\d?(?:[tT]|[ \t]+)\d\d?:\d{2}:\d{2}(?:\.\d*)?(?:[ \t]*(?:Z|[-+]\d\d?(?::\d{2})?))?|\d{4}-\d{2}-\d{2}|\d\d?:\d{2}(?::\d{2}(?:\.\d*)?)?/.source), lookbehind: true, alias: "number" }, boolean: { pattern: i3(/false|true/.source, "i"), lookbehind: true, alias: "important" }, null: { pattern: i3(/null|~/.source, "i"), lookbehind: true, alias: "important" }, string: { pattern: i3(a), lookbehind: true, greedy: true }, number: { pattern: i3(/[+-]?(?:0x[\da-f]+|0o[0-7]+|(?:\d+(?:\.\d*)?|\.\d+)(?:e[+-]?\d+)?|\.inf|\.nan)/.source, "i"), lookbehind: true }, tag: r5, important: t4, punctuation: /---|[:[\]{}\-,|>?]|\.\.\./ }, e5.languages.yml = e5.languages.yaml;
    }(Prism);
  }, 660: (e5, t4, r5) => {
    var n5 = function(e6) {
      var t5 = /(?:^|\s)lang(?:uage)?-([\w-]+)(?=\s|$)/i, r6 = 0, n6 = {}, o4 = { manual: e6.Prism && e6.Prism.manual, disableWorkerMessageHandler: e6.Prism && e6.Prism.disableWorkerMessageHandler, util: { encode: function e7(t6) {
        return t6 instanceof a ? new a(t6.type, e7(t6.content), t6.alias) : Array.isArray(t6) ? t6.map(e7) : t6.replace(/&/g, "&amp;").replace(/</g, "&lt;").replace(/\u00a0/g, " ");
      }, type: function(e7) {
        return Object.prototype.toString.call(e7).slice(8, -1);
      }, objId: function(e7) {
        return e7.__id || Object.defineProperty(e7, "__id", { value: ++r6 }), e7.__id;
      }, clone: function e7(t6, r7) {
        var n7, a2;
        switch (r7 = r7 || {}, o4.util.type(t6)) {
          case "Object":
            if (a2 = o4.util.objId(t6), r7[a2])
              return r7[a2];
            for (var i4 in n7 = {}, r7[a2] = n7, t6)
              t6.hasOwnProperty(i4) && (n7[i4] = e7(t6[i4], r7));
            return n7;
          case "Array":
            return a2 = o4.util.objId(t6), r7[a2] ? r7[a2] : (n7 = [], r7[a2] = n7, t6.forEach(function(t7, o5) {
              n7[o5] = e7(t7, r7);
            }), n7);
          default:
            return t6;
        }
      }, getLanguage: function(e7) {
        for (; e7; ) {
          var r7 = t5.exec(e7.className);
          if (r7)
            return r7[1].toLowerCase();
          e7 = e7.parentElement;
        }
        return "none";
      }, setLanguage: function(e7, r7) {
        e7.className = e7.className.replace(RegExp(t5, "gi"), ""), e7.classList.add("language-" + r7);
      }, currentScript: function() {
        if ("undefined" == typeof document)
          return null;
        if ("currentScript" in document)
          return document.currentScript;
        try {
          throw new Error();
        } catch (n7) {
          var e7 = (/at [^(\r\n]*\((.*):[^:]+:[^:]+\)$/i.exec(n7.stack) || [])[1];
          if (e7) {
            var t6 = document.getElementsByTagName("script");
            for (var r7 in t6)
              if (t6[r7].src == e7)
                return t6[r7];
          }
          return null;
        }
      }, isActive: function(e7, t6, r7) {
        for (var n7 = "no-" + t6; e7; ) {
          var o5 = e7.classList;
          if (o5.contains(t6))
            return true;
          if (o5.contains(n7))
            return false;
          e7 = e7.parentElement;
        }
        return !!r7;
      } }, languages: { plain: n6, plaintext: n6, text: n6, txt: n6, extend: function(e7, t6) {
        var r7 = o4.util.clone(o4.languages[e7]);
        for (var n7 in t6)
          r7[n7] = t6[n7];
        return r7;
      }, insertBefore: function(e7, t6, r7, n7) {
        var a2 = (n7 = n7 || o4.languages)[e7], i4 = {};
        for (var s6 in a2)
          if (a2.hasOwnProperty(s6)) {
            if (s6 == t6)
              for (var l2 in r7)
                r7.hasOwnProperty(l2) && (i4[l2] = r7[l2]);
            r7.hasOwnProperty(s6) || (i4[s6] = a2[s6]);
          }
        var c3 = n7[e7];
        return n7[e7] = i4, o4.languages.DFS(o4.languages, function(t7, r8) {
          r8 === c3 && t7 != e7 && (this[t7] = i4);
        }), i4;
      }, DFS: function e7(t6, r7, n7, a2) {
        a2 = a2 || {};
        var i4 = o4.util.objId;
        for (var s6 in t6)
          if (t6.hasOwnProperty(s6)) {
            r7.call(t6, s6, t6[s6], n7 || s6);
            var l2 = t6[s6], c3 = o4.util.type(l2);
            "Object" !== c3 || a2[i4(l2)] ? "Array" !== c3 || a2[i4(l2)] || (a2[i4(l2)] = true, e7(l2, r7, s6, a2)) : (a2[i4(l2)] = true, e7(l2, r7, null, a2));
          }
      } }, plugins: {}, highlightAll: function(e7, t6) {
        o4.highlightAllUnder(document, e7, t6);
      }, highlightAllUnder: function(e7, t6, r7) {
        var n7 = { callback: r7, container: e7, selector: 'code[class*="language-"], [class*="language-"] code, code[class*="lang-"], [class*="lang-"] code' };
        o4.hooks.run("before-highlightall", n7), n7.elements = Array.prototype.slice.apply(n7.container.querySelectorAll(n7.selector)), o4.hooks.run("before-all-elements-highlight", n7);
        for (var a2, i4 = 0; a2 = n7.elements[i4++]; )
          o4.highlightElement(a2, true === t6, n7.callback);
      }, highlightElement: function(t6, r7, n7) {
        var a2 = o4.util.getLanguage(t6), i4 = o4.languages[a2];
        o4.util.setLanguage(t6, a2);
        var s6 = t6.parentElement;
        s6 && "pre" === s6.nodeName.toLowerCase() && o4.util.setLanguage(s6, a2);
        var l2 = { element: t6, language: a2, grammar: i4, code: t6.textContent };
        function c3(e7) {
          l2.highlightedCode = e7, o4.hooks.run("before-insert", l2), l2.element.innerHTML = l2.highlightedCode, o4.hooks.run("after-highlight", l2), o4.hooks.run("complete", l2), n7 && n7.call(l2.element);
        }
        if (o4.hooks.run("before-sanity-check", l2), (s6 = l2.element.parentElement) && "pre" === s6.nodeName.toLowerCase() && !s6.hasAttribute("tabindex") && s6.setAttribute("tabindex", "0"), !l2.code)
          return o4.hooks.run("complete", l2), void (n7 && n7.call(l2.element));
        if (o4.hooks.run("before-highlight", l2), l2.grammar)
          if (r7 && e6.Worker) {
            var p2 = new Worker(o4.filename);
            p2.onmessage = function(e7) {
              c3(e7.data);
            }, p2.postMessage(JSON.stringify({ language: l2.language, code: l2.code, immediateClose: true }));
          } else
            c3(o4.highlight(l2.code, l2.grammar, l2.language));
        else
          c3(o4.util.encode(l2.code));
      }, highlight: function(e7, t6, r7) {
        var n7 = { code: e7, grammar: t6, language: r7 };
        if (o4.hooks.run("before-tokenize", n7), !n7.grammar)
          throw new Error('The language "' + n7.language + '" has no grammar.');
        return n7.tokens = o4.tokenize(n7.code, n7.grammar), o4.hooks.run("after-tokenize", n7), a.stringify(o4.util.encode(n7.tokens), n7.language);
      }, tokenize: function(e7, t6) {
        var r7 = t6.rest;
        if (r7) {
          for (var n7 in r7)
            t6[n7] = r7[n7];
          delete t6.rest;
        }
        var o5 = new l();
        return c2(o5, o5.head, e7), s5(e7, o5, t6, o5.head, 0), function(e8) {
          var t7 = [], r8 = e8.head.next;
          for (; r8 !== e8.tail; )
            t7.push(r8.value), r8 = r8.next;
          return t7;
        }(o5);
      }, hooks: { all: {}, add: function(e7, t6) {
        var r7 = o4.hooks.all;
        r7[e7] = r7[e7] || [], r7[e7].push(t6);
      }, run: function(e7, t6) {
        var r7 = o4.hooks.all[e7];
        if (r7 && r7.length)
          for (var n7, a2 = 0; n7 = r7[a2++]; )
            n7(t6);
      } }, Token: a };
      function a(e7, t6, r7, n7) {
        this.type = e7, this.content = t6, this.alias = r7, this.length = 0 | (n7 || "").length;
      }
      function i3(e7, t6, r7, n7) {
        e7.lastIndex = t6;
        var o5 = e7.exec(r7);
        if (o5 && n7 && o5[1]) {
          var a2 = o5[1].length;
          o5.index += a2, o5[0] = o5[0].slice(a2);
        }
        return o5;
      }
      function s5(e7, t6, r7, n7, l2, d2) {
        for (var u3 in r7)
          if (r7.hasOwnProperty(u3) && r7[u3]) {
            var h2 = r7[u3];
            h2 = Array.isArray(h2) ? h2 : [h2];
            for (var f2 = 0; f2 < h2.length; ++f2) {
              if (d2 && d2.cause == u3 + "," + f2)
                return;
              var m = h2[f2], y = m.inside, g = !!m.lookbehind, v = !!m.greedy, b = m.alias;
              if (v && !m.pattern.global) {
                var x2 = m.pattern.toString().match(/[imsuy]*$/)[0];
                m.pattern = RegExp(m.pattern.source, x2 + "g");
              }
              for (var w = m.pattern || m, $ = n7.next, k = l2; $ !== t6.tail && !(d2 && k >= d2.reach); k += $.value.length, $ = $.next) {
                var S = $.value;
                if (t6.length > e7.length)
                  return;
                if (!(S instanceof a)) {
                  var A, E = 1;
                  if (v) {
                    if (!(A = i3(w, k, e7, g)) || A.index >= e7.length)
                      break;
                    var O = A.index, T2 = A.index + A[0].length, C = k;
                    for (C += $.value.length; O >= C; )
                      C += ($ = $.next).value.length;
                    if (k = C -= $.value.length, $.value instanceof a)
                      continue;
                    for (var j = $; j !== t6.tail && (C < T2 || "string" == typeof j.value); j = j.next)
                      E++, C += j.value.length;
                    E--, S = e7.slice(k, C), A.index -= k;
                  } else if (!(A = i3(w, 0, S, g)))
                    continue;
                  O = A.index;
                  var I = A[0], _ = S.slice(0, O), P = S.slice(O + I.length), R = k + S.length;
                  d2 && R > d2.reach && (d2.reach = R);
                  var L = $.prev;
                  if (_ && (L = c2(t6, L, _), k += _.length), p(t6, L, E), $ = c2(t6, L, new a(u3, y ? o4.tokenize(I, y) : I, b, I)), P && c2(t6, $, P), E > 1) {
                    var F = { cause: u3 + "," + f2, reach: R };
                    s5(e7, t6, r7, $.prev, k, F), d2 && F.reach > d2.reach && (d2.reach = F.reach);
                  }
                }
              }
            }
          }
      }
      function l() {
        var e7 = { value: null, prev: null, next: null }, t6 = { value: null, prev: e7, next: null };
        e7.next = t6, this.head = e7, this.tail = t6, this.length = 0;
      }
      function c2(e7, t6, r7) {
        var n7 = t6.next, o5 = { value: r7, prev: t6, next: n7 };
        return t6.next = o5, n7.prev = o5, e7.length++, o5;
      }
      function p(e7, t6, r7) {
        for (var n7 = t6.next, o5 = 0; o5 < r7 && n7 !== e7.tail; o5++)
          n7 = n7.next;
        t6.next = n7, n7.prev = t6, e7.length -= o5;
      }
      if (e6.Prism = o4, a.stringify = function e7(t6, r7) {
        if ("string" == typeof t6)
          return t6;
        if (Array.isArray(t6)) {
          var n7 = "";
          return t6.forEach(function(t7) {
            n7 += e7(t7, r7);
          }), n7;
        }
        var a2 = { type: t6.type, content: e7(t6.content, r7), tag: "span", classes: ["token", t6.type], attributes: {}, language: r7 }, i4 = t6.alias;
        i4 && (Array.isArray(i4) ? Array.prototype.push.apply(a2.classes, i4) : a2.classes.push(i4)), o4.hooks.run("wrap", a2);
        var s6 = "";
        for (var l2 in a2.attributes)
          s6 += " " + l2 + '="' + (a2.attributes[l2] || "").replace(/"/g, "&quot;") + '"';
        return "<" + a2.tag + ' class="' + a2.classes.join(" ") + '"' + s6 + ">" + a2.content + "</" + a2.tag + ">";
      }, !e6.document)
        return e6.addEventListener ? (o4.disableWorkerMessageHandler || e6.addEventListener("message", function(t6) {
          var r7 = JSON.parse(t6.data), n7 = r7.language, a2 = r7.code, i4 = r7.immediateClose;
          e6.postMessage(o4.highlight(a2, o4.languages[n7], n7)), i4 && e6.close();
        }, false), o4) : o4;
      var d = o4.util.currentScript();
      function u2() {
        o4.manual || o4.highlightAll();
      }
      if (d && (o4.filename = d.src, d.hasAttribute("data-manual") && (o4.manual = true)), !o4.manual) {
        var h = document.readyState;
        "loading" === h || "interactive" === h && d && d.defer ? document.addEventListener("DOMContentLoaded", u2) : window.requestAnimationFrame ? window.requestAnimationFrame(u2) : window.setTimeout(u2, 16);
      }
      return o4;
    }("undefined" != typeof window ? window : "undefined" != typeof WorkerGlobalScope && self instanceof WorkerGlobalScope ? self : {});
    e5.exports && (e5.exports = n5), void 0 !== r5.g && (r5.g.Prism = n5), n5.languages.markup = { comment: { pattern: /<!--(?:(?!<!--)[\s\S])*?-->/, greedy: true }, prolog: { pattern: /<\?[\s\S]+?\?>/, greedy: true }, doctype: { pattern: /<!DOCTYPE(?:[^>"'[\]]|"[^"]*"|'[^']*')+(?:\[(?:[^<"'\]]|"[^"]*"|'[^']*'|<(?!!--)|<!--(?:[^-]|-(?!->))*-->)*\]\s*)?>/i, greedy: true, inside: { "internal-subset": { pattern: /(^[^\[]*\[)[\s\S]+(?=\]>$)/, lookbehind: true, greedy: true, inside: null }, string: { pattern: /"[^"]*"|'[^']*'/, greedy: true }, punctuation: /^<!|>$|[[\]]/, "doctype-tag": /^DOCTYPE/i, name: /[^\s<>'"]+/ } }, cdata: { pattern: /<!\[CDATA\[[\s\S]*?\]\]>/i, greedy: true }, tag: { pattern: /<\/?(?!\d)[^\s>\/=$<%]+(?:\s(?:\s*[^\s>\/=]+(?:\s*=\s*(?:"[^"]*"|'[^']*'|[^\s'">=]+(?=[\s>]))|(?=[\s/>])))+)?\s*\/?>/, greedy: true, inside: { tag: { pattern: /^<\/?[^\s>\/]+/, inside: { punctuation: /^<\/?/, namespace: /^[^\s>\/:]+:/ } }, "special-attr": [], "attr-value": { pattern: /=\s*(?:"[^"]*"|'[^']*'|[^\s'">=]+)/, inside: { punctuation: [{ pattern: /^=/, alias: "attr-equals" }, { pattern: /^(\s*)["']|["']$/, lookbehind: true }] } }, punctuation: /\/?>/, "attr-name": { pattern: /[^\s>\/]+/, inside: { namespace: /^[^\s>\/:]+:/ } } } }, entity: [{ pattern: /&[\da-z]{1,8};/i, alias: "named-entity" }, /&#x?[\da-f]{1,8};/i] }, n5.languages.markup.tag.inside["attr-value"].inside.entity = n5.languages.markup.entity, n5.languages.markup.doctype.inside["internal-subset"].inside = n5.languages.markup, n5.hooks.add("wrap", function(e6) {
      "entity" === e6.type && (e6.attributes.title = e6.content.replace(/&amp;/, "&"));
    }), Object.defineProperty(n5.languages.markup.tag, "addInlined", { value: function(e6, t5) {
      var r6 = {};
      r6["language-" + t5] = { pattern: /(^<!\[CDATA\[)[\s\S]+?(?=\]\]>$)/i, lookbehind: true, inside: n5.languages[t5] }, r6.cdata = /^<!\[CDATA\[|\]\]>$/i;
      var o4 = { "included-cdata": { pattern: /<!\[CDATA\[[\s\S]*?\]\]>/i, inside: r6 } };
      o4["language-" + t5] = { pattern: /[\s\S]+/, inside: n5.languages[t5] };
      var a = {};
      a[e6] = { pattern: RegExp(/(<__[^>]*>)(?:<!\[CDATA\[(?:[^\]]|\](?!\]>))*\]\]>|(?!<!\[CDATA\[)[\s\S])*?(?=<\/__>)/.source.replace(/__/g, function() {
        return e6;
      }), "i"), lookbehind: true, greedy: true, inside: o4 }, n5.languages.insertBefore("markup", "cdata", a);
    } }), Object.defineProperty(n5.languages.markup.tag, "addAttribute", { value: function(e6, t5) {
      n5.languages.markup.tag.inside["special-attr"].push({ pattern: RegExp(/(^|["'\s])/.source + "(?:" + e6 + ")" + /\s*=\s*(?:"[^"]*"|'[^']*'|[^\s'">=]+(?=[\s>]))/.source, "i"), lookbehind: true, inside: { "attr-name": /^[^\s=]+/, "attr-value": { pattern: /=[\s\S]+/, inside: { value: { pattern: /(^=\s*(["']|(?!["'])))\S[\s\S]*(?=\2$)/, lookbehind: true, alias: [t5, "language-" + t5], inside: n5.languages[t5] }, punctuation: [{ pattern: /^=/, alias: "attr-equals" }, /"|'/] } } } });
    } }), n5.languages.html = n5.languages.markup, n5.languages.mathml = n5.languages.markup, n5.languages.svg = n5.languages.markup, n5.languages.xml = n5.languages.extend("markup", {}), n5.languages.ssml = n5.languages.xml, n5.languages.atom = n5.languages.xml, n5.languages.rss = n5.languages.xml, function(e6) {
      var t5 = /(?:"(?:\\(?:\r\n|[\s\S])|[^"\\\r\n])*"|'(?:\\(?:\r\n|[\s\S])|[^'\\\r\n])*')/;
      e6.languages.css = { comment: /\/\*[\s\S]*?\*\//, atrule: { pattern: RegExp("@[\\w-](?:" + /[^;{\s"']|\s+(?!\s)/.source + "|" + t5.source + ")*?" + /(?:;|(?=\s*\{))/.source), inside: { rule: /^@[\w-]+/, "selector-function-argument": { pattern: /(\bselector\s*\(\s*(?![\s)]))(?:[^()\s]|\s+(?![\s)])|\((?:[^()]|\([^()]*\))*\))+(?=\s*\))/, lookbehind: true, alias: "selector" }, keyword: { pattern: /(^|[^\w-])(?:and|not|only|or)(?![\w-])/, lookbehind: true } } }, url: { pattern: RegExp("\\burl\\((?:" + t5.source + "|" + /(?:[^\\\r\n()"']|\\[\s\S])*/.source + ")\\)", "i"), greedy: true, inside: { function: /^url/i, punctuation: /^\(|\)$/, string: { pattern: RegExp("^" + t5.source + "$"), alias: "url" } } }, selector: { pattern: RegExp(`(^|[{}\\s])[^{}\\s](?:[^{};"'\\s]|\\s+(?![\\s{])|` + t5.source + ")*(?=\\s*\\{)"), lookbehind: true }, string: { pattern: t5, greedy: true }, property: { pattern: /(^|[^-\w\xA0-\uFFFF])(?!\s)[-_a-z\xA0-\uFFFF](?:(?!\s)[-\w\xA0-\uFFFF])*(?=\s*:)/i, lookbehind: true }, important: /!important\b/i, function: { pattern: /(^|[^-a-z0-9])[-a-z0-9]+(?=\()/i, lookbehind: true }, punctuation: /[(){};:,]/ }, e6.languages.css.atrule.inside.rest = e6.languages.css;
      var r6 = e6.languages.markup;
      r6 && (r6.tag.addInlined("style", "css"), r6.tag.addAttribute("style", "css"));
    }(n5), n5.languages.clike = { comment: [{ pattern: /(^|[^\\])\/\*[\s\S]*?(?:\*\/|$)/, lookbehind: true, greedy: true }, { pattern: /(^|[^\\:])\/\/.*/, lookbehind: true, greedy: true }], string: { pattern: /(["'])(?:\\(?:\r\n|[\s\S])|(?!\1)[^\\\r\n])*\1/, greedy: true }, "class-name": { pattern: /(\b(?:class|extends|implements|instanceof|interface|new|trait)\s+|\bcatch\s+\()[\w.\\]+/i, lookbehind: true, inside: { punctuation: /[.\\]/ } }, keyword: /\b(?:break|catch|continue|do|else|finally|for|function|if|in|instanceof|new|null|return|throw|try|while)\b/, boolean: /\b(?:false|true)\b/, function: /\b\w+(?=\()/, number: /\b0x[\da-f]+\b|(?:\b\d+(?:\.\d*)?|\B\.\d+)(?:e[+-]?\d+)?/i, operator: /[<>]=?|[!=]=?=?|--?|\+\+?|&&?|\|\|?|[?*/~^%]/, punctuation: /[{}[\];(),.:]/ }, n5.languages.javascript = n5.languages.extend("clike", { "class-name": [n5.languages.clike["class-name"], { pattern: /(^|[^$\w\xA0-\uFFFF])(?!\s)[_$A-Z\xA0-\uFFFF](?:(?!\s)[$\w\xA0-\uFFFF])*(?=\.(?:constructor|prototype))/, lookbehind: true }], keyword: [{ pattern: /((?:^|\})\s*)catch\b/, lookbehind: true }, { pattern: /(^|[^.]|\.\.\.\s*)\b(?:as|assert(?=\s*\{)|async(?=\s*(?:function\b|\(|[$\w\xA0-\uFFFF]|$))|await|break|case|class|const|continue|debugger|default|delete|do|else|enum|export|extends|finally(?=\s*(?:\{|$))|for|from(?=\s*(?:['"]|$))|function|(?:get|set)(?=\s*(?:[#\[$\w\xA0-\uFFFF]|$))|if|implements|import|in|instanceof|interface|let|new|null|of|package|private|protected|public|return|static|super|switch|this|throw|try|typeof|undefined|var|void|while|with|yield)\b/, lookbehind: true }], function: /#?(?!\s)[_$a-zA-Z\xA0-\uFFFF](?:(?!\s)[$\w\xA0-\uFFFF])*(?=\s*(?:\.\s*(?:apply|bind|call)\s*)?\()/, number: { pattern: RegExp(/(^|[^\w$])/.source + "(?:" + /NaN|Infinity/.source + "|" + /0[bB][01]+(?:_[01]+)*n?/.source + "|" + /0[oO][0-7]+(?:_[0-7]+)*n?/.source + "|" + /0[xX][\dA-Fa-f]+(?:_[\dA-Fa-f]+)*n?/.source + "|" + /\d+(?:_\d+)*n/.source + "|" + /(?:\d+(?:_\d+)*(?:\.(?:\d+(?:_\d+)*)?)?|\.\d+(?:_\d+)*)(?:[Ee][+-]?\d+(?:_\d+)*)?/.source + ")" + /(?![\w$])/.source), lookbehind: true }, operator: /--|\+\+|\*\*=?|=>|&&=?|\|\|=?|[!=]==|<<=?|>>>?=?|[-+*/%&|^!=<>]=?|\.{3}|\?\?=?|\?\.?|[~:]/ }), n5.languages.javascript["class-name"][0].pattern = /(\b(?:class|extends|implements|instanceof|interface|new)\s+)[\w.\\]+/, n5.languages.insertBefore("javascript", "keyword", { regex: { pattern: RegExp(/((?:^|[^$\w\xA0-\uFFFF."'\])\s]|\b(?:return|yield))\s*)/.source + /\//.source + "(?:" + /(?:\[(?:[^\]\\\r\n]|\\.)*\]|\\.|[^/\\\[\r\n])+\/[dgimyus]{0,7}/.source + "|" + /(?:\[(?:[^[\]\\\r\n]|\\.|\[(?:[^[\]\\\r\n]|\\.|\[(?:[^[\]\\\r\n]|\\.)*\])*\])*\]|\\.|[^/\\\[\r\n])+\/[dgimyus]{0,7}v[dgimyus]{0,7}/.source + ")" + /(?=(?:\s|\/\*(?:[^*]|\*(?!\/))*\*\/)*(?:$|[\r\n,.;:})\]]|\/\/))/.source), lookbehind: true, greedy: true, inside: { "regex-source": { pattern: /^(\/)[\s\S]+(?=\/[a-z]*$)/, lookbehind: true, alias: "language-regex", inside: n5.languages.regex }, "regex-delimiter": /^\/|\/$/, "regex-flags": /^[a-z]+$/ } }, "function-variable": { pattern: /#?(?!\s)[_$a-zA-Z\xA0-\uFFFF](?:(?!\s)[$\w\xA0-\uFFFF])*(?=\s*[=:]\s*(?:async\s*)?(?:\bfunction\b|(?:\((?:[^()]|\([^()]*\))*\)|(?!\s)[_$a-zA-Z\xA0-\uFFFF](?:(?!\s)[$\w\xA0-\uFFFF])*)\s*=>))/, alias: "function" }, parameter: [{ pattern: /(function(?:\s+(?!\s)[_$a-zA-Z\xA0-\uFFFF](?:(?!\s)[$\w\xA0-\uFFFF])*)?\s*\(\s*)(?!\s)(?:[^()\s]|\s+(?![\s)])|\([^()]*\))+(?=\s*\))/, lookbehind: true, inside: n5.languages.javascript }, { pattern: /(^|[^$\w\xA0-\uFFFF])(?!\s)[_$a-z\xA0-\uFFFF](?:(?!\s)[$\w\xA0-\uFFFF])*(?=\s*=>)/i, lookbehind: true, inside: n5.languages.javascript }, { pattern: /(\(\s*)(?!\s)(?:[^()\s]|\s+(?![\s)])|\([^()]*\))+(?=\s*\)\s*=>)/, lookbehind: true, inside: n5.languages.javascript }, { pattern: /((?:\b|\s|^)(?!(?:as|async|await|break|case|catch|class|const|continue|debugger|default|delete|do|else|enum|export|extends|finally|for|from|function|get|if|implements|import|in|instanceof|interface|let|new|null|of|package|private|protected|public|return|set|static|super|switch|this|throw|try|typeof|undefined|var|void|while|with|yield)(?![$\w\xA0-\uFFFF]))(?:(?!\s)[_$a-zA-Z\xA0-\uFFFF](?:(?!\s)[$\w\xA0-\uFFFF])*\s*)\(\s*|\]\s*\(\s*)(?!\s)(?:[^()\s]|\s+(?![\s)])|\([^()]*\))+(?=\s*\)\s*\{)/, lookbehind: true, inside: n5.languages.javascript }], constant: /\b[A-Z](?:[A-Z_]|\dx?)*\b/ }), n5.languages.insertBefore("javascript", "string", { hashbang: { pattern: /^#!.*/, greedy: true, alias: "comment" }, "template-string": { pattern: /`(?:\\[\s\S]|\$\{(?:[^{}]|\{(?:[^{}]|\{[^}]*\})*\})+\}|(?!\$\{)[^\\`])*`/, greedy: true, inside: { "template-punctuation": { pattern: /^`|`$/, alias: "string" }, interpolation: { pattern: /((?:^|[^\\])(?:\\{2})*)\$\{(?:[^{}]|\{(?:[^{}]|\{[^}]*\})*\})+\}/, lookbehind: true, inside: { "interpolation-punctuation": { pattern: /^\$\{|\}$/, alias: "punctuation" }, rest: n5.languages.javascript } }, string: /[\s\S]+/ } }, "string-property": { pattern: /((?:^|[,{])[ \t]*)(["'])(?:\\(?:\r\n|[\s\S])|(?!\2)[^\\\r\n])*\2(?=\s*:)/m, lookbehind: true, greedy: true, alias: "property" } }), n5.languages.insertBefore("javascript", "operator", { "literal-property": { pattern: /((?:^|[,{])[ \t]*)(?!\s)[_$a-zA-Z\xA0-\uFFFF](?:(?!\s)[$\w\xA0-\uFFFF])*(?=\s*:)/m, lookbehind: true, alias: "property" } }), n5.languages.markup && (n5.languages.markup.tag.addInlined("script", "javascript"), n5.languages.markup.tag.addAttribute(/on(?:abort|blur|change|click|composition(?:end|start|update)|dblclick|error|focus(?:in|out)?|key(?:down|up)|load|mouse(?:down|enter|leave|move|out|over|up)|reset|resize|scroll|select|slotchange|submit|unload|wheel)/.source, "javascript")), n5.languages.js = n5.languages.javascript, function() {
      if (void 0 !== n5 && "undefined" != typeof document) {
        Element.prototype.matches || (Element.prototype.matches = Element.prototype.msMatchesSelector || Element.prototype.webkitMatchesSelector);
        var e6 = { js: "javascript", py: "python", rb: "ruby", ps1: "powershell", psm1: "powershell", sh: "bash", bat: "batch", h: "c", tex: "latex" }, t5 = "data-src-status", r6 = "loading", o4 = "loaded", a = 'pre[data-src]:not([data-src-status="loaded"]):not([data-src-status="loading"])';
        n5.hooks.add("before-highlightall", function(e7) {
          e7.selector += ", " + a;
        }), n5.hooks.add("before-sanity-check", function(i4) {
          var s5 = i4.element;
          if (s5.matches(a)) {
            i4.code = "", s5.setAttribute(t5, r6);
            var l = s5.appendChild(document.createElement("CODE"));
            l.textContent = "Loading\u2026";
            var c2 = s5.getAttribute("data-src"), p = i4.language;
            if ("none" === p) {
              var d = (/\.(\w+)$/.exec(c2) || [, "none"])[1];
              p = e6[d] || d;
            }
            n5.util.setLanguage(l, p), n5.util.setLanguage(s5, p);
            var u2 = n5.plugins.autoloader;
            u2 && u2.loadLanguages(p), function(e7, t6, r7) {
              var n6 = new XMLHttpRequest();
              n6.open("GET", e7, true), n6.onreadystatechange = function() {
                4 == n6.readyState && (n6.status < 400 && n6.responseText ? t6(n6.responseText) : n6.status >= 400 ? r7("\u2716 Error " + n6.status + " while fetching file: " + n6.statusText) : r7("\u2716 Error: File does not exist or is empty"));
              }, n6.send(null);
            }(c2, function(e7) {
              s5.setAttribute(t5, o4);
              var r7 = function(e8) {
                var t6 = /^\s*(\d+)\s*(?:(,)\s*(?:(\d+)\s*)?)?$/.exec(e8 || "");
                if (t6) {
                  var r8 = Number(t6[1]), n6 = t6[2], o5 = t6[3];
                  return n6 ? o5 ? [r8, Number(o5)] : [r8, void 0] : [r8, r8];
                }
              }(s5.getAttribute("data-range"));
              if (r7) {
                var a2 = e7.split(/\r\n?|\n/g), i5 = r7[0], c3 = null == r7[1] ? a2.length : r7[1];
                i5 < 0 && (i5 += a2.length), i5 = Math.max(0, Math.min(i5 - 1, a2.length)), c3 < 0 && (c3 += a2.length), c3 = Math.max(0, Math.min(c3, a2.length)), e7 = a2.slice(i5, c3).join("\n"), s5.hasAttribute("data-start") || s5.setAttribute("data-start", String(i5 + 1));
              }
              l.textContent = e7, n5.highlightElement(l);
            }, function(e7) {
              s5.setAttribute(t5, "failed"), l.textContent = e7;
            });
          }
        }), n5.plugins.fileHighlight = { highlight: function(e7) {
          for (var t6, r7 = (e7 || document).querySelectorAll(a), o5 = 0; t6 = r7[o5++]; )
            n5.highlightElement(t6);
        } };
        var i3 = false;
        n5.fileHighlight = function() {
          i3 || (console.warn("Prism.fileHighlight is deprecated. Use `Prism.plugins.fileHighlight.highlight` instead."), i3 = true), n5.plugins.fileHighlight.highlight.apply(this, arguments);
        };
      }
    }();
  }, 464: (e5) => {
    "use strict";
    var t4, r5 = "";
    e5.exports = function(e6, n5) {
      if ("string" != typeof e6)
        throw new TypeError("expected a string");
      if (1 === n5)
        return e6;
      if (2 === n5)
        return e6 + e6;
      var o4 = e6.length * n5;
      if (t4 !== e6 || void 0 === t4)
        t4 = e6, r5 = "";
      else if (r5.length >= o4)
        return r5.substr(0, o4);
      for (; o4 > r5.length && n5 > 1; )
        1 & n5 && (r5 += e6), n5 >>= 1, e6 += e6;
      return r5 = (r5 += e6).substr(0, o4);
    };
  }, 131: (e5, t4, r5) => {
    "use strict";
    var n5 = r5(464), o4 = function(e6) {
      return /<\/+[^>]+>/.test(e6);
    }, a = function(e6) {
      return /<[^>]+\/>/.test(e6);
    };
    function i3(e6) {
      return e6.split(/(<\/?[^>]+>)/g).filter(function(e7) {
        return "" !== e7.trim();
      }).map(function(e7) {
        return { value: e7, type: s5(e7) };
      });
    }
    function s5(e6) {
      return o4(e6) ? "ClosingTag" : function(e7) {
        return function(e8) {
          return /<[^>!]+>/.test(e8);
        }(e7) && !o4(e7) && !a(e7);
      }(e6) ? "OpeningTag" : a(e6) ? "SelfClosingTag" : "Text";
    }
    e5.exports = function(e6) {
      var t5 = arguments.length > 1 && void 0 !== arguments[1] ? arguments[1] : {}, r6 = t5.indentor, o5 = t5.textNodesOnSameLine, a2 = 0, s6 = [];
      r6 = r6 || "    ";
      var l = i3(e6).map(function(e7, t6, i4) {
        var l2 = e7.value, c2 = e7.type;
        "ClosingTag" === c2 && a2--;
        var p = n5(r6, a2), d = p + l2;
        if ("OpeningTag" === c2 && a2++, o5) {
          var u2 = i4[t6 - 1], h = i4[t6 - 2];
          "ClosingTag" === c2 && "Text" === u2.type && "OpeningTag" === h.type && (d = "" + p + h.value + u2.value + l2, s6.push(t6 - 2, t6 - 1));
        }
        return d;
      });
      return s6.forEach(function(e7) {
        return l[e7] = null;
      }), l.filter(function(e7) {
        return !!e7;
      }).join("\n");
    };
  } }, n4 = {};
  function o3(e5) {
    var t4 = n4[e5];
    if (void 0 !== t4) {
      if (void 0 !== t4.error)
        throw t4.error;
      return t4.exports;
    }
    var a = n4[e5] = { exports: {} };
    try {
      var i3 = { id: e5, module: a, factory: r4[e5], require: o3 };
      o3.i.forEach(function(e6) {
        e6(i3);
      }), a = i3.module, i3.factory.call(a.exports, a, a.exports, i3.require);
    } catch (e6) {
      throw a.error = e6, e6;
    }
    return a.exports;
  }
  o3.m = r4, o3.c = n4, o3.i = [], o3.n = (e5) => {
    var t4 = e5 && e5.__esModule ? () => e5.default : () => e5;
    return o3.d(t4, { a: t4 }), t4;
  }, o3.d = (e5, t4) => {
    for (var r5 in t4)
      o3.o(t4, r5) && !o3.o(e5, r5) && Object.defineProperty(e5, r5, { enumerable: true, get: t4[r5] });
  }, o3.hu = (e5) => e5 + "." + o3.h() + ".hot-update.js", o3.hmrF = () => "main." + o3.h() + ".hot-update.json", o3.h = () => "fdf734afd7a6f574c7ff", o3.g = function() {
    if ("object" == typeof globalThis)
      return globalThis;
    try {
      return this || new Function("return this")();
    } catch (e5) {
      if ("object" == typeof window)
        return window;
    }
  }(), o3.o = (e5, t4) => Object.prototype.hasOwnProperty.call(e5, t4), e4 = {}, t3 = "rapidoc:", o3.l = (r5, n5, a, i3) => {
    if (e4[r5])
      e4[r5].push(n5);
    else {
      var s5, l;
      if (void 0 !== a)
        for (var c2 = document.getElementsByTagName("script"), p = 0; p < c2.length; p++) {
          var d = c2[p];
          if (d.getAttribute("src") == r5 || d.getAttribute("data-webpack") == t3 + a) {
            s5 = d;
            break;
          }
        }
      s5 || (l = true, (s5 = document.createElement("script")).charset = "utf-8", s5.timeout = 120, o3.nc && s5.setAttribute("nonce", o3.nc), s5.setAttribute("data-webpack", t3 + a), s5.src = r5), e4[r5] = [n5];
      var u2 = (t4, n6) => {
        s5.onerror = s5.onload = null, clearTimeout(h);
        var o4 = e4[r5];
        if (delete e4[r5], s5.parentNode && s5.parentNode.removeChild(s5), o4 && o4.forEach((e5) => e5(n6)), t4)
          return t4(n6);
      }, h = setTimeout(u2.bind(null, void 0, { type: "timeout", target: s5 }), 12e4);
      s5.onerror = u2.bind(null, s5.onerror), s5.onload = u2.bind(null, s5.onload), l && document.head.appendChild(s5);
    }
  }, (() => {
    var e5, t4, r5, n5 = {}, a = o3.c, i3 = [], s5 = [], l = "idle", c2 = 0, p = [];
    function d(e6) {
      l = e6;
      for (var t5 = [], r6 = 0; r6 < s5.length; r6++)
        t5[r6] = s5[r6].call(null, e6);
      return Promise.all(t5);
    }
    function u2() {
      0 == --c2 && d("ready").then(function() {
        if (0 === c2) {
          var e6 = p;
          p = [];
          for (var t5 = 0; t5 < e6.length; t5++)
            e6[t5]();
        }
      });
    }
    function h(e6) {
      if ("idle" !== l)
        throw new Error("check() is only allowed in idle status");
      return d("check").then(o3.hmrM).then(function(r6) {
        return r6 ? d("prepare").then(function() {
          var n6 = [];
          return t4 = [], Promise.all(Object.keys(o3.hmrC).reduce(function(e7, a2) {
            return o3.hmrC[a2](r6.c, r6.r, r6.m, e7, t4, n6), e7;
          }, [])).then(function() {
            return t5 = function() {
              return e6 ? m(e6) : d("ready").then(function() {
                return n6;
              });
            }, 0 === c2 ? t5() : new Promise(function(e7) {
              p.push(function() {
                e7(t5());
              });
            });
            var t5;
          });
        }) : d(y() ? "ready" : "idle").then(function() {
          return null;
        });
      });
    }
    function f2(e6) {
      return "ready" !== l ? Promise.resolve().then(function() {
        throw new Error("apply() is only allowed in ready status (state: " + l + ")");
      }) : m(e6);
    }
    function m(e6) {
      e6 = e6 || {}, y();
      var n6 = t4.map(function(t5) {
        return t5(e6);
      });
      t4 = void 0;
      var o4 = n6.map(function(e7) {
        return e7.error;
      }).filter(Boolean);
      if (o4.length > 0)
        return d("abort").then(function() {
          throw o4[0];
        });
      var a2 = d("dispose");
      n6.forEach(function(e7) {
        e7.dispose && e7.dispose();
      });
      var i4, s6 = d("apply"), l2 = function(e7) {
        i4 || (i4 = e7);
      }, c3 = [];
      return n6.forEach(function(e7) {
        if (e7.apply) {
          var t5 = e7.apply(l2);
          if (t5)
            for (var r6 = 0; r6 < t5.length; r6++)
              c3.push(t5[r6]);
        }
      }), Promise.all([a2, s6]).then(function() {
        return i4 ? d("fail").then(function() {
          throw i4;
        }) : r5 ? m(e6).then(function(e7) {
          return c3.forEach(function(t5) {
            e7.indexOf(t5) < 0 && e7.push(t5);
          }), e7;
        }) : d("idle").then(function() {
          return c3;
        });
      });
    }
    function y() {
      if (r5)
        return t4 || (t4 = []), Object.keys(o3.hmrI).forEach(function(e6) {
          r5.forEach(function(r6) {
            o3.hmrI[e6](r6, t4);
          });
        }), r5 = void 0, true;
    }
    o3.hmrD = n5, o3.i.push(function(p2) {
      var m2, y2, g, v, b = p2.module, x2 = function(t5, r6) {
        var n6 = a[r6];
        if (!n6)
          return t5;
        var o4 = function(o5) {
          if (n6.hot.active) {
            if (a[o5]) {
              var s7 = a[o5].parents;
              -1 === s7.indexOf(r6) && s7.push(r6);
            } else
              i3 = [r6], e5 = o5;
            -1 === n6.children.indexOf(o5) && n6.children.push(o5);
          } else
            console.warn("[HMR] unexpected require(" + o5 + ") from disposed module " + r6), i3 = [];
          return t5(o5);
        }, s6 = function(e6) {
          return { configurable: true, enumerable: true, get: function() {
            return t5[e6];
          }, set: function(r7) {
            t5[e6] = r7;
          } };
        };
        for (var p3 in t5)
          Object.prototype.hasOwnProperty.call(t5, p3) && "e" !== p3 && Object.defineProperty(o4, p3, s6(p3));
        return o4.e = function(e6) {
          return function(e7) {
            switch (l) {
              case "ready":
                d("prepare");
              case "prepare":
                return c2++, e7.then(u2, u2), e7;
              default:
                return e7;
            }
          }(t5.e(e6));
        }, o4;
      }(p2.require, p2.id);
      b.hot = (m2 = p2.id, y2 = b, v = { _acceptedDependencies: {}, _acceptedErrorHandlers: {}, _declinedDependencies: {}, _selfAccepted: false, _selfDeclined: false, _selfInvalidated: false, _disposeHandlers: [], _main: g = e5 !== m2, _requireSelf: function() {
        i3 = y2.parents.slice(), e5 = g ? void 0 : m2, o3(m2);
      }, active: true, accept: function(e6, t5, r6) {
        if (void 0 === e6)
          v._selfAccepted = true;
        else if ("function" == typeof e6)
          v._selfAccepted = e6;
        else if ("object" == typeof e6 && null !== e6)
          for (var n6 = 0; n6 < e6.length; n6++)
            v._acceptedDependencies[e6[n6]] = t5 || function() {
            }, v._acceptedErrorHandlers[e6[n6]] = r6;
        else
          v._acceptedDependencies[e6] = t5 || function() {
          }, v._acceptedErrorHandlers[e6] = r6;
      }, decline: function(e6) {
        if (void 0 === e6)
          v._selfDeclined = true;
        else if ("object" == typeof e6 && null !== e6)
          for (var t5 = 0; t5 < e6.length; t5++)
            v._declinedDependencies[e6[t5]] = true;
        else
          v._declinedDependencies[e6] = true;
      }, dispose: function(e6) {
        v._disposeHandlers.push(e6);
      }, addDisposeHandler: function(e6) {
        v._disposeHandlers.push(e6);
      }, removeDisposeHandler: function(e6) {
        var t5 = v._disposeHandlers.indexOf(e6);
        t5 >= 0 && v._disposeHandlers.splice(t5, 1);
      }, invalidate: function() {
        switch (this._selfInvalidated = true, l) {
          case "idle":
            t4 = [], Object.keys(o3.hmrI).forEach(function(e6) {
              o3.hmrI[e6](m2, t4);
            }), d("ready");
            break;
          case "ready":
            Object.keys(o3.hmrI).forEach(function(e6) {
              o3.hmrI[e6](m2, t4);
            });
            break;
          case "prepare":
          case "check":
          case "dispose":
          case "apply":
            (r5 = r5 || []).push(m2);
        }
      }, check: h, apply: f2, status: function(e6) {
        if (!e6)
          return l;
        s5.push(e6);
      }, addStatusHandler: function(e6) {
        s5.push(e6);
      }, removeStatusHandler: function(e6) {
        var t5 = s5.indexOf(e6);
        t5 >= 0 && s5.splice(t5, 1);
      }, data: n5[m2] }, e5 = void 0, v), b.parents = i3, b.children = [], i3 = [], p2.require = x2;
    }), o3.hmrC = {}, o3.hmrI = {};
  })(), o3.p = "", (() => {
    var e5, t4, r5, n5, a, i3 = o3.hmrS_jsonp = o3.hmrS_jsonp || { 179: 0 }, s5 = {};
    function l(t5, r6) {
      return e5 = r6, new Promise((e6, r7) => {
        s5[t5] = e6;
        var n6 = o3.p + o3.hu(t5), a2 = new Error();
        o3.l(n6, (e7) => {
          if (s5[t5]) {
            s5[t5] = void 0;
            var n7 = e7 && ("load" === e7.type ? "missing" : e7.type), o4 = e7 && e7.target && e7.target.src;
            a2.message = "Loading hot update chunk " + t5 + " failed.\n(" + n7 + ": " + o4 + ")", a2.name = "ChunkLoadError", a2.type = n7, a2.request = o4, r7(a2);
          }
        });
      });
    }
    function c2(e6) {
      function s6(e7) {
        for (var t5 = [e7], r6 = {}, n6 = t5.map(function(e8) {
          return { chain: [e8], id: e8 };
        }); n6.length > 0; ) {
          var a2 = n6.pop(), i4 = a2.id, s7 = a2.chain, c4 = o3.c[i4];
          if (c4 && (!c4.hot._selfAccepted || c4.hot._selfInvalidated)) {
            if (c4.hot._selfDeclined)
              return { type: "self-declined", chain: s7, moduleId: i4 };
            if (c4.hot._main)
              return { type: "unaccepted", chain: s7, moduleId: i4 };
            for (var p2 = 0; p2 < c4.parents.length; p2++) {
              var d2 = c4.parents[p2], u3 = o3.c[d2];
              if (u3) {
                if (u3.hot._declinedDependencies[i4])
                  return { type: "declined", chain: s7.concat([d2]), moduleId: i4, parentId: d2 };
                -1 === t5.indexOf(d2) && (u3.hot._acceptedDependencies[i4] ? (r6[d2] || (r6[d2] = []), l2(r6[d2], [i4])) : (delete r6[d2], t5.push(d2), n6.push({ chain: s7.concat([d2]), id: d2 })));
              }
            }
          }
        }
        return { type: "accepted", moduleId: e7, outdatedModules: t5, outdatedDependencies: r6 };
      }
      function l2(e7, t5) {
        for (var r6 = 0; r6 < t5.length; r6++) {
          var n6 = t5[r6];
          -1 === e7.indexOf(n6) && e7.push(n6);
        }
      }
      o3.f && delete o3.f.jsonpHmr, t4 = void 0;
      var c3 = {}, p = [], d = {}, u2 = function(e7) {
        console.warn("[HMR] unexpected require(" + e7.id + ") to disposed module");
      };
      for (var h in r5)
        if (o3.o(r5, h)) {
          var f2, m = r5[h], y = false, g = false, v = false, b = "";
          switch ((f2 = m ? s6(h) : { type: "disposed", moduleId: h }).chain && (b = "\nUpdate propagation: " + f2.chain.join(" -> ")), f2.type) {
            case "self-declined":
              e6.onDeclined && e6.onDeclined(f2), e6.ignoreDeclined || (y = new Error("Aborted because of self decline: " + f2.moduleId + b));
              break;
            case "declined":
              e6.onDeclined && e6.onDeclined(f2), e6.ignoreDeclined || (y = new Error("Aborted because of declined dependency: " + f2.moduleId + " in " + f2.parentId + b));
              break;
            case "unaccepted":
              e6.onUnaccepted && e6.onUnaccepted(f2), e6.ignoreUnaccepted || (y = new Error("Aborted because " + h + " is not accepted" + b));
              break;
            case "accepted":
              e6.onAccepted && e6.onAccepted(f2), g = true;
              break;
            case "disposed":
              e6.onDisposed && e6.onDisposed(f2), v = true;
              break;
            default:
              throw new Error("Unexception type " + f2.type);
          }
          if (y)
            return { error: y };
          if (g)
            for (h in d[h] = m, l2(p, f2.outdatedModules), f2.outdatedDependencies)
              o3.o(f2.outdatedDependencies, h) && (c3[h] || (c3[h] = []), l2(c3[h], f2.outdatedDependencies[h]));
          v && (l2(p, [f2.moduleId]), d[h] = u2);
        }
      r5 = void 0;
      for (var x2, w = [], $ = 0; $ < p.length; $++) {
        var k = p[$], S = o3.c[k];
        S && (S.hot._selfAccepted || S.hot._main) && d[k] !== u2 && !S.hot._selfInvalidated && w.push({ module: k, require: S.hot._requireSelf, errorHandler: S.hot._selfAccepted });
      }
      return { dispose: function() {
        var e7;
        n5.forEach(function(e8) {
          delete i3[e8];
        }), n5 = void 0;
        for (var t5, r6 = p.slice(); r6.length > 0; ) {
          var a2 = r6.pop(), s7 = o3.c[a2];
          if (s7) {
            var l3 = {}, d2 = s7.hot._disposeHandlers;
            for ($ = 0; $ < d2.length; $++)
              d2[$].call(null, l3);
            for (o3.hmrD[a2] = l3, s7.hot.active = false, delete o3.c[a2], delete c3[a2], $ = 0; $ < s7.children.length; $++) {
              var u3 = o3.c[s7.children[$]];
              u3 && ((e7 = u3.parents.indexOf(a2)) >= 0 && u3.parents.splice(e7, 1));
            }
          }
        }
        for (var h2 in c3)
          if (o3.o(c3, h2) && (s7 = o3.c[h2]))
            for (x2 = c3[h2], $ = 0; $ < x2.length; $++)
              t5 = x2[$], (e7 = s7.children.indexOf(t5)) >= 0 && s7.children.splice(e7, 1);
      }, apply: function(t5) {
        for (var r6 in d)
          o3.o(d, r6) && (o3.m[r6] = d[r6]);
        for (var n6 = 0; n6 < a.length; n6++)
          a[n6](o3);
        for (var i4 in c3)
          if (o3.o(c3, i4)) {
            var s7 = o3.c[i4];
            if (s7) {
              x2 = c3[i4];
              for (var l3 = [], u3 = [], h2 = [], f3 = 0; f3 < x2.length; f3++) {
                var m2 = x2[f3], y2 = s7.hot._acceptedDependencies[m2], g2 = s7.hot._acceptedErrorHandlers[m2];
                if (y2) {
                  if (-1 !== l3.indexOf(y2))
                    continue;
                  l3.push(y2), u3.push(g2), h2.push(m2);
                }
              }
              for (var v2 = 0; v2 < l3.length; v2++)
                try {
                  l3[v2].call(null, x2);
                } catch (r7) {
                  if ("function" == typeof u3[v2])
                    try {
                      u3[v2](r7, { moduleId: i4, dependencyId: h2[v2] });
                    } catch (n7) {
                      e6.onErrored && e6.onErrored({ type: "accept-error-handler-errored", moduleId: i4, dependencyId: h2[v2], error: n7, originalError: r7 }), e6.ignoreErrored || (t5(n7), t5(r7));
                    }
                  else
                    e6.onErrored && e6.onErrored({ type: "accept-errored", moduleId: i4, dependencyId: h2[v2], error: r7 }), e6.ignoreErrored || t5(r7);
                }
            }
          }
        for (var b2 = 0; b2 < w.length; b2++) {
          var $2 = w[b2], k2 = $2.module;
          try {
            $2.require(k2);
          } catch (r7) {
            if ("function" == typeof $2.errorHandler)
              try {
                $2.errorHandler(r7, { moduleId: k2, module: o3.c[k2] });
              } catch (n7) {
                e6.onErrored && e6.onErrored({ type: "self-accept-error-handler-errored", moduleId: k2, error: n7, originalError: r7 }), e6.ignoreErrored || (t5(n7), t5(r7));
              }
            else
              e6.onErrored && e6.onErrored({ type: "self-accept-errored", moduleId: k2, error: r7 }), e6.ignoreErrored || t5(r7);
          }
        }
        return p;
      } };
    }
    self.webpackHotUpdaterapidoc = (t5, n6, i4) => {
      for (var l2 in n6)
        o3.o(n6, l2) && (r5[l2] = n6[l2], e5 && e5.push(l2));
      i4 && a.push(i4), s5[t5] && (s5[t5](), s5[t5] = void 0);
    }, o3.hmrI.jsonp = function(e6, t5) {
      r5 || (r5 = {}, a = [], n5 = [], t5.push(c2)), o3.o(r5, e6) || (r5[e6] = o3.m[e6]);
    }, o3.hmrC.jsonp = function(e6, s6, p, d, u2, h) {
      u2.push(c2), t4 = {}, n5 = s6, r5 = p.reduce(function(e7, t5) {
        return e7[t5] = false, e7;
      }, {}), a = [], e6.forEach(function(e7) {
        o3.o(i3, e7) && void 0 !== i3[e7] ? (d.push(l(e7, h)), t4[e7] = true) : t4[e7] = false;
      }), o3.f && (o3.f.jsonpHmr = function(e7, r6) {
        t4 && o3.o(t4, e7) && !t4[e7] && (r6.push(l(e7)), t4[e7] = true);
      });
    }, o3.hmrM = () => {
      if ("undefined" == typeof fetch)
        throw new Error("No browser support: need fetch API");
      return fetch(o3.p + o3.hmrF()).then((e6) => {
        if (404 !== e6.status) {
          if (!e6.ok)
            throw new Error("Failed to fetch update manifest " + e6.statusText);
          return e6.json();
        }
      });
    };
  })();
  o3(656);
})();

// node_modules/lit/node_modules/lit-html/directives/if-defined.js
var o2 = (o3) => o3 ?? T;

// src/standalone/api-browser/index.ts
var APIBrowser = class extends Interface {
  constructor() {
    super(...arguments);
    this.bgColor = "#000000";
    this.textColor = "#000000";
  }
  static get styles() {
    return [
      i`
                img.logo {
                    width: 100%;
                    padding: 1rem 0.5rem 1.5rem 0.5rem;
                    min-height: 48px;
                }
            `
    ];
  }
  firstUpdated() {
    this.addEventListener(EVENT_THEME_CHANGE, (ev) => {
      const style = getComputedStyle(document.documentElement);
      if (ev.detail === UiThemeEnum.Light) {
        this.bgColor = style.getPropertyValue("--pf-global--BackgroundColor--light-300").trim();
        this.textColor = style.getPropertyValue("--pf-global--Color--300").trim();
      } else {
        this.bgColor = style.getPropertyValue("--ak-dark-background").trim();
        this.textColor = style.getPropertyValue("--ak-dark-foreground").trim();
      }
    });
    this.dispatchEvent(
      new CustomEvent(EVENT_THEME_CHANGE, {
        bubbles: true,
        composed: true,
        detail: UiThemeEnum.Automatic
      })
    );
  }
  async getTheme() {
    return globalAK()?.brand.uiTheme || UiThemeEnum.Automatic;
  }
  render() {
    return x`
            <ak-locale-context>
                <rapi-doc
                    spec-url=${o2(this.schemaPath)}
                    heading-text=""
                    theme="light"
                    render-style="read"
                    default-schema-tab="schema"
                    primary-color="#fd4b2d"
                    nav-bg-color="#212427"
                    bg-color=${this.bgColor}
                    text-color=${this.textColor}
                    nav-text-color="#ffffff"
                    nav-hover-bg-color="#3c3f42"
                    nav-accent-color="#4f5255"
                    nav-hover-text-color="#ffffff"
                    use-path-in-nav-bar="true"
                    nav-item-spacing="relaxed"
                    allow-server-selection="false"
                    show-header="false"
                    allow-spec-url-load="false"
                    allow-spec-file-load="false"
                    show-method-in-nav-bar="as-colored-text"
                    @before-try=${(e4) => {
      e4.detail.request.headers.append(
        CSRFHeaderName,
        getCookie("authentik_csrf")
      );
    }}
                >
                    <div slot="nav-logo">
                        <img
                            alt="authentik Logo"
                            class="logo"
                            src="${first(this.brand?.brandingLogo, DefaultBrand.brandingLogo)}"
                        />
                    </div>
                </rapi-doc>
            </ak-locale-context>
        `;
  }
};
__decorateClass([
  n2()
], APIBrowser.prototype, "schemaPath", 2);
__decorateClass([
  r3()
], APIBrowser.prototype, "bgColor", 2);
__decorateClass([
  r3()
], APIBrowser.prototype, "textColor", 2);
APIBrowser = __decorateClass([
  t("ak-api-browser")
], APIBrowser);
export {
  APIBrowser
};
/*! Bundled license information:

@lit/reactive-element/decorators/custom-element.js:
  (**
   * @license
   * Copyright 2017 Google LLC
   * SPDX-License-Identifier: BSD-3-Clause
   *)

@lit/reactive-element/decorators/property.js:
  (**
   * @license
   * Copyright 2017 Google LLC
   * SPDX-License-Identifier: BSD-3-Clause
   *)

@lit/reactive-element/decorators/state.js:
  (**
   * @license
   * Copyright 2017 Google LLC
   * SPDX-License-Identifier: BSD-3-Clause
   *)

@lit/reactive-element/decorators/event-options.js:
  (**
   * @license
   * Copyright 2017 Google LLC
   * SPDX-License-Identifier: BSD-3-Clause
   *)

@lit/reactive-element/decorators/base.js:
  (**
   * @license
   * Copyright 2017 Google LLC
   * SPDX-License-Identifier: BSD-3-Clause
   *)

@lit/reactive-element/decorators/query.js:
  (**
   * @license
   * Copyright 2017 Google LLC
   * SPDX-License-Identifier: BSD-3-Clause
   *)

@lit/reactive-element/decorators/query-all.js:
  (**
   * @license
   * Copyright 2017 Google LLC
   * SPDX-License-Identifier: BSD-3-Clause
   *)

@lit/reactive-element/decorators/query-async.js:
  (**
   * @license
   * Copyright 2017 Google LLC
   * SPDX-License-Identifier: BSD-3-Clause
   *)

@lit/reactive-element/decorators/query-assigned-elements.js:
  (**
   * @license
   * Copyright 2021 Google LLC
   * SPDX-License-Identifier: BSD-3-Clause
   *)

@lit/reactive-element/decorators/query-assigned-nodes.js:
  (**
   * @license
   * Copyright 2017 Google LLC
   * SPDX-License-Identifier: BSD-3-Clause
   *)

@lit/context/lib/context-request-event.js:
  (**
   * @license
   * Copyright 2021 Google LLC
   * SPDX-License-Identifier: BSD-3-Clause
   *)

@lit/context/lib/create-context.js:
  (**
   * @license
   * Copyright 2021 Google LLC
   * SPDX-License-Identifier: BSD-3-Clause
   *)

@lit/context/lib/controllers/context-consumer.js:
  (**
   * @license
   * Copyright 2021 Google LLC
   * SPDX-License-Identifier: BSD-3-Clause
   *)

@lit/context/lib/value-notifier.js:
  (**
   * @license
   * Copyright 2021 Google LLC
   * SPDX-License-Identifier: BSD-3-Clause
   *)

@lit/context/lib/controllers/context-provider.js:
  (**
   * @license
   * Copyright 2021 Google LLC
   * SPDX-License-Identifier: BSD-3-Clause
   *)

@lit/context/lib/context-root.js:
  (**
   * @license
   * Copyright 2021 Google LLC
   * SPDX-License-Identifier: BSD-3-Clause
   *)

@lit/context/lib/decorators/provide.js:
  (**
   * @license
   * Copyright 2017 Google LLC
   * SPDX-License-Identifier: BSD-3-Clause
   *)

@lit/context/lib/decorators/consume.js:
  (**
   * @license
   * Copyright 2022 Google LLC
   * SPDX-License-Identifier: BSD-3-Clause
   *)

rapidoc/dist/rapidoc-min.js:
  (*! RapiDoc 9.3.4 | Author - Mrinmoy Majumdar | License information can be found in rapidoc-min.js.LICENSE.txt  *)

lit-html/directives/if-defined.js:
  (**
   * @license
   * Copyright 2018 Google LLC
   * SPDX-License-Identifier: BSD-3-Clause
   *)
*/
//# sourceMappingURL=index.js.map
